:- style_check(-singleton).
:- style_check(-discontiguous).


/* fluents AVAILABLE as defined fluent */

assembly(X) :- X=a1;X=a2;X=a3.
resource(X) :- X=r1;X=r2.

/* A - assembly, R - resource, P - part, W - whole */

fluent(available(X)) :- assembly(X);resource(X).
fluent(complete(A)) :- assembly(A).
fluent(committed(R,A)) :- assembly(A), resource(R).
fluent(incorporated(P,W)) :- assembly(P), assembly(W).

static(requires(A,R)) :- assembly(A), resource(R).
static(part_of(P,W)) :- assembly(P), assembly(W).
static(assemble_order(P1,P2,W)) :- assembly(P1), assembly(P2), assembly(W).
static(transient_part(P,W)) :- assembly(P), assembly(W).
static(remove_order(P1,P2,W)) :- assembly(P1), assembly(P2), assembly(W).

axiom(-(part_of(P,W)&part_of(W,P))) :- static(part_of(P,W)).
axiom(-part_of(P,P)) :- static(part_of(P,P)).
axiom(-(transient_part(P,W)&transient_part(W,P))) :- static(transient_part(P,W)).
axiom(-transient_part(P,P)) :- static(transient_part(P,P)).
axiom(-remove_order(P,P,W)) :- static(-remove_order(P,P,W)).
axiom(-assemble_order(P,P,W)) :- static(-assemble_order(P,P,W)).
axiom(-(part_of(P,W)&transient_part(P,W))) :- static(part_of(P,W)).
axiom(assemble_order(P1,P2,W) -> (part_of(P1,W) & part_of(P2,W))) :-
    static(assemble_order(P1,P2,W)).
axiom(remove_order(P1,P2,W) -> (transient_part(P1,W) & transient_part(P2,W))) :-
    static(remove_order(P1,P2,W)).
axiom(incorporated(P,W) -> (part_of(P,W) \/ transient_part(P,W))) :-
  fluent(incorporated(P,W)).


causes(available(R), -committed(R,A)) :- resource(R), fluent(committed(R,A)).
causes(committed(R,A), -available(R)) :- resource(R), fluent(committed(R,A)).
causes(committed(R,A), -committed(R,B)) :- fluent(committed(R,A)),
 fluent(committed(R,B)), A\==B.
causes(incorporated(P,W), -incorporated(P,W1)) :-
  fluent(incorporated(P,W)),   fluent(incorporated(P,W1)),
  W\==W1.
causes(incorporated(P,W), -incorporated(W,P)) :- fluent(incorporated(P,W)).

defined(available(A), all(x, assembly(x), 
  (part_of(x,A)->incorporated(x,A)) & 
  (transient_part(x,A)-> (-incorporated(x,A))))
& all(x, assembly(x), -incorporated(A,x))) :-
  assembly(A).
defined(complete(A), all(x, assembly(x), 
  (part_of(x,A)->incorporated(x,A)) & 
  (transient_part(x,A)-> (-incorporated(x,A)))))
 :- fluent(complete(A)).

action(commit(R,A)) :- resource(R), assembly(A).
poss(commit(R,A), available(R)).
effect(commit(R,A), true, committed(R,A)).

action(release(R,A)) :- resource(R), assembly(A).
poss(release(R,A), committed(R,A)).
effect(release(R,A), true, available(R)).

action(assemble(P,W)) :- assembly(P), assembly(W), P\==W.
poss(assemble(P,W), available(P)).
poss(assemble(P,W), -incorporated(P,W)).
poss(assemble(P,W), all(r, resource(r), requires(W,r)->committed(r,W))).
poss(assemble(P,W), part_of(P,W) \/ transient_part(P,W)).
poss(assemble(P,W), all(a, assembly(a), assemble_order(a,P,W)->incorporated(a,W))).
effect(assemble(P,W), true, incorporated(P,W)).

action(remove(P,W)) :-  assembly(P), assembly(W), P\==W.
poss(remove(P,W), incorporated(P,W)).
poss(remove(P,W), all(r, resource(r), requires(W,r)->committed(r,W))).
poss(remove(P,W), transient_part(P,W) ->
    all(a, assembly(a), remove_order(a,P,W)->(-incorporated(a,W)))).
poss(remove(P,W), part_of(P,W) ->
    all(a, assembly(a), assemble_order(P,a,W)->(-incorporated(a,W)))).
effect(remove(P,W), true, -incorporated(P,W)).
