/* from ferry.pddl in McDermott's PDDL library */

:- style_check(-singleton).
:- style_check(-discontiguous).

/* types */

auto(X) :- member(X, [a1,a2,a3]).
place(X) :- member(X, [p1,p2,p3]).

/* fluents */

fluent(at(X,Y)) :- auto(X), place(Y).
fluent(empty_ferry).
fluent(at_ferry(X)) :- place(X).
fluent(on_ferry(X)) :- auto(X).

/* causal rules */

causes(at(X,Y), -at(X,Y1)) :- fluent(at(X,Y)),fluent(at(X,Y1)), Y\==Y1.
causes(at_ferry(X), -at_ferry(X1)) :- fluent(at_ferry(X)),
    fluent(at_ferry(X1)), X1\==X.
causes(on_ferry(X), -on_ferry(X1)) :- fluent(on_ferry(X)),
    fluent(on_ferry(X1)), X1\==X.
causes(at(X,Y), -on_ferry(X)) :- fluent(at(X,Y)).
causes(on_ferry(X), -at(X,Y)) :- fluent(at(X,Y)).

/* defined fluents */

defined(empty_ferry, -some(x, auto(x), on_ferry(x))).

action(board(X,Y)) :- auto(X),place(Y).
poss(board(X,Y), at(X,Y)).
poss(board(X,Y), at_ferry(Y)).
poss(board(X,Y), empty_ferry).
effect(board(X,Y), true, on_ferry(X)).

action(sail(X,Y)) :- place(X),place(Y),X\==Y.
poss(sail(X,Y), at_ferry(X)).
effect(sail(X,Y), true, at_ferry(Y)).

action(debark(X,Y)) :- auto(X), place(Y).
poss(debark(X,Y), on_ferry(X)).
poss(debark(X,Y), at_ferry(Y)).
effect(debark(X,Y), true, at(X,Y)).
