/* fridge from McDermott's PDDL library */
:- style_check(-singleton).
:- style_check(-discontiguous).

/* types */

screw(S) :- member(S, [s1,s2,s3]).
backplane(B) :- member(B, [b1,b2,b3]).
compressor(C) :- member(C, [c1,c2]).
fridge(F) :- member(F, [f1,f2]).

/* fluents */

fluent(screwed(S)) :- screw(S).
fluent(in_place(B)) :- backplane(B).
fluent(fridge_on(F)) :- fridge(F).
fluent(covers(B,C)) :- backplane(B), compressor(C).
fluent(attached(C)) :- compressor(C).
fluent(ok(C)) :- compressor(C).

static(part_of(B,F)) :- backplane(B), fridge(F).
static(holds(S,B)) :- screw(S), backplane(B).

/* actions */

action(unfasten(S, B)) :- screw(S), backplane(B).
poss(unfasten(S,B), screwed(S) & holds(S,B)).
effect(unfasten(S,B), true, -screwed(S)).

action(fasten(S,B)) :- screw(S), backplane(B).
poss(fasten(S,B), -screwed(S) & holds(S,B)).
effect(fasten(S,B), true, screwed(S)).

action(remove_backplane(B,F,S1,S2,S3,S4)) :- backplane(B), fridge(F),
    screw(S1), screw(S2), S2\==S1, screw(S3), S3\==S2, S3\==S1,
    screw(S4), S4\==S1, S4\==S2, S4\==S3.
poss(remove_backplane(B,F,S1,S2,S3,S4), 
     in_place(B) & part_of(B,F) & -fridge_on(F) 
     holds(S1,B) & holds(S2,B) & holds(S31,B) & holds(S4,B) &
     -screwed(S1) & -screwed(S2) & -screwed(S3) & -screwed(S4)).
effect(remove_backplane(B,F,S1,S2,S3,S4), true, -in_place(B)).

/* this action should really takes only one parameter:
   poss(remove_backplane(B), in_place(B) &
         all(F, fridge(F), part_of(B,F)-> -fridge_on(F)) &
         all(S, screw(S), holds(S,B)-> -screwed(S)))
*/


  (:action attach-backplane
	     :parameters (?x - backplane ?f - fridge
			  ?a ?b ?c ?d - screw)
	     :precondition (and (not (= ?a ?b)) (not (= ?a ?c)) (not (= ?a ?d))
				 (not (= ?b ?c)) (not (= ?b ?d)) (not (= ?c ?d))
				 (not (in-place ?x))
				 (part-of ?x ?f) (not (fridge-on ?f))
				 (holds ?a ?x)  (holds ?b ?x) 
				 (holds ?c ?x)  (holds ?d ?x)
				 (not (screwed ?a)) (not (screwed ?b))
				 (not (screwed ?c)) (not (screwed ?d)))
	     :effect (in-place ?X))
  (:action start-fridge
	     :parameters (?f - fridge ?a ?b ?c ?d - screw ?x - backplane)
	     :precondition (and (not (= ?a ?b)) (not (= ?a ?c)) (not (= ?a ?d))
				 (not (= ?b ?c)) (not (= ?b ?d)) (not (= ?c ?d))
				 (in-place ?x) (part-of ?x ?f)
				 (holds ?a ?x)(holds ?b ?x)
				 (holds ?c ?x)(holds ?d ?x)
				 (screwed ?a) (screwed ?b) 
				 (screwed ?c) (screwed ?d)
				 (not (fridge-on ?f)))
	     :effect (fridge-on ?f))
  (:action stop-fridge
	     :parameters (?f - fridge)
	     :precondition (fridge-on ?f)
	     :effect
	     (not (fridge-on ?f)))
  (:action change-compressor
	     :parameters (?x ?y - compressor ?a - backplane)
	     :precondition (and (not (= ?x ?y))  
				 (not (in-place ?a))
				 (covers ?a ?x)
				 (attached ?x) (not (attached ?y)))
	     :effect (and (not (attached ?X)) (attached ?y)
			   (not (covers ?a ?x)) (covers ?a ?y))))

