(define (domain grid-typed)
   (:requirements :typing
		  :conditional-effects :existential-preconditions)
   (:types location key shape agent direction)
   (:predicates
      (locked ?l - location)
      (loc-shape ?l - location ?c - shape)
      (key-shape ?k - key ?c - shape)
      (at ?a - (either agent key) ?l - location)
      (carrying ?a - agent ?b - key)
      (adjacent ?l1 ?l2 - location ?d - direction))
   (:constants left right up down - direction
	       triangle circle diamond - shape
	       robot - agent)

   (:action move
       :parameters (?dir - direction)
       :vars (?l ?l1 - location)
       :precondition (and (at robot ?l)
			  (adjacent ?l ?l1 ?dir)
			  (not (locked ?l1)))
       :effect (and (not (at robot ?l))
		    (at robot ?l1)))

   (:action unlock
       :parameters (?l1 - location)
       :vars (?l - location)
       :precondition (and (at robot ?l)
			  (exists (?dir - direction)
			      (adjacent ?l ?l1 ?dir))
			  (exists (?k - key ?c - shape)
			     (and (carrying robot ?k)
				  (loc-shape ?l1 ?c)
				  (key-shape ?k ?c))))
       :effect (when (locked ?l1)
		     (not (locked ?l1))))

   (:action pick-up
       :parameters (?k - key)
       :vars (?l - location)
       :precondition (and (at ?k ?l)
			  (at robot ?l))
       :effect (and (not (at ?k ?l))
		    (carrying robot ?k)
		    (forall (?k1 - key)
		       (when (carrying robot ?k1)
			     (and (not (carrying robot ?k1))
				  (at ?k1 ?l))))))

   (:action put-down
       :parameters (?k - key)
       :precondition (carrying robot ?k)
       :effect (and (not (carrying robot ?k))
		    (forall (?l - location)
		       (when (at robot ?l)
			     (at ?k ?l))))))

(define (domain grid-strips)
  (:requirements :strips)
  (:predicates (conn ?x ?y)
	       (key-shape ?k ?s)
	       (lock-shape ?x ?s)
	       (at ?r ?x )
	       (at-robot ?x)
	       (place ?p)
	       (key ?k)
	       (shape ?s)
	       (locked ?x)
	       (holding ?k)
	       (open ?x)
	       (arm-empty))

  (:action unlock
      :parameters (?curpos ?lockpos ?key ?shape)
      :precondition (and (place ?curpos) (place ?lockpos)
			 (key ?key) (shape ?shape)
			 (conn ?curpos ?lockpos) (key-shape ?key ?shape)
			 (lock-shape ?lockpos ?shape) (at-robot ?curpos) 
			 (locked ?lockpos) (holding ?key))
      :effect (and  (open ?lockpos) (not (locked ?lockpos))))

  (:action move
     :parameters (?curpos ?nextpos)
     :precondition (and (place ?curpos) (place ?nextpos)
			(at-robot ?curpos) (conn ?curpos ?nextpos)
			(open ?nextpos))
     :effect (and (at-robot ?nextpos) (not (at-robot ?curpos))))

  (:action pick-up
     :parameters (?curpos ?key)
     :precondition (and (place ?curpos) (key ?key) 
			(at-robot ?curpos) (at ?key ?curpos) (arm-empty ))
     :effect (and (holding ?key)
		  (not (at ?key ?curpos)) (not (arm-empty ))))

  (:action pick-up-and-lose
     :parameters (?curpos ?newkey ?oldkey)
     :precondition (and (place ?curpos) (key ?newkey) (key ?oldkey)
			(at-robot ?curpos) (holding ?oldkey)
			(at ?newkey ?curpos))
     :effect (and (holding ?newkey) (at ?oldkey ?curpos)
		  (not (holding ?oldkey)) (not (at ?newkey ?curpos))))

  (:action put-down
     :parameters (?curpos ?key)
     :precondition (and (place ?curpos) (key ?key) 
			(at-robot ?curpos) (holding ?key))
     :effect (and (arm-empty ) (at ?key ?curpos) (not (holding ?key)))))

(define (domain grid-numbers)
   (:requirements :typing :expression-evaluation
		  :conditional-effects :existential-preconditions)
   (:types coord - integer shape key agent direction - object) 
   (:domain-variables (coord-lim 5) - integer)
   (:predicates
      (legal-coord ?i - integer)
      (locked ?i ?j - integer)
      (loc-shape ?i ?j - integer ?c - shape)
      (key-shape ?k - key ?c - shape)
      (at ?a - (either agent key) ?i ?j - integer)
      (carrying ?a - agent ?b - key)
      (adjacent ?i ?j ?i1 ?j1 - integer ?d - direction)
      (consecutive ?i ?j  - integer))
   (:constants left right up down - direction
	       triangle circle diamond - shape
	       robot - agent)

   (:action move
       :parameters (?dir - direction)
       :vars (?i ?j ?i1 ?j1 - integer)
       :precondition (and (at robot ?i ?j)
			  (adjacent ?i ?j ?i1 ?j1 ?dir)
			  (not (locked ?i1 ?j1)))
       :effect (and (not (at robot ?i ?j))
		    (at robot ?i1 ?j1)))

   (:action unlock
       :parameters (?i1 ?j1 - integer)
       :vars (?i ?j - integer)
       :precondition (and (at robot ?i ?j)
			  (exists (?dir - direction)
			      (adjacent ?i ?j ?i1 ?j1 ?dir))
			  (exists (?k - key ?c - shape)
			     (and (carrying robot ?k)
				  (loc-shape ?i1 ?j1 ?c)
				  (key-shape ?k ?c))))
       :effect (when (locked ?i1 ?j1)
		     (not (locked ?i1 ?j1))))

   (:action pick-up
       :parameters (?k - key)
       :vars (?i ?j - integer)
       :precondition (and (at ?k ?i ?j)
			  (at robot ?i ?j))
       :effect (and (not (at ?k ?I ?J))
		    (carrying robot ?k)
		    (forall (?k1 - key)
		       (when (carrying robot ?k1)
			     (and (not (carrying robot ?k1))
				  (at ?k1 ?i ?j))))))

   (:action put-down
       :parameters (?k - key)
       :precondition (carrying robot ?k)
       :effect (and (not (carrying robot ?k))
		    (forall (?i ?j - integer)
		       (when (at robot ?i ?j)
			     (at ?k ?i ?j))))))

(define (addendum adjacent-def)
   (:domain grid-numbers)
   (:axiom
      :vars (?i ?j ?i1 - integer)
      :implies (adjacent ?i ?j ?i1 ?j right)
      :context (and (equation (+ ?i 1) ?i1)
		    (legal-coord ?i)
		    (legal-coord ?i1)))
   (:axiom
      :vars (?i ?j ?i1 - integer)
      :implies (adjacent ?i ?j ?i1 ?j left)
      :context (and (equation (- ?i 1) ?i1)
		    (legal-coord ?i)
		    (legal-coord ?i1)))
   (:axiom
      :vars (?i ?j ?j1 - integer)
      :implies (adjacent ?i ?j ?i ?j1 up)
      :context (and (equation (+ ?j 1) ?j1)
		    (legal-coord ?j)
		    (legal-coord ?j1)))
   (:axiom
      :vars (?i ?j ?j1 - integer)
      :implies (adjacent ?i ?j ?i ?j1 down)
      :context (and (equation (- ?j 1) ?j1)
		    (legal-coord ?j)
		    (legal-coord ?j1)))
   (:axiom
      :vars (?i - integer)  ; ?l - integer
      :implies (legal-coord ?i)
      :context (and ;(eval (- coord-lim 1) ?l)
		    (bounded-int ?i (- 1 coord-lim) (- coord-lim 1)))))


(define (situation space-mcd)
   (:domain grid)
   (:objects tk ck dk - key)
   (:init
       (at robot 0 0)
       (locked -2 -4)
       (locked -3 -3)
       (locked -1 -3)
       (locked -2 -2)
       (locked -2 -1)
       (locked -2 0)
       (locked -2 1)
       (loc-shape -2 -4 triangle)
       (loc-shape -3 -3 triangle)
       (loc-shape -1 -2 triangle)
       (loc-shape -2 -2 triangle)
       (loc-shape -2 -1 triangle)
       (loc-shape -2 0 triangle)
       (loc-shape -2 1 triangle)
       (key-shape tk triangle)
       (at tk -2 -3)   ; tk unreachable
       (locked -3 1)
       (locked -4 0)
       (locked -3 -1)
       (loc-shape -3 1 diamond)
       (loc-shape -4 0 diamond)
       (loc-shape -3 -1 diamond)
       (key-shape ck circle)
       (at ck -3 0)
       (locked 2 0)
       (locked 3 1)
       (locked 4 0)
       (locked 3 -1)
       (loc-shape 2 0 triangle)
       (loc-shape 3 1 circle)
       (loc-shape 4 0 triangle)
       (loc-shape 3 -1 triangle)
       (key-shape dk diamond)
       (at dk 2 1)))

; The problem discussed in McDermott papers on regression-match
; graphs.
(define (problem mcd)
   (:domain grid)
   (:situation space-mcd)
   (:goal (at dk 3 0)))

(define (problem mcd-simp)
   (:domain grid)
   (:situation space-mcd)
   (:goal (at ck 0 0)))

; From aips98 competition, suitably translated.
(define (problem comp-grid-y-1)
   (:domain grid)
   (:objects key0 key1 key2 key3 key4 key5 key6 key7 key8
	     - key)
   (:init (locked 4 3)
          (loc-shape 4 3 square)
          (locked 4 4)
          (loc-shape 4 4 square)
          (locked 3 4)
          (loc-shape 3 4 square)
          (locked 3 3)
          (loc-shape 3 3 square)
          (locked 2 3)
          (loc-shape 2 3 square)
          (locked 2 2)
          (loc-shape 2 2 square)
          (locked 3 2)
          (loc-shape 3 2 square)
          (locked 4 2)
          (loc-shape 4 2 square)
          (key-shape key0 triangle)
          (at key0 2 3)
          (key key1)
          (key-shape key1 circle)
          (at key1 1 3)
          (key key2)
          (key-shape key2 diamond)
          (at key2 0 4)
          (key key3)
          (key-shape key3 square)
          (at key3 0 2)
          (key key4)
          (key-shape key4 square)
          (at key4 3 3)
          (key key5)
          (key-shape key5 triangle)
          (at key5 4 1)
          (key key6)
          (key-shape key6 triangle)
          (at key6 4 4)
          (key key7)
          (key-shape key7 circle)
          (at key7 3 4)
          (key key8)
          (key-shape key8 triangle)
          (at key8 2 2)
          (at robot 2 4))
   (:goal (and (at key0 1 1))))


