/* adapted from McDermott's PDDL library */
:- style_check(-singleton).
:- style_check(-discontiguous).

/* types */

loc(X) :- member(X,[l1,l2,l3]).  /* location */
key(X) :- member(X,[k1,k2,k3]).
shape(X) :- member(X,[triangle,circle]).
agent(X) :- member(X,[robot,a1,a2]).
dir(X) :- member(X, [left,right]). /* direction */

/* fluents */

fluent(locked(L)) :- loc(L).
fluent(at(X,L)) :- loc(L), (agent(X);key(X)).
fluent(carrying(A,K)) :- agent(A), key(K).

/* static fluent */

static(adjacent(L1,L2,D)) :- loc(L1), loc(L2), dir(D).
static(loc_shape(L,S)) :- loc(L), shape(S).
static(key_shape(K,S)) :- key(K), shape(S).

/* causal rules */

causes(at(X,L), -at(X,L1)) :- fluent(at(X,L)), fluent(at(X,L1)), L\==L1.
causes(carrying(A,K), -carrying(B,K)) :- fluent(carrying(A,K)),
    fluent(carrying(B,K)), A\==B.
causes(carrying(A,K), -at(K,L)) :- fluent(carrying(A,K)), fluent(at(K,L)).
causes(at(K,L), -carrying(A,K)) :- fluent(carrying(A,K)), fluent(at(K,L)).
causes(carrying(A,K), -carrying(A,K1)) :- fluent(carrying(A,K)),
    fluent(carrying(A,K1)), K\==K1.

action(move(D,L1,L2)) :- dir(D), loc(L1), loc(L2), L1\==L2.
poss(move(D,L1,L2), at(robot,L1)).
poss(move(D,L1,L2), adjacent(L1,L2,D)).
poss(move(D,L1,L2), -locked(L2)).
effect(move(D,L1,L2), true, at(robot,L2)).

action(unlock(L1,L)) :- loc(L), loc(L1), L\==L1.
poss(unlock(L1,L), at(robot,L)).
poss(unlock(L1,L), some(x, dir(x), adjacent(L,L1,x))).
poss(unlock(L1,L), some(k, key(k), 
    some(c, shape(c), carrying(robot,k) & loc_shape(L1,c) & key_shape(k,c)))).
effect(unlock(L1,L), locked(L1), -locked(L1)).

action(pickup(K,L)) :- key(K), loc(L).
poss(pickup(K,L), at(K,L)).
poss(pickup(K,L), at(robot,L)).
effect(pickup(K,L), true, carrying(robot,K)).
effect(pickup(K,L), carrying(robot,K1), at(K1,L)) :- key(K1).

action(putdown(K)) :- key(K).
poss(putdown(K), carrying(robot,K)).
effect(putdown(K), at(robot,L), at(K,L)) :- loc(L).

