/* gripper domain from McDermott's PDDL library */
:- style_check(-singleton).
:- style_check(-discontiguous).

room(R) :- member(R,[r1,r2]).
ball(B) :- member(B,[b1,b2]).
gripper(G) :- member(G, [left,right,g1,g2]).

/* fluents */

fluent(at_robby(R)) :- room(R).
fluent(at(B,R)) :- room(R), ball(B).
fluent(carry(B,G)) :- ball(B), gripper(G).
fluent(free(G)) :- gripper(G).

/* complex fluents */

defined(free(G), -some(b, ball(b), carry(b,G))) :- gripper(G).

/* causal rules */

causes(at_robby(R), -at_robby(R1)) :- room(R), room(R1), R\==R1.
causes(at(B,R), -at(B,R1)) :- ball(B), room(R), room(R1), R\==R1.
causes(carry(B,G), -carry(B1,G)) :- ball(B), ball(B1), gripper(G), B1\==B.
causes(carry(B,G), -carry(B,G1)) :- ball(B), gripper(G1), gripper(G), G1\==G.
causes(carry(B,G), -at(B,R)) :- ball(B), gripper(G), room(R).
causes(at(B,R), -carry(B,G)) :- ball(B), gripper(G), room(R).



/* actions */

action(move(R1,R2)) :- room(R1), room(R2).
poss(move(R1,R2), at_robby(R1)).
effect(move(R1,R2), true, at_robby(R2)).

action(pick(B,R,G)) :- ball(B), room(R), gripper(G).
poss(pick(B,R,G), at(B,R)).
poss(pick(B,R,G), at_robby(R)).
poss(pick(B,R,G), free(G)).
effect(pick(B,R,G), true, carry(B,G)).

action(drop(B,R,G)) :- ball(B), room(R), gripper(G).
poss(drop(B,R,G), carry(B,G)).
poss(drop(B,R,G), at_robby(R)).
effect(drop(B,R,G), true, at(B,R)).

