/* fluents */

loc(X) :- X=1;X=2 ;X=3. 
object(X) :- X=monkey; X=box; X=banana; X=knife; X=glass; X=fountain.


fluent(on_floor).
fluent(at(M,X)) :- loc(X), object(M).
fluent(hasknife).
fluent(onbox(X)) :- loc(X).
fluent(hasbanana).
fluent(haswater).
fluent(hasglass).

/* causal rules */

causes(onbox(X),at(monkey,X)) :- loc(X).
causes(onbox(X), -on_floor) :- loc(X).
causes(on_floor, -onbox(X)) :- loc(X).
causes(at(M,X), -at(M,Y)) :- object(M), loc(X),loc(Y), X\==Y.

/* in the original monkey.pddl specs found in McDermott's package, it's
   possible to have both, say at(box,1) and onbox(2) etc. The following
   causal rules are needed for avoiding these physically impossible
   situations.
*/

causes(onbox(X), at(box,X)) :- loc(X).
causes(hasglass & at(monkey, X), at(glass,X)) :- loc(X).
causes(hasknife & at(monkey, X), at(knife,X)) :- loc(X).
causes(hasbanana & at(monkey, X), at(banana,X)) :- loc(X).


/* actions */

action(goto(X,Y)) :- loc(X),loc(Y), X\==Y.
action(climb(X)) :- loc(X).
action(down(X)) :- loc(X).
action(pushbox(X,Y)) :- loc(X),loc(Y), X\==Y.
action(getknife(X)) :- loc(X).
action(getbanana(X)) :- loc(X).
action(pickglass(X)) :- loc(X).
action(getwater(X)) :- loc(X).

/* goto(x,y): monkey goes to x from y */

poss(goto(X,Y), at(monkey,Y)).
poss(goto(X,Y), on_floor).

effect(goto(X,Y), true, at(monkey,X)).

/* climb(X): monkey climbs onto the box at location x */

poss(climb(X), at(box,X)).
poss(climb(X), on_floor).
poss(climb(X), at(monkey, X)).

effect(climb(X), true, onbox(X)).

/* down(X): monkey climbs down from the box at location X */

poss(down(X), at(box,X)).
poss(down(X), onbox(X)).

effect(down(X), true, on_floor).

/* pushbox(X,Y): monkey pushes the box from Y to X */

poss(pushbox(X,Y), at(monkey,Y)).
poss(pushbox(X,Y), at(box,Y)).
poss(pushbox(X,Y),on_floor).

effect(pushbox(X,Y), true, at(monkey,X)).
effect(pushbox(X,Y), true, at(box,X)).

/* getknife(X): gets knife at location X */

poss(getknife(X), at(knife,X)).
poss(getknife(X), at(monkey,X)).
poss(getknife(X), -hasknife).

effect(getknife(X), true, hasknife).

/* getbanana(X): gets banana at loc X, needs to be on a box */

poss(getbanana(X), onbox(X)).
poss(getbanana(X), at(banana,X)).
poss(getbanana(X), -hasbanana).

effect(getbanana(X), true, hasbanana).

/* getwater(X): gets water from fountain at loc X (monkey needs on box) */

poss(getwater(X), at(fountain,X)).
poss(getwater(X), onbox(X)).
poss(getwater(X), hasglass).
poss(getwater(X), -haswater).

effect(getwater(X), true, haswater).

/* pickglass(X): picks up glass at loc X */

poss(pickglass(X), at(glass,X)).
poss(pickglass(X), at(monkey,X)).
poss(pickglass(X), -hasglass).

effect(pickglass(X), true, hasglass).


