/* montlake domain from McDermott's PDDL library */

:- style_check(-singleton).
:- style_check(-discontiguous).

color(C) :- member(C,[red,yellow,green]).
place(P) :- member(P,[tower,pin,landing]).
gate(G) :- member(G,[1,2]).

/* static */

static(next_color(X,Y)) :- color(X), color(Y).

axiom(next_color(X,Y) <-> ((X=red & Y=yellow) \/
                           (X=yellow & Y=green) \/
                           (X=green & Y=red))) :- color(X), color(Y).

/* fluents */

fluent(semaphore(X)) :- color(X).
fluent(up(G)) :- gate(G).
fluent(all_gates_up).
fluent(all_gates_down).
fluent(bridge_up).
fluent(boats_waiting).
fluent(pin_in).
fluent(joe_at(P)) :- place(P).

/* complex fluents */

defined(all_gates_up, all(g, gate(g), up(g))).
defined(all_gates_down, all(g, gate(g), -up(g))).

/* causal rules */

causes(joe_at(P), -joe_at(P1)) :- place(P), place(P1), P\==P1.
causes(semaphore(C), -semaphore(C1)) :- color(C), color(C1), C\==C1.

/* actions */

action(open_bridge).
poss(open_bridge, all_gates_down).
poss(open_bridge, -pin_in).
poss(open_bridge, (joe_at(tower)\/joe_at(landing))).
effect(open_bridge, true, bridge_up).
effect(open_bridge, true, -boats_waiting).

action(switch_semaphore).
poss(switch_semaphore, true).
effect(switch_semaphore, semaphore(C) & next_color(C,C1), semaphore(C1)) :-
    color(C), color(C1).

action(shut_first_gates).
poss(shut_first_gates, semaphore(red)).
effect(shut_first_gates, true, -up(1)).

action(shut_second_gates).
poss(shut_second_gates, -up(1)).
effect(shut_second_gates, true, -up(2)).

action(open_first_gates).
poss(open_first_gates, up(2)).
effect(open_first_gates, true, up(1)).

action(open_second_gates).
poss(open_second_gates, -up(2)).
poss(open_second_gates, pin_in).
poss(open_second_gates, joe_at(tower)).
effect(open_second_gates, true, up(2)).

action(pull_pin).
poss(pull_pin, all_gates_down).
poss(pull_pin, joe_at(pin)).
poss(pull_pin, pin_in).
effect(pull_pin, -pin_in).

action(push_pin).
poss(push_pin, all_gates_down).
poss(push_pin, joe_at(pin)).
poss(push_pin, -pin_in).
effect(push_pin, pin_in).

action(joe_move(P1,P2)) :- place(P1),place(P2), P1\==P2.
poss(joe_move(P1,P2), joe_at(P1)).
effect(joe_move(P1,P2), true, joe_at(P2)).


action(close_bridge).
poss(close_bridge, true).
poss(close_bridge, bridge_up).
effect(close_bridge, true, -bridge_up).
