(define (domain SOKOBAN)
   (:requirements :typing :domain-axioms :expression-evaluation
		  :existential-preconditions :conditional-effects)
   (:types ;coord - integer  <- type system could not handle this
	   ball agent direction - object) 
   (:constants robot - agent left right down up - direction)
               ; a b c d e f g h - ball <- generates billions of useless goals
	       ; to move nonexistent balls
   (:predicates (navigable ?i ?j - integer)  ; no wall there
		(empty ?i ?j - integer) ; nothing there
		(at ?a - (either agent ball) ?i ?j - integer)
		(adjacent ?i ?j ?i1 ?j1 - integer ?d - direction)
		(x-consecutive ?i ?j  - integer)
		(y-consecutive ?i ?j  - integer)
		(x-max ?i - integer)
		(y-max ?j - integer)
		(coord-max ?i - integer)
	        (coord ?i - integer))
   
   (:axiom
      :vars (?i ?mx - integer)
      :implies (coord ?i)
      :context (and (coord-max ?mx)
		    (test (< ?i ?mx))
		    (test (<= 0 ?i))))

   (:axiom
      :vars (?i ?j ?i1 ?j - integer)
      :implies (adjacent ?i ?j ?i1 ?j right)
      :context (x-consecutive ?i ?i1))

   (:axiom
      :vars (?i ?j ?i1 ?j - integer)
      :implies (adjacent ?i ?j ?i1 ?j left)
      :context (x-consecutive ?i1 ?i))

   (:axiom 
      :vars (?i ?j ?i ?j1 - integer)
      :implies (adjacent ?i ?j ?i ?j1 down)
      :context (y-consecutive ?j ?j1))

   (:axiom
      :vars (?i ?j ?i ?j1 - integer)
      :implies (adjacent ?i ?j ?i ?j1 up)
      :context (y-consecutive ?j1 ?j))

   (:axiom
      :vars (?i1 ?i2 - integer) 
      :implies (x-consecutive ?i1 ?i2)
      :context (and (equation (+ ?i1 1) ?i2)
		    (exists (?xm - integer)
		       (and (x-max ?xm)
			    (bounded-int ?i1 0 (- ?xm 1))
			    (bounded-int ?i2 0 (- ?xm 1))))))

   (:axiom
      :vars (?j1 ?j2 - integer)
      :implies (y-consecutive ?j1 ?j2)
      :context (and (equation (+ ?j1 1) ?j2)
		    (exists (?ym - integer)
		       (and (y-max ?ym)
			    (bounded-int ?j1 0 (- ?ym 1))
			    (bounded-int ?j2 0 (- ?ym 1))))))

   (:action (move ?dir - direction)
      :vars (?i ?j ?i1 ?j1 - integer)
      :precondition (and (at robot ?i ?j)
			 (adjacent ?i ?j ?i1 ?j1 ?dir)
			 (navigable ?i1 ?j1)
			 (empty ?i1 ?j1))
      :effect (and (not (at robot ?i ?j))
		   (not (empty ?i1 ?j1))
	           (at robot ?i1 ?j1)
		   (empty ?i ?j)))

   (:action (push ?dir - direction)
      :vars (?i ?j ?i1 ?j1 ?i2 ?j2 - integer ?ball - ball)
      :precondition (and (at robot ?i ?j)
			 (at ?ball ?i1 ?j1)
			 (adjacent ?i1 ?j1 ?i2 ?j2 ?dir)
			 (adjacent ?i ?j ?i1 ?j1 ?dir)
			 (empty ?i2 ?j2)
			 (navigable ?i2 ?j2))
      :effect (and (not (at robot ?i ?j))
		   (not (at ?ball ?i1 ?j1))
		   (not (empty ?i2 ?j2))
		   (at robot ?i1 ?j1)
		   (empty ?i ?j)
		   (at ?ball ?i2 ?j2))))

(define (problem easy-sok)
   (:domain sokoban)
   (:objects the-ball - ball)
   (:init (at robot 2 0) (at the-ball 4 0)
	  (navigable 0 0) (navigable 1 0) (navigable 2 0)
	  (navigable 3 0) (navigable 4 0)
	  (navigable 5 0) (navigable 6 0) (navigable 7 0)
	  (navigable 8 0) (navigable 9 0)
	  (empty 0 0) (empty 1 0) (empty 3 0)
	  (empty 5 0) (empty 6 0) (empty 7 0) (empty 8 0) (empty 9 0)
          (x-max 10) (y-max 1) (coord-max 10))
   (:goal (at the-ball 6 0)))

