/* adapted from McDermott's PDDL library */
:- style_check(-singleton).
:- style_check(-discontiguous).

/* types */

coord(X) :- member(X, [1,2]).
ball(B) :- member(B, [b1,b2]).
agent(A) :- member(A, [robot, a1]).
dir(D) :- member(D, [l, r]). /* directions */

/* static fluents */

static(navigable(I,J)) :- coord(I), coord(J).
static(adjacent(I, J, I1, J1, D)) :- coord(I), coord(J), coord(I1),
    coord(J1), dir(D).
static(x_max(I)) :- coord(I).
static(y_max(I)) :- coord(I).
static(coord_max(I)) :- coord(I).
static(x_consecutive(I,J)) :- coord(I), coord(J).
static(y_consecutive(I,J)) :- coord(I), coord(J).

/* fluents */

fluent(at(A, I, J)) :- (agent(A); ball(A)), coord(I), coord(J).
fluent(empty(I,J)) :- coord(I), coord(J).

/* defined fluents */

defined(empty(I,J), -some(a, agent(a), at(a,I,J)) &
    -some(b, ball(b), at(b,I,J))) :- coord(I), coord(J).

/* causal rules */

causes(at(A,I,J), -at(A,I1,J1)) :- fluent(at(A,I,J)), fluent(at(A,I1,J1)),
    I\==I1.
causes(at(A,I,J), -at(A,I1,J1)) :- fluent(at(A,I,J)), fluent(at(A,I1,J1)),
    J\==J1.

/* actions */

action(move(D, I, J, I1, J1)) :- dir(D), coord(I), coord(J),
     coord(I1), coord(J1).
poss(move(D,I,J,I1,J1), at(robot,I,J) &
			 adjacent(I,J,I1,J1,D) &
			 navigable(I1,J1) &
			 empty(I1,J1)).
effect(move(D,I,J,I1,J1), true, at(robot,I1,J1)).

action(push(D,B,I,J,I1,J1,I2,J2)) :- dir(D), ball(B),
    coord(I), coord(J),
    coord(I1), coord(J1),
    coord(I2), coord(J2).
poss(push(D,B,I,J,I1,J1,I2,J2), at(robot,I,J) &
			 at(B,I1,J1) &
			 adjacent(I1,J1,I2,J2,D) &
			 adjacent(I,J,I1,J1,D) &
			 empty(I2,J2) &
			 navigable(I2,J2)).
effect(push(D,B,I,J,I1,J1,I2,J2), true, at(robot,I1,J1)).
effect(push(D,B,I,J,I1,J1,I2,J2), true, at(B,I2,J2)).

