/* a revised version of sokoban.pl. The main change is in putting parameters
of the actions into action preconditions. This of course dramatically cuts
down the number of actions */

:- style_check(-singleton).
:- style_check(-discontiguous).

/* types */

coord(X) :- member(X, [1,2,3]).
ball(B) :- member(B, [b1,b2]).
agent(A) :- member(A, [robot, a1]).
dir(D) :- member(D, [left, right, up, down]). /* directions */

/* static fluents */

static(navigable(I,J)) :- coord(I), coord(J).
static(adjacent(I, J, I1, J1, D)) :- coord(I), coord(J), coord(I1),
    coord(J1), dir(D).
static(x_max(I)) :- coord(I).
static(y_max(I)) :- coord(I).
static(coord_max(I)) :- coord(I).
static(x_consecutive(I,J)) :- coord(I), coord(J).
static(y_consecutive(I,J)) :- coord(I), coord(J).


axiom(adjacent(I,J,I1,J,left)) :- coord(I), coord(J), 
    I1 is (I-1), coord(I1).
axiom(adjacent(I,J,I1,J,right)) :- coord(I), coord(J), 
    I1 is (I+1), coord(I1).
axiom(adjacent(I,J,I,J1,up)) :- coord(I), coord(J), 
    J1 is (J+1), coord(J1).
axiom(adjacent(I,J,I,J1,down)) :- coord(I), coord(J), 
    J1 is (J-1), coord(J1).


/* fluents */

fluent(at(A, I, J)) :- (agent(A); ball(A)), coord(I), coord(J).
fluent(empty(I,J)) :- coord(I), coord(J).

/* defined fluents */

defined(empty(I,J), -some(a, agent(a), at(a,I,J)) &
    -some(b, ball(b), at(b,I,J))) :- coord(I), coord(J).

/* causal rules */

causes(at(A,I,J), -at(A,I1,J1)) :- fluent(at(A,I,J)), fluent(at(A,I1,J1)),
    I\==I1.
causes(at(A,I,J), -at(A,I1,J1)) :- fluent(at(A,I,J)), fluent(at(A,I1,J1)),
    J\==J1.

/* actions */

action(move(D, I, J)) :- dir(D), coord(I), coord(J).

poss(move(D,I,J), at(robot,I,J) &
			 navigable(I1,J1) &
			 empty(I1,J1)) :-  axiom(adjacent(I,J,I1,J1,D)).
effect(move(D,I,J), true, at(robot,I1,J1)) :- axiom(adjacent(I,J,I1,J1,D)).

action(push(D,B,I,J)) :- dir(D), ball(B),
    coord(I), coord(J).
poss(push(D,B,I,J), at(robot,I,J) &
            at(B,I1,J1) &
            empty(I2,J2) &
	    navigable(I2,J2))  :-
        axiom(adjacent(I,J,I1,J1,D)), axiom(adjacent(I1,J1,I2,J2,D)).

effect(push(D,B,I,J), true, at(robot,I1,J1)) :- axiom(adjacent(I,J,I1,J1,D)).
effect(push(D,B,I,J), true, at(B,I2,J2)) :-
    axiom(adjacent(I,J,I1,J1,D)), axiom(adjacent(I1,J1,I2,J2,D)).

