(in-package "UNPOP")

; From U. of Wash.
; Note that this is not a "strips" domain in the usual PDDL sense.

(define (domain strips-world)
   (:requirements :typing :expression-evaluation :conditional-effects
		  :equality :disjunctive-preconditions)
   (:types agent physob room door door-status)
   (:constants robot - agent open closed - door-status
	       rpdp rclk rril runi rmys rram rhal - room)
   (:predicates
      (in-room ?ob - (either agent physob) ?r - room)
      (loc-in-room ?x ?y - integer ?r - room)
      (x-y-in-bounds ?x ?xl ?xh ?y ?yl ?yh - integer)
      (connects ?d - door ?r1 ?r2 - room)
      (at ?b - (either physob agent)
	  ?x ?y - integer)
      (next-to ?a - (either physob agent)
	       ?b - (either physob agent door))
      (status ?d - door ?s - door-status)  ; "statis" - sic
      (pushable ?b - physob))

   (:axiom
       :vars (?x ?y - integer ?room - room)
       :implies (loc-in-room ?x ?y rpdp)
       :context (x-y-in-bounds ?x 3 4 ?y 1 5))

   (:axiom
       :vars (?x ?y - integer ?room - room)
       :implies (loc-in-room ?x ?y rclk)
       :context (x-y-in-bounds ?x 5 9 ?y 1 5))

   (:axiom
       :vars (?x ?y - integer ?room - room)
       :implies (loc-in-room ?x ?y rril)
       :context (x-y-in-bounds ?x 10 12 ?y 1 5))

   (:axiom
       :vars (?x ?y - integer ?room - room)
       :implies (loc-in-room ?x ?y runi)
       :context (x-y-in-bounds ?x 1 2 ?y 6 10))

   (:axiom
       :vars (?x ?y - integer ?room - room)
       :implies (loc-in-room ?x ?y rmys)
       :context (x-y-in-bounds ?x 3 6 ?y 6 10))

   (:axiom
       :vars (?x ?y - integer ?room - room)
       :implies (loc-in-room ?x ?y rram)
       :context (x-y-in-bounds ?x 7 9 ?y 6 10))

   (:axiom
       :vars (?x ?y - integer ?room - room)
       :implies (loc-in-room ?x ?y rhal)
       :context (x-y-in-bounds ?x 10 12 ?y 6 10))

   (:axiom
       :vars (?x ?xl ?xh ?y ?yl ?yh - integer)
       :implies (x-y-in-bounds ?x ?xl ?xh ?y ?yl ?yh)
       :context (and (test (>= ?x ?xl))
		     (test (<= ?x ?xh))
		     (test (>= ?y ?yl))
		     (test (<= ?y ?yh))))

   (:action (GOTO-BOX ?box - physob ?room - room)
      :precondition 
          (and (in-room ?box ?room)	
	       (in-room robot ?room))	
      :effect (and (forall (?x ?y - integer)
		      (when (at robot ?x ?y)
			    (not (at robot ?x ?y))))
		   (forall (?b - (either physob agent door))
		      (when (and (next-to robot ?b) (not (= ?b ?box)))
			    (not (next-to robot ?b))))
		   (next-to robot ?box)))

  (:action (GOTO-DOOR ?door - door ?roomx ?roomy - room)
      :precondition 
      (and (connects ?door ?roomx ?roomy) ;[6]
	   (in-room robot ?roomx))	;[5]
      :effect (and (forall (?x ?y - integer)
		      (when (at robot ?x ?y)
			   (not (at robot ?x ?y))))
		   (forall (?b - (either physob agent door))
		      (when (and (next-to robot ?b) (not (= ?b ?door)))
			    (not (next-to robot ?b))))
		   (next-to robot ?door)))
  
  (:action (GOTO-LOC ?x ?y - integer ?roomx - room)
      :precondition 
      (and (loc-in-room ?x ?y ?roomx) ;[6]
	    (in-room robot ?roomx))	;[5]
      :effect (and (forall (?x1 ?y1 - integer)
		      (when (at robot ?x1 ?y1)
			    (not (at robot ?x1 ?y1))))
		   (forall (?b - (either physob agent door))
		      (when (next-to robot ?b)
			    (not (next-to robot ?b))))
		   (at robot ?x ?y)))
  
  (:action (PUSH-BOX ?boxx ?boxy - physob ?roomx - room)
      :precondition 
      (and (pushable ?boxx)		;[6]
	    (in-room ?boxx ?roomx)	;[5]
	    (in-room ?boxy ?roomx)	;[5]
	    (in-room robot ?roomx)	;[5]
	    (next-to robot ?boxx)	;[1]
	    (not (= ?boxx ?boxy)))
      :effect
       (and (forall (?x ?y - integer)
	       (when (at robot ?x ?y)
		     (not (at robot ?x ?y))))
	    (forall (?x ?y - integer)
	       (when (at ?boxx ?x ?y)
		     (not (at ?boxx ?x ?y))))
	    (forall (?b - (either physob agent door))
	       (and (when (and (next-to robot ?b) (not (= ?b ?boxx)))
			  (not (next-to robot ?b)))
		    (when (and (next-to ?boxx ?b) (not (= ?b ?boxy)))
			  (not (next-to ?boxx ?b)))
		    (when (and (next-to ?b ?boxx)
			       (not (= ?b ?boxy))
			       (not (= ?b robot)))
			  (not (next-to ?b ?boxx)))))
	    (next-to ?boxy ?boxx)
	    (next-to ?boxx ?boxy)
	    (next-to robot ?boxx)))
  
  (:action (PUSH-TO-DOOR ?box - physob ?door - door ?roomx ?roomy - room)
      :precondition
      (and (connects ?door ?roomx ?roomy) ;[6]
	    (pushable ?box)		;[6]
	    (in-room robot ?roomx)	;[5]
	    (in-room ?box ?roomx)	;[5]
	    (next-to robot ?box))	;[1]
      :effect     
      (and (forall (?x ?y - integer)
	       (when (at robot ?x ?y)
		     (not (at robot ?x ?y))))
	    (forall (?x ?y - integer)
	       (when (at ?box ?x ?y)
		     (not (at ?box ?x ?y))))
	    (forall (?b - (either physob agent door))
	       (and (when (and (next-to robot ?b) (not (= ?b ?box)))
			  (not (next-to robot ?b)))
		    (when (and (next-to ?box ?b) (not (= ?b ?door)))
			  (not (next-to ?box ?b)))
		    (when (and (next-to ?b ?box) (not (= ?b robot)))
			  (not (next-to ?b ?box)))))
	    (next-to ?box ?door)
	    (next-to robot ?box)))
  
  (:action (PUSH-TO-LOC ?box - physob ?x ?y - integer ?roomx - room)
      :precondition
      (and (pushable ?box)		;[6]
	    (loc-in-room ?x ?y ?roomx)	;[6]
	    (in-room robot ?roomx)	;[5]
	    (in-room ?box ?roomx)	;[5]
	    (next-to robot ?box))	;[1]
      :effect
      (and (forall (?x1 ?y1 - integer)
	      (when (at robot ?x1 ?y1)
		    (not (at robot ?x1 ?y1))))
	   (forall (?x2 ?y2 - integer)
	      (when (and (at ?box ?x2 ?y2)
			 (or (not (= ?y ?y2))
			     (not (= ?x ?x2))))
		    (not (at ?box ?x2 ?y2))))
	   (forall (?b - (either physob agent door))
	      (and (when (and (next-to robot ?b) (not (= ?b ?box)))
			 (not (next-to robot ?b)))
		   (when (next-to ?box ?b) 
			 (not (next-to ?box ?b)))
		   (when (and (next-to ?b ?box) (not (= ?b robot)))
			 (not (next-to ?b ?box)))))
	    (at ?box ?x ?y)
	    (next-to robot ?box)))
  
  (:action (GO-THRU-DOOR ?door - door ?roomy ?roomx - room)
      :precondition 
      (and (connects ?door ?roomx ?roomy) ;[6]
	    (in-room robot ?roomy)	;[5]
	    (status ?door open)	;[2]
	    (next-to robot ?door))	;[1]
      :effect   
      (and (forall (?x ?y - integer)
	     (when (at robot ?x ?y)
		   (not (at robot ?x ?y))))
	    (forall (?b - (either physob agent door))
	       (when (next-to robot ?b)
		     (not (next-to robot ?b))))
	    (not (in-room robot ?roomy))
	    (in-room robot ?roomx)))
  
  (:action (PUSH-THRU-DOOR ?box - physob ?door - door ?roomy ?roomx - room)
      :precondition
      (and (connects ?door ?roomy ?roomx) ;[6]
	    (pushable ?box)		;[6]
	    (in-room robot ?roomy)	;[5]
	    (in-room ?box ?roomy)	;[5]
	    (status ?door open)		;[2]
	    (next-to ?box ?door)	;[1]
	    (next-to robot ?box))	;[1]
      :effect
      (and (forall (?x ?y - integer)
              (when (at robot ?x ?y)
		    (not (at robot ?x ?y))))
	   (forall (?x ?y - integer)
	      (when (at ?box ?x ?y)
		    (not (at ?box ?x ?y))))
	   (forall (?b - (either physob agent door))
	       (and (when (and (next-to robot ?b) (not (= ?b ?box)))
			  (not (next-to robot ?b)))
		    (when (next-to ?box ?b)
			  (not (next-to ?box ?b)))
		    (when (and (next-to ?b ?box) (not (= ?b robot)))
			  (not (next-to ?b ?box)))))
	    (when (in-room robot ?roomy) (not (in-room robot ?roomy)))
	    (when (in-room ?box ?roomy) (not (in-room ?box ?roomy)))
	    (in-room robot ?roomx)
	    (in-room ?box ?roomx)
	    (next-to robot ?box)))
       
  (:action (OPEN-DOOR ?door - door)
      :precondition 
      (and (next-to robot ?door)	;[5]
	    (status ?door closed))	;[5]
      :effect
      (and (not (status ?door closed))
	    (status ?door open)))
  
  (:action (CLOSE-DOOR ?door - door)
      :precondition 
      (and (next-to robot ?door)	;[5]
	    (status ?door open))	;[5]
      :effect
      (and (not (status ?door open))
	    (status ?door closed)))
)

(define (problem move-boxes)
   (:domain strips-world)
   (:objects dunimys dmysram dramhal dmyspdp dpdpclk dmysclk
	     dramclk dclkril - door
	     box1 box2 box3 - physob)
   (:init (connects dunimys runi rmys) (connects dmysram rmys rram)
	  (connects dramhal rram rhal) (connects dmyspdp rmys rpdp)
	  (connects dpdpclk rpdp rclk) (connects dmysclk rmys rclk)
	  (connects dramclk rram rclk) (connects dclkril rclk rril)
	  (connects dunimys rmys runi) (connects dmysram rram rmys)
	  (connects dramhal rhal rram) (connects dmyspdp rpdp rmys)
	  (connects dpdpclk rclk rpdp) (connects dmysclk rclk rmys)
	  (connects dramclk rclk rram) (connects dclkril rril rclk)
	  (status dunimys open) (status dmysram open) (status dramhal open)
	  (status dmyspdp open) (status dpdpclk open) (status dmysclk open)
	  (status dramclk open) (status dclkril closed)
	  (in-room robot rril) (in-room box1 rpdp) (in-room box2 rpdp)
	  (in-room box3 rclk)
	  (pushable box1) (pushable box2) (pushable box3))
   (:goal (and  (next-to box1 box2)(next-to box2 box3))))

(specdecl mb-soln-1 mb-soln-2 - (lst action))

(defproc setup-strips-solns - void ()
   (let ((strips-domain (domain-unpopify
			   (get-global-pddl-symbol 'strips-world))))
      (!= mb-soln-1
             (for (a in '((goto-door dclkril rril rclk)
                          (open-door dclkril)
			  (go-thru-door dclkril rril rclk)
			  (goto-box box3 rclk)
			  (push-to-door box3 dpdpclk rclk rpdp)
			  (push-thru-door box3 dpdpclk rclk rpdp)
			  (push-box box3 box2 rpdp)
			  (goto-box box1 rpdp)
			  (push-box box1 box2 rpdp)))
                  (save (uniquify-action a strips-domain))))
      (!= mb-soln-2
	     (for (a in '((goto-door dclkril rril rclk)
                          (open-door dclkril)
			  (go-thru-door dclkril rril rclk)
			  (goto-door dpdpclk rclk rpdp)
			  (go-thru-door dpdpclk rclk rpdp)
			  (goto-box box2 rpdp)
			  (push-to-door box2 dpdpclk rpdp rclk)
			  (push-thru-door box2 dpdpclk rpdp rclk)
			  (goto-door dpdpclk rclk rpdp)
			  (go-thru-door dpdpclk rclk rpdp)
			  (goto-box box1 rpdp)
			  (push-to-door box1 dpdpclk rpdp rclk)
			  (push-thru-door box1 dpdpclk rpdp rclk)
			  (push-box box1 box2 rclk)))
                  (save (uniquify-action a strips-domain))))))

(define (problem move-boxes-1)
   (:domain strips-world)
   (:situation move-boxes)
   (:goal (and  (next-to box1 box2)(in-room box2 rclk))))

(define (problem simple-strips-1)
   (:domain strips-world)
   (:situation move-boxes)
   (:goal (next-to box1 box2)))

(define (problem simple-strips-2)
   (:domain strips-world)
   (:situation move-boxes)
   (:goal (in-room box2 rclk)))

(define (problem simple-strips-3)
   (:domain strips-world)
   (:situation move-boxes)
   (:goal (next-to box1 box3)))