/*
(in-package "UNPOP")

; From U. of Wash.
; Note that this is not a "strips" domain in the usual PDDL sense.
*/

doorstatus(X) :- X=open;X=closed.
pushable(X) :- X=box1;X=box2.
phyobject(X) :- pushable(X).
object(X) :- phyobject(X).
object(X) :- agent(X).
agent(robot).
door(X) :- X=d1;X=d2;X=d3.
room(R) :- R=r1;R=r2;R=r3;R=r4.
connect(D,R1,R2) :- (D=d1,R1=r1,R2=r2);
    (D=d2,R1=r2,R2=r3);
    (D=d3,R1=r3,R2=r4).
loc(X) :- X=1;X=2;X=3.

fluent(inroom(X,R)) :- object(X), room(R).
fluent(locinroom(X,Y,R)) :- loc(X), loc(Y), room(R).
fluent(connect(D,R1,R2)) :- door(D), room(R1), room(R2).
fluent(at(X,L1,L2)) :- object(X), loc(L1), loc(L2).
fluent(nextto(X,Y)) :- object(X), (object(Y); door(Y)).
fluent(status(D,Y)) :- door(D), doorstatus(Y).
fluent(pushable(X)) :- phyobject(X).

/* causal rules */

causes(inroom(X,R),-inroom(X,R1)) :- object(X),room(R),room(R1),R1\==R.
causes(nextto(X,Y),-nextto(X,Y1)) :- object(X),
    (object(Y);door(Y)),(object(Y1);door(Y1)), Y\==Y1.
causes(nextto(X,Y),-at(X,L1,L2)) :- object(X),object(Y),loc(L1),loc(L2).
causes(at(X,L1,L2),-at(X,L11,L22)) :-object(X),loc(L1),loc(L2),
    loc(L11),loc(L22), (L1\==L11;L2\==L22).
causes(at(X,L1,L2),-nextto(X,Y)) :- object(X),object(Y),loc(L1),loc(L2).
causes(status(D,open),-status(D,closed)) :- door(D).
causes(status(D,closed),-status(D,open)) :- door(D).

/* actions */

/* robot go next to a box in a room */
action(gotobox(B,R)) :- phyobject(B), room(R).
poss(gotobox(B,R), inroom(B,R)).
poss(gotobox(B,R), inroom(robot,R)).
effect(gotobox(B,R), true, nextto(robot,B)).

/* robot go next to a door in a room */
action(gotodoor(D,R1,R2)) :- connect(D,R1,R2).
poss(gotodoor(D,R1,R2), inroom(robot,R1)).
effect(gotodoor(D,R1,R2), true, nextto(robot,D)).

/* robot go to a location in a room */
action(gotoloc(X,Y,R)) :- loc(X),loc(Y),room(X).
poss(gotoloc(X,Y,R),locinroom(X,Y,R)).
poss(gotoloc(X,Y,R),inroom(robot,R)).
effect(gotoloc(X,Y,R),true,at(robot,X,Y)).

/* robot pushes a box next to another in a room */
action(pushbox(B1,B2,R)) :- pushable(B1),
    phyobject(B2), B1\==B2, room(R).
poss(pushbox(B1,B2,R), inroom(B1,R)).
poss(pushbox(B1,B2,R), inroom(B2,R)).
poss(pushbox(B1,B2,R), inroom(robot,R)).
poss(pushbox(B1,B2,R), nextto(robot,B1)).
effect(pushbox(B1,B2,R), true, nextto(B1,B2)).
effect(pushbox(B1,B2,R), true, nextto(B2,B1)).

/* robot pushes a box next to a door in a room */
action(pushtodoor(B,D,R1,R2)) :- pushable(B),
    connect(D,R1,R2).
poss(pushtodoor(B,D,R1,R2), inroom(robot,R)).
poss(pushtodoor(B,D,R1,R2), inroom(B,R)).
poss(pushtodoor(B,D,R1,R2), nextto(robot,B)).
effect(pushtodoor(B,D,R1,R2), true, nextto(B,D)).

/* robot pushes a box to a location in a room */
action(pushtoloc(B,X,Y,R)) :- phyobject(B), loc(X),loc(Y),room(R).
poss(pushtoloc(B,X,Y,R),locinroom(X,Y,R)).
poss(pushtoloc(B,X,Y,R),inroom(robot,R)).
poss(pushtoloc(B,X,Y,R),inroom(B,R)).
poss(pushtoloc(B,X,Y,R),nextto(robot,B)).
effect(pushtoloc(B,X,Y,R),true, at(B,X,Y)).

/* robot goes through a door */
action(gothrudoor(D,R1,R2)) :- connect(D,R1,R2).
poss(gothrudoor(D,R1,R2),inroom(robot,R2)).
poss(gothrudoor(D,R1,R2),status(D,open)).
poss(gothrudoor(D,R1,R2),nextto(robot,D)).
effect(gothrudoor(D,R1,R2),true,inroom(robot,R1)).

/* robot pushes a box through a door */
action(pushthrudoor(B,D,R1,R2)) :- pushable(B), connect(D,R1,R2).
poss(pushthrudoor(B,D,R1,R2),inroom(B,R2)).
poss(pushthrudoor(B,D,R1,R2),inroom(robot,R2)).
poss(pushthrudoor(B,D,R1,R2),nextto(robot,B)).
poss(pushthrudoor(B,D,R1,R2),nextto(B,D)).
poss(pushthrudoor(B,D,R1,R2),status(D,open)).
effect(pushthrudoor(B,D,R1,R2),true,inroom(B,R1)).
effect(pushthrudoor(B,D,R1,R2),true,inroom(robot,R1)).

/* robot opens a door */
action(open(D)) :- door(D).
poss(open(D), status(D,closed)).
poss(open(D), nextto(robot,D)).
effect(open(D), true, status(D,open)).

/* robot closes a door */
action(close(D)) :- door(D).
poss(close(D), status(D,open)).
poss(close(D), nextto(robot,D)).
effect(close(D), true, status(D,closed)).

