(define (domain assembly)
   (:requirements :adl)
   (:types assembly resource)   ; Individual parts are atomic assemblies
   (:predicates (available ?x - (either resource assembly))
		(complete ?a - assembly)
		(requires ?a - assembly ?r - resource)
		(committed ?r - resource ?a - assembly)
		(incorporated ?part ?whole - assembly)
		(part-of ?part ?whole - assembly)
		(to-be-removed ?part ?whole - assembly)
		(assemble-order ?part1 ?part2 ?whole - assembly)
		(transient-part ?part ?whole - assembly)
		; After ?part1 is included, ?part2 must be removed
		; for the ?whole to be complete:
		(remove-order ?part1 ?part2 ?whole - assembly))

   (:action commit
      :parameters (?res - resource ?as - assembly)
      :precondition (available ?res)
      :effect (and (not (available ?res))
		   (committed ?res ?as)))

   (:action release
      :parameters (?res - resource ?as - assembly)
      :precondition (committed ?res ?as)
      :effect (and (not (committed ?res ?as))
		   (available ?res)))
		
		
   (:action assemble
      :parameters (?part ?whole - assembly)
      :precondition (and (forall (?res - resource)
			    (imply (requires ?whole ?res)
				   (committed ?res ?whole)))
			 (or (part-of ?part ?whole)
			     (transient-part ?part ?whole))
			 (available ?part)
			 (forall (?prev - assembly)
			    (imply (assemble-order ?prev ?part ?whole)
				   (incorporated ?prev ?whole))))
      :effect (and (incorporated ?part ?whole)
		   (not (available ?part))
		   (when (and (not (exists (?p - assembly)
				      (and (part-of ?p ?whole)
	                                   (not (= ?p ?part))
					   (not (incorporated ?p ?whole)))))
			      (not (exists (?tp - assembly)
				      (and (transient-part ?tp ?whole)
					   (incorporated ?tp ?whole)))))
			 (and (complete ?whole)
			      (available ?whole)))))

   ; You can remove the last part added, or a cleanup part at the
   ; end.
   (:action remove
      :parameters (?part ?whole - assembly)
      :vars (?res - resource)
      :precondition (and (forall (?res - resource)
			    (imply (requires ?whole ?res)
				   (committed ?res ?whole)))
			 (incorporated ?part ?whole)
			 (or (and (transient-part ?part ?whole)
				  (forall (?prev - assembly)
				     (imply
				        (remove-order ?prev ?part ?whole)
					(incorporated ?prev ?whole))))
			     (and (part-of ?part ?whole)
				  (not (exists (?prev - assembly)
					  (and (assemble-order
						  ?prev ?part ?whole)
					       (incorporated
						  ?prev ?whole)))))))
      :effect (and (not (incorporated ?part ?whole))
		   (available ?part)
		   (when (and (not (exists (?p - assembly)
				      (and (part-of ?p ?whole)
					   (not (incorporated ?p ?whole)))))
			      (not (exists (?tp - assembly)
				      (and (transient-part ?tp ?whole)
                                           (not (= ?tp ?part))
					   (incorporated ?tp ?whole)))))
			 (and (complete ?whole)
			      (available ?whole))))))
      
(define (problem assembly-test)
   (:domain assembly)
   (:objects lwing rwing fuselage tail lflaps rflaps
	     engine1 engine2 propeller1 propeller2 linchpin
	     airplane - assembly
	     scaffold - resource)
   (:init (available scaffold)
	  (available linchpin)
	  (available propeller1)
	  (available propeller2)
          (available lflaps)
          (available rflaps)
          (available fuselage)

          (requires lwing scaffold)
	  (requires rwing scaffold)
	  (requires tail scaffold)
	  (requires airplane scaffold)
	  (transient-part linchpin engine1)
	  (transient-part linchpin engine2)
	  (part-of propeller1 engine1)
	  (part-of propeller2 engine2)
	  (part-of engine1 lwing)
	  (part-of engine2 rwing)
	  (part-of lflaps lwing)
	  (part-of rflaps rwing)
	  (part-of lwing airplane)
	  (part-of rwing airplane)
	  (part-of fuselage airplane)
	  (part-of linchpin tail)
	  (part-of tail airplane)

	  (assemble-order linchpin propeller1 engine1)
	  (assemble-order linchpin propeller2 engine2)
	  (remove-order propeller1 linchpin engine1)
	  (remove-order propeller2 linchpin engine2)
	  (assemble-order fuselage lwing airplane)
	  (assemble-order fuselage rwing airplane)
	  (assemble-order fuselage tail airplane))
   (:goal (complete airplane)))

(defvar assembly-0-solution*
        '((assemble linchpin engine1)
	  (assemble propeller1 engine1)
	  (remove linchpin engine1)
	  (assemble linchpin engine2)
	  (assemble propeller2 engine2)
	  (remove linchpin engine2)

	  (commit scaffold rwing)
	  (assemble engine2 rwing)
	  (assemble rflaps rwing)
	  (release scaffold rwing)

	  (commit scaffold lwing)
	  (assemble engine1 lwing)
	  (assemble lflaps lwing)
	  (release scaffold lwing)

	  (commit scaffold tail)
	  (assemble linchpin tail)
	  (release scaffold tail)

	  (commit scaffold airplane)
	  (assemble fuselage airplane)
	  (assemble lwing airplane)
	  (assemble rwing airplane)
	  (assemble tail airplane)))

(DEFINE (PROBLEM ASSEM-0)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS FROB SOCKET KLUDGE PLUG WIDGET MOUNT WHATSIS DOODAD HACK
             GIMCRACK - ASSEMBLY
             FILE - RESOURCE)
   (:INIT (AVAILABLE KLUDGE)
          (AVAILABLE PLUG)
          (AVAILABLE WIDGET)
          (AVAILABLE WHATSIS)
          (AVAILABLE HACK)
          (AVAILABLE GIMCRACK)
          (REQUIRES SOCKET FILE)
          (REQUIRES DOODAD FILE)
          (PART-OF SOCKET FROB)
          (PART-OF MOUNT FROB)
          (PART-OF KLUDGE SOCKET)
          (PART-OF PLUG SOCKET)
          (PART-OF WIDGET SOCKET)
          (PART-OF WHATSIS MOUNT)
          (PART-OF DOODAD MOUNT)
          (PART-OF HACK DOODAD)
          (PART-OF GIMCRACK DOODAD)
          (ASSEMBLE-ORDER MOUNT SOCKET FROB)
          (ASSEMBLE-ORDER KLUDGE WIDGET SOCKET)
          (ASSEMBLE-ORDER PLUG KLUDGE SOCKET)
          (ASSEMBLE-ORDER GIMCRACK HACK DOODAD))
   (:GOAL (COMPLETE FROB)))

(DEFINE (PROBLEM ASSEM-1)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS HOOZAWHATSIE PLUG HACK DOODAD WIRE TUBE VALVE COIL
             FASTENER GIMCRACK KLUDGE - ASSEMBLY
             CLAMP HAMMER - RESOURCE)
   (:INIT (AVAILABLE HACK)
          (AVAILABLE DOODAD)
          (AVAILABLE WIRE)
          (AVAILABLE TUBE)
          (AVAILABLE VALVE)
          (AVAILABLE FASTENER)
          (AVAILABLE GIMCRACK)
          (AVAILABLE KLUDGE)
          (REQUIRES PLUG HAMMER)
          (REQUIRES COIL CLAMP)
          (PART-OF PLUG HOOZAWHATSIE)
          (PART-OF COIL HOOZAWHATSIE)
          (PART-OF HACK PLUG)
          (PART-OF DOODAD PLUG)
          (PART-OF WIRE PLUG)
          (PART-OF TUBE PLUG)
          (PART-OF VALVE PLUG)
          (PART-OF FASTENER COIL)
          (PART-OF GIMCRACK COIL)
          (PART-OF KLUDGE COIL)
          (ASSEMBLE-ORDER COIL PLUG HOOZAWHATSIE)
          (ASSEMBLE-ORDER DOODAD HACK PLUG)
          (ASSEMBLE-ORDER WIRE HACK PLUG)
          (ASSEMBLE-ORDER VALVE DOODAD PLUG))
   (:GOAL (COMPLETE HOOZAWHATSIE)))

(DEFINE (PROBLEM ASSEM-2)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS KLUDGE HOOZAWHATSIE WIDGET THINGUMBOB SPROCKET COIL
             BRACKET FROB UNIT VALVE FASTENER - ASSEMBLY
             SCOPE HAMMER - RESOURCE)
   (:INIT (AVAILABLE HOOZAWHATSIE)
          (AVAILABLE THINGUMBOB)
          (AVAILABLE COIL)
          (AVAILABLE BRACKET)
          (AVAILABLE UNIT)
          (AVAILABLE VALVE)
          (AVAILABLE FASTENER)
          (REQUIRES WIDGET HAMMER)
          (REQUIRES SPROCKET SCOPE)
          (REQUIRES FROB HAMMER)
          (PART-OF HOOZAWHATSIE KLUDGE)
          (PART-OF WIDGET KLUDGE)
          (PART-OF SPROCKET KLUDGE)
          (PART-OF COIL WIDGET)
          (PART-OF THINGUMBOB WIDGET)
          (TRANSIENT-PART COIL SPROCKET)
          (PART-OF BRACKET SPROCKET)
          (PART-OF FROB SPROCKET)
          (PART-OF UNIT FROB)
          (PART-OF VALVE FROB)
          (PART-OF FASTENER FROB)
          (ASSEMBLE-ORDER HOOZAWHATSIE SPROCKET KLUDGE)
          (ASSEMBLE-ORDER COIL BRACKET WIDGET)
          (ASSEMBLE-ORDER COIL BRACKET SPROCKET)
          (REMOVE-ORDER BRACKET COIL SPROCKET)
          (ASSEMBLE-ORDER FROB COIL SPROCKET)
          (ASSEMBLE-ORDER UNIT FASTENER FROB))
   (:GOAL (COMPLETE KLUDGE)))

(DEFINE (PROBLEM ASSEM-3)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS SOCKET WIDGET FOOBAR CONNECTOR THINGUMBOB VALVE WIRE
             BRACKET HACK PLUG FASTENER DEVICE KLUDGE - ASSEMBLY
             PLIERS - RESOURCE)
   (:INIT (AVAILABLE WIDGET)
          (AVAILABLE FOOBAR)
          (AVAILABLE THINGUMBOB)
          (AVAILABLE VALVE)
          (AVAILABLE WIRE)
          (AVAILABLE HACK)
          (AVAILABLE PLUG)
          (AVAILABLE DEVICE)
          (AVAILABLE KLUDGE)
          (REQUIRES CONNECTOR PLIERS)
          (REQUIRES BRACKET PLIERS)
          (REQUIRES FASTENER PLIERS)
          (PART-OF WIDGET SOCKET)
          (PART-OF FOOBAR SOCKET)
          (PART-OF CONNECTOR SOCKET)
          (PART-OF BRACKET SOCKET)
          (PART-OF FASTENER SOCKET)
          (PART-OF THINGUMBOB CONNECTOR)
          (PART-OF VALVE CONNECTOR)
          (PART-OF WIRE CONNECTOR)
          (PART-OF HACK BRACKET)
          (PART-OF PLUG BRACKET)
          (PART-OF DEVICE FASTENER)
          (PART-OF KLUDGE FASTENER)
          (ASSEMBLE-ORDER WIDGET CONNECTOR SOCKET)
          (ASSEMBLE-ORDER WIDGET FOOBAR SOCKET)
          (ASSEMBLE-ORDER CONNECTOR FOOBAR SOCKET)
          (ASSEMBLE-ORDER BRACKET FASTENER SOCKET)
          (ASSEMBLE-ORDER DEVICE KLUDGE FASTENER))
   (:GOAL (COMPLETE SOCKET)))

(DEFINE (PROBLEM ASSEM-4)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS KLUDGE BRACKET WHATSIS SPROCKET DOODAD CONTRAPTION
             WIRE GIMCRACK PLUG HOOZAWHATSIE THINGUMBOB COIL FASTENER
             WIDGET - ASSEMBLY
             CHARGER PLIERS - RESOURCE)
   (:INIT (AVAILABLE SPROCKET)
          (AVAILABLE DOODAD)
          (AVAILABLE CONTRAPTION)
          (AVAILABLE WIRE)
          (AVAILABLE PLUG)
          (AVAILABLE HOOZAWHATSIE)
          (AVAILABLE THINGUMBOB)
          (AVAILABLE FASTENER)
          (AVAILABLE WIDGET)
          (REQUIRES BRACKET CHARGER)
          (REQUIRES WHATSIS PLIERS)
          (REQUIRES GIMCRACK PLIERS)
          (REQUIRES COIL PLIERS)
          (PART-OF BRACKET KLUDGE)
          (PART-OF COIL KLUDGE)
          (PART-OF WHATSIS BRACKET)
          (PART-OF GIMCRACK BRACKET)
          (PART-OF SPROCKET WHATSIS)
          (PART-OF DOODAD WHATSIS)
          (PART-OF CONTRAPTION WHATSIS)
          (PART-OF WIRE WHATSIS)
          (PART-OF PLUG GIMCRACK)
          (PART-OF HOOZAWHATSIE GIMCRACK)
          (PART-OF THINGUMBOB GIMCRACK)
          (PART-OF FASTENER COIL)
          (PART-OF WIDGET COIL)
          (ASSEMBLE-ORDER BRACKET COIL KLUDGE)
          (ASSEMBLE-ORDER WHATSIS GIMCRACK BRACKET)
          (ASSEMBLE-ORDER WIRE CONTRAPTION WHATSIS)
          (ASSEMBLE-ORDER PLUG THINGUMBOB GIMCRACK))
   (:GOAL (COMPLETE KLUDGE)))

(DEFINE (PROBLEM ASSEM-5)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS WIDGET PLUG SOCKET HOOZAWHATSIE CONTRAPTION DOODAD
             VALVE SPROCKET FROB THINGUMBOB FOOBAR FASTENER BRACKET
             WHATSIS CONNECTOR - ASSEMBLY
             TWEEZERS - RESOURCE)
   (:INIT (AVAILABLE SOCKET)
          (AVAILABLE HOOZAWHATSIE)
          (AVAILABLE CONTRAPTION)
          (AVAILABLE DOODAD)
          (AVAILABLE VALVE)
          (AVAILABLE SPROCKET)
          (AVAILABLE FOOBAR)
          (AVAILABLE FASTENER)
          (AVAILABLE WHATSIS)
          (AVAILABLE CONNECTOR)
          (REQUIRES PLUG TWEEZERS)
          (REQUIRES FROB TWEEZERS)
          (PART-OF PLUG WIDGET)
          (PART-OF FROB WIDGET)
          (PART-OF SOCKET PLUG)
          (PART-OF HOOZAWHATSIE PLUG)
          (PART-OF CONTRAPTION PLUG)
          (PART-OF DOODAD PLUG)
          (PART-OF VALVE PLUG)
          (PART-OF SPROCKET PLUG)
          (PART-OF THINGUMBOB FROB)
          (PART-OF BRACKET FROB)
          (PART-OF FOOBAR THINGUMBOB)
          (PART-OF FASTENER THINGUMBOB)
          (PART-OF WHATSIS BRACKET)
          (PART-OF CONNECTOR BRACKET)
          (ASSEMBLE-ORDER PLUG FROB WIDGET)
          (ASSEMBLE-ORDER SOCKET DOODAD PLUG)
          (ASSEMBLE-ORDER DOODAD CONTRAPTION PLUG)
          (ASSEMBLE-ORDER SPROCKET HOOZAWHATSIE PLUG)
          (ASSEMBLE-ORDER THINGUMBOB BRACKET FROB)
          (ASSEMBLE-ORDER CONNECTOR WHATSIS BRACKET))
   (:GOAL (COMPLETE WIDGET)))

(DEFINE (PROBLEM ASSEM-6)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS MOUNT HOOZAWHATSIE BRACKET TUBE SOCKET HACK WHATSIS
             WIDGET CONNECTOR FASTENER VALVE GIMCRACK THINGUMBOB DEVICE
             FOOBAR - ASSEMBLY
             CHARGER HAMMER - RESOURCE)
   (:INIT (AVAILABLE BRACKET)
          (AVAILABLE TUBE)
          (AVAILABLE SOCKET)
          (AVAILABLE WIDGET)
          (AVAILABLE CONNECTOR)
          (AVAILABLE VALVE)
          (AVAILABLE GIMCRACK)
          (AVAILABLE DEVICE)
          (AVAILABLE FOOBAR)
          (REQUIRES HOOZAWHATSIE CHARGER)
          (REQUIRES HACK CHARGER)
          (REQUIRES WHATSIS HAMMER)
          (REQUIRES FASTENER HAMMER)
          (REQUIRES THINGUMBOB HAMMER)
          (PART-OF HOOZAWHATSIE MOUNT)
          (PART-OF HACK MOUNT)
          (PART-OF THINGUMBOB MOUNT)
          (PART-OF BRACKET HOOZAWHATSIE)
          (PART-OF DEVICE HOOZAWHATSIE)
          (PART-OF TUBE HOOZAWHATSIE)
          (PART-OF SOCKET HOOZAWHATSIE)
          (PART-OF WHATSIS HACK)
          (PART-OF FASTENER HACK)
          (PART-OF WIDGET WHATSIS)
          (PART-OF CONNECTOR WHATSIS)
          (PART-OF VALVE FASTENER)
          (PART-OF GIMCRACK FASTENER)
          (TRANSIENT-PART DEVICE THINGUMBOB)
          (PART-OF FOOBAR THINGUMBOB)
          (ASSEMBLE-ORDER DEVICE FOOBAR HOOZAWHATSIE)
          (ASSEMBLE-ORDER SOCKET DEVICE HOOZAWHATSIE)
          (ASSEMBLE-ORDER WHATSIS FASTENER HACK)
          (ASSEMBLE-ORDER CONNECTOR WIDGET WHATSIS)
          (ASSEMBLE-ORDER VALVE GIMCRACK FASTENER)
          (ASSEMBLE-ORDER DEVICE FOOBAR THINGUMBOB)
          (REMOVE-ORDER FOOBAR DEVICE THINGUMBOB))
   (:GOAL (COMPLETE MOUNT)))

(DEFINE (PROBLEM ASSEM-7)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS WIDGET HOOZAWHATSIE UNIT FASTENER SOCKET PLUG WIRE
             CONTRAPTION FOOBAR KLUDGE THINGUMBOB HACK WHATSIS CONNECTOR DEVICE
             COIL BRACKET - ASSEMBLY
             HAMMOCK CLAMP - RESOURCE)
   (:INIT (AVAILABLE UNIT)
          (AVAILABLE FASTENER)
          (AVAILABLE PLUG)
          (AVAILABLE WIRE)
          (AVAILABLE FOOBAR)
          (AVAILABLE KLUDGE)
          (AVAILABLE HACK)
          (AVAILABLE WHATSIS)
          (AVAILABLE CONNECTOR)
          (AVAILABLE DEVICE)
          (AVAILABLE COIL)
          (AVAILABLE BRACKET)
          (REQUIRES HOOZAWHATSIE CLAMP)
          (REQUIRES SOCKET CLAMP)
          (REQUIRES CONTRAPTION HAMMOCK)
          (REQUIRES THINGUMBOB CLAMP)
          (PART-OF HOOZAWHATSIE WIDGET)
          (PART-OF SOCKET WIDGET)
          (PART-OF CONTRAPTION WIDGET)
          (PART-OF THINGUMBOB WIDGET)
          (PART-OF UNIT HOOZAWHATSIE)
          (PART-OF FASTENER HOOZAWHATSIE)
          (PART-OF PLUG SOCKET)
          (PART-OF WIRE SOCKET)
          (PART-OF FOOBAR CONTRAPTION)
          (PART-OF KLUDGE CONTRAPTION)
          (PART-OF HACK THINGUMBOB)
          (PART-OF WHATSIS THINGUMBOB)
          (PART-OF CONNECTOR THINGUMBOB)
          (PART-OF DEVICE THINGUMBOB)
          (PART-OF COIL THINGUMBOB)
          (PART-OF BRACKET THINGUMBOB)
          (ASSEMBLE-ORDER CONTRAPTION THINGUMBOB WIDGET)
          (ASSEMBLE-ORDER FASTENER UNIT HOOZAWHATSIE)
          (ASSEMBLE-ORDER WIRE PLUG SOCKET)
          (ASSEMBLE-ORDER FOOBAR KLUDGE CONTRAPTION)
          (ASSEMBLE-ORDER WHATSIS CONNECTOR THINGUMBOB)
          (ASSEMBLE-ORDER CONNECTOR BRACKET THINGUMBOB)
          (ASSEMBLE-ORDER CONNECTOR HACK THINGUMBOB)
          (ASSEMBLE-ORDER DEVICE COIL THINGUMBOB)
          (ASSEMBLE-ORDER COIL WHATSIS THINGUMBOB))
   (:GOAL (COMPLETE WIDGET)))

(DEFINE (PROBLEM ASSEM-8)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS GIMCRACK COIL CONTRAPTION FROB DOODAD WIRE BRACKET
             DEVICE WIDGET MOUNT KLUDGE FASTENER HACK SOCKET PLUG TUBE
             - ASSEMBLY
             HAMMOCK PLIERS - RESOURCE)
   (:INIT (AVAILABLE CONTRAPTION)
          (AVAILABLE FROB)
          (AVAILABLE DOODAD)
          (AVAILABLE WIRE)
          (AVAILABLE BRACKET)
          (AVAILABLE WIDGET)
          (AVAILABLE MOUNT)
          (AVAILABLE KLUDGE)
          (AVAILABLE HACK)
          (AVAILABLE SOCKET)
          (AVAILABLE PLUG)
          (AVAILABLE TUBE)
          (REQUIRES COIL HAMMOCK)
          (REQUIRES DEVICE PLIERS)
          (REQUIRES FASTENER HAMMOCK)
          (PART-OF COIL GIMCRACK)
          (PART-OF DEVICE GIMCRACK)
          (PART-OF FASTENER GIMCRACK)
          (TRANSIENT-PART CONTRAPTION COIL)
          (PART-OF FROB COIL)
          (PART-OF DOODAD COIL)
          (PART-OF WIRE COIL)
          (TRANSIENT-PART BRACKET COIL)
          (PART-OF WIDGET DEVICE)
          (PART-OF CONTRAPTION DEVICE)
          (PART-OF MOUNT DEVICE)
          (PART-OF KLUDGE DEVICE)
          (PART-OF BRACKET FASTENER)
          (PART-OF HACK FASTENER)
          (PART-OF SOCKET FASTENER)
          (PART-OF PLUG FASTENER)
          (PART-OF TUBE FASTENER)
          (ASSEMBLE-ORDER CONTRAPTION DOODAD COIL)
          (ASSEMBLE-ORDER CONTRAPTION FROB COIL)
          (REMOVE-ORDER DOODAD CONTRAPTION COIL)
          (ASSEMBLE-ORDER DOODAD BRACKET COIL)
          (ASSEMBLE-ORDER BRACKET FROB COIL)
          (REMOVE-ORDER FROB BRACKET COIL)
          (ASSEMBLE-ORDER WIDGET KLUDGE DEVICE)
          (ASSEMBLE-ORDER CONTRAPTION DOODAD DEVICE)
          (ASSEMBLE-ORDER CONTRAPTION FROB DEVICE)
          (ASSEMBLE-ORDER MOUNT WIDGET DEVICE)
          (ASSEMBLE-ORDER BRACKET FROB FASTENER)
          (ASSEMBLE-ORDER PLUG SOCKET FASTENER))
   (:GOAL (COMPLETE GIMCRACK)))

(DEFINE (PROBLEM ASSEM-9)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS WHATSIS MOUNT WIRE FROB GIMCRACK TUBE DOODAD PLUG
             CONNECTOR FOOBAR DEVICE WIDGET KLUDGE BRACKET FASTENER HACK UNIT
             HOOZAWHATSIE - ASSEMBLY
             SCAFFOLD SCALPEL SCOPE - RESOURCE)
   (:INIT (AVAILABLE WIRE)
          (AVAILABLE FROB)
          (AVAILABLE TUBE)
          (AVAILABLE DOODAD)
          (AVAILABLE PLUG)
          (AVAILABLE CONNECTOR)
          (AVAILABLE FOOBAR)
          (AVAILABLE DEVICE)
          (AVAILABLE BRACKET)
          (AVAILABLE FASTENER)
          (AVAILABLE UNIT)
          (AVAILABLE HOOZAWHATSIE)
          (REQUIRES MOUNT SCAFFOLD)
          (REQUIRES GIMCRACK SCALPEL)
          (REQUIRES WIDGET SCOPE)
          (REQUIRES KLUDGE SCOPE)
          (REQUIRES HACK SCOPE)
          (PART-OF MOUNT WHATSIS)
          (PART-OF GIMCRACK WHATSIS)
          (PART-OF WIDGET WHATSIS)
          (PART-OF WIRE MOUNT)
          (PART-OF FROB MOUNT)
          (PART-OF KLUDGE MOUNT)
          (PART-OF TUBE GIMCRACK)
          (PART-OF DOODAD GIMCRACK)
          (PART-OF PLUG GIMCRACK)
          (PART-OF CONNECTOR GIMCRACK)
          (PART-OF FOOBAR GIMCRACK)
          (PART-OF DEVICE GIMCRACK)
          (TRANSIENT-PART KLUDGE WIDGET)
          (PART-OF HACK WIDGET)
          (PART-OF BRACKET KLUDGE)
          (PART-OF FASTENER KLUDGE)
          (PART-OF UNIT HACK)
          (PART-OF HOOZAWHATSIE HACK)
          (ASSEMBLE-ORDER GIMCRACK WIDGET WHATSIS)
          (ASSEMBLE-ORDER WIRE FROB MOUNT)
          (ASSEMBLE-ORDER KLUDGE HACK MOUNT)
          (ASSEMBLE-ORDER KLUDGE HACK MOUNT)
          (ASSEMBLE-ORDER TUBE DOODAD GIMCRACK)
          (ASSEMBLE-ORDER CONNECTOR PLUG GIMCRACK)
          (ASSEMBLE-ORDER FOOBAR CONNECTOR GIMCRACK)
          (ASSEMBLE-ORDER FOOBAR PLUG GIMCRACK)
          (ASSEMBLE-ORDER DEVICE TUBE GIMCRACK)
          (ASSEMBLE-ORDER KLUDGE HACK WIDGET)
          (ASSEMBLE-ORDER KLUDGE HACK WIDGET)
          (REMOVE-ORDER HACK KLUDGE WIDGET)
          (ASSEMBLE-ORDER FASTENER BRACKET KLUDGE)
          (ASSEMBLE-ORDER HOOZAWHATSIE UNIT HACK))
   (:GOAL (COMPLETE WHATSIS)))

(DEFINE (PROBLEM ASSEM-10)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS DEVICE TUBE CONNECTOR WIDGET SOCKET FROB UNIT GIMCRACK
             WHATSIS HACK HOOZAWHATSIE CONTRAPTION SPROCKET VALVE MOUNT
             PLUG FOOBAR - ASSEMBLY
             SCALPEL SCOPE SCAFFOLD - RESOURCE)
   (:INIT (AVAILABLE CONNECTOR)
          (AVAILABLE WIDGET)
          (AVAILABLE SOCKET)
          (AVAILABLE FROB)
          (AVAILABLE UNIT)
          (AVAILABLE WHATSIS)
          (AVAILABLE HACK)
          (AVAILABLE HOOZAWHATSIE)
          (AVAILABLE CONTRAPTION)
          (AVAILABLE SPROCKET)
          (AVAILABLE PLUG)
          (AVAILABLE FOOBAR)
          (REQUIRES GIMCRACK SCAFFOLD)
          (REQUIRES VALVE SCALPEL)
          (REQUIRES MOUNT SCOPE)
          (PART-OF TUBE DEVICE)
          (PART-OF GIMCRACK DEVICE)
          (PART-OF VALVE DEVICE)
          (PART-OF CONNECTOR TUBE)
          (TRANSIENT-PART WIDGET TUBE)
          (PART-OF SOCKET TUBE)
          (PART-OF FROB TUBE)
          (PART-OF UNIT TUBE)
          (PART-OF WHATSIS GIMCRACK)
          (PART-OF HACK GIMCRACK)
          (PART-OF HOOZAWHATSIE GIMCRACK)
          (PART-OF CONTRAPTION GIMCRACK)
          (PART-OF SPROCKET GIMCRACK)
          (PART-OF WIDGET VALVE)
          (PART-OF MOUNT VALVE)
          (PART-OF PLUG MOUNT)
          (PART-OF FOOBAR MOUNT)
          (ASSEMBLE-ORDER GIMCRACK VALVE DEVICE)
          (ASSEMBLE-ORDER GIMCRACK TUBE DEVICE)
          (ASSEMBLE-ORDER WIDGET SOCKET TUBE)
          (REMOVE-ORDER SOCKET WIDGET TUBE)
          (ASSEMBLE-ORDER SOCKET FROB TUBE)
          (ASSEMBLE-ORDER UNIT WIDGET TUBE)
          (ASSEMBLE-ORDER UNIT FROB TUBE)
          (ASSEMBLE-ORDER WHATSIS HOOZAWHATSIE GIMCRACK)
          (ASSEMBLE-ORDER SPROCKET HOOZAWHATSIE GIMCRACK)
          (ASSEMBLE-ORDER WIDGET SOCKET VALVE)
          (ASSEMBLE-ORDER MOUNT WIDGET VALVE)
          (ASSEMBLE-ORDER FOOBAR PLUG MOUNT))
   (:GOAL (COMPLETE DEVICE)))

(DEFINE (PROBLEM ASSEM-11)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS TUBE CONNECTOR VALVE THINGUMBOB FOOBAR WHATSIS
             HOOZAWHATSIE COIL HACK DEVICE PLUG MOUNT SPROCKET FROB UNIT
             CONTRAPTION WIRE FASTENER SOCKET - ASSEMBLY
             CHARGER TWEEZERS PLIERS - RESOURCE)
   (:INIT (AVAILABLE VALVE)
          (AVAILABLE THINGUMBOB)
          (AVAILABLE WHATSIS)
          (AVAILABLE HOOZAWHATSIE)
          (AVAILABLE HACK)
          (AVAILABLE DEVICE)
          (AVAILABLE PLUG)
          (AVAILABLE MOUNT)
          (AVAILABLE FROB)
          (AVAILABLE UNIT)
          (AVAILABLE CONTRAPTION)
          (AVAILABLE WIRE)
          (AVAILABLE FASTENER)
          (AVAILABLE SOCKET)
          (REQUIRES CONNECTOR PLIERS)
          (REQUIRES FOOBAR TWEEZERS)
          (REQUIRES COIL PLIERS)
          (REQUIRES SPROCKET CHARGER)
          (PART-OF CONNECTOR TUBE)
          (PART-OF FOOBAR TUBE)
          (PART-OF COIL TUBE)
          (PART-OF SPROCKET TUBE)
          (PART-OF VALVE CONNECTOR)
          (PART-OF THINGUMBOB CONNECTOR)
          (PART-OF DEVICE CONNECTOR)
          (PART-OF WHATSIS FOOBAR)
          (PART-OF HOOZAWHATSIE FOOBAR)
          (PART-OF HACK FOOBAR)
          (TRANSIENT-PART HACK COIL)
          (TRANSIENT-PART DEVICE COIL)
          (PART-OF PLUG COIL)
          (PART-OF MOUNT COIL)
          (PART-OF FROB SPROCKET)
          (PART-OF UNIT SPROCKET)
          (PART-OF CONTRAPTION SPROCKET)
          (PART-OF WIRE SPROCKET)
          (PART-OF FASTENER SPROCKET)
          (PART-OF SOCKET SPROCKET)
          (ASSEMBLE-ORDER COIL SPROCKET TUBE)
          (ASSEMBLE-ORDER DEVICE PLUG CONNECTOR)
          (ASSEMBLE-ORDER DEVICE PLUG CONNECTOR)
          (ASSEMBLE-ORDER HACK MOUNT FOOBAR)
          (ASSEMBLE-ORDER HACK MOUNT COIL)
          (REMOVE-ORDER MOUNT HACK COIL)
          (ASSEMBLE-ORDER DEVICE PLUG COIL)
          (ASSEMBLE-ORDER DEVICE PLUG COIL)
          (REMOVE-ORDER PLUG DEVICE COIL)
          (ASSEMBLE-ORDER PLUG HACK COIL)
          (ASSEMBLE-ORDER UNIT FROB SPROCKET)
          (ASSEMBLE-ORDER WIRE CONTRAPTION SPROCKET)
          (ASSEMBLE-ORDER SOCKET FROB SPROCKET))
   (:GOAL (COMPLETE TUBE)))

(DEFINE (PROBLEM ASSEM-12)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS SOCKET HOOZAWHATSIE COIL DEVICE PLUG SPROCKET FROB
             CONTRAPTION THINGUMBOB WHATSIS CONNECTOR UNIT DOODAD WIDGET
             GIMCRACK FASTENER TUBE HACK MOUNT VALVE FOOBAR BRACKET
             - ASSEMBLY
             TWEEZERS HAMMER - RESOURCE)
   (:INIT (AVAILABLE HOOZAWHATSIE)
          (AVAILABLE COIL)
          (AVAILABLE PLUG)
          (AVAILABLE SPROCKET)
          (AVAILABLE FROB)
          (AVAILABLE CONTRAPTION)
          (AVAILABLE WHATSIS)
          (AVAILABLE CONNECTOR)
          (AVAILABLE UNIT)
          (AVAILABLE DOODAD)
          (AVAILABLE WIDGET)
          (AVAILABLE GIMCRACK)
          (AVAILABLE HACK)
          (AVAILABLE MOUNT)
          (AVAILABLE FOOBAR)
          (AVAILABLE BRACKET)
          (REQUIRES THINGUMBOB HAMMER)
          (REQUIRES FASTENER HAMMER)
          (REQUIRES TUBE HAMMER)
          (REQUIRES VALVE HAMMER)
          (PART-OF HOOZAWHATSIE SOCKET)
          (PART-OF COIL SOCKET)
          (PART-OF DEVICE SOCKET)
          (PART-OF THINGUMBOB SOCKET)
          (PART-OF FASTENER SOCKET)
          (PART-OF PLUG DEVICE)
          (PART-OF SPROCKET DEVICE)
          (PART-OF FROB DEVICE)
          (PART-OF CONTRAPTION DEVICE)
          (PART-OF WHATSIS THINGUMBOB)
          (PART-OF CONNECTOR THINGUMBOB)
          (PART-OF UNIT THINGUMBOB)
          (PART-OF DOODAD THINGUMBOB)
          (PART-OF WIDGET THINGUMBOB)
          (PART-OF GIMCRACK THINGUMBOB)
          (PART-OF TUBE FASTENER)
          (PART-OF VALVE FASTENER)
          (PART-OF HACK TUBE)
          (PART-OF MOUNT TUBE)
          (PART-OF FOOBAR VALVE)
          (PART-OF BRACKET VALVE)
          (ASSEMBLE-ORDER FROB PLUG DEVICE)
          (ASSEMBLE-ORDER FROB CONTRAPTION DEVICE)
          (ASSEMBLE-ORDER CONTRAPTION PLUG DEVICE)
          (ASSEMBLE-ORDER WHATSIS WIDGET THINGUMBOB)
          (ASSEMBLE-ORDER WHATSIS DOODAD THINGUMBOB)
          (ASSEMBLE-ORDER DOODAD CONNECTOR THINGUMBOB))
   (:GOAL (COMPLETE SOCKET)))

(DEFINE (PROBLEM ASSEM-13)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS SPROCKET MOUNT TUBE WIRE DEVICE KLUDGE VALVE
             HOOZAWHATSIE COIL SOCKET CONNECTOR FASTENER DOODAD FROB CONTRAPTION
             WHATSIS WIDGET BRACKET UNIT HACK FOOBAR GIMCRACK THINGUMBOB
             - ASSEMBLY
             HAMMER - RESOURCE)
   (:INIT (AVAILABLE TUBE)
          (AVAILABLE WIRE)
          (AVAILABLE KLUDGE)
          (AVAILABLE VALVE)
          (AVAILABLE COIL)
          (AVAILABLE SOCKET)
          (AVAILABLE FASTENER)
          (AVAILABLE DOODAD)
          (AVAILABLE CONTRAPTION)
          (AVAILABLE WHATSIS)
          (AVAILABLE BRACKET)
          (AVAILABLE UNIT)
          (AVAILABLE HACK)
          (AVAILABLE FOOBAR)
          (AVAILABLE GIMCRACK)
          (AVAILABLE THINGUMBOB)
          (REQUIRES MOUNT HAMMER)
          (REQUIRES HOOZAWHATSIE HAMMER)
          (REQUIRES CONNECTOR HAMMER)
          (REQUIRES WIDGET HAMMER)
          (PART-OF MOUNT SPROCKET)
          (PART-OF HOOZAWHATSIE SPROCKET)
          (PART-OF CONNECTOR SPROCKET)
          (PART-OF WIDGET SPROCKET)
          (PART-OF TUBE MOUNT)
          (PART-OF WIRE MOUNT)
          (PART-OF DEVICE MOUNT)
          (PART-OF KLUDGE DEVICE)
          (PART-OF VALVE DEVICE)
          (PART-OF COIL HOOZAWHATSIE)
          (PART-OF SOCKET HOOZAWHATSIE)
          (PART-OF FASTENER CONNECTOR)
          (PART-OF DOODAD CONNECTOR)
          (PART-OF FROB CONNECTOR)
          (PART-OF CONTRAPTION FROB)
          (PART-OF WHATSIS FROB)
          (PART-OF BRACKET WIDGET)
          (PART-OF UNIT WIDGET)
          (PART-OF HACK WIDGET)
          (PART-OF FOOBAR WIDGET)
          (PART-OF GIMCRACK WIDGET)
          (PART-OF THINGUMBOB WIDGET)
          (ASSEMBLE-ORDER WIDGET CONNECTOR SPROCKET)
          (ASSEMBLE-ORDER WIDGET MOUNT SPROCKET)
          (ASSEMBLE-ORDER WIRE TUBE MOUNT)
          (ASSEMBLE-ORDER DEVICE WIRE MOUNT)
          (ASSEMBLE-ORDER KLUDGE VALVE DEVICE)
          (ASSEMBLE-ORDER SOCKET COIL HOOZAWHATSIE)
          (ASSEMBLE-ORDER DOODAD FASTENER CONNECTOR)
          (ASSEMBLE-ORDER FOOBAR GIMCRACK WIDGET)
          (ASSEMBLE-ORDER FOOBAR UNIT WIDGET))
   (:GOAL (COMPLETE SPROCKET)))

(DEFINE (PROBLEM ASSEM-14)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS SOCKET BRACKET HACK KLUDGE THINGUMBOB PLUG TUBE DOODAD
             GIMCRACK CONNECTOR SPROCKET FOOBAR FROB WHATSIS DEVICE
             CONTRAPTION WIDGET VALVE MOUNT - ASSEMBLY
             PLIERS CLAMP HAMMOCK - RESOURCE)
   (:INIT (AVAILABLE KLUDGE)
          (AVAILABLE THINGUMBOB)
          (AVAILABLE TUBE)
          (AVAILABLE DOODAD)
          (AVAILABLE GIMCRACK)
          (AVAILABLE SPROCKET)
          (AVAILABLE FOOBAR)
          (AVAILABLE FROB)
          (AVAILABLE DEVICE)
          (AVAILABLE WIDGET)
          (AVAILABLE VALVE)
          (AVAILABLE MOUNT)
          (REQUIRES BRACKET PLIERS)
          (REQUIRES HACK HAMMOCK)
          (REQUIRES PLUG CLAMP)
          (REQUIRES CONNECTOR PLIERS)
          (REQUIRES WHATSIS PLIERS)
          (REQUIRES CONTRAPTION CLAMP)
          (PART-OF BRACKET SOCKET)
          (PART-OF PLUG SOCKET)
          (PART-OF CONNECTOR SOCKET)
          (PART-OF WHATSIS SOCKET)
          (PART-OF DOODAD BRACKET)
          (PART-OF HACK BRACKET)
          (TRANSIENT-PART KLUDGE HACK)
          (PART-OF THINGUMBOB HACK)
          (TRANSIENT-PART TUBE PLUG)
          (TRANSIENT-PART DOODAD PLUG)
          (PART-OF GIMCRACK PLUG)
          (TRANSIENT-PART SPROCKET CONNECTOR)
          (PART-OF FOOBAR CONNECTOR)
          (PART-OF FROB CONNECTOR)
          (PART-OF TUBE WHATSIS)
          (PART-OF DEVICE WHATSIS)
          (PART-OF CONTRAPTION WHATSIS)
          (PART-OF WIDGET CONTRAPTION)
          (PART-OF VALVE CONTRAPTION)
          (PART-OF MOUNT CONTRAPTION)
          (ASSEMBLE-ORDER DOODAD GIMCRACK BRACKET)
          (ASSEMBLE-ORDER KLUDGE THINGUMBOB HACK)
          (ASSEMBLE-ORDER KLUDGE THINGUMBOB HACK)
          (REMOVE-ORDER THINGUMBOB KLUDGE HACK)
          (ASSEMBLE-ORDER TUBE DOODAD PLUG)
          (ASSEMBLE-ORDER TUBE GIMCRACK PLUG)
          (REMOVE-ORDER DOODAD TUBE PLUG)
          (ASSEMBLE-ORDER DOODAD GIMCRACK PLUG)
          (REMOVE-ORDER GIMCRACK DOODAD PLUG)
          (ASSEMBLE-ORDER SPROCKET FROB CONNECTOR)
          (REMOVE-ORDER FROB SPROCKET CONNECTOR)
          (ASSEMBLE-ORDER FOOBAR SPROCKET CONNECTOR)
          (ASSEMBLE-ORDER TUBE DOODAD WHATSIS)
          (ASSEMBLE-ORDER TUBE GIMCRACK WHATSIS)
          (ASSEMBLE-ORDER DEVICE CONTRAPTION WHATSIS)
          (ASSEMBLE-ORDER VALVE WIDGET CONTRAPTION))
   (:GOAL (COMPLETE SOCKET)))

(DEFINE (PROBLEM ASSEM-15)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS DEVICE CONNECTOR WIDGET-2 FOOBAR FASTENER WHATSIS UNIT
             THINGUMBOB BRACKET SOCKET CONTRAPTION HOOZAWHATSIE PLUG KLUDGE
             WIDGET WIRE HACK GIMCRACK DOODAD COIL FROB TUBE SPROCKET VALVE
             MOUNT - ASSEMBLY
             HAMMOCK SCAFFOLD SCOPE - RESOURCE)
   (:INIT (AVAILABLE WIDGET-2)
          (AVAILABLE FASTENER)
          (AVAILABLE WHATSIS)
          (AVAILABLE THINGUMBOB)
          (AVAILABLE BRACKET)
          (AVAILABLE SOCKET)
          (AVAILABLE CONTRAPTION)
          (AVAILABLE PLUG)
          (AVAILABLE KLUDGE)
          (AVAILABLE WIDGET)
          (AVAILABLE WIRE)
          (AVAILABLE HACK)
          (AVAILABLE GIMCRACK)
          (AVAILABLE FROB)
          (AVAILABLE TUBE)
          (AVAILABLE VALVE)
          (AVAILABLE MOUNT)
          (REQUIRES CONNECTOR SCAFFOLD)
          (REQUIRES FOOBAR SCAFFOLD)
          (REQUIRES UNIT SCAFFOLD)
          (REQUIRES HOOZAWHATSIE SCAFFOLD)
          (REQUIRES DOODAD SCAFFOLD)
          (REQUIRES SPROCKET SCOPE)
          (PART-OF CONNECTOR DEVICE)
          (PART-OF UNIT DEVICE)
          (PART-OF HOOZAWHATSIE DEVICE)
          (PART-OF DOODAD DEVICE)
          (PART-OF WIDGET-2 CONNECTOR)
          (PART-OF FOOBAR CONNECTOR)
          (PART-OF FASTENER FOOBAR)
          (PART-OF WHATSIS FOOBAR)
          (PART-OF THINGUMBOB UNIT)
          (PART-OF BRACKET UNIT)
          (PART-OF SOCKET UNIT)
          (PART-OF CONTRAPTION UNIT)
          (PART-OF PLUG HOOZAWHATSIE)
          (PART-OF KLUDGE HOOZAWHATSIE)
          (PART-OF WIDGET HOOZAWHATSIE)
          (PART-OF WIRE HOOZAWHATSIE)
          (PART-OF HACK HOOZAWHATSIE)
          (PART-OF GIMCRACK HOOZAWHATSIE)
          (PART-OF COIL DOODAD)
          (PART-OF SPROCKET DOODAD)
          (PART-OF FROB COIL)
          (PART-OF TUBE COIL)
          (PART-OF VALVE SPROCKET)
          (PART-OF MOUNT SPROCKET)
          (ASSEMBLE-ORDER UNIT CONNECTOR DEVICE)
          (ASSEMBLE-ORDER DOODAD CONNECTOR DEVICE)
          (ASSEMBLE-ORDER WIRE PLUG HOOZAWHATSIE)
          (ASSEMBLE-ORDER SPROCKET COIL DOODAD)
          (ASSEMBLE-ORDER FROB TUBE COIL)
          (ASSEMBLE-ORDER VALVE MOUNT SPROCKET))
   (:GOAL (COMPLETE DEVICE)))

(DEFINE (PROBLEM ASSEM-16)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS BRACKET DOODAD WIDGET-1 WIRE-2 WIRE KLUDGE WHATSIS
             THINGUMBOB UNIT GIMCRACK SOCKET COIL SPROCKET FOOBAR MOUNT
             FASTENER DEVICE CONTRAPTION HOOZAWHATSIE VALVE FROB TUBE
             CONNECTOR PLUG HACK WIDGET - ASSEMBLY
             SCAFFOLD HAMMOCK - RESOURCE)
   (:INIT (AVAILABLE WIDGET-1)
          (AVAILABLE WIRE-2)
          (AVAILABLE WIRE)
          (AVAILABLE KLUDGE)
          (AVAILABLE WHATSIS)
          (AVAILABLE THINGUMBOB)
          (AVAILABLE GIMCRACK)
          (AVAILABLE SOCKET)
          (AVAILABLE COIL)
          (AVAILABLE SPROCKET)
          (AVAILABLE FOOBAR)
          (AVAILABLE MOUNT)
          (AVAILABLE CONTRAPTION)
          (AVAILABLE HOOZAWHATSIE)
          (AVAILABLE FROB)
          (AVAILABLE TUBE)
          (AVAILABLE PLUG)
          (AVAILABLE HACK)
          (AVAILABLE WIDGET)
          (REQUIRES DOODAD SCAFFOLD)
          (REQUIRES UNIT HAMMOCK)
          (REQUIRES FASTENER HAMMOCK)
          (REQUIRES DEVICE HAMMOCK)
          (REQUIRES VALVE HAMMOCK)
          (REQUIRES CONNECTOR HAMMOCK)
          (PART-OF DOODAD BRACKET)
          (PART-OF UNIT BRACKET)
          (PART-OF FASTENER BRACKET)
          (PART-OF CONNECTOR BRACKET)
          (PART-OF WIDGET-1 DOODAD)
          (PART-OF WIRE-2 DOODAD)
          (PART-OF WIRE DOODAD)
          (PART-OF KLUDGE DOODAD)
          (PART-OF WHATSIS DOODAD)
          (PART-OF THINGUMBOB DOODAD)
          (PART-OF GIMCRACK UNIT)
          (PART-OF SOCKET UNIT)
          (PART-OF COIL UNIT)
          (PART-OF SPROCKET UNIT)
          (PART-OF FOOBAR UNIT)
          (PART-OF MOUNT UNIT)
          (PART-OF DEVICE FASTENER)
          (PART-OF VALVE FASTENER)
          (PART-OF CONTRAPTION DEVICE)
          (PART-OF HOOZAWHATSIE DEVICE)
          (PART-OF FROB VALVE)
          (PART-OF TUBE VALVE)
          (PART-OF PLUG CONNECTOR)
          (PART-OF HACK CONNECTOR)
          (PART-OF WIDGET CONNECTOR)
          (ASSEMBLE-ORDER UNIT CONNECTOR BRACKET)
          (ASSEMBLE-ORDER FASTENER DOODAD BRACKET)
          (ASSEMBLE-ORDER CONNECTOR DOODAD BRACKET)
          (ASSEMBLE-ORDER WIDGET-1 THINGUMBOB DOODAD)
          (ASSEMBLE-ORDER WIRE-2 WIRE DOODAD)
          (ASSEMBLE-ORDER WHATSIS WIRE DOODAD)
          (ASSEMBLE-ORDER DEVICE VALVE FASTENER)
          (ASSEMBLE-ORDER PLUG WIDGET CONNECTOR))
   (:GOAL (COMPLETE BRACKET)))

(DEFINE (PROBLEM ASSEM-17)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS HACK DOODAD-2 WHATSIS-4 SOCKET-1 SPROCKET THINGUMBOB
             WIRE PLUG COIL WIDGET TUBE GIMCRACK VALVE KLUDGE WHATSIS
             HOOZAWHATSIE BRACKET DOODAD UNIT FASTENER FOOBAR DEVICE - ASSEMBLY
             FILE TWEEZERS - RESOURCE)
   (:INIT (AVAILABLE WHATSIS-4)
          (AVAILABLE SOCKET-1)
          (AVAILABLE THINGUMBOB)
          (AVAILABLE WIRE)
          (AVAILABLE COIL)
          (AVAILABLE WIDGET)
          (AVAILABLE TUBE)
          (AVAILABLE GIMCRACK)
          (AVAILABLE KLUDGE)
          (AVAILABLE WHATSIS)
          (AVAILABLE HOOZAWHATSIE)
          (AVAILABLE BRACKET)
          (AVAILABLE DOODAD)
          (AVAILABLE FOOBAR)
          (AVAILABLE DEVICE)
          (REQUIRES DOODAD-2 TWEEZERS)
          (REQUIRES SPROCKET TWEEZERS)
          (REQUIRES PLUG FILE)
          (REQUIRES VALVE TWEEZERS)
          (REQUIRES UNIT FILE)
          (REQUIRES FASTENER TWEEZERS)
          (PART-OF DOODAD-2 HACK)
          (PART-OF SPROCKET HACK)
          (PART-OF PLUG HACK)
          (PART-OF VALVE HACK)
          (PART-OF UNIT HACK)
          (PART-OF WHATSIS-4 DOODAD-2)
          (PART-OF SOCKET-1 DOODAD-2)
          (PART-OF GIMCRACK SPROCKET)
          (TRANSIENT-PART THINGUMBOB SPROCKET)
          (PART-OF WIRE SPROCKET)
          (PART-OF COIL PLUG)
          (PART-OF WIDGET PLUG)
          (PART-OF TUBE PLUG)
          (PART-OF THINGUMBOB PLUG)
          (TRANSIENT-PART GIMCRACK PLUG)
          (PART-OF KLUDGE VALVE)
          (PART-OF WHATSIS VALVE)
          (PART-OF HOOZAWHATSIE VALVE)
          (TRANSIENT-PART BRACKET VALVE)
          (PART-OF DOODAD VALVE)
          (PART-OF BRACKET UNIT)
          (PART-OF FASTENER UNIT)
          (PART-OF FOOBAR FASTENER)
          (PART-OF DEVICE FASTENER)
          (ASSEMBLE-ORDER DOODAD-2 SPROCKET HACK)
          (ASSEMBLE-ORDER DOODAD-2 VALVE HACK)
          (ASSEMBLE-ORDER PLUG UNIT HACK)
          (ASSEMBLE-ORDER WHATSIS-4 SOCKET-1 DOODAD-2)
          (ASSEMBLE-ORDER GIMCRACK COIL SPROCKET)
          (ASSEMBLE-ORDER THINGUMBOB WIRE SPROCKET)
          (REMOVE-ORDER WIRE THINGUMBOB SPROCKET)
          (ASSEMBLE-ORDER THINGUMBOB WIRE PLUG)
          (ASSEMBLE-ORDER GIMCRACK COIL PLUG)
          (REMOVE-ORDER COIL GIMCRACK PLUG)
          (ASSEMBLE-ORDER HOOZAWHATSIE DOODAD VALVE)
          (ASSEMBLE-ORDER HOOZAWHATSIE WHATSIS VALVE)
          (ASSEMBLE-ORDER BRACKET HOOZAWHATSIE VALVE)
          (ASSEMBLE-ORDER BRACKET HOOZAWHATSIE VALVE)
          (REMOVE-ORDER HOOZAWHATSIE BRACKET VALVE)
          (ASSEMBLE-ORDER BRACKET HOOZAWHATSIE UNIT)
          (ASSEMBLE-ORDER BRACKET HOOZAWHATSIE UNIT)
          (ASSEMBLE-ORDER FOOBAR DEVICE FASTENER))
   (:GOAL (COMPLETE HACK)))

(DEFINE (PROBLEM ASSEM-18)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS SOCKET DEVICE DOODAD-3 KLUDGE-4 HACK-1 GIMCRACK-2 FROB
             VALVE TUBE PLUG DOODAD KLUDGE SPROCKET WIRE HACK BRACKET
             WIDGET UNIT CONNECTOR HOOZAWHATSIE THINGUMBOB FASTENER
             GIMCRACK CONTRAPTION FOOBAR WHATSIS COIL MOUNT - ASSEMBLY
             HAMMOCK CLAMP - RESOURCE)
   (:INIT (AVAILABLE DOODAD-3)
          (AVAILABLE KLUDGE-4)
          (AVAILABLE HACK-1)
          (AVAILABLE GIMCRACK-2)
          (AVAILABLE VALVE)
          (AVAILABLE TUBE)
          (AVAILABLE DOODAD)
          (AVAILABLE KLUDGE)
          (AVAILABLE WIRE)
          (AVAILABLE HACK)
          (AVAILABLE BRACKET)
          (AVAILABLE UNIT)
          (AVAILABLE CONNECTOR)
          (AVAILABLE HOOZAWHATSIE)
          (AVAILABLE THINGUMBOB)
          (AVAILABLE GIMCRACK)
          (AVAILABLE CONTRAPTION)
          (AVAILABLE FOOBAR)
          (AVAILABLE WHATSIS)
          (AVAILABLE COIL)
          (AVAILABLE MOUNT)
          (REQUIRES DEVICE CLAMP)
          (REQUIRES FROB HAMMOCK)
          (REQUIRES PLUG CLAMP)
          (REQUIRES SPROCKET CLAMP)
          (REQUIRES WIDGET CLAMP)
          (REQUIRES FASTENER CLAMP)
          (PART-OF DEVICE SOCKET)
          (PART-OF FROB SOCKET)
          (PART-OF PLUG SOCKET)
          (PART-OF WIDGET SOCKET)
          (PART-OF FASTENER SOCKET)
          (PART-OF DOODAD-3 DEVICE)
          (PART-OF KLUDGE-4 DEVICE)
          (PART-OF HACK-1 DEVICE)
          (PART-OF GIMCRACK-2 DEVICE)
          (PART-OF VALVE FROB)
          (PART-OF TUBE FROB)
          (PART-OF DOODAD PLUG)
          (PART-OF KLUDGE PLUG)
          (PART-OF SPROCKET PLUG)
          (PART-OF WIRE SPROCKET)
          (PART-OF HACK SPROCKET)
          (PART-OF BRACKET SPROCKET)
          (PART-OF UNIT WIDGET)
          (PART-OF CONNECTOR WIDGET)
          (PART-OF HOOZAWHATSIE WIDGET)
          (PART-OF THINGUMBOB WIDGET)
          (PART-OF GIMCRACK FASTENER)
          (PART-OF CONTRAPTION FASTENER)
          (PART-OF FOOBAR FASTENER)
          (PART-OF WHATSIS FASTENER)
          (PART-OF COIL FASTENER)
          (PART-OF MOUNT FASTENER)
          (ASSEMBLE-ORDER PLUG DEVICE SOCKET)
          (ASSEMBLE-ORDER WIDGET PLUG SOCKET)
          (ASSEMBLE-ORDER DOODAD-3 KLUDGE-4 DEVICE)
          (ASSEMBLE-ORDER HACK-1 DOODAD-3 DEVICE)
          (ASSEMBLE-ORDER GIMCRACK-2 DOODAD-3 DEVICE)
          (ASSEMBLE-ORDER VALVE TUBE FROB)
          (ASSEMBLE-ORDER DOODAD SPROCKET PLUG)
          (ASSEMBLE-ORDER HOOZAWHATSIE UNIT WIDGET)
          (ASSEMBLE-ORDER THINGUMBOB HOOZAWHATSIE WIDGET))
   (:GOAL (COMPLETE SOCKET)))

(DEFINE (PROBLEM ASSEM-19)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS VALVE DEVICE BRACKET-8 COIL-3 WIRE-4 FOOBAR-1
             HOOZAWHATSIE-2 MOUNT GIMCRACK PLUG SPROCKET DOODAD COIL WIDGET
             CONTRAPTION HACK THINGUMBOB CONNECTOR UNIT KLUDGE FROB FASTENER
             SOCKET WIRE HOOZAWHATSIE BRACKET FOOBAR WHATSIS - ASSEMBLY
             PLIERS VOLTMETER - RESOURCE)
   (:INIT (AVAILABLE BRACKET-8)
          (AVAILABLE COIL-3)
          (AVAILABLE WIRE-4)
          (AVAILABLE FOOBAR-1)
          (AVAILABLE HOOZAWHATSIE-2)
          (AVAILABLE MOUNT)
          (AVAILABLE GIMCRACK)
          (AVAILABLE PLUG)
          (AVAILABLE DOODAD)
          (AVAILABLE COIL)
          (AVAILABLE WIDGET)
          (AVAILABLE HACK)
          (AVAILABLE THINGUMBOB)
          (AVAILABLE CONNECTOR)
          (AVAILABLE KLUDGE)
          (AVAILABLE FROB)
          (AVAILABLE SOCKET)
          (AVAILABLE WIRE)
          (AVAILABLE HOOZAWHATSIE)
          (AVAILABLE BRACKET)
          (AVAILABLE FOOBAR)
          (AVAILABLE WHATSIS)
          (REQUIRES DEVICE VOLTMETER)
          (REQUIRES SPROCKET VOLTMETER)
          (REQUIRES CONTRAPTION PLIERS)
          (REQUIRES UNIT VOLTMETER)
          (REQUIRES FASTENER PLIERS)
          (PART-OF DEVICE VALVE)
          (PART-OF SPROCKET VALVE)
          (PART-OF CONTRAPTION VALVE)
          (PART-OF UNIT VALVE)
          (PART-OF FASTENER VALVE)
          (PART-OF BRACKET-8 DEVICE)
          (PART-OF COIL-3 DEVICE)
          (PART-OF WIRE-4 DEVICE)
          (PART-OF FOOBAR-1 DEVICE)
          (PART-OF HOOZAWHATSIE-2 DEVICE)
          (PART-OF MOUNT DEVICE)
          (PART-OF GIMCRACK DEVICE)
          (PART-OF PLUG DEVICE)
          (PART-OF DOODAD SPROCKET)
          (PART-OF COIL SPROCKET)
          (PART-OF WIDGET SPROCKET)
          (TRANSIENT-PART HACK CONTRAPTION)
          (PART-OF THINGUMBOB CONTRAPTION)
          (PART-OF CONNECTOR CONTRAPTION)
          (PART-OF KLUDGE UNIT)
          (PART-OF FROB UNIT)
          (PART-OF HACK UNIT)
          (PART-OF SOCKET FASTENER)
          (PART-OF WIRE FASTENER)
          (PART-OF HOOZAWHATSIE FASTENER)
          (PART-OF BRACKET FASTENER)
          (PART-OF FOOBAR FASTENER)
          (PART-OF WHATSIS FASTENER)
          (ASSEMBLE-ORDER DEVICE CONTRAPTION VALVE)
          (ASSEMBLE-ORDER DEVICE UNIT VALVE)
          (ASSEMBLE-ORDER UNIT SPROCKET VALVE)
          (ASSEMBLE-ORDER FASTENER CONTRAPTION VALVE)
          (ASSEMBLE-ORDER BRACKET-8 MOUNT DEVICE)
          (ASSEMBLE-ORDER COIL-3 GIMCRACK DEVICE)
          (ASSEMBLE-ORDER WIRE-4 PLUG DEVICE)
          (ASSEMBLE-ORDER MOUNT GIMCRACK DEVICE)
          (ASSEMBLE-ORDER PLUG BRACKET-8 DEVICE)
          (ASSEMBLE-ORDER PLUG HOOZAWHATSIE-2 DEVICE)
          (ASSEMBLE-ORDER COIL DOODAD SPROCKET)
          (ASSEMBLE-ORDER WIDGET DOODAD SPROCKET)
          (ASSEMBLE-ORDER HACK CONNECTOR CONTRAPTION)
          (REMOVE-ORDER CONNECTOR HACK CONTRAPTION)
          (ASSEMBLE-ORDER FROB KLUDGE UNIT)
          (ASSEMBLE-ORDER HACK CONNECTOR UNIT)
          (ASSEMBLE-ORDER WIRE SOCKET FASTENER)
          (ASSEMBLE-ORDER HOOZAWHATSIE BRACKET FASTENER)
          (ASSEMBLE-ORDER BRACKET WIRE FASTENER)
          (ASSEMBLE-ORDER BRACKET FOOBAR FASTENER))
   (:GOAL (COMPLETE VALVE)))

; The remaining problems are from Round 1 of the AIPS-98 competition

(define (problem assem-x-1)
   (:domain assembly)
   (:objects bracket valve device frob fastener widget tube sprocket
             wire doodad gimcrack connector hack plug contraption mount
             socket unit hoozawhatsie - assembly
             charger voltmeter - resource)
   (:init (available valve)
          (available device)
          (available fastener)
          (available widget)
          (available tube)
          (available wire)
          (available gimcrack)
          (available connector)
          (available hack)
          (available contraption)
          (available mount)
          (available unit)
          (available hoozawhatsie)
          (available charger)
          (available voltmeter)
          (requires frob charger)
          (requires sprocket charger)
          (requires doodad voltmeter)
          (requires plug voltmeter)
          (requires socket voltmeter)
          (part-of valve bracket)
          (part-of device bracket)
          (part-of frob bracket)
          (part-of sprocket bracket)
          (part-of plug bracket)
          (part-of fastener frob)
          (part-of widget frob)
          (part-of tube frob)
          (part-of mount sprocket)
          (part-of wire sprocket)
          (part-of doodad sprocket)
          (part-of gimcrack doodad)
          (part-of connector doodad)
          (part-of hack doodad)
          (part-of contraption plug)
          (transient-part mount plug)
          (part-of socket plug)
          (part-of unit socket)
          (part-of hoozawhatsie socket)
          (assemble-order fastener tube frob)
          (assemble-order widget tube frob)
          (assemble-order mount contraption sprocket)
          (assemble-order wire mount sprocket)
          (assemble-order mount contraption plug)
          (remove-order contraption mount plug)
          (assemble-order hoozawhatsie unit socket))
   (:goal (complete bracket)))

(define (problem assem-x-2)
   (:domain assembly)
   (:objects mount gimcrack hack frob foobar tube sprocket
             contraption connector socket whatsis bracket wire plug thingumbob
             doodad valve widget kludge unit device - assembly
             hammock - resource)
   (:init (available frob)
          (available foobar)
          (available tube)
          (available contraption)
          (available connector)
          (available whatsis)
          (available bracket)
          (available wire)
          (available plug)
          (available thingumbob)
          (available valve)
          (available widget)
          (available unit)
          (available device)
          (available hammock)
          (requires gimcrack hammock)
          (requires socket hammock)
          (requires doodad hammock)
          (part-of gimcrack mount)
          (part-of socket mount)
          (part-of doodad mount)
          (part-of hack gimcrack)
          (part-of sprocket gimcrack)
          (part-of frob hack)
          (part-of foobar hack)
          (part-of tube hack)
          (part-of contraption sprocket)
          (part-of connector sprocket)
          (part-of whatsis socket)
          (part-of bracket socket)
          (part-of widget socket)
          (part-of wire socket)
          (part-of plug socket)
          (part-of thingumbob socket)
          (part-of valve doodad)
          (transient-part widget doodad)
          (part-of kludge doodad)
          (part-of unit kludge)
          (part-of device kludge)
          (assemble-order gimcrack socket mount)
          (assemble-order sprocket hack gimcrack)
          (assemble-order frob foobar hack)
          (assemble-order widget valve socket)
          (assemble-order widget valve socket)
          (assemble-order widget valve doodad)
          (assemble-order widget valve doodad)
          (remove-order valve widget doodad))
   (:goal (complete mount)))

(define (problem assem-x-3)
   (:domain assembly)
   (:objects foobar coil widget tube frob socket hack hoozawhatsie
             sprocket thingumbob whatsis doodad gimcrack kludge contraption
             connector wire plug device fastener valve mount bracket unit
             - assembly
             clamp hammer file - resource)
   (:init (available coil)
          (available widget)
          (available frob)
          (available socket)
          (available hoozawhatsie)
          (available sprocket)
          (available thingumbob)
          (available whatsis)
          (available gimcrack)
          (available kludge)
          (available wire)
          (available plug)
          (available fastener)
          (available valve)
          (available bracket)
          (available unit)
          (available clamp)
          (available hammer)
          (available file)
          (requires tube clamp)
          (requires hack clamp)
          (requires doodad hammer)
          (requires contraption file)
          (requires device file)
          (requires mount hammer)
          (part-of coil foobar)
          (part-of widget foobar)
          (part-of tube foobar)
          (part-of hack foobar)
          (part-of doodad foobar)
          (part-of contraption foobar)
          (part-of mount foobar)
          (part-of frob tube)
          (part-of socket tube)
          (part-of hoozawhatsie hack)
          (part-of sprocket hack)
          (part-of thingumbob hack)
          (part-of whatsis hack)
          (part-of gimcrack doodad)
          (part-of kludge doodad)
          (part-of connector contraption)
          (part-of device contraption)
          (part-of wire connector)
          (part-of plug connector)
          (part-of fastener device)
          (part-of valve device)
          (part-of bracket mount)
          (part-of unit mount)
          (assemble-order coil hack foobar)
          (assemble-order frob socket tube)
          (assemble-order hoozawhatsie whatsis hack)
          (assemble-order thingumbob hoozawhatsie hack)
          (assemble-order whatsis sprocket hack)
          (assemble-order gimcrack kludge doodad)
          (assemble-order plug wire connector)
          (assemble-order valve fastener device)
          (assemble-order bracket unit mount))
   (:goal (complete foobar)))

(define (problem assem-x-4)
   (:domain assembly)
   (:objects frob connector socket-1 contraption-2 coil whatsis
             bracket hoozawhatsie thingumbob contraption unit hack widget
             sprocket device tube doodad fastener plug gimcrack socket valve
             mount wire kludge - assembly
             voltmeter hammock charger - resource)
   (:init (available socket-1)
          (available contraption-2)
          (available coil)
          (available whatsis)
          (available bracket)
          (available thingumbob)
          (available contraption)
          (available unit)
          (available widget)
          (available sprocket)
          (available device)
          (available tube)
          (available doodad)
          (available fastener)
          (available gimcrack)
          (available socket)
          (available mount)
          (available wire)
          (available kludge)
          (available voltmeter)
          (available hammock)
          (available charger)
          (requires connector hammock)
          (requires hoozawhatsie hammock)
          (requires hack charger)
          (requires plug voltmeter)
          (requires valve hammock)
          (part-of connector frob)
          (part-of hoozawhatsie frob)
          (part-of hack frob)
          (part-of plug frob)
          (part-of socket-1 connector)
          (part-of contraption-2 connector)
          (part-of coil connector)
          (part-of valve connector)
          (part-of whatsis connector)
          (part-of bracket connector)
          (part-of thingumbob hoozawhatsie)
          (part-of contraption hoozawhatsie)
          (part-of unit hoozawhatsie)
          (part-of widget hack)
          (part-of sprocket hack)
          (part-of device hack)
          (part-of tube hack)
          (part-of doodad hack)
          (part-of fastener hack)
          (part-of gimcrack plug)
          (part-of socket plug)
          (transient-part valve plug)
          (part-of mount valve)
          (part-of wire valve)
          (part-of kludge valve)
          (assemble-order connector hoozawhatsie frob)
          (assemble-order hoozawhatsie hack frob)
          (assemble-order plug hack frob)
          (assemble-order valve gimcrack connector)
          (assemble-order whatsis contraption-2 connector)
          (assemble-order bracket valve connector)
          (assemble-order thingumbob contraption hoozawhatsie)
          (assemble-order unit contraption hoozawhatsie)
          (assemble-order device fastener hack)
          (assemble-order tube doodad hack)
          (assemble-order valve gimcrack plug)
          (remove-order gimcrack valve plug)
          (assemble-order mount kludge valve)
          (assemble-order kludge wire valve))
   (:goal (complete frob)))

(define (problem assem-x-5)
   (:domain assembly)
   (:objects thingumbob connector-3 bracket-4 plug socket-1
             contraption gimcrack frob mount tube widget foobar valve fastener
             sprocket wire kludge hack bracket unit socket doodad device
             - assembly
             hammock pliers scalpel - resource)
   (:init (available connector-3)
          (available bracket-4)
          (available socket-1)
          (available gimcrack)
          (available frob)
          (available mount)
          (available tube)
          (available valve)
          (available fastener)
          (available wire)
          (available hack)
          (available bracket)
          (available unit)
          (available socket)
          (available doodad)
          (available device)
          (available hammock)
          (available pliers)
          (available scalpel)
          (requires plug scalpel)
          (requires contraption pliers)
          (requires widget hammock)
          (requires foobar scalpel)
          (requires sprocket pliers)
          (requires kludge pliers)
          (part-of connector-3 thingumbob)
          (part-of bracket-4 thingumbob)
          (part-of plug thingumbob)
          (part-of contraption thingumbob)
          (part-of widget thingumbob)
          (part-of sprocket thingumbob)
          (part-of kludge thingumbob)
          (part-of socket-1 plug)
          (part-of doodad plug)
          (part-of gimcrack contraption)
          (part-of frob contraption)
          (part-of mount contraption)
          (part-of tube contraption)
          (part-of foobar widget)
          (part-of hack widget)
          (part-of valve foobar)
          (part-of fastener foobar)
          (part-of wire sprocket)
          (part-of socket sprocket)
          (transient-part hack kludge)
          (part-of bracket kludge)
          (part-of unit kludge)
          (transient-part socket kludge)
          (transient-part doodad kludge)
          (part-of device kludge)
          (assemble-order connector-3 sprocket thingumbob)
          (assemble-order contraption widget thingumbob)
          (assemble-order contraption plug thingumbob)
          (assemble-order sprocket bracket-4 thingumbob)
          (assemble-order sprocket contraption thingumbob)
          (assemble-order sprocket widget thingumbob)
          (assemble-order doodad unit plug)
          (assemble-order mount frob contraption)
          (assemble-order mount tube contraption)
          (assemble-order mount gimcrack contraption)
          (assemble-order hack device widget)
          (assemble-order valve fastener foobar)
          (assemble-order socket device sprocket)
          (assemble-order hack device kludge)
          (remove-order device hack kludge)
          (assemble-order bracket hack kludge)
          (assemble-order bracket unit kludge)
          (assemble-order socket device kludge)
          (remove-order device socket kludge)
          (assemble-order doodad unit kludge)
          (remove-order unit doodad kludge))
   (:goal (complete thingumbob)))

(define (problem assem-x-6)
   (:domain assembly)
   (:objects bracket doodad wire-3 plug-7 thingumbob-8 gimcrack
             socket-4 connector-1 device-2 device plug kludge fastener wire
             frob thingumbob mount socket coil contraption widget
             hoozawhatsie sprocket valve hack unit tube foobar whatsis connector
             - assembly
             tweezers - resource)
   (:init (available plug-7)
          (available thingumbob-8)
          (available socket-4)
          (available connector-1)
          (available device-2)
          (available plug)
          (available kludge)
          (available fastener)
          (available wire)
          (available frob)
          (available thingumbob)
          (available socket)
          (available coil)
          (available contraption)
          (available widget)
          (available hoozawhatsie)
          (available sprocket)
          (available hack)
          (available unit)
          (available tube)
          (available foobar)
          (available whatsis)
          (available connector)
          (available tweezers)
          (requires doodad tweezers)
          (requires device tweezers)
          (requires mount tweezers)
          (requires valve tweezers)
          (part-of doodad bracket)
          (part-of device bracket)
          (part-of mount bracket)
          (part-of valve bracket)
          (part-of wire-3 doodad)
          (part-of gimcrack doodad)
          (part-of plug-7 wire-3)
          (part-of thingumbob-8 wire-3)
          (part-of socket-4 gimcrack)
          (part-of connector-1 gimcrack)
          (part-of device-2 gimcrack)
          (part-of plug device)
          (part-of kludge device)
          (part-of fastener device)
          (part-of wire device)
          (part-of frob device)
          (part-of thingumbob device)
          (part-of socket mount)
          (part-of coil mount)
          (part-of contraption mount)
          (part-of widget mount)
          (part-of hoozawhatsie mount)
          (part-of sprocket mount)
          (part-of hack valve)
          (part-of unit valve)
          (part-of tube valve)
          (part-of foobar valve)
          (part-of whatsis valve)
          (part-of connector valve)
          (assemble-order mount doodad bracket)
          (assemble-order valve doodad bracket)
          (assemble-order gimcrack wire-3 doodad)
          (assemble-order connector-1 device-2 gimcrack)
          (assemble-order fastener kludge device)
          (assemble-order wire kludge device)
          (assemble-order frob thingumbob device)
          (assemble-order thingumbob kludge device)
          (assemble-order coil socket mount)
          (assemble-order contraption socket mount)
          (assemble-order widget sprocket mount)
          (assemble-order hoozawhatsie sprocket mount)
          (assemble-order tube whatsis valve))
   (:goal (complete bracket)))

(define (problem assem-x-7)
   (:domain assembly)
   (:objects unit kludge-4 connector-5 gimcrack-6 mount-7
             sprocket-3 foobar device-1 socket-2 wire kludge whatsis plug
             widget socket doodad thingumbob gimcrack tube contraption
             valve mount frob hack connector fastener bracket device
             - assembly
             scope pliers voltmeter - resource)
   (:init (available connector-5)
          (available gimcrack-6)
          (available mount-7)
          (available sprocket-3)
          (available device-1)
          (available socket-2)
          (available kludge)
          (available whatsis)
          (available widget)
          (available socket)
          (available doodad)
          (available gimcrack)
          (available tube)
          (available valve)
          (available mount)
          (available frob)
          (available hack)
          (available connector)
          (available bracket)
          (available device)
          (available scope)
          (available pliers)
          (available voltmeter)
          (requires kludge-4 voltmeter)
          (requires foobar voltmeter)
          (requires wire voltmeter)
          (requires plug voltmeter)
          (requires thingumbob pliers)
          (requires contraption scope)
          (requires fastener pliers)
          (part-of kludge-4 unit)
          (part-of foobar unit)
          (part-of plug unit)
          (part-of thingumbob unit)
          (part-of contraption unit)
          (part-of fastener unit)
          (transient-part connector-5 kludge-4)
          (part-of gimcrack-6 kludge-4)
          (part-of mount-7 kludge-4)
          (part-of bracket kludge-4)
          (part-of sprocket-3 kludge-4)
          (part-of device-1 foobar)
          (part-of socket-2 foobar)
          (part-of wire foobar)
          (part-of kludge wire)
          (part-of whatsis wire)
          (part-of widget plug)
          (transient-part socket plug)
          (part-of doodad plug)
          (part-of hack thingumbob)
          (part-of socket thingumbob)
          (part-of gimcrack thingumbob)
          (part-of tube thingumbob)
          (part-of valve contraption)
          (part-of mount contraption)
          (part-of frob contraption)
          (transient-part hack contraption)
          (part-of connector-5 contraption)
          (part-of connector contraption)
          (transient-part bracket fastener)
          (part-of device fastener)
          (assemble-order foobar kludge-4 unit)
          (assemble-order foobar contraption unit)
          (assemble-order foobar plug unit)
          (assemble-order connector-5 mount-7 kludge-4)
          (remove-order mount-7 connector-5 kludge-4)
          (assemble-order bracket device kludge-4)
          (assemble-order bracket device kludge-4)
          (assemble-order sprocket-3 bracket kludge-4)
          (assemble-order sprocket-3 connector-5 kludge-4)
          (assemble-order socket-2 device-1 foobar)
          (assemble-order kludge whatsis wire)
          (assemble-order socket doodad plug)
          (remove-order doodad socket plug)
          (assemble-order hack connector-5 thingumbob)
          (assemble-order socket doodad thingumbob)
          (assemble-order gimcrack tube thingumbob)
          (assemble-order hack connector-5 contraption)
          (remove-order sprocket hack contraption)
          (assemble-order connector-5 mount-7 contraption)
          (assemble-order bracket device fastener)
          (assemble-order bracket device fastener)
          (remove-order device bracket fastener))
   (:goal (complete unit)))

(define (problem assem-x-8)
   (:domain assembly)
   (:objects mount gimcrack-15 wire-16 coil-7 unit-5 tube-6
             hoozawhatsie thingumbob-8 bracket-4 widget-1 valve frob tube device
             foobar whatsis plug gimcrack hack sprocket connector fastener
             kludge thingumbob unit doodad socket - assembly
             voltmeter - resource)
   (:init (available gimcrack-15)
          (available wire-16)
          (available unit-5)
          (available tube-6)
          (available thingumbob-8)
          (available bracket-4)
          (available widget-1)
          (available valve)
          (available tube)
          (available device)
          (available whatsis)
          (available plug)
          (available gimcrack)
          (available hack)
          (available sprocket)
          (available connector)
          (available kludge)
          (available thingumbob)
          (available unit)
          (available doodad)
          (available socket)
          (available voltmeter)
          (requires coil-7 voltmeter)
          (requires hoozawhatsie voltmeter)
          (requires frob voltmeter)
          (requires foobar voltmeter)
          (requires fastener voltmeter)
          (part-of gimcrack-15 mount)
          (part-of wire-16 mount)
          (part-of coil-7 mount)
          (part-of hoozawhatsie mount)
          (part-of frob mount)
          (part-of foobar mount)
          (part-of fastener mount)
          (part-of unit-5 coil-7)
          (transient-part tube-6 coil-7)
          (part-of thingumbob-8 hoozawhatsie)
          (part-of unit hoozawhatsie)
          (transient-part bracket-4 hoozawhatsie)
          (part-of widget-1 hoozawhatsie)
          (part-of hack hoozawhatsie)
          (part-of valve hoozawhatsie)
          (part-of tube frob)
          (part-of device frob)
          (part-of tube-6 frob)
          (part-of whatsis foobar)
          (part-of plug foobar)
          (part-of gimcrack foobar)
          (transient-part hack foobar)
          (part-of sprocket foobar)
          (part-of connector foobar)
          (part-of kludge fastener)
          (part-of thingumbob fastener)
          (transient-part unit fastener)
          (part-of bracket-4 fastener)
          (part-of doodad fastener)
          (part-of socket fastener)
          (assemble-order frob wire-16 mount)
          (assemble-order foobar fastener mount)
          (assemble-order fastener coil-7 mount)
          (assemble-order fastener frob mount)
          (assemble-order tube-6 unit-5 coil-7)
          (assemble-order tube-6 unit-5 coil-7)
          (remove-order unit-5 tube-6 coil-7)
          (assemble-order unit kludge hoozawhatsie)
          (assemble-order unit socket hoozawhatsie)
          (assemble-order bracket-4 thingumbob-8 hoozawhatsie)
          (assemble-order bracket-4 unit hoozawhatsie)
          (remove-order thingumbob-8 bracket-4 hoozawhatsie)
          (assemble-order hack gimcrack hoozawhatsie)
          (assemble-order hack whatsis hoozawhatsie)
          (assemble-order valve bracket-4 hoozawhatsie)
          (assemble-order tube tube-6 frob)
          (assemble-order tube-6 unit-5 frob)
          (assemble-order tube-6 unit-5 frob)
          (assemble-order plug hack foobar)
          (assemble-order plug sprocket foobar)
          (assemble-order plug gimcrack foobar)
          (assemble-order gimcrack connector foobar)
          (assemble-order hack gimcrack foobar)
          (assemble-order hack whatsis foobar)
          (remove-order gimcrack hack foobar)
          (assemble-order thingumbob doodad fastener)
          (assemble-order unit kludge fastener)
          (assemble-order unit socket fastener)
          (remove-order kludge unit fastener)
          (assemble-order bracket-4 thingumbob-8 fastener)
          (assemble-order bracket-4 unit fastener)
          (assemble-order socket doodad fastener))
   (:goal (complete mount)))

(define (problem assem-x-9)
   (:domain assembly)
   (:objects mount hack-15 wire-13 frob-7 sprocket-16 foobar-5
             bracket-6 tube fastener-8 hoozawhatsie-3 contraption-4 unit-1
             doodad-2 hack kludge coil sprocket foobar fastener contraption
             whatsis hoozawhatsie gimcrack unit wire device widget socket
             bracket plug doodad connector valve thingumbob - assembly
             file - resource)
   (:init (available wire-13)
          (available sprocket-16)
          (available foobar-5)
          (available bracket-6)
          (available fastener-8)
          (available hoozawhatsie-3)
          (available contraption-4)
          (available unit-1)
          (available doodad-2)
          (available hack)
          (available coil)
          (available sprocket)
          (available foobar)
          (available fastener)
          (available contraption)
          (available whatsis)
          (available unit)
          (available device)
          (available widget)
          (available plug)
          (available doodad)
          (available valve)
          (available thingumbob)
          (available file)
          (requires hack-15 file)
          (requires frob-7 file)
          (requires tube file)
          (requires kludge file)
          (requires hoozawhatsie file)
          (requires socket file)
          (part-of hack-15 mount)
          (part-of frob-7 mount)
          (part-of tube mount)
          (part-of kludge mount)
          (part-of hoozawhatsie mount)
          (part-of socket mount)
          (part-of wire-13 hack-15)
          (part-of foobar-5 hack-15)
          (part-of sprocket-16 frob-7)
          (transient-part foobar-5 frob-7)
          (part-of bracket-6 frob-7)
          (part-of fastener-8 tube)
          (part-of hoozawhatsie-3 tube)
          (part-of contraption-4 tube)
          (part-of unit-1 tube)
          (part-of doodad-2 tube)
          (part-of hack tube)
          (part-of coil kludge)
          (part-of sprocket kludge)
          (part-of foobar kludge)
          (part-of fastener kludge)
          (part-of contraption kludge)
          (part-of whatsis kludge)
          (part-of gimcrack hoozawhatsie)
          (part-of wire hoozawhatsie)
          (part-of widget gimcrack)
          (part-of unit gimcrack)
          (part-of device wire)
          (transient-part widget wire)
          (part-of bracket socket)
          (part-of connector socket)
          (part-of plug bracket)
          (part-of doodad bracket)
          (part-of valve connector)
          (part-of thingumbob connector)
          (assemble-order frob-7 kludge mount)
          (assemble-order frob-7 tube mount)
          (assemble-order tube hoozawhatsie mount)
          (assemble-order socket kludge mount)
          (assemble-order foobar-5 bracket-6 hack-15)
          (assemble-order foobar-5 bracket-6 hack-15)
          (assemble-order sprocket-16 foobar-5 frob-7)
          (assemble-order foobar-5 bracket-6 frob-7)
          (assemble-order foobar-5 bracket-6 frob-7)
          (remove-order bracket-6 foobar-5 frob-7)
          (assemble-order fastener-8 contraption-4 tube)
          (assemble-order contraption-4 hoozawhatsie-3 tube)
          (assemble-order unit-1 doodad-2 tube)
          (assemble-order doodad-2 contraption-4 tube)
          (assemble-order widget device gimcrack)
          (assemble-order widget device gimcrack)
          (assemble-order widget device wire)
          (assemble-order widget device wire)
          (remove-order device widget wire)
          (assemble-order connector bracket socket))
   (:goal (complete mount)))

(define (problem assem-x-10)
   (:domain assembly)
   (:objects wire thingumbob-15 bracket-12 whatsis-13 wire-14
             sprocket-7 widget-16 coil-5 frob-6 whatsis unit-8 hack-3
             contraption-4 valve-1 foobar-2 gimcrack connector device foobar
             widget bracket mount thingumbob tube valve unit sprocket coil
             kludge contraption hoozawhatsie socket doodad hack frob plug
             fastener - assembly
             pliers - resource)
   (:init (available bracket-12)
          (available whatsis-13)
          (available wire-14)
          (available widget-16)
          (available coil-5)
          (available frob-6)
          (available unit-8)
          (available hack-3)
          (available contraption-4)
          (available valve-1)
          (available foobar-2)
          (available gimcrack)
          (available device)
          (available foobar)
          (available bracket)
          (available mount)
          (available thingumbob)
          (available valve)
          (available unit)
          (available sprocket)
          (available coil)
          (available kludge)
          (available contraption)
          (available socket)
          (available doodad)
          (available frob)
          (available plug)
          (available fastener)
          (available pliers)
          (requires thingumbob-15 pliers)
          (requires whatsis pliers)
          (requires connector pliers)
          (requires tube pliers)
          (requires hoozawhatsie pliers)
          (part-of thingumbob-15 wire)
          (part-of sprocket-7 wire)
          (part-of whatsis wire)
          (part-of connector wire)
          (part-of tube wire)
          (part-of hoozawhatsie wire)
          (part-of doodad thingumbob-15)
          (part-of bracket-12 thingumbob-15)
          (part-of whatsis-13 thingumbob-15)
          (part-of wire-14 thingumbob-15)
          (part-of widget-16 sprocket-7)
          (part-of coil-5 sprocket-7)
          (part-of frob-6 sprocket-7)
          (part-of unit-8 whatsis)
          (part-of hack-3 whatsis)
          (part-of contraption-4 whatsis)
          (part-of valve-1 whatsis)
          (part-of foobar-2 whatsis)
          (part-of gimcrack whatsis)
          (part-of device connector)
          (part-of foobar connector)
          (part-of widget connector)
          (part-of bracket widget)
          (part-of mount widget)
          (part-of thingumbob widget)
          (part-of valve tube)
          (part-of unit tube)
          (part-of sprocket tube)
          (part-of coil tube)
          (part-of kludge tube)
          (part-of contraption tube)
          (part-of socket hoozawhatsie)
          (transient-part doodad hoozawhatsie)
          (part-of hack hoozawhatsie)
          (part-of frob hack)
          (part-of plug hack)
          (part-of fastener hack)
          (assemble-order thingumbob-15 sprocket-7 wire)
          (assemble-order sprocket-7 whatsis wire)
          (assemble-order whatsis connector wire)
          (assemble-order doodad socket thingumbob-15)
          (assemble-order doodad socket thingumbob-15)
          (assemble-order widget-16 frob-6 sprocket-7)
          (assemble-order foobar widget connector)
          (assemble-order widget device connector)
          (assemble-order bracket mount widget)
          (assemble-order bracket thingumbob widget)
          (assemble-order doodad socket hoozawhatsie)
          (assemble-order doodad socket hoozawhatsie)
          (remove-order socket doodad hoozawhatsie)
          (assemble-order plug frob hack)
          (assemble-order fastener plug hack))
   (:goal (complete wire)))

(define (problem assem-x-11)
   (:domain assembly)
   (:objects connector mount-9 doodad-10 valve-13 tube-11 coil-12
             hack-16 widget-14 hoozawhatsie-15 frob-7 foobar-5 bracket-6
             device gimcrack-8 wire-3 whatsis-4 fastener-1 connector-2
             valve widget gimcrack unit mount plug foobar whatsis sprocket
             kludge frob wire fastener socket bracket coil doodad
             contraption hack thingumbob tube - assembly
             scope scaffold - resource)
   (:init (available mount-9)
          (available doodad-10)
          (available tube-11)
          (available coil-12)
          (available widget-14)
          (available hoozawhatsie-15)
          (available foobar-5)
          (available bracket-6)
          (available gimcrack-8)
          (available wire-3)
          (available whatsis-4)
          (available fastener-1)
          (available connector-2)
          (available valve)
          (available gimcrack)
          (available unit)
          (available mount)
          (available foobar)
          (available whatsis)
          (available kludge)
          (available frob)
          (available wire)
          (available socket)
          (available bracket)
          (available doodad)
          (available contraption)
          (available hack)
          (available thingumbob)
          (available tube)
          (available scope)
          (available scaffold)
          (requires valve-13 scaffold)
          (requires hack-16 scaffold)
          (requires frob-7 scaffold)
          (requires widget scaffold)
          (requires plug scaffold)
          (requires sprocket scaffold)
          (requires fastener scaffold)
          (requires coil scaffold)
          (part-of mount-9 connector)
          (part-of doodad-10 connector)
          (part-of valve-13 connector)
          (part-of hack-16 connector)
          (part-of frob-7 connector)
          (part-of device connector)
          (part-of widget connector)
          (part-of plug connector)
          (part-of fastener connector)
          (part-of coil connector)
          (part-of tube-11 valve-13)
          (part-of coil-12 valve-13)
          (transient-part widget-14 hack-16)
          (part-of hoozawhatsie-15 hack-16)
          (part-of foobar-5 frob-7)
          (part-of bracket-6 frob-7)
          (part-of gimcrack-8 device)
          (part-of wire-3 device)
          (part-of whatsis-4 device)
          (part-of fastener-1 device)
          (part-of connector-2 device)
          (part-of valve device)
          (part-of gimcrack widget)
          (part-of unit widget)
          (part-of mount widget)
          (part-of foobar plug)
          (part-of whatsis plug)
          (part-of sprocket plug)
          (part-of kludge sprocket)
          (part-of frob sprocket)
          (part-of wire sprocket)
          (part-of socket fastener)
          (part-of bracket fastener)
          (part-of widget-14 coil)
          (part-of doodad coil)
          (part-of contraption coil)
          (part-of hack coil)
          (part-of thingumbob coil)
          (part-of tube coil)
          (assemble-order mount-9 doodad-10 connector)
          (assemble-order valve-13 fastener connector)
          (assemble-order frob-7 fastener connector)
          (assemble-order frob-7 doodad-10 connector)
          (assemble-order device hack-16 connector)
          (assemble-order plug hack-16 connector)
          (assemble-order fastener coil connector)
          (assemble-order fastener device connector)
          (assemble-order coil-12 tube-11 valve-13)
          (assemble-order widget-14 hoozawhatsie-15 hack-16)
          (remove-order hoozawhatsie-15 widget-14 hack-16)
          (assemble-order bracket-6 foobar-5 frob-7)
          (assemble-order gimcrack-8 wire-3 device)
          (assemble-order whatsis-4 valve device)
          (assemble-order whatsis-4 gimcrack-8 device)
          (assemble-order whatsis-4 connector-2 device)
          (assemble-order fastener-1 valve device)
          (assemble-order unit gimcrack widget)
          (assemble-order mount gimcrack widget)
          (assemble-order whatsis sprocket plug)
          (assemble-order sprocket foobar plug)
          (assemble-order frob wire sprocket)
          (assemble-order socket bracket fastener)
          (assemble-order widget-14 hoozawhatsie-15 coil)
          (assemble-order thingumbob doodad coil)
          (assemble-order thingumbob widget-14 coil))
   (:goal (complete connector)))

(define (problem assem-x-12)
   (:domain assembly)
   (:objects hack foobar-10 contraption-32 bracket-9 whatsis-14
             socket-11 widget-12 coil-13 thingumbob-7 valve-15 mount-16
             tube-5 connector-6 kludge-2 plug-8 sprocket-1
             hoozawhatsie-3 unit-4 whatsis wire thingumbob coil widget connector
             device fastener socket foobar plug kludge doodad unit mount
             gimcrack valve bracket tube sprocket frob contraption
             - assembly
             hammer hammock - resource)
   (:init (available contraption-32)
          (available bracket-9)
          (available socket-11)
          (available widget-12)
          (available coil-13)
          (available valve-15)
          (available mount-16)
          (available tube-5)
          (available connector-6)
          (available plug-8)
          (available hoozawhatsie-3)
          (available unit-4)
          (available wire)
          (available thingumbob)
          (available coil)
          (available widget)
          (available connector)
          (available fastener)
          (available socket)
          (available foobar)
          (available plug)
          (available kludge)
          (available doodad)
          (available mount)
          (available gimcrack)
          (available bracket)
          (available tube)
          (available sprocket)
          (available frob)
          (available contraption)
          (available hammer)
          (available hammock)
          (requires foobar-10 hammock)
          (requires whatsis-14 hammock)
          (requires thingumbob-7 hammock)
          (requires kludge-2 hammer)
          (requires sprocket-1 hammock)
          (requires whatsis hammock)
          (requires device hammock)
          (requires unit hammer)
          (requires valve hammock)
          (part-of foobar-10 hack)
          (part-of whatsis-14 hack)
          (part-of thingumbob-7 hack)
          (part-of kludge-2 hack)
          (part-of whatsis hack)
          (part-of device hack)
          (part-of unit hack)
          (part-of valve hack)
          (part-of hoozawhatsie foobar-10)
          (part-of contraption-32 foobar-10)
          (part-of bracket-9 foobar-10)
          (part-of socket-11 whatsis-14)
          (part-of widget-12 whatsis-14)
          (part-of coil-13 whatsis-14)
          (part-of valve-15 thingumbob-7)
          (part-of mount-16 thingumbob-7)
          (part-of tube-5 thingumbob-7)
          (part-of connector-6 thingumbob-7)
          (part-of plug-8 kludge-2)
          (part-of sprocket-1 kludge-2)
          (part-of hoozawhatsie-3 sprocket-1)
          (part-of unit-4 sprocket-1)
          (part-of wire whatsis)
          (part-of thingumbob whatsis)
          (part-of coil whatsis)
          (part-of widget whatsis)
          (part-of connector whatsis)
          (part-of fastener device)
          (part-of socket device)
          (part-of foobar device)
          (part-of plug device)
          (part-of kludge device)
          (part-of doodad device)
          (transient-part mount unit)
          (part-of gimcrack unit)
          (part-of mount valve)
          (part-of bracket valve)
          (part-of tube valve)
          (part-of sprocket valve)
          (part-of frob valve)
          (part-of contraption valve)
          (assemble-order hoozawhatsie frob foobar-10)
          (assemble-order widget-12 socket-11 whatsis-14)
          (assemble-order coil-13 widget-12 whatsis-14)
          (assemble-order connector-6 mount-16 thingumbob-7)
          (assemble-order thingumbob wire whatsis)
          (assemble-order thingumbob connector whatsis)
          (assemble-order widget connector whatsis)
          (assemble-order widget wire whatsis)
          (assemble-order fastener doodad device)
          (assemble-order socket plug device)
          (assemble-order foobar doodad device)
          (assemble-order plug kludge device)
          (assemble-order plug doodad device)
          (assemble-order mount gimcrack unit)
          (assemble-order mount gimcrack unit)
          (remove-order gimcrack mount unit)
          (assemble-order mount gimcrack valve)
          (assemble-order mount gimcrack valve)
          (remove-order frob mount valve))
   (:goal (complete hack)))

(define (problem assem-x-13)
   (:domain assembly)
   (:objects frob sprocket-32 hack-29 fastener-31 plug-14
             whatsis-9 contraption-10 tube-11 connector-12 foobar-13
             mount-7 device-15 thingumbob-16 widget-5 doodad-6 plug coil-8
             gimcrack-3 valve-4 socket-1 hoozawhatsie-2 device whatsis
             sprocket kludge valve wire contraption widget thingumbob mount
             foobar socket hoozawhatsie hack unit - assembly
             voltmeter - resource)
   (:init (available hack-29)
          (available fastener-31)
          (available whatsis-9)
          (available contraption-10)
          (available tube-11)
          (available connector-12)
          (available foobar-13)
          (available device-15)
          (available thingumbob-16)
          (available widget-5)
          (available doodad-6)
          (available coil-8)
          (available gimcrack-3)
          (available valve-4)
          (available socket-1)
          (available hoozawhatsie-2)
          (available device)
          (available sprocket)
          (available valve)
          (available wire)
          (available contraption)
          (available thingumbob)
          (available foobar)
          (available socket)
          (available hoozawhatsie)
          (available hack)
          (available unit)
          (available voltmeter)
          (requires plug-14 voltmeter)
          (requires mount-7 voltmeter)
          (requires plug voltmeter)
          (requires whatsis voltmeter)
          (requires widget voltmeter)
          (requires mount voltmeter)
          (part-of sprocket-32 frob)
          (part-of plug-14 frob)
          (part-of mount-7 frob)
          (part-of plug frob)
          (part-of whatsis frob)
          (part-of widget frob)
          (part-of mount frob)
          (part-of hack-29 sprocket-32)
          (part-of socket sprocket-32)
          (part-of fastener-31 sprocket-32)
          (part-of whatsis-9 plug-14)
          (transient-part contraption-10 plug-14)
          (part-of tube-11 plug-14)
          (part-of connector-12 plug-14)
          (part-of foobar-13 plug-14)
          (transient-part device-15 mount-7)
          (part-of thingumbob-16 mount-7)
          (part-of widget-5 mount-7)
          (part-of doodad-6 mount-7)
          (transient-part coil-8 plug)
          (part-of gimcrack-3 plug)
          (transient-part valve-4 plug)
          (part-of socket-1 plug)
          (transient-part hoozawhatsie-2 plug)
          (part-of device plug)
          (part-of sprocket whatsis)
          (part-of device-15 whatsis)
          (part-of kludge whatsis)
          (part-of valve kludge)
          (part-of wire kludge)
          (part-of contraption kludge)
          (part-of thingumbob widget)
          (part-of valve-4 widget)
          (part-of coil-8 widget)
          (part-of foobar mount)
          (transient-part socket mount)
          (part-of hoozawhatsie-2 mount)
          (part-of hoozawhatsie mount)
          (part-of hack mount)
          (part-of unit mount)
          (assemble-order sprocket-32 whatsis frob)
          (assemble-order plug-14 mount-7 frob)
          (assemble-order plug mount-7 frob)
          (assemble-order plug sprocket-32 frob)
          (assemble-order socket hoozawhatsie-2 sprocket-32)
          (assemble-order contraption-10 whatsis-9 plug-14)
          (remove-order whatsis-9 contraption-10 plug-14)
          (assemble-order device-15 doodad-6 mount-7)
          (remove-order doodad-6 device-15 mount-7)
          (assemble-order widget-5 device-15 mount-7)
          (assemble-order widget-5 doodad-6 mount-7)
          (assemble-order coil-8 hoozawhatsie-2 plug)
          (assemble-order coil-8 gimcrack-3 plug)
          (remove-order hoozawhatsie-2 coil-8 plug)
          (assemble-order valve-4 gimcrack-3 plug)
          (remove-order gimcrack-3 valve-4 plug)
          (assemble-order socket-1 coil-8 plug)
          (assemble-order hoozawhatsie-2 gimcrack-3 plug)
          (remove-order gimcrack-3 hoozawhatsie-2 plug)
          (assemble-order device hoozawhatsie-2 plug)
          (assemble-order device-15 doodad-6 whatsis)
          (assemble-order contraption valve kludge)
          (assemble-order valve-4 gimcrack-3 widget)
          (assemble-order coil-8 hoozawhatsie-2 widget)
          (assemble-order coil-8 gimcrack-3 widget)
          (assemble-order socket hoozawhatsie-2 mount)
          (remove-order tube socket mount)
          (assemble-order hoozawhatsie-2 gimcrack-3 mount))
   (:goal (complete frob)))

(define (problem assem-x-14)
   (:domain assembly)
   (:objects frob whatsis-27 connector-28 kludge-9 coil-29
             thingumbob-30 bracket-31 wire-32 device-16 doodad-11 tube-15
             fastener-12 frob-13 valve-14 socket-1 contraption-5 hack-6
             sprocket-7 widget-3 mount-4 widget sprocket whatsis doodad
             hoozawhatsie kludge bracket hack valve socket contraption plug coil
             device connector wire thingumbob - assembly
             scalpel - resource)
   (:init (available whatsis-27)
          (available connector-28)
          (available coil-29)
          (available thingumbob-30)
          (available bracket-31)
          (available wire-32)
          (available doodad-11)
          (available fastener-12)
          (available frob-13)
          (available valve-14)
          (available contraption-5)
          (available hack-6)
          (available sprocket-7)
          (available widget-3)
          (available mount-4)
          (available whatsis)
          (available doodad)
          (available kludge)
          (available bracket)
          (available hack)
          (available socket)
          (available coil)
          (available device)
          (available wire)
          (available thingumbob)
          (available scalpel)
          (requires kludge-9 scalpel)
          (requires device-16 scalpel)
          (requires socket-1 scalpel)
          (requires widget scalpel)
          (requires sprocket scalpel)
          (requires valve scalpel)
          (requires contraption scalpel)
          (part-of whatsis-27 frob)
          (part-of connector-28 frob)
          (part-of kludge-9 frob)
          (part-of device-16 frob)
          (part-of socket-1 frob)
          (part-of widget frob)
          (part-of sprocket frob)
          (part-of valve frob)
          (part-of contraption frob)
          (part-of coil-29 kludge-9)
          (part-of thingumbob-30 kludge-9)
          (transient-part bracket-31 kludge-9)
          (transient-part wire-32 kludge-9)
          (part-of hack-6 device-16)
          (part-of doodad-11 device-16)
          (part-of tube-15 device-16)
          (part-of fastener-12 tube-15)
          (part-of frob-13 tube-15)
          (part-of valve-14 tube-15)
          (part-of contraption-5 socket-1)
          (transient-part hack-6 socket-1)
          (part-of sprocket-7 socket-1)
          (part-of wire-32 socket-1)
          (part-of widget-3 socket-1)
          (transient-part mount-4 socket-1)
          (part-of mount-4 widget)
          (part-of foobar widget)
          (part-of whatsis sprocket)
          (transient-part doodad sprocket)
          (part-of hoozawhatsie sprocket)
          (part-of kludge hoozawhatsie)
          (part-of bracket hoozawhatsie)
          (part-of hack hoozawhatsie)
          (part-of socket valve)
          (part-of doodad valve)
          (part-of bracket-31 valve)
          (part-of plug contraption)
          (part-of connector contraption)
          (part-of coil plug)
          (part-of device plug)
          (part-of wire connector)
          (part-of thingumbob connector)
          (assemble-order connector-28 sprocket frob)
          (assemble-order sprocket widget frob)
          (assemble-order valve socket-1 frob)
          (assemble-order contraption socket-1 frob)
          (assemble-order bracket-31 coil-29 kludge-9)
          (remove-order coil-29 bracket-31 kludge-9)
          (assemble-order wire-32 bracket-31 kludge-9)
          (remove-order bracket-31 wire-32 kludge-9)
          (assemble-order hack-6 sprocket-7 device-16)
          (assemble-order hack-6 sprocket-7 socket-1)
          (remove-order sprocket-7 hack-6 socket-1)
          (assemble-order wire-32 bracket-31 socket-1)
          (assemble-order mount-4 sprocket-7 socket-1)
          (remove-order sprocket-7 mount-4 socket-1)
          (assemble-order mount-4 sprocket-7 widget)
          (assemble-order foobar bracket-31 widget)
          (assemble-order whatsis doodad sprocket)
          (assemble-order whatsis hoozawhatsie sprocket)
          (assemble-order doodad hoozawhatsie sprocket)
          (remove-order hoozawhatsie doodad sprocket)
          (assemble-order kludge bracket hoozawhatsie)
          (assemble-order hack kludge hoozawhatsie)
          (assemble-order socket doodad valve)
          (assemble-order doodad hoozawhatsie valve)
          (remove-order mount doodad valve)
          (assemble-order bracket-31 coil-29 valve)
          (assemble-order plug connector contraption))
   (:goal (complete frob)))

(define (problem assem-x-15)
   (:domain assembly)
   (:objects foobar unit-27 frob-25 tube-26 thingumbob-9
             sprocket-28 kludge-29 socket-32 device-30 whatsis-31 gimcrack-12
             hack-10 coil-11 plug-7 widget-13 valve-14 mount-6 bracket-15
             wire-16 hoozawhatsie-5 contraption doodad-8 foobar-3
             connector-4 fastener-1 contraption-2 doodad valve wire unit kludge
             hack socket coil sprocket widget hoozawhatsie gimcrack
             whatsis frob thingumbob bracket connector fastener plug
             - assembly
             tweezers hammer - resource)
   (:init (available frob-25)
          (available tube-26)
          (available sprocket-28)
          (available kludge-29)
          (available device-30)
          (available whatsis-31)
          (available hack-10)
          (available coil-11)
          (available widget-13)
          (available valve-14)
          (available bracket-15)
          (available wire-16)
          (available hoozawhatsie-5)
          (available doodad-8)
          (available foobar-3)
          (available connector-4)
          (available fastener-1)
          (available contraption-2)
          (available doodad)
          (available unit)
          (available kludge)
          (available coil)
          (available sprocket)
          (available hoozawhatsie)
          (available gimcrack)
          (available frob)
          (available thingumbob)
          (available bracket)
          (available connector)
          (available fastener)
          (available plug)
          (available tweezers)
          (available hammer)
          (requires unit-27 hammer)
          (requires thingumbob-9 hammer)
          (requires socket-32 hammer)
          (requires plug-7 tweezers)
          (requires mount-6 hammer)
          (requires contraption hammer)
          (requires valve hammer)
          (requires wire hammer)
          (requires hack hammer)
          (requires socket hammer)
          (requires widget hammer)
          (requires whatsis tweezers)
          (part-of unit-27 foobar)
          (part-of thingumbob-9 foobar)
          (part-of gimcrack-12 foobar)
          (part-of plug-7 foobar)
          (part-of contraption foobar)
          (part-of valve foobar)
          (part-of hack foobar)
          (part-of whatsis foobar)
          (part-of frob-25 unit-27)
          (part-of tube-26 unit-27)
          (part-of sprocket-28 thingumbob-9)
          (part-of kludge-29 thingumbob-9)
          (part-of socket-32 thingumbob-9)
          (part-of device-30 socket-32)
          (part-of whatsis-31 socket-32)
          (part-of hack-10 gimcrack-12)
          (part-of coil-11 gimcrack-12)
          (part-of widget-13 plug-7)
          (part-of valve-14 plug-7)
          (part-of mount-6 plug-7)
          (part-of bracket-15 mount-6)
          (part-of wire-16 mount-6)
          (part-of hoozawhatsie-5 mount-6)
          (part-of doodad-8 contraption)
          (part-of foobar-3 contraption)
          (part-of connector-4 contraption)
          (part-of fastener-1 contraption)
          (part-of contraption-2 contraption)
          (part-of doodad contraption)
          (part-of connector valve)
          (part-of wire valve)
          (part-of unit wire)
          (part-of kludge wire)
          (part-of socket hack)
          (part-of widget hack)
          (part-of coil socket)
          (part-of sprocket socket)
          (part-of hoozawhatsie widget)
          (part-of gimcrack widget)
          (part-of frob whatsis)
          (part-of thingumbob whatsis)
          (part-of bracket whatsis)
          (transient-part connector whatsis)
          (part-of fastener whatsis)
          (part-of plug whatsis)
          (assemble-order thingumbob-9 gimcrack-12 foobar)
          (assemble-order thingumbob-9 contraption foobar)
          (assemble-order plug-7 contraption foobar)
          (assemble-order contraption unit-27 foobar)
          (assemble-order hack contraption foobar)
          (assemble-order whatsis gimcrack-12 foobar)
          (assemble-order whatsis contraption foobar)
          (assemble-order whatsis-31 device-30 socket-32)
          (assemble-order widget-13 valve-14 plug-7)
          (assemble-order wire-16 bracket-15 mount-6)
          (assemble-order hoozawhatsie-5 wire-16 mount-6)
          (assemble-order doodad-8 contraption-2 contraption)
          (assemble-order fastener-1 contraption-2 contraption)
          (assemble-order contraption-2 doodad contraption)
          (assemble-order contraption-2 foobar-3 contraption)
          (assemble-order connector plug valve)
          (assemble-order wire connector valve)
          (assemble-order kludge unit wire)
          (assemble-order widget socket hack)
          (assemble-order coil sprocket socket)
          (assemble-order thingumbob connector whatsis)
          (assemble-order thingumbob bracket whatsis)
          (assemble-order connector plug whatsis)
          (remove-order plug connector whatsis))
   (:goal (complete foobar)))

(define (problem assem-x-16)
   (:domain assembly)
   (:objects connector unit-26 hoozawhatsie-23 socket-24
             contraption-25 frob-32 device-27 valve-28 mount-31 doodad-29 tube-30
             hoozawhatsie-15 kludge-9 hack-10 foobar-14 thingumbob-11
             connector-12 sprocket-13 whatsis-7 wire-16 widget-5 coil-6
             thingumbob bracket-8 fastener-3 gimcrack-4 plug-1 socket-2
             kludge sprocket bracket coil contraption doodad mount
             gimcrack frob hack foobar widget whatsis hoozawhatsie fastener
             valve unit device wire socket tube - assembly
             hammer tweezers scalpel - resource)
   (:init (available hoozawhatsie-23)
          (available socket-24)
          (available contraption-25)
          (available device-27)
          (available valve-28)
          (available doodad-29)
          (available tube-30)
          (available kludge-9)
          (available hack-10)
          (available thingumbob-11)
          (available connector-12)
          (available sprocket-13)
          (available wire-16)
          (available widget-5)
          (available coil-6)
          (available bracket-8)
          (available fastener-3)
          (available gimcrack-4)
          (available plug-1)
          (available socket-2)
          (available kludge)
          (available bracket)
          (available coil)
          (available contraption)
          (available doodad)
          (available mount)
          (available gimcrack)
          (available hack)
          (available foobar)
          (available whatsis)
          (available hoozawhatsie)
          (available fastener)
          (available device)
          (available wire)
          (available tube)
          (available hammer)
          (available tweezers)
          (available scalpel)
          (requires unit-26 scalpel)
          (requires frob-32 scalpel)
          (requires mount-31 tweezers)
          (requires hoozawhatsie-15 scalpel)
          (requires foobar-14 tweezers)
          (requires whatsis-7 tweezers)
          (requires thingumbob hammer)
          (requires sprocket hammer)
          (requires frob scalpel)
          (requires widget scalpel)
          (requires valve tweezers)
          (requires unit scalpel)
          (requires socket scalpel)
          (part-of unit-26 connector)
          (part-of frob-32 connector)
          (part-of hoozawhatsie-15 connector)
          (part-of whatsis-7 connector)
          (part-of thingumbob connector)
          (part-of sprocket connector)
          (part-of frob connector)
          (part-of valve connector)
          (part-of hoozawhatsie-23 unit-26)
          (part-of socket-24 unit-26)
          (part-of contraption-25 unit-26)
          (part-of device-27 frob-32)
          (part-of valve-28 frob-32)
          (part-of mount-31 frob-32)
          (part-of doodad-29 mount-31)
          (part-of tube-30 mount-31)
          (part-of kludge-9 hoozawhatsie-15)
          (part-of hack-10 hoozawhatsie-15)
          (part-of foobar-14 hoozawhatsie-15)
          (part-of thingumbob-11 foobar-14)
          (part-of connector-12 foobar-14)
          (part-of sprocket-13 foobar-14)
          (part-of wire-16 whatsis-7)
          (part-of widget-5 whatsis-7)
          (part-of coil-6 whatsis-7)
          (part-of bracket-8 thingumbob)
          (part-of fastener-3 thingumbob)
          (part-of gimcrack-4 thingumbob)
          (part-of plug-1 thingumbob)
          (part-of socket-2 thingumbob)
          (part-of kludge thingumbob)
          (part-of bracket sprocket)
          (part-of coil sprocket)
          (part-of contraption sprocket)
          (part-of doodad sprocket)
          (part-of mount sprocket)
          (part-of gimcrack sprocket)
          (part-of hack frob)
          (part-of foobar frob)
          (part-of widget frob)
          (part-of whatsis widget)
          (part-of hoozawhatsie widget)
          (part-of fastener widget)
          (part-of unit valve)
          (part-of socket valve)
          (part-of device unit)
          (transient-part wire unit)
          (part-of tube socket)
          (part-of wire socket)
          (assemble-order hoozawhatsie-15 frob-32 connector)
          (assemble-order whatsis-7 frob connector)
          (assemble-order thingumbob unit-26 connector)
          (assemble-order socket-24 contraption-25 unit-26)
          (assemble-order contraption-25 hoozawhatsie-23 unit-26)
          (assemble-order valve-28 device-27 frob-32)
          (assemble-order doodad-29 tube-30 mount-31)
          (assemble-order thingumbob-11 sprocket-13 foobar-14)
          (assemble-order widget-5 coil-6 whatsis-7)
          (assemble-order fastener-3 plug-1 thingumbob)
          (assemble-order plug-1 bracket-8 thingumbob)
          (assemble-order socket-2 fastener-3 thingumbob)
          (assemble-order kludge bracket-8 thingumbob)
          (assemble-order kludge gimcrack-4 thingumbob)
          (assemble-order hack foobar frob)
          (assemble-order wire device unit)
          (remove-order device wire unit)
          (assemble-order wire device socket))
   (:goal (complete connector)))

(define (problem assem-x-17)
   (:domain assembly)
   (:objects hoozawhatsie socket-23 unit-22 frob-26 connector-24
             tube-25 connector-29 device-27 valve-28 foobar-32 widget-30
             whatsis-31 bracket-15 hoozawhatsie-9 kludge-10 socket-11
             coil-12 unit-13 fastener-14 hack-7 wire-16 doodad-5 plug-6
             doodad gimcrack-4 contraption-8 thingumbob-3 device mount-1
             sprocket-2 gimcrack hack valve tube frob plug foobar connector
             fastener unit kludge whatsis mount thingumbob sprocket wire
             - assembly
             charger hammer - resource)
   (:init (available unit-22)
          (available connector-24)
          (available tube-25)
          (available device-27)
          (available valve-28)
          (available widget-30)
          (available whatsis-31)
          (available hoozawhatsie-9)
          (available kludge-10)
          (available socket-11)
          (available coil-12)
          (available unit-13)
          (available fastener-14)
          (available wire-16)
          (available doodad-5)
          (available plug-6)
          (available contraption-8)
          (available thingumbob-3)
          (available mount-1)
          (available sprocket-2)
          (available hack)
          (available valve)
          (available tube)
          (available frob)
          (available plug)
          (available foobar)
          (available fastener)
          (available unit)
          (available kludge)
          (available whatsis)
          (available mount)
          (available thingumbob)
          (available wire)
          (available charger)
          (available hammer)
          (requires socket-23 hammer)
          (requires frob-26 hammer)
          (requires connector-29 charger)
          (requires foobar-32 charger)
          (requires bracket-15 charger)
          (requires hack-7 hammer)
          (requires doodad charger)
          (requires gimcrack-4 hammer)
          (requires device hammer)
          (requires gimcrack charger)
          (requires connector hammer)
          (requires sprocket charger)
          (part-of socket-23 hoozawhatsie)
          (part-of frob-26 hoozawhatsie)
          (part-of connector-29 hoozawhatsie)
          (part-of foobar-32 hoozawhatsie)
          (part-of bracket-15 hoozawhatsie)
          (part-of hack-7 hoozawhatsie)
          (part-of doodad hoozawhatsie)
          (part-of gimcrack hoozawhatsie)
          (part-of connector hoozawhatsie)
          (part-of sprocket hoozawhatsie)
          (part-of fastener-14 socket-23)
          (part-of unit-22 socket-23)
          (part-of connector-24 frob-26)
          (part-of tube-25 frob-26)
          (part-of device-27 connector-29)
          (part-of valve-28 connector-29)
          (part-of widget-30 foobar-32)
          (part-of whatsis-31 foobar-32)
          (part-of hoozawhatsie-9 bracket-15)
          (part-of kludge-10 bracket-15)
          (part-of socket-11 bracket-15)
          (part-of coil-12 bracket-15)
          (part-of unit-13 bracket-15)
          (transient-part fastener-14 bracket-15)
          (part-of wire-16 hack-7)
          (part-of doodad-5 hack-7)
          (part-of plug-6 hack-7)
          (part-of gimcrack-4 doodad)
          (part-of device doodad)
          (part-of contraption-8 gimcrack-4)
          (part-of thingumbob-3 gimcrack-4)
          (part-of mount-1 device)
          (part-of sprocket-2 device)
          (part-of hack gimcrack)
          (part-of valve gimcrack)
          (part-of tube gimcrack)
          (part-of frob gimcrack)
          (part-of plug gimcrack)
          (transient-part foobar gimcrack)
          (part-of fastener connector)
          (part-of unit connector)
          (part-of kludge connector)
          (transient-part whatsis connector)
          (part-of mount connector)
          (part-of thingumbob connector)
          (part-of wire sprocket)
          (part-of foobar sprocket)
          (part-of whatsis sprocket)
          (assemble-order fastener-14 unit-13 socket-23)
          (assemble-order fastener-14 coil-12 socket-23)
          (assemble-order fastener-14 unit-13 socket-23)
          (assemble-order device-27 valve-28 connector-29)
          (assemble-order widget-30 whatsis-31 foobar-32)
          (assemble-order hoozawhatsie-9 unit-13 bracket-15)
          (assemble-order hoozawhatsie-9 coil-12 bracket-15)
          (assemble-order unit-13 socket-11 bracket-15)
          (assemble-order fastener-14 unit-13 bracket-15)
          (assemble-order fastener-14 coil-12 bracket-15)
          (assemble-order fastener-14 unit-13 bracket-15)
          (remove-order unit-13 fastener-14 bracket-15)
          (assemble-order device gimcrack-4 doodad)
          (assemble-order contraption-8 thingumbob-3 gimcrack-4)
          (assemble-order valve hack gimcrack)
          (assemble-order frob plug gimcrack)
          (assemble-order frob foobar gimcrack)
          (assemble-order foobar plug gimcrack)
          (assemble-order foobar hack gimcrack)
          (assemble-order foobar plug gimcrack)
          (remove-order plug foobar gimcrack)
          (assemble-order whatsis kludge connector)
          (remove-order kludge whatsis connector)
          (assemble-order foobar plug sprocket)
          (assemble-order foobar hack sprocket)
          (assemble-order foobar plug sprocket)
          (assemble-order whatsis kludge sprocket))
   (:goal (complete hoozawhatsie)))

(define (problem assem-x-18)
   (:domain assembly)
   (:objects connector connector-23 plug-19 coil-20 tube-21
             gimcrack-22 thingumbob-29 frob-24 frob-25 hack-28 unit-26 tube-27
             bracket-12 widget-30 connector-31 gimcrack-32 valve-9 device-10
             doodad-11 wire-7 contraption-15 coil-13 kludge-14 sprocket-6
             mount-5 sprocket hoozawhatsie-8 whatsis-3 plug-4 socket-1
             fastener-2 tube gimcrack valve device plug frob unit hack mount wire
             doodad socket kludge widget coil fastener foobar whatsis
             hoozawhatsie thingumbob contraption bracket - assembly
             scalpel clamp hammock - resource)
   (:init (available plug-19)
          (available coil-20)
          (available tube-21)
          (available gimcrack-22)
          (available frob-24)
          (available frob-25)
          (available unit-26)
          (available tube-27)
          (available widget-30)
          (available connector-31)
          (available gimcrack-32)
          (available valve-9)
          (available device-10)
          (available doodad-11)
          (available coil-13)
          (available kludge-14)
          (available mount-5)
          (available hoozawhatsie-8)
          (available whatsis-3)
          (available plug-4)
          (available socket-1)
          (available fastener-2)
          (available tube)
          (available valve)
          (available device)
          (available plug)
          (available frob)
          (available unit)
          (available hack)
          (available doodad)
          (available socket)
          (available widget)
          (available coil)
          (available foobar)
          (available whatsis)
          (available hoozawhatsie)
          (available thingumbob)
          (available contraption)
          (available bracket)
          (available scalpel)
          (available clamp)
          (available hammock)
          (requires connector-23 clamp)
          (requires thingumbob-29 scalpel)
          (requires hack-28 hammock)
          (requires bracket-12 clamp)
          (requires wire-7 scalpel)
          (requires contraption-15 clamp)
          (requires sprocket-6 hammock)
          (requires sprocket scalpel)
          (requires gimcrack scalpel)
          (requires mount clamp)
          (requires wire clamp)
          (requires kludge clamp)
          (requires fastener hammock)
          (part-of connector-23 connector)
          (part-of thingumbob-29 connector)
          (part-of bracket-12 connector)
          (part-of wire-7 connector)
          (part-of sprocket connector)
          (part-of gimcrack connector)
          (part-of mount connector)
          (part-of fastener connector)
          (part-of plug-19 connector-23)
          (part-of coil-20 connector-23)
          (part-of tube-21 connector-23)
          (part-of gimcrack-22 connector-23)
          (part-of frob-24 thingumbob-29)
          (part-of frob-25 thingumbob-29)
          (part-of hack-28 thingumbob-29)
          (part-of unit-26 hack-28)
          (part-of tube-27 hack-28)
          (part-of widget-30 bracket-12)
          (part-of connector-31 bracket-12)
          (part-of gimcrack-32 bracket-12)
          (part-of valve-9 bracket-12)
          (part-of device-10 bracket-12)
          (part-of doodad-11 bracket-12)
          (part-of contraption-15 wire-7)
          (part-of sprocket-6 wire-7)
          (transient-part coil-13 contraption-15)
          (part-of kludge-14 contraption-15)
          (part-of coil-13 sprocket-6)
          (part-of mount-5 sprocket-6)
          (part-of hoozawhatsie-8 sprocket)
          (part-of whatsis-3 sprocket)
          (part-of plug-4 sprocket)
          (part-of socket-1 sprocket)
          (part-of fastener-2 sprocket)
          (part-of tube sprocket)
          (part-of valve gimcrack)
          (part-of device gimcrack)
          (part-of plug gimcrack)
          (part-of frob gimcrack)
          (part-of unit gimcrack)
          (part-of hack gimcrack)
          (part-of wire mount)
          (part-of kludge mount)
          (part-of doodad wire)
          (part-of socket wire)
          (part-of widget kludge)
          (part-of coil kludge)
          (part-of foobar fastener)
          (part-of whatsis fastener)
          (part-of hoozawhatsie fastener)
          (part-of thingumbob fastener)
          (part-of contraption fastener)
          (part-of bracket fastener)
          (assemble-order thingumbob-29 fastener connector)
          (assemble-order bracket-12 fastener connector)
          (assemble-order bracket-12 gimcrack connector)
          (assemble-order gimcrack thingumbob-29 connector)
          (assemble-order mount wire-7 connector)
          (assemble-order fastener sprocket connector)
          (assemble-order frob-25 frob-24 thingumbob-29)
          (assemble-order tube-27 unit-26 hack-28)
          (assemble-order widget-30 connector-31 bracket-12)
          (assemble-order connector-31 doodad-11 bracket-12)
          (assemble-order valve-9 gimcrack-32 bracket-12)
          (assemble-order device-10 connector-31 bracket-12)
          (assemble-order coil-13 kludge-14 contraption-15)
          (assemble-order coil-13 kludge-14 contraption-15)
          (remove-order kludge-14 coil-13 contraption-15)
          (assemble-order coil-13 kludge-14 sprocket-6)
          (assemble-order coil-13 kludge-14 sprocket-6)
          (assemble-order mount-5 coil-13 sprocket-6)
          (assemble-order whatsis-3 fastener-2 sprocket)
          (assemble-order plug-4 socket-1 sprocket)
          (assemble-order tube whatsis-3 sprocket)
          (assemble-order kludge wire mount)
          (assemble-order whatsis contraption fastener)
          (assemble-order hoozawhatsie contraption fastener))
   (:goal (complete connector)))

(define (problem assem-x-19)
   (:domain assembly)
   (:objects unit plug-20 mount-17 whatsis-18 connector-19
             device-24 valve-21 widget-22 bracket-23 plug-31 gimcrack-25
             doodad-27 kludge-28 hoozawhatsie-29 contraption-30 device-13
             sprocket-32 valve-10 socket-11 foobar-12 connector-8 frob-14
             fastener-15 hack-16 coil-5 widget-6 bracket-7 bracket
             thingumbob-3 wire-4 hoozawhatsie mount-1 tube-2 kludge wire valve
             connector doodad gimcrack foobar plug hack fastener contraption
             - assembly
             voltmeter hammock - resource)
   (:init (available mount-17)
          (available whatsis-18)
          (available connector-19)
          (available valve-21)
          (available widget-22)
          (available bracket-23)
          (available gimcrack-25)
          (available doodad-27)
          (available kludge-28)
          (available hoozawhatsie-29)
          (available contraption-30)
          (available sprocket-32)
          (available valve-10)
          (available socket-11)
          (available foobar-12)
          (available frob-14)
          (available fastener-15)
          (available hack-16)
          (available coil-5)
          (available widget-6)
          (available bracket-7)
          (available thingumbob-3)
          (available wire-4)
          (available mount-1)
          (available tube-2)
          (available kludge)
          (available valve)
          (available gimcrack)
          (available plug)
          (available hack)
          (available contraption)
          (available voltmeter)
          (available hammock)
          (requires plug-31 hammock)
          (requires device-13 hammock)
          (requires connector-8 hammock)
          (requires bracket hammock)
          (requires hoozawhatsie hammock)
          (requires wire hammock)
          (requires connector hammock)
          (requires doodad hammock)
          (requires foobar voltmeter)
          (requires fastener hammock)
          (part-of plug-20 unit)
          (part-of device-24 unit)
          (part-of plug-31 unit)
          (part-of device-13 unit)
          (part-of connector-8 unit)
          (part-of bracket unit)
          (part-of wire unit)
          (part-of connector unit)
          (part-of foobar unit)
          (part-of fastener unit)
          (part-of mount-17 plug-20)
          (part-of whatsis-18 plug-20)
          (transient-part connector-19 plug-20)
          (part-of valve-21 device-24)
          (transient-part widget-22 device-24)
          (part-of bracket-23 device-24)
          (part-of gimcrack-25 plug-31)
          (part-of connector-19 plug-31)
          (transient-part doodad-27 plug-31)
          (part-of kludge-28 plug-31)
          (part-of hoozawhatsie-29 plug-31)
          (part-of contraption-30 plug-31)
          (transient-part sprocket-32 device-13)
          (part-of device device-13)
          (part-of valve-10 device-13)
          (part-of socket-11 device-13)
          (part-of foobar-12 device-13)
          (part-of frob-14 connector-8)
          (part-of fastener-15 connector-8)
          (part-of hack-16 connector-8)
          (part-of coil-5 connector-8)
          (part-of widget-6 connector-8)
          (part-of bracket-7 connector-8)
          (part-of thingumbob-3 bracket)
          (part-of wire-4 bracket)
          (part-of hoozawhatsie bracket)
          (part-of mount-1 hoozawhatsie)
          (part-of tube-2 hoozawhatsie)
          (part-of kludge hoozawhatsie)
          (part-of plug wire)
          (part-of valve wire)
          (part-of doodad connector)
          (part-of sprocket-32 connector)
          (part-of gimcrack doodad)
          (part-of socket doodad)
          (transient-part plug foobar)
          (part-of hack foobar)
          (part-of doodad-27 foobar)
          (part-of contraption fastener)
          (part-of widget-22 fastener)
          (assemble-order connector-8 connector unit)
          (assemble-order fastener plug-20 unit)
          (assemble-order mount-17 whatsis-18 plug-20)
          (assemble-order connector-19 mount-17 plug-20)
          (remove-order mount-17 connector-19 plug-20)
          (assemble-order widget-22 valve-21 device-24)
          (assemble-order widget-22 valve-21 device-24)
          (remove-order valve-21 widget-22 device-24)
          (assemble-order bracket-23 widget-22 device-24)
          (assemble-order gimcrack-25 connector-19 plug-31)
          (assemble-order gimcrack-25 doodad-27 plug-31)
          (assemble-order connector-19 mount-17 plug-31)
          (assemble-order doodad-27 hoozawhatsie-29 plug-31)
          (remove-order hoozawhatsie-29 doodad-27 plug-31)
          (assemble-order contraption-30 kludge-28 plug-31)
          (assemble-order sprocket-32 valve-10 device-13)
          (assemble-order sprocket-32 socket-11 device-13)
          (remove-order valve-10 sprocket-32 device-13)
          (assemble-order device doodad device-13)
          (assemble-order foobar-12 valve-10 device-13)
          (assemble-order kludge tube-2 hoozawhatsie)
          (assemble-order plug hack wire)
          (assemble-order sprocket-32 valve-10 connector)
          (assemble-order sprocket-32 socket-11 connector)
          (remove-order doodad sprocket-32 connector)
          (assemble-order socket thingumbob doodad)
          (assemble-order plug hack foobar)
          (remove-order hack plug foobar)
          (assemble-order doodad-27 hoozawhatsie-29 foobar)
          (assemble-order widget-22 valve-21 fastener)
          (assemble-order widget-22 valve-21 fastener))
   (:goal (complete unit)))

(define (problem assem-x-20)
   (:domain assembly)
   (:objects unit bracket-21 fastener-17 plug-63 wire-64
             connector-20 doodad-18 unit-19 contraption-28 hack-22 socket-23
             contraption-24 sprocket-25 mount-26 doodad-27 socket-10 hack-29
             widget-30 thingumbob-9 frob-31 whatsis-32 unit-15 gimcrack-11
             hoozawhatsie-12 wire-13 bracket-14 connector-4 valve-16 plug-5
             foobar-6 device-7 fastener-8 coil-3 tube kludge-1 tube-2
             gimcrack thingumbob widget coil frob hack whatsis mount
             hoozawhatsie foobar fastener wire connector bracket device kludge
             contraption socket doodad plug valve - assembly
             scope scaffold pliers - resource)
   (:init (available plug-63)
          (available wire-64)
          (available doodad-18)
          (available unit-19)
          (available hack-22)
          (available socket-23)
          (available contraption-24)
          (available sprocket-25)
          (available mount-26)
          (available doodad-27)
          (available hack-29)
          (available widget-30)
          (available frob-31)
          (available whatsis-32)
          (available gimcrack-11)
          (available hoozawhatsie-12)
          (available wire-13)
          (available bracket-14)
          (available valve-16)
          (available plug-5)
          (available foobar-6)
          (available device-7)
          (available fastener-8)
          (available coil-3)
          (available kludge-1)
          (available tube-2)
          (available thingumbob)
          (available widget)
          (available frob)
          (available hack)
          (available whatsis)
          (available hoozawhatsie)
          (available foobar)
          (available fastener)
          (available wire)
          (available connector)
          (available bracket)
          (available kludge)
          (available contraption)
          (available socket)
          (available doodad)
          (available plug)
          (available valve)
          (available scope)
          (available scaffold)
          (available pliers)
          (requires bracket-21 pliers)
          (requires fastener-17 scaffold)
          (requires connector-20 pliers)
          (requires contraption-28 pliers)
          (requires socket-10 scope)
          (requires thingumbob-9 scaffold)
          (requires unit-15 pliers)
          (requires connector-4 pliers)
          (requires tube scaffold)
          (requires gimcrack scaffold)
          (requires mount scaffold)
          (requires device pliers)
          (part-of bracket-21 unit)
          (part-of contraption-28 unit)
          (part-of socket-10 unit)
          (part-of unit-15 unit)
          (part-of connector-4 unit)
          (part-of tube unit)
          (part-of gimcrack unit)
          (part-of mount unit)
          (part-of device unit)
          (part-of fastener-17 bracket-21)
          (part-of connector-20 bracket-21)
          (part-of plug-63 fastener-17)
          (part-of wire-64 fastener-17)
          (part-of doodad-18 connector-20)
          (part-of unit-19 connector-20)
          (part-of hack-22 contraption-28)
          (part-of socket-23 contraption-28)
          (part-of contraption-24 contraption-28)
          (part-of sprocket-25 contraption-28)
          (part-of mount-26 contraption-28)
          (part-of doodad-27 contraption-28)
          (part-of hack-29 socket-10)
          (part-of widget-30 socket-10)
          (part-of thingumbob-9 socket-10)
          (part-of frob-31 thingumbob-9)
          (part-of whatsis-32 thingumbob-9)
          (part-of gimcrack-11 unit-15)
          (part-of hoozawhatsie-12 unit-15)
          (part-of wire-13 unit-15)
          (part-of bracket-14 unit-15)
          (part-of valve-16 connector-4)
          (part-of plug-5 connector-4)
          (part-of foobar-6 connector-4)
          (part-of device-7 connector-4)
          (part-of fastener-8 connector-4)
          (part-of coil-3 connector-4)
          (part-of kludge-1 tube)
          (part-of tube-2 tube)
          (part-of coil tube)
          (part-of thingumbob gimcrack)
          (part-of widget gimcrack)
          (transient-part coil gimcrack)
          (part-of frob coil)
          (part-of hack coil)
          (part-of whatsis coil)
          (part-of hoozawhatsie mount)
          (part-of foobar mount)
          (part-of fastener mount)
          (part-of wire mount)
          (part-of connector mount)
          (part-of bracket mount)
          (part-of kludge device)
          (part-of contraption device)
          (part-of socket device)
          (part-of doodad device)
          (part-of plug device)
          (part-of valve device)
          (assemble-order fastener-17 connector-20 bracket-21)
          (assemble-order widget-30 hack-29 socket-10)
          (assemble-order hoozawhatsie-12 gimcrack-11 unit-15)
          (assemble-order bracket-14 wire-13 unit-15)
          (assemble-order bracket-14 hoozawhatsie-12 unit-15)
          (assemble-order foobar-6 valve-16 connector-4)
          (assemble-order coil-3 fastener-8 connector-4)
          (assemble-order coil-3 foobar-6 connector-4)
          (assemble-order kludge-1 tube-2 tube)
          (assemble-order kludge-1 coil tube)
          (assemble-order coil thingumbob tube)
          (assemble-order coil thingumbob tube)
          (assemble-order thingumbob widget gimcrack)
          (assemble-order coil thingumbob gimcrack)
          (assemble-order coil thingumbob gimcrack)
          (remove-order thingumbob coil gimcrack)
          (assemble-order hack frob coil)
          (assemble-order whatsis frob coil)
          (assemble-order hoozawhatsie connector mount)
          (assemble-order fastener connector mount)
          (assemble-order bracket connector mount)
          (assemble-order contraption plug device)
          (assemble-order contraption doodad device)
          (assemble-order contraption socket device)
          (assemble-order plug socket device))
   (:goal (complete unit)))

(define (problem assem-x-21)
   (:domain assembly)
   (:objects hack thingumbob-61 unit-62 wire-18 hoozawhatsie-63
             connector-64 bracket-17 socket-24 device-19 coil-20 valve-23
             mount-21 kludge-22 bracket-31 mount-25 plug-26
             hoozawhatsie-30 device-27 unit-28 valve-29 kludge-12 widget-32
             contraption-9 thingumbob-10 foobar-11 gimcrack-7 whatsis-13
             socket-14 connector-15 sprocket-16 frob-5 fastener-6 bracket
             wire-8 doodad-3 tube-4 hack-1 coil-2 hoozawhatsie fastener
             coil socket plug device mount kludge frob contraption unit
             tube whatsis foobar valve gimcrack thingumbob sprocket wire
             doodad connector widget - assembly
             scalpel file - resource)
   (:init (available thingumbob-61)
          (available unit-62)
          (available hoozawhatsie-63)
          (available connector-64)
          (available bracket-17)
          (available device-19)
          (available coil-20)
          (available mount-21)
          (available kludge-22)
          (available mount-25)
          (available plug-26)
          (available device-27)
          (available unit-28)
          (available valve-29)
          (available widget-32)
          (available contraption-9)
          (available thingumbob-10)
          (available foobar-11)
          (available whatsis-13)
          (available socket-14)
          (available connector-15)
          (available sprocket-16)
          (available frob-5)
          (available fastener-6)
          (available wire-8)
          (available doodad-3)
          (available tube-4)
          (available hack-1)
          (available coil-2)
          (available hoozawhatsie)
          (available coil)
          (available socket)
          (available plug)
          (available device)
          (available mount)
          (available kludge)
          (available contraption)
          (available unit)
          (available tube)
          (available whatsis)
          (available foobar)
          (available valve)
          (available thingumbob)
          (available sprocket)
          (available wire)
          (available doodad)
          (available connector)
          (available widget)
          (available scalpel)
          (available file)
          (requires wire-18 scalpel)
          (requires socket-24 scalpel)
          (requires valve-23 file)
          (requires hoozawhatsie-30 scalpel)
          (requires kludge-12 scalpel)
          (requires gimcrack-7 scalpel)
          (requires bracket scalpel)
          (requires frob scalpel)
          (requires gimcrack scalpel)
          (part-of thingumbob-61 hack)
          (part-of unit-62 hack)
          (part-of wire-18 hack)
          (part-of socket-24 hack)
          (part-of bracket-31 hack)
          (part-of kludge-12 hack)
          (part-of gimcrack-7 hack)
          (part-of bracket hack)
          (part-of fastener hack)
          (part-of frob hack)
          (part-of gimcrack hack)
          (part-of hoozawhatsie-63 wire-18)
          (part-of connector-64 wire-18)
          (part-of bracket-17 wire-18)
          (part-of device-19 socket-24)
          (part-of coil-20 socket-24)
          (part-of valve-23 socket-24)
          (part-of mount-21 valve-23)
          (part-of kludge-22 valve-23)
          (part-of mount-25 bracket-31)
          (part-of plug-26 bracket-31)
          (part-of hoozawhatsie-30 bracket-31)
          (part-of device-27 hoozawhatsie-30)
          (part-of unit-28 hoozawhatsie-30)
          (part-of valve-29 hoozawhatsie-30)
          (part-of widget-32 kludge-12)
          (part-of contraption-9 kludge-12)
          (part-of thingumbob-10 kludge-12)
          (part-of foobar-11 kludge-12)
          (part-of whatsis-13 gimcrack-7)
          (part-of socket-14 gimcrack-7)
          (part-of connector-15 gimcrack-7)
          (part-of sprocket-16 gimcrack-7)
          (part-of frob-5 gimcrack-7)
          (part-of fastener-6 gimcrack-7)
          (part-of wire-8 bracket)
          (part-of doodad-3 bracket)
          (part-of tube-4 bracket)
          (part-of hack-1 bracket)
          (part-of coil-2 bracket)
          (part-of hoozawhatsie bracket)
          (part-of coil fastener)
          (part-of socket fastener)
          (part-of plug fastener)
          (part-of device fastener)
          (part-of mount fastener)
          (part-of kludge fastener)
          (part-of contraption frob)
          (part-of unit frob)
          (part-of tube frob)
          (part-of whatsis frob)
          (part-of foobar frob)
          (part-of valve frob)
          (part-of thingumbob gimcrack)
          (part-of sprocket gimcrack)
          (part-of wire gimcrack)
          (part-of doodad gimcrack)
          (part-of connector gimcrack)
          (part-of widget gimcrack)
          (assemble-order unit-62 fastener hack)
          (assemble-order wire-18 socket-24 hack)
          (assemble-order wire-18 kludge-12 hack)
          (assemble-order socket-24 thingumbob-61 hack)
          (assemble-order bracket-31 thingumbob-61 hack)
          (assemble-order gimcrack-7 wire-18 hack)
          (assemble-order gimcrack-7 kludge-12 hack)
          (assemble-order fastener bracket hack)
          (assemble-order fastener gimcrack-7 hack)
          (assemble-order gimcrack unit-62 hack)
          (assemble-order bracket-17 connector-64 wire-18)
          (assemble-order valve-23 coil-20 socket-24)
          (assemble-order kludge-22 mount-21 valve-23)
          (assemble-order mount-25 hoozawhatsie-30 bracket-31)
          (assemble-order plug-26 hoozawhatsie-30 bracket-31)
          (assemble-order unit-28 device-27 hoozawhatsie-30)
          (assemble-order valve-29 device-27 hoozawhatsie-30)
          (assemble-order socket-14 connector-15 gimcrack-7)
          (assemble-order sprocket thingumbob gimcrack)
          (assemble-order sprocket connector gimcrack)
          (assemble-order widget sprocket gimcrack))
   (:goal (complete hack)))

(define (problem assem-x-22)
   (:domain assembly)
   (:objects mount sprocket-17 wire-59 coil-60 connector-61
             tube-62 thingumbob-63 whatsis-64 hoozawhatsie-22 foobar-18
             hack-19 contraption-20 socket-21 tube-25 fastener-23
             bracket-24 thingumbob-30 sprocket-26 contraption-27 widget-28
             device-29 bracket-13 connector-31 valve-32 frob-9 whatsis-10
             plug-11 unit-12 doodad-8 socket-14 coil-15 hoozawhatsie-7
             fastener-16 kludge-5 hack-6 hoozawhatsie wire-3 mount-4
             gimcrack-1 foobar-2 coil thingumbob socket bracket kludge frob
             gimcrack wire unit connector contraption device foobar hack tube
             valve widget whatsis fastener sprocket doodad plug
             - assembly
             hammer - resource)
   (:init (available wire-59)
          (available coil-60)
          (available connector-61)
          (available tube-62)
          (available thingumbob-63)
          (available whatsis-64)
          (available foobar-18)
          (available hack-19)
          (available contraption-20)
          (available socket-21)
          (available fastener-23)
          (available bracket-24)
          (available sprocket-26)
          (available contraption-27)
          (available widget-28)
          (available device-29)
          (available connector-31)
          (available valve-32)
          (available frob-9)
          (available whatsis-10)
          (available plug-11)
          (available unit-12)
          (available socket-14)
          (available coil-15)
          (available fastener-16)
          (available kludge-5)
          (available hack-6)
          (available wire-3)
          (available mount-4)
          (available gimcrack-1)
          (available foobar-2)
          (available coil)
          (available socket)
          (available bracket)
          (available kludge)
          (available frob)
          (available gimcrack)
          (available wire)
          (available contraption)
          (available device)
          (available hack)
          (available tube)
          (available widget)
          (available whatsis)
          (available fastener)
          (available sprocket)
          (available doodad)
          (available plug)
          (available hammer)
          (requires sprocket-17 hammer)
          (requires hoozawhatsie-22 hammer)
          (requires tube-25 hammer)
          (requires thingumbob-30 hammer)
          (requires doodad-8 hammer)
          (requires hoozawhatsie hammer)
          (requires thingumbob hammer)
          (requires unit hammer)
          (requires valve hammer)
          (part-of sprocket-17 mount)
          (part-of hoozawhatsie-22 mount)
          (part-of tube-25 mount)
          (part-of thingumbob-30 mount)
          (part-of bracket-13 mount)
          (part-of doodad-8 mount)
          (part-of hoozawhatsie mount)
          (part-of thingumbob mount)
          (part-of unit mount)
          (part-of valve mount)
          (part-of wire-59 sprocket-17)
          (part-of coil-60 sprocket-17)
          (part-of connector-61 sprocket-17)
          (part-of tube-62 sprocket-17)
          (part-of thingumbob-63 sprocket-17)
          (part-of whatsis-64 sprocket-17)
          (part-of foobar-18 hoozawhatsie-22)
          (part-of hack-19 hoozawhatsie-22)
          (part-of contraption-20 hoozawhatsie-22)
          (part-of socket-21 hoozawhatsie-22)
          (part-of fastener-23 tube-25)
          (part-of bracket-24 tube-25)
          (part-of sprocket-26 thingumbob-30)
          (part-of contraption-27 thingumbob-30)
          (part-of widget-28 thingumbob-30)
          (part-of device-29 thingumbob-30)
          (part-of connector-31 bracket-13)
          (part-of valve-32 bracket-13)
          (part-of frob-9 bracket-13)
          (part-of whatsis-10 bracket-13)
          (part-of plug-11 bracket-13)
          (part-of unit-12 bracket-13)
          (part-of socket-14 doodad-8)
          (part-of coil-15 doodad-8)
          (part-of hoozawhatsie-7 doodad-8)
          (part-of fastener-16 hoozawhatsie-7)
          (part-of kludge-5 hoozawhatsie-7)
          (part-of hack-6 hoozawhatsie-7)
          (part-of wire-3 hoozawhatsie)
          (part-of mount-4 hoozawhatsie)
          (part-of gimcrack-1 hoozawhatsie)
          (part-of foobar-2 hoozawhatsie)
          (part-of coil hoozawhatsie)
          (part-of socket thingumbob)
          (part-of bracket thingumbob)
          (part-of kludge thingumbob)
          (part-of frob thingumbob)
          (part-of gimcrack thingumbob)
          (part-of wire thingumbob)
          (part-of connector unit)
          (part-of foobar unit)
          (part-of contraption connector)
          (part-of device connector)
          (part-of hack foobar)
          (part-of tube foobar)
          (part-of widget valve)
          (part-of whatsis valve)
          (part-of fastener valve)
          (part-of sprocket valve)
          (part-of doodad valve)
          (part-of plug valve)
          (assemble-order sprocket-17 bracket-13 mount)
          (assemble-order hoozawhatsie valve mount)
          (assemble-order wire-59 tube-62 sprocket-17)
          (assemble-order connector-61 coil-60 sprocket-17)
          (assemble-order tube-62 coil-60 sprocket-17)
          (assemble-order tube-62 connector-61 sprocket-17)
          (assemble-order hack-19 socket-21 hoozawhatsie-22)
          (assemble-order hack-19 contraption-20 hoozawhatsie-22)
          (assemble-order fastener-23 bracket-24 tube-25)
          (assemble-order sprocket-26 widget-28 thingumbob-30)
          (assemble-order widget-28 device-29 thingumbob-30)
          (assemble-order widget-28 contraption-27 thingumbob-30)
          (assemble-order connector-31 valve-32 bracket-13)
          (assemble-order whatsis-10 connector-31 bracket-13)
          (assemble-order socket-14 hoozawhatsie-7 doodad-8)
          (assemble-order coil-15 hoozawhatsie-7 doodad-8)
          (assemble-order mount-4 coil hoozawhatsie)
          (assemble-order socket wire thingumbob)
          (assemble-order bracket gimcrack thingumbob)
          (assemble-order bracket frob thingumbob)
          (assemble-order connector foobar unit)
          (assemble-order contraption device connector)
          (assemble-order tube hack foobar)
          (assemble-order doodad sprocket valve))
   (:goal (complete mount)))

(define (problem assem-x-23)
   (:domain assembly)
   (:objects tube mount-17 device-57 hoozawhatsie-58 widget-59
             thingumbob-60 tube-61 coil-62 connector-63 foobar-64 whatsis-22
             kludge-18 unit-21 contraption-19 socket-20 kludge-29
             fastener-23 wire-24 wire-28 gimcrack-25 frob-26 whatsis-27
             bracket-12 foobar-30 contraption-31 mount-11 tube-32
             connector-9 socket-10 unit-7 doodad-13 fastener-14 device-15
             plug-16 coil-5 widget-6 frob hoozawhatsie-4 sprocket-8
             sprocket hack-1 valve-2 unit contraption widget hoozawhatsie
             foobar plug fastener device coil thingumbob bracket doodad
             valve wire hack whatsis kludge gimcrack mount socket
             connector - assembly
             clamp scope - resource)
   (:init (available device-57)
          (available hoozawhatsie-58)
          (available widget-59)
          (available thingumbob-60)
          (available tube-61)
          (available coil-62)
          (available connector-63)
          (available foobar-64)
          (available kludge-18)
          (available contraption-19)
          (available socket-20)
          (available fastener-23)
          (available wire-24)
          (available gimcrack-25)
          (available frob-26)
          (available whatsis-27)
          (available foobar-30)
          (available contraption-31)
          (available tube-32)
          (available connector-9)
          (available socket-10)
          (available doodad-13)
          (available fastener-14)
          (available device-15)
          (available plug-16)
          (available coil-5)
          (available widget-6)
          (available sprocket-8)
          (available hack-1)
          (available valve-2)
          (available contraption)
          (available widget)
          (available foobar)
          (available plug)
          (available fastener)
          (available coil)
          (available thingumbob)
          (available bracket)
          (available doodad)
          (available valve)
          (available wire)
          (available kludge)
          (available gimcrack)
          (available socket)
          (available connector)
          (available clamp)
          (available scope)
          (requires mount-17 scope)
          (requires whatsis-22 clamp)
          (requires unit-21 scope)
          (requires kludge-29 clamp)
          (requires wire-28 scope)
          (requires bracket-12 scope)
          (requires mount-11 scope)
          (requires unit-7 scope)
          (requires frob scope)
          (requires hoozawhatsie-4 scope)
          (requires sprocket scope)
          (requires unit scope)
          (requires hoozawhatsie scope)
          (requires device clamp)
          (requires hack clamp)
          (requires whatsis scope)
          (requires mount scope)
          (part-of mount-17 tube)
          (part-of whatsis-22 tube)
          (part-of kludge-29 tube)
          (part-of bracket-12 tube)
          (part-of unit-7 tube)
          (part-of frob tube)
          (part-of unit tube)
          (part-of device tube)
          (part-of hack tube)
          (part-of device-57 mount-17)
          (part-of hoozawhatsie-58 mount-17)
          (part-of widget-59 mount-17)
          (part-of thingumbob-60 mount-17)
          (part-of tube-61 mount-17)
          (part-of coil-62 mount-17)
          (part-of connector-63 mount-17)
          (part-of foobar-64 mount-17)
          (part-of kludge-18 whatsis-22)
          (part-of unit-21 whatsis-22)
          (part-of contraption-19 unit-21)
          (part-of socket-20 unit-21)
          (part-of fastener-23 kludge-29)
          (part-of wire-24 kludge-29)
          (part-of wire-28 kludge-29)
          (part-of gimcrack-25 wire-28)
          (part-of frob-26 wire-28)
          (part-of whatsis-27 wire-28)
          (part-of foobar-30 bracket-12)
          (part-of contraption-31 bracket-12)
          (part-of mount-11 bracket-12)
          (part-of tube-32 mount-11)
          (part-of connector-9 mount-11)
          (part-of socket-10 mount-11)
          (part-of doodad-13 unit-7)
          (part-of fastener-14 unit-7)
          (part-of device-15 unit-7)
          (part-of plug-16 unit-7)
          (part-of coil-5 unit-7)
          (part-of widget-6 unit-7)
          (part-of hoozawhatsie-4 frob)
          (part-of sprocket frob)
          (part-of sprocket-8 hoozawhatsie-4)
          (part-of valve-2 hoozawhatsie-4)
          (part-of hack-1 sprocket)
          (transient-part valve-2 sprocket)
          (part-of contraption unit)
          (part-of widget unit)
          (part-of hoozawhatsie unit)
          (part-of foobar hoozawhatsie)
          (part-of plug hoozawhatsie)
          (part-of fastener hoozawhatsie)
          (part-of coil device)
          (part-of thingumbob device)
          (part-of bracket device)
          (part-of doodad device)
          (part-of valve device)
          (part-of wire device)
          (part-of whatsis hack)
          (part-of mount hack)
          (part-of kludge whatsis)
          (part-of gimcrack whatsis)
          (part-of socket mount)
          (part-of connector mount)
          (assemble-order mount-17 unit tube)
          (assemble-order whatsis-22 frob tube)
          (assemble-order kludge-29 unit tube)
          (assemble-order bracket-12 hack tube)
          (assemble-order unit-7 hack tube)
          (assemble-order hack device tube)
          (assemble-order hack mount-17 tube)
          (assemble-order hoozawhatsie-58 widget-59 mount-17)
          (assemble-order thingumbob-60 device-57 mount-17)
          (assemble-order tube-61 device-57 mount-17)
          (assemble-order gimcrack-25 frob-26 wire-28)
          (assemble-order foobar-30 contraption-31 bracket-12)
          (assemble-order doodad-13 plug-16 unit-7)
          (assemble-order plug-16 coil-5 unit-7)
          (assemble-order plug-16 fastener-14 unit-7)
          (assemble-order widget-6 plug-16 unit-7)
          (assemble-order widget-6 device-15 unit-7)
          (assemble-order valve-2 hack-1 hoozawhatsie-4)
          (assemble-order valve-2 hack-1 sprocket)
          (remove-order hack-1 valve-2 sprocket)
          (assemble-order fastener foobar hoozawhatsie)
          (assemble-order fastener plug hoozawhatsie)
          (assemble-order bracket thingumbob device)
          (assemble-order bracket doodad device)
          (assemble-order valve bracket device)
          (assemble-order valve doodad device)
          (assemble-order whatsis mount hack))
   (:goal (complete tube)))

(define (problem assem-x-24)
   (:domain assembly)
   (:objects widget doodad-63 connector-57 wire-55
             hoozawhatsie-56 plug-62 hack-58 frob-59 fastener-60 valve-61
             sprocket-22 gimcrack-18 device-64 bracket-17 mount-21 coil-19
             whatsis-20 wire-29 tube-23 foobar-24 kludge-25 thingumbob-26
             socket-27 whatsis-28 contraption-12 unit-30 sprocket-31
             hack-32 tube-9 widget-10 coil-11 frob-7 plug-13 connector-14
             foobar-15 valve-16 mount-5 fastener-6 device device-8
             hoozawhatsie-3 plug bracket-4 gimcrack-1 doodad-2 contraption valve
             mount doodad hoozawhatsie sprocket whatsis kludge coil
             connector wire hack bracket tube gimcrack foobar socket unit
             fastener thingumbob - assembly
             hammer scope - resource)
   (:init (available wire-55)
          (available hoozawhatsie-56)
          (available hack-58)
          (available frob-59)
          (available fastener-60)
          (available valve-61)
          (available device-64)
          (available bracket-17)
          (available coil-19)
          (available whatsis-20)
          (available tube-23)
          (available foobar-24)
          (available kludge-25)
          (available thingumbob-26)
          (available socket-27)
          (available whatsis-28)
          (available unit-30)
          (available sprocket-31)
          (available hack-32)
          (available tube-9)
          (available widget-10)
          (available coil-11)
          (available plug-13)
          (available connector-14)
          (available foobar-15)
          (available valve-16)
          (available mount-5)
          (available fastener-6)
          (available device-8)
          (available hoozawhatsie-3)
          (available bracket-4)
          (available gimcrack-1)
          (available doodad-2)
          (available valve)
          (available mount)
          (available doodad)
          (available hoozawhatsie)
          (available sprocket)
          (available whatsis)
          (available coil)
          (available wire)
          (available hack)
          (available bracket)
          (available foobar)
          (available socket)
          (available fastener)
          (available thingumbob)
          (available hammer)
          (available scope)
          (requires doodad-63 hammer)
          (requires connector-57 scope)
          (requires plug-62 scope)
          (requires sprocket-22 scope)
          (requires gimcrack-18 scope)
          (requires mount-21 scope)
          (requires wire-29 scope)
          (requires contraption-12 scope)
          (requires frob-7 hammer)
          (requires device scope)
          (requires plug scope)
          (requires contraption hammer)
          (requires kludge scope)
          (requires connector scope)
          (requires tube hammer)
          (requires gimcrack scope)
          (part-of doodad-63 widget)
          (part-of sprocket-22 widget)
          (part-of wire-29 widget)
          (part-of contraption-12 widget)
          (part-of frob-7 widget)
          (part-of device widget)
          (part-of contraption widget)
          (part-of kludge widget)
          (part-of tube widget)
          (part-of connector-57 doodad-63)
          (part-of plug-62 doodad-63)
          (part-of wire-55 connector-57)
          (part-of hoozawhatsie-56 connector-57)
          (part-of hack-58 plug-62)
          (part-of frob-59 plug-62)
          (part-of fastener-60 plug-62)
          (part-of valve-61 plug-62)
          (part-of gimcrack-18 sprocket-22)
          (part-of mount-21 sprocket-22)
          (part-of device-64 gimcrack-18)
          (part-of bracket-17 gimcrack-18)
          (part-of coil-19 mount-21)
          (part-of whatsis-20 mount-21)
          (part-of tube-23 wire-29)
          (part-of foobar-24 wire-29)
          (part-of kludge-25 wire-29)
          (part-of thingumbob-26 wire-29)
          (part-of socket-27 wire-29)
          (part-of whatsis-28 wire-29)
          (part-of unit-30 contraption-12)
          (part-of sprocket-31 contraption-12)
          (part-of hack-32 contraption-12)
          (part-of tube-9 contraption-12)
          (part-of widget-10 contraption-12)
          (part-of coil-11 contraption-12)
          (part-of plug-13 frob-7)
          (part-of connector-14 frob-7)
          (part-of foobar-15 frob-7)
          (part-of valve-16 frob-7)
          (part-of mount-5 frob-7)
          (part-of fastener-6 frob-7)
          (part-of device-8 device)
          (part-of hoozawhatsie-3 device)
          (part-of plug device)
          (part-of bracket-4 plug)
          (part-of gimcrack-1 plug)
          (part-of doodad-2 plug)
          (part-of valve contraption)
          (part-of mount contraption)
          (part-of doodad contraption)
          (part-of hoozawhatsie contraption)
          (part-of sprocket contraption)
          (part-of whatsis contraption)
          (part-of unit kludge)
          (part-of coil kludge)
          (part-of connector kludge)
          (part-of wire connector)
          (part-of hack connector)
          (part-of bracket connector)
          (part-of gimcrack tube)
          (transient-part unit tube)
          (part-of foobar gimcrack)
          (part-of socket gimcrack)
          (part-of fastener unit)
          (part-of thingumbob unit)
          (assemble-order doodad-63 frob-7 widget)
          (assemble-order doodad-63 contraption-12 widget)
          (assemble-order sprocket-22 contraption-12 widget)
          (assemble-order sprocket-22 device widget)
          (assemble-order wire-29 contraption-12 widget)
          (assemble-order contraption device widget)
          (assemble-order tube contraption-12 widget)
          (assemble-order connector-57 plug-62 doodad-63)
          (assemble-order hoozawhatsie-56 wire-55 connector-57)
          (assemble-order mount-21 gimcrack-18 sprocket-22)
          (assemble-order whatsis-20 coil-19 mount-21)
          (assemble-order tube-23 thingumbob-26 wire-29)
          (assemble-order foobar-24 kludge-25 wire-29)
          (assemble-order thingumbob-26 foobar-24 wire-29)
          (assemble-order socket-27 foobar-24 wire-29)
          (assemble-order socket-27 whatsis-28 wire-29)
          (assemble-order sprocket-31 coil-11 contraption-12)
          (assemble-order hack-32 tube-9 contraption-12)
          (assemble-order hack-32 unit-30 contraption-12)
          (assemble-order coil-11 tube-9 contraption-12)
          (assemble-order plug-13 valve-16 frob-7)
          (assemble-order plug-13 connector-14 frob-7)
          (assemble-order plug-13 fastener-6 frob-7)
          (assemble-order mount-5 valve-16 frob-7)
          (assemble-order bracket-4 gimcrack-1 plug)
          (assemble-order bracket-4 doodad-2 plug)
          (assemble-order valve sprocket contraption)
          (assemble-order doodad mount contraption)
          (assemble-order sprocket doodad contraption)
          (assemble-order unit gimcrack kludge)
          (assemble-order unit gimcrack kludge)
          (assemble-order coil unit kludge)
          (assemble-order connector coil kludge)
          (assemble-order unit gimcrack tube)
          (assemble-order unit gimcrack tube)
          (remove-order gimcrack unit tube)
          (assemble-order foobar socket gimcrack)
          (assemble-order thingumbob fastener unit))
   (:goal (complete widget)))

(define (problem assem-x-25)
   (:domain assembly)
   (:objects gimcrack whatsis-57 doodad-53 gimcrack-54 socket-55
             wire-56 fastener-63 bracket-59 connector-60 kludge-61
             mount-62 widget-22 coil-64 device-17 frob-18 valve-20
             foobar-21 tube-29 contraption-25 unit-23 plug-24 unit-28
             doodad-27 gimcrack-12 whatsis-30 coil-31 foobar-32 sprocket-9
             device-10 hoozawhatsie-11 connector-7 widget-13 hack-14
             frob-15 bracket-16 plug-5 socket-6 hack fastener-8 wire-4
             kludge-1 mount-2 tube valve connector sprocket contraption
             device thingumbob widget whatsis fastener bracket plug
             hoozawhatsie unit wire coil kludge socket doodad mount frob foobar
             - assembly
             hammer scalpel - resource)
   (:init (available doodad-53)
          (available gimcrack-54)
          (available socket-55)
          (available wire-56)
          (available bracket-59)
          (available connector-60)
          (available kludge-61)
          (available mount-62)
          (available coil-64)
          (available device-17)
          (available frob-18)
          (available valve-20)
          (available foobar-21)
          (available unit-23)
          (available plug-24)
          (available doodad-27)
          (available whatsis-30)
          (available coil-31)
          (available foobar-32)
          (available sprocket-9)
          (available device-10)
          (available hoozawhatsie-11)
          (available widget-13)
          (available hack-14)
          (available frob-15)
          (available bracket-16)
          (available plug-5)
          (available socket-6)
          (available fastener-8)
          (available wire-4)
          (available kludge-1)
          (available mount-2)
          (available tube)
          (available sprocket)
          (available contraption)
          (available thingumbob)
          (available widget)
          (available fastener)
          (available bracket)
          (available hoozawhatsie)
          (available unit)
          (available wire)
          (available kludge)
          (available socket)
          (available doodad)
          (available mount)
          (available frob)
          (available foobar)
          (available hammer)
          (available scalpel)
          (requires whatsis-57 scalpel)
          (requires fastener-63 scalpel)
          (requires widget-22 scalpel)
          (requires tube-29 scalpel)
          (requires contraption-25 scalpel)
          (requires unit-28 scalpel)
          (requires gimcrack-12 hammer)
          (requires connector-7 hammer)
          (requires hack scalpel)
          (requires valve hammer)
          (requires connector scalpel)
          (requires device scalpel)
          (requires whatsis hammer)
          (requires coil hammer)
          (part-of whatsis-57 gimcrack)
          (part-of fastener-63 gimcrack)
          (part-of widget-22 gimcrack)
          (part-of tube-29 gimcrack)
          (part-of gimcrack-12 gimcrack)
          (part-of connector-7 gimcrack)
          (part-of hack gimcrack)
          (part-of valve gimcrack)
          (part-of whatsis gimcrack)
          (part-of coil gimcrack)
          (part-of doodad-53 whatsis-57)
          (part-of gimcrack-54 whatsis-57)
          (part-of socket-55 whatsis-57)
          (part-of wire-56 whatsis-57)
          (part-of foobar fastener-63)
          (part-of bracket-59 fastener-63)
          (part-of connector-60 fastener-63)
          (part-of kludge-61 fastener-63)
          (part-of mount-62 fastener-63)
          (part-of coil-64 widget-22)
          (part-of device-17 widget-22)
          (part-of frob-18 widget-22)
          (part-of bracket widget-22)
          (part-of valve-20 widget-22)
          (part-of foobar-21 widget-22)
          (part-of contraption-25 tube-29)
          (transient-part unit-28 tube-29)
          (part-of unit-23 contraption-25)
          (transient-part plug-24 contraption-25)
          (part-of plug-24 unit-28)
          (part-of doodad-27 unit-28)
          (part-of whatsis-30 gimcrack-12)
          (part-of coil-31 gimcrack-12)
          (part-of foobar-32 gimcrack-12)
          (part-of sprocket-9 gimcrack-12)
          (part-of device-10 gimcrack-12)
          (part-of hoozawhatsie-11 gimcrack-12)
          (part-of widget-13 connector-7)
          (part-of hack-14 connector-7)
          (part-of frob-15 connector-7)
          (part-of bracket-16 connector-7)
          (part-of plug-5 connector-7)
          (part-of socket-6 connector-7)
          (part-of fastener-8 hack)
          (part-of unit-28 hack)
          (part-of wire-4 hack)
          (part-of kludge-1 hack)
          (part-of mount-2 hack)
          (part-of tube hack)
          (part-of connector valve)
          (part-of device valve)
          (part-of sprocket connector)
          (part-of contraption connector)
          (part-of thingumbob device)
          (part-of widget device)
          (part-of fastener whatsis)
          (transient-part bracket whatsis)
          (part-of plug whatsis)
          (part-of hoozawhatsie plug)
          (part-of unit plug)
          (part-of wire plug)
          (part-of kludge coil)
          (part-of socket coil)
          (part-of doodad coil)
          (part-of mount coil)
          (part-of frob coil)
          (transient-part foobar coil)
          (assemble-order whatsis-57 tube-29 gimcrack)
          (assemble-order widget-22 whatsis-57 gimcrack)
          (assemble-order gimcrack-12 hack gimcrack)
          (assemble-order gimcrack-12 valve gimcrack)
          (assemble-order coil gimcrack-12 gimcrack)
          (assemble-order coil whatsis-57 gimcrack)
          (assemble-order coil tube-29 gimcrack)
          (assemble-order foobar socket fastener-63)
          (assemble-order mount-62 foobar fastener-63)
          (assemble-order coil-64 valve-20 widget-22)
          (assemble-order device-17 frob-18 widget-22)
          (assemble-order bracket fastener widget-22)
          (assemble-order valve-20 foobar-21 widget-22)
          (assemble-order valve-20 frob-18 widget-22)
          (assemble-order unit-28 contraption-25 tube-29)
          (remove-order contraption-25 unit-28 tube-29)
          (assemble-order plug-24 unit-23 contraption-25)
          (remove-order unit-23 plug-24 contraption-25)
          (assemble-order plug-24 unit-23 unit-28)
          (assemble-order doodad-27 plug-24 unit-28)
          (assemble-order whatsis-30 device-10 gimcrack-12)
          (assemble-order device-10 foobar-32 gimcrack-12)
          (assemble-order hoozawhatsie-11 sprocket-9 gimcrack-12)
          (assemble-order widget-13 bracket-16 connector-7)
          (assemble-order widget-13 plug-5 connector-7)
          (assemble-order plug-5 socket-6 connector-7)
          (assemble-order fastener-8 wire-4 hack)
          (assemble-order unit-28 contraption-25 hack)
          (assemble-order wire-4 unit-28 hack)
          (assemble-order kludge-1 tube hack)
          (assemble-order mount-2 unit-28 hack)
          (assemble-order mount-2 fastener-8 hack)
          (assemble-order sprocket contraption connector)
          (assemble-order widget thingumbob device)
          (assemble-order bracket fastener whatsis)
          (remove-order fastener bracket whatsis)
          (assemble-order plug bracket whatsis)
          (assemble-order unit hoozawhatsie plug)
          (assemble-order wire unit plug)
          (assemble-order foobar socket coil)
          (remove-order socket foobar coil))
   (:goal (complete gimcrack)))

(define (problem assem-x-26)
   (:domain assembly)
   (:objects valve unit-56 gimcrack-51 contraption-52 hack-53
             sprocket-54 thingumbob-55 fastener-60 valve-57 foobar-58
             socket-59 coil-64 widget-61 device-63 connector-20 mount-17
             whatsis-18 frob-19 whatsis-27 plug-21 hoozawhatsie-22 kludge-26
             wire-23 kludge-24 hoozawhatsie-25 valve-10 fastener-28
             foobar-29 thingumbob-9 socket-30 wire-31 bracket-32
             contraption-13 plug-12 hack-8 gimcrack-14 frob-15 tube-16 sprocket-5
             coil-7 unit-1 doodad-3 connector-4 hoozawhatsie device-2
             socket kludge frob widget hack wire thingumbob unit whatsis
             doodad gimcrack sprocket connector contraption foobar
             fastener mount bracket tube plug device coil - assembly
             scalpel - resource)
   (:init (available gimcrack-51)
          (available contraption-52)
          (available hack-53)
          (available sprocket-54)
          (available thingumbob-55)
          (available valve-57)
          (available foobar-58)
          (available socket-59)
          (available widget-61)
          (available device-63)
          (available mount-17)
          (available whatsis-18)
          (available frob-19)
          (available plug-21)
          (available hoozawhatsie-22)
          (available wire-23)
          (available kludge-24)
          (available hoozawhatsie-25)
          (available fastener-28)
          (available foobar-29)
          (available socket-30)
          (available wire-31)
          (available bracket-32)
          (available plug-12)
          (available gimcrack-14)
          (available frob-15)
          (available tube-16)
          (available sprocket-5)
          (available coil-7)
          (available doodad-3)
          (available connector-4)
          (available device-2)
          (available socket)
          (available kludge)
          (available frob)
          (available widget)
          (available hack)
          (available thingumbob)
          (available unit)
          (available whatsis)
          (available doodad)
          (available gimcrack)
          (available sprocket)
          (available contraption)
          (available foobar)
          (available fastener)
          (available mount)
          (available bracket)
          (available tube)
          (available device)
          (available coil)
          (available scalpel)
          (requires unit-56 scalpel)
          (requires fastener-60 scalpel)
          (requires coil-64 scalpel)
          (requires connector-20 scalpel)
          (requires whatsis-27 scalpel)
          (requires valve-10 scalpel)
          (requires contraption-13 scalpel)
          (requires hack-8 scalpel)
          (requires unit-1 scalpel)
          (requires wire scalpel)
          (requires connector scalpel)
          (requires plug scalpel)
          (part-of unit-56 valve)
          (part-of fastener-60 valve)
          (part-of coil-64 valve)
          (part-of connector-20 valve)
          (part-of whatsis-27 valve)
          (part-of valve-10 valve)
          (part-of contraption-13 valve)
          (part-of hack-8 valve)
          (part-of unit-1 valve)
          (part-of hoozawhatsie valve)
          (part-of wire valve)
          (part-of connector valve)
          (part-of plug valve)
          (part-of gimcrack-51 unit-56)
          (part-of contraption-52 unit-56)
          (part-of hack-53 unit-56)
          (part-of sprocket-54 unit-56)
          (part-of thingumbob-55 unit-56)
          (part-of valve-57 fastener-60)
          (transient-part foobar-58 fastener-60)
          (part-of socket-59 fastener-60)
          (part-of widget-61 coil-64)
          (part-of coil-7 coil-64)
          (part-of device-63 coil-64)
          (part-of mount-17 connector-20)
          (part-of whatsis-18 connector-20)
          (part-of frob-19 connector-20)
          (part-of plug-21 whatsis-27)
          (part-of hoozawhatsie-22 whatsis-27)
          (part-of kludge-26 whatsis-27)
          (part-of wire-23 kludge-26)
          (part-of kludge-24 kludge-26)
          (part-of hoozawhatsie-25 kludge-26)
          (part-of fastener-28 valve-10)
          (part-of foobar-29 valve-10)
          (part-of thingumbob-9 valve-10)
          (part-of socket-30 thingumbob-9)
          (part-of wire-31 thingumbob-9)
          (part-of bracket-32 thingumbob-9)
          (part-of foobar-58 contraption-13)
          (part-of plug-12 contraption-13)
          (part-of gimcrack-14 hack-8)
          (part-of frob-15 hack-8)
          (part-of tube-16 hack-8)
          (part-of sprocket-5 hack-8)
          (part-of whatsis hack-8)
          (transient-part coil-7 hack-8)
          (part-of doodad-3 unit-1)
          (part-of connector-4 unit-1)
          (part-of device-2 hoozawhatsie)
          (part-of socket hoozawhatsie)
          (part-of kludge hoozawhatsie)
          (part-of frob hoozawhatsie)
          (part-of widget hoozawhatsie)
          (part-of hack hoozawhatsie)
          (part-of thingumbob wire)
          (part-of unit wire)
          (transient-part whatsis wire)
          (part-of doodad wire)
          (part-of gimcrack wire)
          (part-of sprocket wire)
          (part-of contraption connector)
          (part-of foobar connector)
          (part-of fastener connector)
          (part-of mount connector)
          (part-of bracket connector)
          (part-of tube connector)
          (part-of device plug)
          (part-of coil plug)
          (assemble-order unit-1 hack-8 valve)
          (assemble-order hack-53 contraption-52 unit-56)
          (assemble-order sprocket-54 gimcrack-51 unit-56)
          (assemble-order foobar-58 valve-57 fastener-60)
          (remove-order valve-57 foobar-58 fastener-60)
          (assemble-order socket-59 foobar-58 fastener-60)
          (assemble-order coil-7 frob-15 coil-64)
          (assemble-order plug-21 kludge-26 whatsis-27)
          (assemble-order foobar-29 fastener-28 valve-10)
          (assemble-order thingumbob-9 fastener-28 valve-10)
          (assemble-order wire-31 socket-30 thingumbob-9)
          (assemble-order wire-31 bracket-32 thingumbob-9)
          (assemble-order foobar-58 valve-57 contraption-13)
          (assemble-order gimcrack-14 whatsis hack-8)
          (assemble-order tube-16 frob-15 hack-8)
          (assemble-order tube-16 coil-7 hack-8)
          (assemble-order whatsis sprocket hack-8)
          (assemble-order coil-7 frob-15 hack-8)
          (remove-order frob-15 coil-7 hack-8)
          (assemble-order device-2 hack hoozawhatsie)
          (assemble-order socket kludge hoozawhatsie)
          (assemble-order kludge device-2 hoozawhatsie)
          (assemble-order kludge frob hoozawhatsie)
          (assemble-order hack frob hoozawhatsie)
          (assemble-order whatsis sprocket wire)
          (remove-order sprocket whatsis wire)
          (assemble-order gimcrack unit wire)
          (assemble-order gimcrack sprocket wire)
          (assemble-order contraption fastener connector)
          (assemble-order foobar tube connector)
          (assemble-order fastener tube connector)
          (assemble-order bracket mount connector)
          (assemble-order bracket tube connector)
          (assemble-order coil device plug))
   (:goal (complete valve)))

(define (problem assem-x-27)
   (:domain assembly)
   (:objects connector frob-51 mount-49 tube-58 wire-52 kludge-53
             device-54 bracket-56 thingumbob-17 hack-59 valve-61 widget-62
             connector-63 unit-64 fastener-24 foobar-18 contraption-19 plug-21
             doodad-22 plug-31 bracket-25 whatsis-26 hoozawhatsie-27
             foobar-28 wire-29 connector-30 hack-14 doodad-32 device-9
             fastener-10 valve-11 tube-13 frob-3 sprocket-15 coil-16 kludge-5
             contraption-7 gimcrack-8 unit mount-4 unit-1 widget-2 thingumbob
             sprocket kludge widget valve wire tube socket device frob
             fastener bracket hoozawhatsie whatsis foobar gimcrack
             - assembly
             hammock scalpel voltmeter - resource)
   (:init (available mount-49)
          (available wire-52)
          (available kludge-53)
          (available device-54)
          (available bracket-56)
          (available hack-59)
          (available valve-61)
          (available widget-62)
          (available connector-63)
          (available unit-64)
          (available foobar-18)
          (available contraption-19)
          (available plug-21)
          (available doodad-22)
          (available bracket-25)
          (available whatsis-26)
          (available hoozawhatsie-27)
          (available foobar-28)
          (available wire-29)
          (available connector-30)
          (available doodad-32)
          (available device-9)
          (available fastener-10)
          (available valve-11)
          (available tube-13)
          (available sprocket-15)
          (available coil-16)
          (available kludge-5)
          (available contraption-7)
          (available gimcrack-8)
          (available mount-4)
          (available unit-1)
          (available widget-2)
          (available thingumbob)
          (available widget)
          (available valve)
          (available tube)
          (available frob)
          (available hoozawhatsie)
          (available foobar)
          (available gimcrack)
          (available hammock)
          (available scalpel)
          (available voltmeter)
          (requires frob-51 voltmeter)
          (requires tube-58 hammock)
          (requires thingumbob-17 voltmeter)
          (requires fastener-24 hammock)
          (requires plug-31 hammock)
          (requires hack-14 hammock)
          (requires frob-3 voltmeter)
          (requires unit voltmeter)
          (requires sprocket scalpel)
          (requires kludge scalpel)
          (requires wire voltmeter)
          (requires socket scalpel)
          (requires device voltmeter)
          (requires fastener hammock)
          (requires bracket scalpel)
          (part-of frob-51 connector)
          (part-of tube-58 connector)
          (part-of thingumbob-17 connector)
          (part-of fastener-24 connector)
          (part-of plug-31 connector)
          (part-of hack-14 connector)
          (part-of frob-3 connector)
          (part-of unit connector)
          (part-of sprocket connector)
          (part-of socket connector)
          (part-of fastener connector)
          (part-of mount-49 frob-51)
          (part-of contraption-7 frob-51)
          (part-of wire-52 tube-58)
          (part-of kludge-53 tube-58)
          (part-of device-54 tube-58)
          (part-of hoozawhatsie-27 tube-58)
          (transient-part bracket-56 tube-58)
          (part-of sprocket-15 tube-58)
          (part-of hack-59 thingumbob-17)
          (part-of device thingumbob-17)
          (part-of valve-61 thingumbob-17)
          (part-of widget-62 thingumbob-17)
          (part-of connector-63 thingumbob-17)
          (part-of unit-64 thingumbob-17)
          (part-of foobar-18 fastener-24)
          (part-of contraption-19 fastener-24)
          (part-of mount-4 fastener-24)
          (part-of plug-21 fastener-24)
          (transient-part doodad-22 fastener-24)
          (part-of kludge fastener-24)
          (part-of bracket-25 plug-31)
          (part-of whatsis-26 plug-31)
          (transient-part hoozawhatsie-27 plug-31)
          (transient-part foobar-28 plug-31)
          (part-of wire-29 plug-31)
          (part-of connector-30 plug-31)
          (part-of doodad-32 hack-14)
          (part-of device-9 hack-14)
          (part-of fastener-10 hack-14)
          (part-of valve-11 hack-14)
          (part-of bracket-56 hack-14)
          (part-of tube-13 hack-14)
          (transient-part sprocket-15 frob-3)
          (part-of coil-16 frob-3)
          (part-of kludge-5 frob-3)
          (part-of doodad-22 frob-3)
          (transient-part contraption-7 frob-3)
          (part-of gimcrack-8 frob-3)
          (transient-part mount-4 unit)
          (part-of unit-1 unit)
          (part-of widget-2 unit)
          (part-of thingumbob unit)
          (transient-part kludge sprocket)
          (part-of wire sprocket)
          (transient-part widget kludge)
          (part-of valve kludge)
          (part-of tube wire)
          (part-of widget wire)
          (part-of foobar-28 socket)
          (transient-part device socket)
          (part-of coil device)
          (part-of frob device)
          (part-of bracket fastener)
          (part-of whatsis fastener)
          (part-of hoozawhatsie bracket)
          (part-of foobar bracket)
          (transient-part foobar whatsis)
          (part-of gimcrack whatsis)
          (assemble-order plug-31 unit connector)
          (assemble-order frob-3 plug-31 connector)
          (assemble-order fastener frob-51 connector)
          (assemble-order fastener socket connector)
          (assemble-order contraption-7 gimcrack-8 frob-51)
          (assemble-order kludge-53 wire-52 tube-58)
          (assemble-order kludge-53 hoozawhatsie-27 tube-58)
          (assemble-order hoozawhatsie-27 connector-30 tube-58)
          (assemble-order bracket-56 kludge-53 tube-58)
          (assemble-order bracket-56 hoozawhatsie-27 tube-58)
          (assemble-order bracket-56 device-54 tube-58)
          (remove-order kludge-53 bracket-56 tube-58)
          (assemble-order sprocket-15 gimcrack-8 tube-58)
          (assemble-order device foobar-28 thingumbob-17)
          (assemble-order mount-4 widget-2 fastener-24)
          (assemble-order doodad-22 contraption-19 fastener-24)
          (remove-order contraption-19 doodad-22 fastener-24)
          (assemble-order kludge wire fastener-24)
          (assemble-order whatsis-26 hoozawhatsie-27 plug-31)
          (assemble-order whatsis-26 foobar-28 plug-31)
          (assemble-order hoozawhatsie-27 connector-30 plug-31)
          (remove-order connector-30 hoozawhatsie-27 plug-31)
          (assemble-order foobar-28 bracket-25 plug-31)
          (remove-order bracket-25 foobar-28 plug-31)
          (assemble-order wire-29 whatsis-26 plug-31)
          (assemble-order connector-30 foobar-28 plug-31)
          (assemble-order doodad-32 fastener-10 hack-14)
          (assemble-order doodad-32 valve-11 hack-14)
          (assemble-order device-9 valve-11 hack-14)
          (assemble-order bracket-56 kludge-53 hack-14)
          (assemble-order bracket-56 hoozawhatsie-27 hack-14)
          (assemble-order bracket-56 device-54 hack-14)
          (assemble-order sprocket-15 gimcrack-8 frob-3)
          (remove-order gimcrack-8 sprocket-15 frob-3)
          (assemble-order doodad-22 contraption-19 frob-3)
          (assemble-order contraption-7 gimcrack-8 frob-3)
          (remove-order gimcrack-8 contraption-7 frob-3)
          (assemble-order mount-4 widget-2 unit)
          (remove-order widget-2 mount-4 unit)
          (assemble-order kludge wire sprocket)
          (remove-order wire kludge sprocket)
          (assemble-order widget valve kludge)
          (remove-order valve widget kludge)
          (assemble-order widget valve wire)
          (assemble-order foobar-28 bracket-25 socket)
          (assemble-order device foobar-28 socket)
          (remove-order contraption device socket)
          (assemble-order coil plug device)
          (assemble-order hoozawhatsie foobar bracket)
          (assemble-order foobar gimcrack bracket)
          (assemble-order foobar gimcrack bracket)
          (assemble-order foobar gimcrack whatsis)
          (assemble-order foobar gimcrack whatsis)
          (remove-order gimcrack foobar whatsis))
   (:goal (complete connector)))

(define (problem assem-x-28)
   (:domain assembly)
   (:objects hack sprocket-54 plug-47 contraption-48
             hoozawhatsie-49 unit-50 socket-51 coil-52 kludge-53 device-61
             connector-55 frob-56 contraption-60 doodad-57 thingumbob-58
             gimcrack-59 mount-20 valve-62 whatsis-63 tube-19 wire-64
             foobar-17 bracket-18 plug-24 hack-21 widget-22 fastener-23
             socket-29 coil-25 hoozawhatsie-26 widget-27 thingumbob-28
             whatsis-12 valve-32 connector-30 device-31 wire-11 plug-9
             foobar-10 gimcrack-7 unit-14 sprocket-6 contraption-15
             doodad-16 bracket-5 foobar tube-8 fastener-3 thingumbob hack-4
             mount-1 frob-2 mount whatsis fastener frob sprocket gimcrack
             widget valve hoozawhatsie unit socket coil doodad wire device
             plug contraption tube connector kludge bracket - assembly
             scaffold - resource)
   (:init (available plug-47)
          (available contraption-48)
          (available hoozawhatsie-49)
          (available unit-50)
          (available socket-51)
          (available coil-52)
          (available kludge-53)
          (available connector-55)
          (available frob-56)
          (available doodad-57)
          (available thingumbob-58)
          (available gimcrack-59)
          (available valve-62)
          (available whatsis-63)
          (available wire-64)
          (available foobar-17)
          (available bracket-18)
          (available hack-21)
          (available widget-22)
          (available fastener-23)
          (available coil-25)
          (available hoozawhatsie-26)
          (available widget-27)
          (available thingumbob-28)
          (available connector-30)
          (available device-31)
          (available plug-9)
          (available foobar-10)
          (available unit-14)
          (available contraption-15)
          (available doodad-16)
          (available bracket-5)
          (available tube-8)
          (available fastener-3)
          (available hack-4)
          (available mount-1)
          (available frob-2)
          (available whatsis)
          (available fastener)
          (available frob)
          (available sprocket)
          (available gimcrack)
          (available widget)
          (available unit)
          (available socket)
          (available doodad)
          (available wire)
          (available plug)
          (available contraption)
          (available tube)
          (available connector)
          (available kludge)
          (available bracket)
          (available scaffold)
          (requires sprocket-54 scaffold)
          (requires contraption-60 scaffold)
          (requires mount-20 scaffold)
          (requires plug-24 scaffold)
          (requires socket-29 scaffold)
          (requires whatsis-12 scaffold)
          (requires gimcrack-7 scaffold)
          (requires thingumbob scaffold)
          (requires mount scaffold)
          (requires valve scaffold)
          (requires device scaffold)
          (part-of sprocket-54 hack)
          (part-of device-61 hack)
          (part-of mount-20 hack)
          (part-of plug-24 hack)
          (part-of socket-29 hack)
          (part-of whatsis-12 hack)
          (part-of gimcrack-7 hack)
          (part-of foobar hack)
          (part-of mount hack)
          (part-of valve hack)
          (part-of device hack)
          (part-of plug-47 sprocket-54)
          (part-of contraption-48 sprocket-54)
          (part-of hoozawhatsie-49 sprocket-54)
          (part-of unit-50 sprocket-54)
          (part-of socket-51 sprocket-54)
          (part-of coil-52 sprocket-54)
          (part-of kludge-53 sprocket-54)
          (part-of connector-55 device-61)
          (part-of frob-56 device-61)
          (part-of contraption-60 device-61)
          (part-of doodad-57 contraption-60)
          (part-of thingumbob-58 contraption-60)
          (part-of gimcrack-59 contraption-60)
          (part-of valve-62 mount-20)
          (part-of whatsis-63 mount-20)
          (part-of tube-19 mount-20)
          (part-of wire-64 tube-19)
          (part-of foobar-17 tube-19)
          (part-of bracket-18 tube-19)
          (part-of hack-21 plug-24)
          (part-of widget-22 plug-24)
          (part-of fastener-23 plug-24)
          (part-of coil-25 socket-29)
          (part-of hoozawhatsie-26 socket-29)
          (part-of widget-27 socket-29)
          (part-of thingumbob-28 socket-29)
          (part-of valve-32 whatsis-12)
          (part-of wire-11 whatsis-12)
          (part-of connector-30 valve-32)
          (part-of device-31 valve-32)
          (part-of plug-9 wire-11)
          (part-of foobar-10 wire-11)
          (part-of contraption gimcrack-7)
          (part-of unit-14 gimcrack-7)
          (part-of sprocket-6 gimcrack-7)
          (part-of contraption-15 sprocket-6)
          (part-of doodad-16 sprocket-6)
          (part-of bracket-5 sprocket-6)
          (part-of tube-8 foobar)
          (part-of fastener-3 foobar)
          (part-of thingumbob foobar)
          (part-of hack-4 thingumbob)
          (part-of mount-1 thingumbob)
          (part-of frob-2 thingumbob)
          (part-of whatsis mount)
          (part-of fastener mount)
          (part-of frob mount)
          (part-of sprocket mount)
          (part-of gimcrack mount)
          (part-of widget mount)
          (part-of hoozawhatsie valve)
          (part-of coil valve)
          (part-of unit hoozawhatsie)
          (part-of socket hoozawhatsie)
          (part-of doodad coil)
          (part-of wire coil)
          (part-of plug device)
          (transient-part contraption device)
          (part-of tube device)
          (part-of connector device)
          (part-of kludge device)
          (part-of bracket device)
          (assemble-order plug-24 whatsis-12 hack)
          (assemble-order plug-24 mount-20 hack)
          (assemble-order gimcrack-7 mount hack)
          (assemble-order mount device-61 hack)
          (assemble-order mount mount-20 hack)
          (assemble-order device whatsis-12 hack)
          (assemble-order device sprocket-54 hack)
          (assemble-order plug-47 kludge-53 sprocket-54)
          (assemble-order contraption-48 hoozawhatsie-49 sprocket-54)
          (assemble-order coil-52 contraption-48 sprocket-54)
          (assemble-order gimcrack-59 thingumbob-58 contraption-60)
          (assemble-order valve-62 tube-19 mount-20)
          (assemble-order foobar-17 bracket-18 tube-19)
          (assemble-order hoozawhatsie-26 thingumbob-28 socket-29)
          (assemble-order wire-11 valve-32 whatsis-12)
          (assemble-order connector-30 device-31 valve-32)
          (assemble-order contraption tube gimcrack-7)
          (assemble-order contraption-15 bracket-5 sprocket-6)
          (assemble-order contraption-15 doodad-16 sprocket-6)
          (assemble-order fastener widget mount)
          (assemble-order sprocket gimcrack mount)
          (assemble-order sprocket widget mount)
          (assemble-order coil hoozawhatsie valve)
          (assemble-order wire doodad coil)
          (assemble-order contraption tube device)
          (remove-order tube contraption device)
          (assemble-order tube plug device)
          (assemble-order connector kludge device))
   (:goal (complete hack)))

(define (problem assem-x-29)
   (:domain assembly)
   (:objects hack tube-49 sprocket-45 widget-46 hack-47
             fastener-48 device-56 unit-50 whatsis-51 fastener-52 coil-53
             hoozawhatsie-54 bracket-55 widget-63 wire-57 sprocket-58 valve-59
             doodad-60 gimcrack-61 socket-62 connector-22 kludge-64 plug-17
             frob-21 contraption-18 thingumbob-19 foobar-20 sprocket-25
             hack-23 mount-24 thingumbob-29 tube-26 contraption-27
             device-28 frob-12 gimcrack-30 valve-31 widget-32 plug-9 unit-10
             doodad-11 socket-7 foobar-13 hoozawhatsie-14 connector-15
             whatsis-16 coil-5 wire-6 foobar mount-4 kludge-8 bracket-3
             whatsis fastener-1 hack-2 gimcrack widget coil sprocket unit
             fastener connector device contraption thingumbob wire mount
             bracket tube hoozawhatsie valve socket kludge frob plug doodad
             - assembly
             pliers - resource)
   (:init (available sprocket-45)
          (available widget-46)
          (available hack-47)
          (available fastener-48)
          (available unit-50)
          (available whatsis-51)
          (available fastener-52)
          (available coil-53)
          (available hoozawhatsie-54)
          (available bracket-55)
          (available wire-57)
          (available sprocket-58)
          (available valve-59)
          (available doodad-60)
          (available gimcrack-61)
          (available socket-62)
          (available kludge-64)
          (available plug-17)
          (available contraption-18)
          (available thingumbob-19)
          (available foobar-20)
          (available hack-23)
          (available mount-24)
          (available tube-26)
          (available contraption-27)
          (available device-28)
          (available gimcrack-30)
          (available valve-31)
          (available widget-32)
          (available plug-9)
          (available unit-10)
          (available doodad-11)
          (available foobar-13)
          (available hoozawhatsie-14)
          (available connector-15)
          (available whatsis-16)
          (available coil-5)
          (available wire-6)
          (available kludge-8)
          (available bracket-3)
          (available fastener-1)
          (available hack-2)
          (available widget)
          (available coil)
          (available sprocket)
          (available unit)
          (available fastener)
          (available connector)
          (available contraption)
          (available thingumbob)
          (available wire)
          (available mount)
          (available bracket)
          (available tube)
          (available socket)
          (available kludge)
          (available plug)
          (available doodad)
          (available pliers)
          (requires tube-49 pliers)
          (requires device-56 pliers)
          (requires widget-63 pliers)
          (requires connector-22 pliers)
          (requires sprocket-25 pliers)
          (requires thingumbob-29 pliers)
          (requires socket-7 pliers)
          (requires foobar pliers)
          (requires gimcrack pliers)
          (requires device pliers)
          (requires hoozawhatsie pliers)
          (part-of tube-49 hack)
          (part-of device-56 hack)
          (part-of widget-63 hack)
          (part-of connector-22 hack)
          (part-of sprocket-25 hack)
          (part-of thingumbob-29 hack)
          (part-of frob-12 hack)
          (part-of socket-7 hack)
          (part-of foobar hack)
          (part-of gimcrack hack)
          (part-of device hack)
          (part-of hoozawhatsie hack)
          (part-of sprocket-45 tube-49)
          (part-of widget-46 tube-49)
          (part-of hack-47 tube-49)
          (part-of fastener-48 tube-49)
          (part-of unit-50 device-56)
          (part-of whatsis-51 device-56)
          (part-of fastener-52 device-56)
          (part-of coil-53 device-56)
          (part-of hoozawhatsie-54 device-56)
          (part-of bracket-55 device-56)
          (part-of wire-57 widget-63)
          (part-of sprocket-58 widget-63)
          (part-of valve-59 widget-63)
          (part-of doodad-60 widget-63)
          (part-of gimcrack-61 widget-63)
          (part-of socket-62 widget-63)
          (part-of kludge-64 connector-22)
          (part-of plug-17 connector-22)
          (part-of frob-21 connector-22)
          (part-of contraption-18 frob-21)
          (part-of thingumbob-19 frob-21)
          (part-of foobar-20 frob-21)
          (part-of hack-23 sprocket-25)
          (part-of mount-24 sprocket-25)
          (part-of tube-26 thingumbob-29)
          (part-of contraption-27 thingumbob-29)
          (part-of device-28 thingumbob-29)
          (part-of gimcrack-30 frob-12)
          (part-of valve-31 frob-12)
          (part-of widget-32 frob-12)
          (part-of plug-9 frob-12)
          (part-of unit-10 frob-12)
          (part-of doodad-11 frob-12)
          (part-of foobar-13 socket-7)
          (part-of hoozawhatsie-14 socket-7)
          (part-of connector-15 socket-7)
          (part-of whatsis-16 socket-7)
          (part-of coil-5 socket-7)
          (part-of wire-6 socket-7)
          (part-of mount-4 foobar)
          (part-of whatsis foobar)
          (part-of kludge-8 mount-4)
          (part-of bracket-3 mount-4)
          (part-of fastener-1 whatsis)
          (part-of hack-2 whatsis)
          (part-of widget gimcrack)
          (part-of coil gimcrack)
          (part-of sprocket gimcrack)
          (part-of unit gimcrack)
          (part-of fastener gimcrack)
          (part-of connector gimcrack)
          (part-of contraption device)
          (part-of thingumbob device)
          (part-of wire device)
          (part-of mount device)
          (part-of bracket device)
          (part-of tube device)
          (part-of valve hoozawhatsie)
          (part-of frob hoozawhatsie)
          (part-of socket valve)
          (part-of kludge valve)
          (part-of plug frob)
          (part-of doodad frob)
          (assemble-order tube-49 foobar hack)
          (assemble-order device-56 frob-12 hack)
          (assemble-order widget-63 sprocket-25 hack)
          (assemble-order connector-22 device-56 hack)
          (assemble-order sprocket-25 thingumbob-29 hack)
          (assemble-order thingumbob-29 hoozawhatsie hack)
          (assemble-order frob-12 gimcrack hack)
          (assemble-order gimcrack hoozawhatsie hack)
          (assemble-order device tube-49 hack)
          (assemble-order hoozawhatsie-54 coil-53 device-56)
          (assemble-order gimcrack-61 sprocket-58 widget-63)
          (assemble-order gimcrack-61 wire-57 widget-63)
          (assemble-order foobar-20 contraption-18 frob-21)
          (assemble-order tube-26 contraption-27 thingumbob-29)
          (assemble-order device-28 contraption-27 thingumbob-29)
          (assemble-order gimcrack-30 valve-31 frob-12)
          (assemble-order valve-31 unit-10 frob-12)
          (assemble-order plug-9 gimcrack-30 frob-12)
          (assemble-order doodad-11 unit-10 frob-12)
          (assemble-order foobar-13 connector-15 socket-7)
          (assemble-order connector-15 coil-5 socket-7)
          (assemble-order wire-6 foobar-13 socket-7)
          (assemble-order mount-4 whatsis foobar)
          (assemble-order hack-2 fastener-1 whatsis)
          (assemble-order coil unit gimcrack)
          (assemble-order sprocket connector gimcrack)
          (assemble-order contraption wire device)
          (assemble-order contraption thingumbob device)
          (assemble-order contraption bracket device)
          (assemble-order wire tube device)
          (assemble-order mount contraption device)
          (assemble-order frob valve hoozawhatsie))
   (:goal (complete hack)))

(define (problem assem-x-30)
   (:domain assembly)
   (:objects wire socket-47 mount-43 wire-44 unit-45 frob-46
             mount-53 gimcrack-48 socket-49 whatsis-50 wire-51 valve-52
             sprocket-60 foobar-54 unit-55 doodad-56 kludge-57 coil-58
             bracket-59 frob-63 thingumbob-61 contraption-62 connector-22
             plug-64 device-17 widget-18 gimcrack-19 hack-20
             hoozawhatsie-21 mount-29 fastener-23 whatsis-25 coil-27 hack-12
             fastener-30 plug-31 unit-32 tube-9 gimcrack-10 socket-11
             hoozawhatsie-7 contraption-13 widget-14 device-16 doodad-5
             sprocket-6 contraption frob-8 valve-3 wire-4 connector-1
             bracket-2 gimcrack unit sprocket tube fastener foobar connector
             frob thingumbob device widget hoozawhatsie coil plug mount
             socket valve bracket kludge hack - assembly
             file - resource)
   (:init (available mount-43)
          (available wire-44)
          (available unit-45)
          (available frob-46)
          (available gimcrack-48)
          (available socket-49)
          (available whatsis-50)
          (available wire-51)
          (available valve-52)
          (available foobar-54)
          (available unit-55)
          (available doodad-56)
          (available kludge-57)
          (available coil-58)
          (available bracket-59)
          (available thingumbob-61)
          (available contraption-62)
          (available plug-64)
          (available device-17)
          (available widget-18)
          (available gimcrack-19)
          (available hack-20)
          (available hoozawhatsie-21)
          (available fastener-23)
          (available whatsis-25)
          (available coil-27)
          (available fastener-30)
          (available plug-31)
          (available unit-32)
          (available tube-9)
          (available gimcrack-10)
          (available socket-11)
          (available contraption-13)
          (available widget-14)
          (available device-16)
          (available doodad-5)
          (available sprocket-6)
          (available frob-8)
          (available valve-3)
          (available wire-4)
          (available connector-1)
          (available bracket-2)
          (available gimcrack)
          (available tube)
          (available foobar)
          (available connector)
          (available device)
          (available widget)
          (available coil)
          (available mount)
          (available socket)
          (available valve)
          (available bracket)
          (available kludge)
          (available hack)
          (available file)
          (requires socket-47 file)
          (requires mount-53 file)
          (requires sprocket-60 file)
          (requires frob-63 file)
          (requires connector-22 file)
          (requires mount-29 file)
          (requires hack-12 file)
          (requires hoozawhatsie-7 file)
          (requires contraption file)
          (requires unit file)
          (requires frob file)
          (requires plug file)
          (part-of socket-47 wire)
          (part-of mount-53 wire)
          (part-of sprocket-60 wire)
          (part-of frob-63 wire)
          (part-of connector-22 wire)
          (part-of mount-29 wire)
          (part-of hack-12 wire)
          (part-of hoozawhatsie-7 wire)
          (part-of contraption wire)
          (part-of unit wire)
          (part-of frob wire)
          (part-of plug wire)
          (part-of mount-43 socket-47)
          (part-of wire-44 socket-47)
          (part-of unit-45 socket-47)
          (part-of frob-46 socket-47)
          (part-of gimcrack-48 mount-53)
          (part-of socket-49 mount-53)
          (part-of whatsis-50 mount-53)
          (part-of wire-51 mount-53)
          (part-of valve-52 mount-53)
          (part-of foobar-54 sprocket-60)
          (part-of unit-55 sprocket-60)
          (part-of doodad-56 sprocket-60)
          (part-of kludge-57 sprocket-60)
          (part-of coil-58 sprocket-60)
          (part-of bracket-59 sprocket-60)
          (part-of thingumbob-61 frob-63)
          (part-of contraption-62 frob-63)
          (part-of plug-64 connector-22)
          (part-of device-17 connector-22)
          (part-of widget-18 connector-22)
          (part-of gimcrack-19 connector-22)
          (part-of hack-20 connector-22)
          (part-of hoozawhatsie-21 connector-22)
          (part-of fastener-23 mount-29)
          (part-of gimcrack mount-29)
          (part-of whatsis-25 mount-29)
          (part-of doodad-5 mount-29)
          (part-of coil-27 mount-29)
          (part-of hoozawhatsie mount-29)
          (part-of fastener-30 hack-12)
          (part-of plug-31 hack-12)
          (part-of unit-32 hack-12)
          (part-of tube-9 hack-12)
          (part-of gimcrack-10 hack-12)
          (part-of socket-11 hack-12)
          (part-of contraption-13 hoozawhatsie-7)
          (part-of widget-14 hoozawhatsie-7)
          (part-of fastener hoozawhatsie-7)
          (part-of device-16 hoozawhatsie-7)
          (transient-part doodad-5 hoozawhatsie-7)
          (part-of sprocket-6 hoozawhatsie-7)
          (part-of frob-8 contraption)
          (part-of valve-3 contraption)
          (part-of wire-4 contraption)
          (part-of connector-1 contraption)
          (part-of bracket-2 contraption)
          (transient-part gimcrack contraption)
          (part-of sprocket unit)
          (transient-part fastener unit)
          (part-of connector sprocket)
          (part-of tube sprocket)
          (part-of foobar fastener)
          (transient-part connector fastener)
          (part-of thingumbob frob)
          (transient-part hoozawhatsie frob)
          (part-of device thingumbob)
          (transient-part widget thingumbob)
          (part-of widget hoozawhatsie)
          (part-of coil hoozawhatsie)
          (part-of mount plug)
          (part-of socket plug)
          (part-of valve plug)
          (part-of bracket plug)
          (part-of kludge plug)
          (part-of hack plug)
          (assemble-order socket-47 unit wire)
          (assemble-order socket-47 connector-22 wire)
          (assemble-order mount-53 frob wire)
          (assemble-order frob-63 sprocket-60 wire)
          (assemble-order connector-22 hoozawhatsie-7 wire)
          (assemble-order contraption unit wire)
          (assemble-order contraption mount-53 wire)
          (assemble-order frob socket-47 wire)
          (assemble-order plug contraption wire)
          (assemble-order gimcrack-48 wire-51 mount-53)
          (assemble-order socket-49 valve-52 mount-53)
          (assemble-order foobar-54 bracket-59 sprocket-60)
          (assemble-order foobar-54 coil-58 sprocket-60)
          (assemble-order coil-58 kludge-57 sprocket-60)
          (assemble-order coil-58 unit-55 sprocket-60)
          (assemble-order bracket-59 coil-58 sprocket-60)
          (assemble-order thingumbob-61 contraption-62 frob-63)
          (assemble-order plug-64 widget-18 connector-22)
          (assemble-order device-17 hack-20 connector-22)
          (assemble-order gimcrack-19 hack-20 connector-22)
          (assemble-order gimcrack wire-4 mount-29)
          (assemble-order gimcrack bracket-2 mount-29)
          (assemble-order whatsis-25 coil-27 mount-29)
          (assemble-order doodad-5 widget-14 mount-29)
          (assemble-order hoozawhatsie thingumbob mount-29)
          (assemble-order contraption-13 doodad-5 hoozawhatsie-7)
          (assemble-order contraption-13 device-16 hoozawhatsie-7)
          (assemble-order fastener sprocket hoozawhatsie-7)
          (assemble-order doodad-5 widget-14 hoozawhatsie-7)
          (remove-order widget-14 doodad-5 hoozawhatsie-7)
          (assemble-order sprocket-6 doodad-5 hoozawhatsie-7)
          (assemble-order valve-3 wire-4 contraption)
          (assemble-order valve-3 bracket-2 contraption)
          (assemble-order connector-1 frob-8 contraption)
          (assemble-order gimcrack wire-4 contraption)
          (assemble-order gimcrack bracket-2 contraption)
          (remove-order wire-4 gimcrack contraption)
          (assemble-order fastener sprocket unit)
          (remove-order sprocket fastener unit)
          (assemble-order connector foobar sprocket)
          (assemble-order connector foobar sprocket)
          (assemble-order tube connector sprocket)
          (assemble-order connector foobar fastener)
          (assemble-order connector foobar fastener)
          (remove-order foobar connector fastener)
          (assemble-order hoozawhatsie thingumbob frob)
          (remove-order thingumbob hoozawhatsie frob)
          (assemble-order widget device thingumbob)
          (remove-order device widget thingumbob)
          (assemble-order widget device hoozawhatsie)
          (assemble-order socket hack plug)
          (assemble-order valve socket plug))
   (:goal (complete wire)))