; Revised by DVM, 6/3/1998 so that all domains have consistent names.
; The only difference in the logic is the use of conditional effects
; in the adl version, so that an object is at a location before it is
; unloaded.

;;; these domains engineered from the att satplan encodings 
;;; which were derived from the graphplan domains
;;; which I think were derived from Veloso's prodigy domains
;;; - DSW 1/97

(define (domain logistics-strips)
  (:requirements :strips) 
  (:predicates 	(OBJ ?obj)
	       	(TRUCK ?truck)
               	(LOCATION ?loc)
		(AIRPLANE ?airplane)
                (CITY ?city)
                (AIRPORT ?airport)
		(at ?obj ?loc)
		(in ?obj1 ?obj2)
		(in-city ?obj ?city))
 
  ; (:types )		; default object

(:action LOAD-TRUCK
  :parameters
   (?obj
    ?truck
    ?loc)
  :precondition
   (and (OBJ ?obj) (TRUCK ?truck) (LOCATION ?loc)
   (at ?truck ?loc) (at ?obj ?loc))
  :effect
   (and (not (at ?obj ?loc)) (in ?obj ?truck)))

(:action LOAD-AIRPLANE
  :parameters
   (?obj
    ?airplane
    ?loc)
  :precondition
   (and (OBJ ?obj) (AIRPLANE ?airplane) (LOCATION ?loc)
   (at ?obj ?loc) (at ?airplane ?loc))
  :effect
   (and (not (at ?obj ?loc)) (in ?obj ?airplane)))

(:action UNLOAD-TRUCK
  :parameters
   (?obj
    ?truck
    ?loc)
  :precondition
   (and (OBJ ?obj) (TRUCK ?truck) (LOCATION ?loc)
        (at ?truck ?loc) (in ?obj ?truck))
  :effect
   (and (not (in ?obj ?truck)) (at ?obj ?loc)))

(:action UNLOAD-AIRPLANE
  :parameters
   (?obj
    ?airplane
    ?loc)
  :precondition
   (and (OBJ ?obj) (AIRPLANE ?airplane) (LOCATION ?loc)
        (in ?obj ?airplane) (at ?airplane ?loc))
  :effect
   (and (not (in ?obj ?airplane)) (at ?obj ?loc)))

(:action DRIVE-TRUCK
  :parameters
   (?truck
    ?loc-from
    ?loc-to
    ?city)
  :precondition
   (and (TRUCK ?truck) (LOCATION ?loc-from) (LOCATION ?loc-to) (CITY ?city)
   (at ?truck ?loc-from)
   (in-city ?loc-from ?city)
   (in-city ?loc-to ?city))
  :effect
   (and (not (at ?truck ?loc-from)) (at ?truck ?loc-to)))

(:action FLY-AIRPLANE
  :parameters
   (?airplane
    ?loc-from
    ?loc-to)
  :precondition
   (and (AIRPLANE ?airplane) (AIRPORT ?loc-from) (AIRPORT ?loc-to)
	(at ?airplane ?loc-from))
  :effect
   (and (not (at ?airplane ?loc-from)) (at ?airplane ?loc-to)))
)

;;; a three step plan works
(define (problem att-log0) 
  (:domain logistics-strips)
  (:objects package1 pgh-truck bos-truck airplane1
	    bos-po pgh-po bos-airport pgh-airport
	    pgh bos)
  (:init (OBJ package1)		; statis predicates
	 (TRUCK pgh-truck)
	 (TRUCK bos-truck)
	 (AIRPLANE airplane1)
	 (LOCATION bos-po)
	 (LOCATION pgh-po)
	 (LOCATION bos-airport)
	 (LOCATION pgh-airport)
	 (AIRPORT bos-airport)
	 (AIRPORT pgh-airport)
	 (CITY pgh)
	 (CITY bos)
	 (IN-CITY pgh-po pgh)
	 (IN-CITY pgh-airport pgh)
	 (IN-CITY bos-po bos)
	 (IN-CITY bos-airport bos)
	 (at package1 pgh-airport);; dynamic predicates
	 (at airplane1 pgh-airport)
	 (at bos-truck bos-po)
	 (at pgh-truck pgh-po))
  (:goal (and (at package1 bos-airport)))
  )


;;; this one takes six steps
(define (problem att-log1) (:domain logistics-strips)
  (:objects package1 pgh-truck bos-truck airplane1
	    bos-po pgh-po bos-airport pgh-airport
	    pgh bos)
  (:init (OBJ package1)			; statis predicates
	 (TRUCK pgh-truck)
	 (TRUCK bos-truck)
	 (AIRPLANE airplane1)
	 (LOCATION bos-po)
	 (LOCATION pgh-po)
	 (LOCATION bos-airport)
	 (LOCATION pgh-airport)
	 (AIRPORT bos-airport)
	 (AIRPORT pgh-airport)
	 (CITY pgh)
	 (CITY bos)
	 (IN-CITY pgh-po pgh)
	 (IN-CITY pgh-airport pgh)
	 (IN-CITY bos-po bos)
	 (IN-CITY bos-airport bos)
	 (at package1 pgh-po);; dynamic predicates
	 (at airplane1 pgh-airport)
	 (at bos-truck bos-po)
	 (at pgh-truck pgh-po))
  (:goal (and (at package1 bos-airport))))

;;; this one takes nine steps
(define (problem att-log2) (:domain logistics-strips)
  (:objects package1 pgh-truck bos-truck airplane1
	    bos-po pgh-po bos-airport pgh-airport
	    pgh bos)
  (:init (OBJ package1)		; statis predicates
	 (TRUCK pgh-truck)
	 (TRUCK bos-truck)
	 (AIRPLANE airplane1)
	 (LOCATION bos-po)
	 (LOCATION pgh-po)
	 (LOCATION bos-airport)
	 (LOCATION pgh-airport)
	 (AIRPORT bos-airport)
	 (AIRPORT pgh-airport)
	 (CITY pgh)
	 (CITY bos)
	 (IN-CITY pgh-po pgh)
	 (IN-CITY pgh-airport pgh)
	 (IN-CITY bos-po bos)
	 (IN-CITY bos-airport bos)
	 (at package1 pgh-po);; dynamic predicates
	 (at airplane1 pgh-airport)
	 (at bos-truck bos-airport)
	 (at pgh-truck pgh-po))
  (:goal (and (at package1 bos-po))))

;;; ten steps
(define (problem att-log3) 
  (:domain logistics-strips)
  (:objects package1 package2 package3 package4 
	    package5 package6 package7 package8
	    pgh-truck bos-truck la-truck airplane1 airplane2
	    bos-po pgh-po la-po bos-airport pgh-airport la-airport
	    pgh bos la)
  (:init (OBJ package1)		; statis predicates
	 (OBJ package2)
	 (OBJ package3)
	 (OBJ package4)
	 (OBJ package5)
	 (OBJ package6)
	 (OBJ package7)
	 (OBJ package8)
	 (TRUCK pgh-truck)
	 (TRUCK bos-truck)
	 (TRUCK la-truck)
	 (AIRPLANE airplane1)
	 (AIRPLANE airplane2)
	 (LOCATION bos-po)
	 (LOCATION la-po)
	 (LOCATION pgh-po)
	 (LOCATION bos-airport)
	 (LOCATION la-airport)
	 (LOCATION pgh-airport)
	 (AIRPORT bos-airport)
	 (AIRPORT pgh-airport)
	 (AIRPORT la-airport)
	 (CITY pgh)
	 (CITY bos)
	 (CITY la)
	 (IN-CITY pgh-po pgh)
	 (IN-CITY pgh-airport pgh)
	 (IN-CITY bos-po bos)
	 (IN-CITY bos-airport bos)
	 (IN-CITY la-po la)
	 (IN-CITY la-airport la)
	 (at package1 pgh-po);; dynamic predicates
	 (at package2 pgh-po)
	 (at package3 pgh-po)
	 (at package4 pgh-po)
	 (at package5 bos-po)
	 (at package6 bos-po)
	 (at package7 bos-po)
	 (at package8 la-po)
	 (at airplane1 pgh-airport)
	 (at airplane2 pgh-airport)
	 (at bos-truck bos-po)
	 (at pgh-truck pgh-po)
	 (at la-truck la-po))
  (:goal (and (at package1 bos-po))))

(define (problem att-log4) 
  (:domain logistics-strips)
  (:objects package1 package2 package3 package4 
	    package5 package6 package7 package8
	    pgh-truck bos-truck la-truck airplane1 airplane2
	    bos-po pgh-po la-po bos-airport pgh-airport la-airport
	    pgh bos la)
  (:init (OBJ package1)		; statis predicates
	 (OBJ package2)
	 (OBJ package3)
	 (OBJ package4)
	 (OBJ package5)
	 (OBJ package6)
	 (OBJ package7)
	 (OBJ package8)
	 (TRUCK pgh-truck)
	 (TRUCK bos-truck)
	 (TRUCK la-truck)
	 (AIRPLANE airplane1)
	 (AIRPLANE airplane2)
	 (LOCATION bos-po)
	 (LOCATION la-po)
	 (LOCATION pgh-po)
	 (LOCATION bos-airport)
	 (LOCATION la-airport)
	 (LOCATION pgh-airport)
	 (AIRPORT bos-airport)
	 (AIRPORT pgh-airport)
	 (AIRPORT la-airport)
	 (CITY pgh)
	 (CITY bos)
	 (CITY la)
	 (IN-CITY pgh-po pgh)
	 (IN-CITY pgh-airport pgh)
	 (IN-CITY bos-po bos)
	 (IN-CITY bos-airport bos)
	 (IN-CITY la-po la)
	 (IN-CITY la-airport la)
	 (at package1 pgh-po);; dynamic predicates
	 (at package2 pgh-po)
	 (at package3 pgh-po)
	 (at package4 pgh-po)
	 (at package5 bos-po)
	 (at package6 bos-po)
	 (at package7 bos-po)
	 (at package8 la-po)
	 (at airplane1 pgh-airport)
	 (at airplane2 pgh-airport)
	 (at bos-truck bos-po)
	 (at pgh-truck pgh-po)
	 (at la-truck la-po))
  (:goal (and (at package1 bos-po)
	      (at package2 bos-airport))))

(define (problem att-log-a) 
  (:domain logistics-strips)
  (:objects package1 package2 package3 package4 
	    package5 package6 package7 package8
	    pgh-truck bos-truck la-truck airplane1 airplane2
	    bos-po pgh-po la-po bos-airport pgh-airport la-airport
	    pgh bos la)
  (:init (OBJ package1)		; statis predicates
	 (OBJ package2)
	 (OBJ package3)
	 (OBJ package4)
	 (OBJ package5)
	 (OBJ package6)
	 (OBJ package7)
	 (OBJ package8)
	 (TRUCK pgh-truck)
	 (TRUCK bos-truck)
	 (TRUCK la-truck)
	 (AIRPLANE airplane1)
	 (AIRPLANE airplane2)
	 (LOCATION bos-po)
	 (LOCATION la-po)
	 (LOCATION pgh-po)
	 (LOCATION bos-airport)
	 (LOCATION la-airport)
	 (LOCATION pgh-airport)
	 (AIRPORT bos-airport)
	 (AIRPORT pgh-airport)
	 (AIRPORT la-airport)
	 (CITY pgh)
	 (CITY bos)
	 (CITY la)
	 (IN-CITY pgh-po pgh)
	 (IN-CITY pgh-airport pgh)
	 (IN-CITY bos-po bos)
	 (IN-CITY bos-airport bos)
	 (IN-CITY la-po la)
	 (IN-CITY la-airport la)
	 (at package1 pgh-po);; dynamic predicates
	 (at package2 pgh-po)
	 (at package3 pgh-po)
	 (at package4 pgh-po)
	 (at package5 bos-po)
	 (at package6 bos-po)
	 (at package7 bos-po)
	 (at package8 la-po)
	 (at airplane1 pgh-airport)
	 (at airplane2 pgh-airport)
	 (at bos-truck bos-po)
	 (at pgh-truck pgh-po)
	 (at la-truck la-po))
  (:goal (and (at package1 bos-po)
	      (at package2 bos-airport)
	      (at package3 la-po)
	      (at package4 la-airport)
	      (at package5 pgh-po)
	      (at package6 pgh-airport)
	      (at package7 pgh-po)
	      (at package8 pgh-po)))
  )


;; ATT-LOGISTICS treats trucks and airplanes
;;fundamentally differently (both loading and unloading).
;;
;; LOGISTICS-TYPED does the same, but it is typed.
;; 
;; LOGISTICS-AXIOM introduces the axiom that says
;; they are both vehicles, and treats them
;; uniformly.
;; 
;; LOGISTICS-ADL treats them uniformly as well. 
;; Whereas TYPED and AXIOM treat a thing as not AT
;; a location until it is unloaded, LOGISTICS uses
;; the conditional effect.

(define (domain logistics-adl)
  (:requirements :adl :domain-axioms)
  (:types physobj - object
	  obj vehicle - physobj
	  truck airplane - vehicle
	  location city - object
	  airport - location)
  (:predicates (at ?x - physobj ?l - location)
	       (in ?x - obj ?t - vehicle)
	       (in-city ?l - location ?c - city)
	       (loaded ?x - physobj))   ; ?x is loaded on a vehicle

  (:action load 
	     :parameters (?obj - obj ?veh - vehicle ?loc - location) 
	     :precondition (and (at ?obj ?loc)
				(at ?veh ?loc)
				(not (loaded ?obj)))
	     :effect (and (in ?obj ?veh)
			  (loaded ?obj)))
  (:action unload 
	     :parameters (?obj - obj ?veh - vehicle ?loc - location) 
	     :precondition (and (in ?obj ?veh) (at ?veh ?loc)) 
	     :effect (and (not (in ?obj ?veh))
			  (not (loaded ?obj))))
  (:action drive-truck 
	   :parameters (?truck - truck ?loc-from ?loc-to - location
			?city - city)
	     :precondition (and (at ?truck ?loc-from) 
				 (in-city ?loc-from ?city) 
				 (in-city ?loc-to ?city))
	     :effect  (and (at ?truck ?loc-to) 
			    (not (at ?truck ?loc-from))		  
			    (forall (?x - obj)
				     (when (and (in ?x ?truck))
					    (and (not (at ?x ?loc-from)) 
						  (at ?x ?loc-to))))))
  (:action fly-airplane
   :parameters (?plane - airplane ?loc-from ?loc-to - airport)
   :precondition (and (at ?plane ?loc-from) )
   :effect  (and (at ?plane ?loc-to) 
		      (not (at ?plane ?loc-from))		  
			      (forall (?x - obj)
				       (when (and (in ?x ?plane))
					      (and (not (at ?x ?loc-from)) 
						    (at ?x ?loc-to)))))))

(define (problem logistics1)
  (:domain logistics-adl)
  (:objects package1 package2 package3 package4 package5 package6 - obj
	    pgh-truck bos-truck la-truck - truck
	    airplane1 airplane2 - airplane
	    bos-po la-po pgh-po - location
	    bos-airport pgh-airport la-airport - airport
	    pgh bos la - city)

  (:init (at package1 pgh-po)
	 (at package2 pgh-po)
	 (at package3 pgh-po)
	 (at package4 pgh-po)
	 (at package5 pgh-po)
	 (at package6 la-po)
	 (at airplane1 pgh-airport)
	 (at airplane2 pgh-airport)
	 (at bos-truck bos-po)
	 (at pgh-truck pgh-po)
	 (at la-truck la-po)
	 (in-city pgh-po pgh)
	 (in-city pgh-airport pgh)
	 (in-city bos-po bos)
	 (in-city bos-airport bos)
	 (in-city la-po la)
	 (in-city la-airport la))
  (:goal (and (at package1 bos-po)
	      (at package2 la-po)
	      (at package3 la-po)
	      (at package4 la-airport)
	      (at package5 bos-po)
	      (at package6 pgh-po)
	      )))

(define (problem logistics2)
  (:domain logistics-adl)
  (:objects package1 package2 package3 package5 package7 - obj
	    pgh-truck bos-truck la-truck ny-truck - truck
	    airplane1 airplane2 - airplane
	    bos-po la-po pgh-po ny-po - location
	    bos-airport pgh-airport la-airport ny-airport - airport
	    pgh bos la ny - city)
  (:init (at package1 pgh-po)
	 (at package2 pgh-po)
	 (at package3 pgh-po)
	 (at package5 bos-po)
	 (at package7 ny-po)
	 (at airplane1 pgh-airport)
	 (at airplane2 pgh-airport)
	 (at bos-truck bos-po)
	 (at pgh-truck pgh-po)
	 (at la-truck la-po)
	 (at ny-truck ny-po)
	 (in-city pgh-po pgh)
	 (in-city pgh-airport pgh)
	 (in-city bos-po bos)
	 (in-city bos-airport bos)
	 (in-city la-po la)
	 (in-city la-airport la)
	 (in-city ny-po ny)
	 (in-city ny-airport ny))
  (:goal (and (at package1 bos-po)
	      (at package2 ny-po)
	      (at package3 la-po)
	      (at package5 pgh-po)
	      (at package7 pgh-po)))
  )

(define (problem logistics3)
  (:domain logistics-adl)
  (:objects package1 package2 package3 package4 
	    package5 package6 package7 - obj
	    pgh-truck bos-truck la-truck ny-truck - truck
	    airplane1 airplane2 - airplane
	    bos-po la-po pgh-po ny-po - location
	    bos-airport pgh-airport la-airport ny-airport - airport
	    pgh bos la ny - city)
  (:init (at package1 pgh-po)
	 (at package2 pgh-po)
	 (at package3 pgh-po)
	 (at package4 ny-po)
	 (at package5 bos-po)
	 (at package6 bos-po)
	 (at package7 ny-po)
	 (at airplane1 pgh-airport)
	 (at airplane2 pgh-airport)
	 (at bos-truck bos-po)
	 (at pgh-truck pgh-po)
	 (at la-truck la-po)
	 (at ny-truck ny-po)
	 (in-city pgh-po pgh)
	 (in-city pgh-airport pgh)
	 (in-city bos-po bos)
	 (in-city bos-airport bos)
	 (in-city la-po la)
	 (in-city la-airport la)
	 (in-city ny-po ny)
	 (in-city ny-airport ny))
  (:goal (and
	  (at package1 bos-po)
	  (at package2 ny-po)
	  (at package3 la-po)
	  (at package4 la-airport)
	  (at package5 pgh-po)
	  (at package6 ny-airport)
	  (at package7 pgh-po)))
    )






;; original name logistics.easy
;; (:length (:parallel 9))
;; optimal
;;

(define (problem log01)
    (:domain logistics-strips)
    (:objects
        package1
        package2
        package3

        airplane1
        airplane2

        pgh
        bos
        la

        pgh-truck
        bos-truck
        la-truck

        pgh-po
        bos-po
        la-po

        pgh-central
        bos-central
        la-central

        pgh-airport
        bos-airport
        la-airport
    )
    (:init
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)

        (AIRPLANE airplane1)
        (AIRPLANE airplane2)

        (CITY pgh)
        (CITY bos)
        (CITY la)

        (TRUCK pgh-truck)
        (TRUCK bos-truck)
        (TRUCK la-truck)

        (LOCATION bos-po)
        (LOCATION la-po)
        (LOCATION pgh-po)

        (LOCATION bos-central)
        (LOCATION la-central)
        (LOCATION pgh-central)

        (AIRPORT bos-airport)
        (LOCATION bos-airport)
        (AIRPORT pgh-airport)
        (LOCATION pgh-airport)
        (AIRPORT la-airport)
        (LOCATION la-airport)

        (in-city pgh-po pgh)
        (in-city pgh-airport pgh)
        (in-city pgh-central pgh)

        (in-city bos-po bos)
        (in-city bos-airport bos)
        (in-city bos-central bos)

        (in-city la-po la)
        (in-city la-airport la)
        (in-city la-central la)

        (at package1 pgh-po)
        (at package2 pgh-po)
        (at package3 pgh-po)

        (at airplane1 pgh-airport)
        (at airplane2 pgh-airport)

        (at bos-truck bos-po)
        (at pgh-truck pgh-po)
        (at la-truck la-po)

    )
    (:goal (and
        (at package1 bos-po)
        (at package2 la-po)
        (at package3 bos-po)
    ))
)

;; original name logistics.fact4pp
;; (:length (:parallel 9))
;; optimal
;;

(define (problem log02)
    (:domain logistics-strips)
    (:objects
        package1
        package2
        package3
        package4

        airplane1
        airplane2

        pgh
        bos
        la

        pgh-truck
        bos-truck
        la-truck

        pgh-po
        bos-po
        la-po

        pgh-central
        bos-central
        la-central

        pgh-airport
        bos-airport
        la-airport
    )
    (:init
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)

        (AIRPLANE airplane1)
        (AIRPLANE airplane2)

        (CITY pgh)
        (CITY bos)
        (CITY la)

        (TRUCK pgh-truck)
        (TRUCK bos-truck)
        (TRUCK la-truck)

        (LOCATION bos-po)
        (LOCATION la-po)
        (LOCATION pgh-po)

        (LOCATION bos-central)
        (LOCATION la-central)
        (LOCATION pgh-central)

        (AIRPORT bos-airport)
        (LOCATION bos-airport)
        (AIRPORT pgh-airport)
        (LOCATION pgh-airport)
        (AIRPORT la-airport)
        (LOCATION la-airport)

        (in-city pgh-po pgh)
        (in-city pgh-airport pgh)
        (in-city pgh-central pgh)

        (in-city bos-po bos)
        (in-city bos-airport bos)
        (in-city bos-central bos)

        (in-city la-po la)
        (in-city la-airport la)
        (in-city la-central la)

        (at package1 pgh-po)
        (at package2 pgh-po)
        (at package3 pgh-po)
        (at package4 pgh-po)
       
        (at airplane1 pgh-airport)
        (at airplane2 pgh-airport)
       
        (at bos-truck bos-po)
        (at pgh-truck pgh-po)
        (at la-truck la-po)

    )
    (:goal (and
        (at package1 bos-po)
        (at package2 la-airport)
        (at package3 bos-po)
        (at package4 la-airport))
    ))
;; original name logistics.a
;; extended version of logistics_facts7h
;; (:length (:parallel 11))
;; optimal
;; #actions 54 #states 10^11
;;
;; note: by going to a non-typed representation
;;       of the problems, the instances become (somewhat)
;;       harder to solve.
;;       (larger propositional representation)
;;

(define (problem log03)
    (:domain logistics-strips)
    (:objects
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8

        airplane1
        airplane2

        pgh
        bos
        la

        pgh-truck
        bos-truck
        la-truck

        pgh-po
        bos-po
        la-po

        pgh-central
        bos-central
        la-central

        pgh-airport
        bos-airport
        la-airport
    )
    (:init
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (OBJ package7)
        (OBJ package8)

        (AIRPLANE airplane1)
        (AIRPLANE airplane2)

        (CITY pgh)
        (CITY bos)
        (CITY la)

        (TRUCK pgh-truck)
        (TRUCK bos-truck)
        (TRUCK la-truck)

        (LOCATION bos-po)
        (LOCATION la-po)
        (LOCATION pgh-po)

        (LOCATION bos-central)
        (LOCATION la-central)
        (LOCATION pgh-central)

        (AIRPORT bos-airport)
        (LOCATION bos-airport)
        (AIRPORT pgh-airport)
        (LOCATION pgh-airport)
        (AIRPORT la-airport)
        (LOCATION la-airport)

        (in-city pgh-po pgh)
        (in-city pgh-airport pgh)
        (in-city pgh-central pgh)

        (in-city bos-po bos)
        (in-city bos-airport bos)
        (in-city bos-central bos)

        (in-city la-po la)
        (in-city la-airport la)
        (in-city la-central la)

        (at package1 pgh-po)
        (at package2 pgh-po)
        (at package3 pgh-po)
        (at package4 pgh-po)
        (at package5 bos-po)
        (at package6 bos-po)
        (at package7 bos-po)
        (at package8 la-po)

        (at airplane1 pgh-airport)
        (at airplane2 pgh-airport)
       
        (at bos-truck bos-po)
        (at pgh-truck pgh-po)
        (at la-truck la-po)
    )
    (:goal (and
        (at package1 bos-po)
        (at package2 bos-airport)
        (at package3 la-po)
        (at package4 la-airport)
        (at package5 pgh-po)
        (at package6 pgh-airport)
        (at package7 pgh-po)
        (at package8 pgh-po)
    ))
)
;; original name logistics.b
;; (:length (:parallel 13))
;; optimal
;; #actions 47 #states 10^8
;;

(define (problem log04)
    (:domain logistics-strips)
    (:objects
        package1
        package2
        package3
        package4
        package5
        package6
        package7

        airplane1
        airplane2

        pgh
        bos
        la
        ny

        pgh-truck
        bos-truck
        la-truck
        ny-truck

        pgh-po
        bos-po
        la-po
        ny-po

        pgh-central
        bos-central
        la-central
        ny-central

        pgh-airport
        bos-airport
        la-airport
        ny-airport
    )
    (:init
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (OBJ package7)

        (AIRPLANE airplane1)
        (AIRPLANE airplane2)

        (CITY pgh)
        (CITY bos)
        (CITY la)
        (CITY ny)

        (TRUCK pgh-truck)
        (TRUCK bos-truck)
        (TRUCK la-truck)
        (TRUCK ny-truck)

        (LOCATION bos-po)
        (LOCATION la-po)
        (LOCATION pgh-po)
        (LOCATION ny-po)

        (LOCATION bos-central)
        (LOCATION la-central)
        (LOCATION pgh-central)
        (LOCATION ny-central)

        (AIRPORT bos-airport)
        (LOCATION bos-airport)
        (AIRPORT pgh-airport)
        (LOCATION pgh-airport)
        (AIRPORT la-airport)
        (LOCATION la-airport)
        (AIRPORT ny-airport)
        (LOCATION ny-airport)

        (in-city pgh-po pgh)
        (in-city pgh-airport pgh)
        (in-city pgh-central pgh)

        (in-city bos-po bos)
        (in-city bos-airport bos)
        (in-city bos-central bos)

        (in-city la-po la)
        (in-city la-airport la)
        (in-city la-central la)

        (in-city ny-po ny)
        (in-city ny-airport ny)
        (in-city ny-central ny)

        (at package1 pgh-po)
        (at package2 pgh-po)
        (at package3 pgh-po)
        (at package5 bos-po)
        (at package7 ny-po)

        (at airplane1 pgh-airport)
        (at airplane2 pgh-airport)

        (at bos-truck bos-po)
        (at pgh-truck pgh-po)
        (at la-truck la-po)
        (at ny-truck ny-po)
    )
    (:goal (and
        (at package1 bos-po)
        (at package2 ny-po)
        (at package3 la-po)
        (at package5 pgh-po)
        (at package7 pgh-po)
    ))
)
;; original name logistics.c
;; (:length (:parallel 13))
;; optimal
;; #actions 63 #states 10^10
;;

(define (problem log05)
    (:domain logistics-strips)
    (:objects
        package1
        package2
        package3
        package4
        package5
        package6
        package7

        airplane1
        airplane2

        pgh
        bos
        la
        ny

        pgh-truck
        bos-truck
        la-truck
        ny-truck

        pgh-po
        bos-po
        la-po
        ny-po

        pgh-central
        bos-central
        la-central
        ny-central

        pgh-airport
        bos-airport
        la-airport
        ny-airport
    )
    (:init
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (OBJ package7)

        (AIRPLANE airplane1)
        (AIRPLANE airplane2)

        (CITY pgh)
        (CITY bos)
        (CITY la)
        (CITY ny)

        (TRUCK pgh-truck)
        (TRUCK bos-truck)
        (TRUCK la-truck)
        (TRUCK ny-truck)

        (LOCATION bos-po)
        (LOCATION la-po)
        (LOCATION pgh-po)
        (LOCATION ny-po)

        (LOCATION bos-central)
        (LOCATION la-central)
        (LOCATION pgh-central)
        (LOCATION ny-central)

        (AIRPORT bos-airport)
        (LOCATION bos-airport)
        (AIRPORT pgh-airport)
        (LOCATION pgh-airport)
        (AIRPORT la-airport)
        (LOCATION la-airport)
        (AIRPORT ny-airport)
        (LOCATION ny-airport)

        (in-city pgh-po pgh)
        (in-city pgh-airport pgh)
        (in-city pgh-central pgh)

        (in-city bos-po bos)
        (in-city bos-airport bos)
        (in-city bos-central bos)

        (in-city la-po la)
        (in-city la-airport la)
        (in-city la-central la)

        (in-city ny-po ny)
        (in-city ny-airport ny)
        (in-city ny-central ny)

        (at package1 pgh-po)
        (at package2 pgh-po)
        (at package3 pgh-po)
        (at package4 ny-po)
        (at package5 bos-po)
        (at package6 bos-po)
        (at package7 ny-po)

        (at airplane1 pgh-airport)
        (at airplane2 pgh-airport)

        (at bos-truck bos-po)
        (at pgh-truck pgh-po)
        (at la-truck la-po)
        (at ny-truck ny-po)

    )
    (:goal (and
        (at package1 bos-po)
        (at package2 ny-po)
        (at package3 la-po)
        (at package4 la-airport)
        (at package5 pgh-po)
        (at package6 ny-airport)
        (at package7 pgh-po)
    ))
)
;; original name logistics.d
;; (:length (:parallel 14))
;; optimal
;; #actions 74 #states 10^16
;; note small bug sf locations
;;      fixed in "log09" (slightly easier)
;;

(define (problem log06)
    (:domain logistics-strips)
    (:objects
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9

        airplane1
        airplane2

        pgh
        bos
        la
        ny
        sf

        pgh-truck
        bos-truck
        la-truck
        ny-truck
        sf-truck

        pgh-po
        bos-po
        la-po
        ny-po
        sf-po

        pgh-central
        bos-central
        la-central
        ny-central
        sf-central

        pgh-airport
        bos-airport
        la-airport
        ny-airport
        sf-airport
    )
    (:init
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (OBJ package7)
        (OBJ package8)
        (OBJ package9)

        (AIRPLANE airplane1)
        (AIRPLANE airplane2)

        (CITY pgh)
        (CITY bos)
        (CITY la)
        (CITY ny)
        (CITY sf)

        (TRUCK pgh-truck)
        (TRUCK bos-truck)
        (TRUCK la-truck)
        (TRUCK ny-truck)
        (TRUCK sf-truck)

        (LOCATION bos-po)
        (LOCATION la-po)
        (LOCATION pgh-po)
        (LOCATION ny-po)
        (LOCATION sf-po)

        (LOCATION bos-central)
        (LOCATION la-central)
        (LOCATION pgh-central)
        (LOCATION ny-central)
        (LOCATION sf-central)

        (AIRPORT bos-airport)
        (LOCATION bos-airport)
        (AIRPORT pgh-airport)
        (LOCATION pgh-airport)
        (AIRPORT la-airport)
        (LOCATION la-airport)
        (AIRPORT ny-airport)
        (LOCATION ny-airport)
        (AIRPORT sf-airport)
        (LOCATION sf-airport)

        (in-city pgh-po pgh)
        (in-city pgh-airport pgh)
        (in-city pgh-central pgh)

        (in-city bos-po bos)
        (in-city bos-airport bos)
        (in-city bos-central bos)

        (in-city la-po la)
        (in-city la-airport la)
        (in-city la-central la)

        (in-city ny-po ny)
        (in-city ny-airport ny)
        (in-city ny-central ny)

        (in-city sf-po ny)
        (in-city sf-airport ny)
        (in-city sf-central ny)

        (at package1 pgh-po)
        (at package2 pgh-central)
        (at package3 pgh-central)
        (at package4 ny-po)
        (at package5 bos-po)
        (at package6 bos-po)
        (at package7 ny-po)
        (at package8 sf-airport)
        (at package9 sf-central)

        (at airplane1 pgh-airport)
        (at airplane2 pgh-airport)

        (at bos-truck bos-po)
        (at pgh-truck pgh-airport)
        (at la-truck la-po)
        (at ny-truck ny-central)
        (at sf-truck sf-airport)
    )
    (:goal (and
       (at package1 bos-po)
       (at package2 ny-po)
       (at package3 la-central)
       (at package4 la-airport)
       (at package5 pgh-po)
       (at package6 ny-central)
       (at package7 pgh-po)
       (at package8 ny-central)
       (at package9 sf-po)
    ))
)

;; original name logistics.d1a
;; (:length (:parallel 13))
;; optimal
;;

(define (problem log07)
    (:domain logistics-strips)
    (:objects
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9

        airplane1
        airplane2
        airplane3

        pgh
        bos
        la
        ny
        sf

        pgh-truck
        bos-truck
        la-truck
        ny-truck
        sf-truck

        pgh-po
        bos-po
        la-po
        ny-po
        sf-po

        pgh-central
        bos-central
        la-central
        ny-central
        sf-central

        pgh-airport
        bos-airport
        la-airport
        ny-airport
        sf-airport
    )
    (:init
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (OBJ package7)
        (OBJ package8)
        (OBJ package9)

        (AIRPLANE airplane1)
        (AIRPLANE airplane2)
        (AIRPLANE airplane3)

        (CITY pgh)
        (CITY bos)
        (CITY la)
        (CITY ny)
        (CITY sf)

        (TRUCK pgh-truck)
        (TRUCK bos-truck)
        (TRUCK la-truck)
        (TRUCK ny-truck)
        (TRUCK sf-truck)

        (LOCATION bos-po)
        (LOCATION la-po)
        (LOCATION pgh-po)
        (LOCATION ny-po)
        (LOCATION sf-po)

        (LOCATION bos-central)
        (LOCATION la-central)
        (LOCATION pgh-central)
        (LOCATION ny-central)
        (LOCATION sf-central)

        (AIRPORT bos-airport)
        (LOCATION bos-airport)
        (AIRPORT pgh-airport)
        (LOCATION pgh-airport)
        (AIRPORT la-airport)
        (LOCATION la-airport)
        (AIRPORT ny-airport)
        (LOCATION ny-airport)
        (AIRPORT sf-airport)
        (LOCATION sf-airport)

        (in-city pgh-po pgh)
        (in-city pgh-airport pgh)
        (in-city pgh-central pgh)

        (in-city bos-po bos)
        (in-city bos-airport bos)
        (in-city bos-central bos)

        (in-city la-po la)
        (in-city la-airport la)
        (in-city la-central la)

        (in-city ny-po ny)
        (in-city ny-airport ny)
        (in-city ny-central ny)

        (in-city sf-po sf)
        (in-city sf-airport sf)
        (in-city sf-central sf)

        (at package1 pgh-po)
        (at package2 pgh-central)
        (at package3 pgh-central)
        (at package4 ny-po)
        (at package5 bos-po)
        (at package6 bos-po)
        (at package7 ny-po)
        (at package8 sf-airport)
        (at package9 sf-central)
       
        (at airplane1 pgh-airport)
        (at airplane2 pgh-airport)
        (at airplane3 pgh-airport)
       
        (at bos-truck bos-po)
        (at pgh-truck pgh-airport)
        (at la-truck la-po)
        (at ny-truck ny-central)
        (at sf-truck sf-airport)
    )
    (:goal (and
        (at package1 bos-po)
        (at package2 ny-po)
        (at package3 la-central)
        (at package4 la-airport)
        (at package5 pgh-po)
        (at package6 ny-central)
        (at package7 pgh-po)
        (at package8 ny-central)
        (at package9 sf-po)
    ))
)
;; original name logistics.d1b
;; (:length (:parallel 17))
;; optimal
;;

(define (problem log08)
    (:domain logistics-strips)
    (:objects
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9

        airplane1

        pgh
        bos
        la
        ny
        sf

        pgh-truck
        bos-truck
        la-truck
        ny-truck
        sf-truck

        pgh-po
        bos-po
        la-po
        ny-po
        sf-po

        pgh-central
        bos-central
        la-central
        ny-central
        sf-central

        pgh-airport
        bos-airport
        la-airport
        ny-airport
        sf-airport
    )
    (:init
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (OBJ package7)
        (OBJ package8)
        (OBJ package9)

        (AIRPLANE airplane1)

        (CITY pgh)
        (CITY bos)
        (CITY la)
        (CITY ny)
        (CITY sf)

        (TRUCK pgh-truck)
        (TRUCK bos-truck)
        (TRUCK la-truck)
        (TRUCK ny-truck)
        (TRUCK sf-truck)

        (LOCATION bos-po)
        (LOCATION la-po)
        (LOCATION pgh-po)
        (LOCATION ny-po)
        (LOCATION sf-po)

        (LOCATION bos-central)
        (LOCATION la-central)
        (LOCATION pgh-central)
        (LOCATION ny-central)
        (LOCATION sf-central)

        (AIRPORT bos-airport)
        (LOCATION bos-airport)
        (AIRPORT pgh-airport)
        (LOCATION pgh-airport)
        (AIRPORT la-airport)
        (LOCATION la-airport)
        (AIRPORT ny-airport)
        (LOCATION ny-airport)
        (AIRPORT sf-airport)
        (LOCATION sf-airport)

        (in-city pgh-po pgh)
        (in-city pgh-airport pgh)
        (in-city pgh-central pgh)

        (in-city bos-po bos)
        (in-city bos-airport bos)
        (in-city bos-central bos)

        (in-city la-po la)
        (in-city la-airport la)
        (in-city la-central la)

        (in-city ny-po ny)
        (in-city ny-airport ny)
        (in-city ny-central ny)

        (in-city sf-po sf)
        (in-city sf-airport sf)
        (in-city sf-central sf)

        (at package1 pgh-po)
        (at package2 pgh-central)
        (at package3 pgh-central)
        (at package4 ny-po)
        (at package5 bos-po)
        (at package6 bos-po)
        (at package7 ny-po)
        (at package8 sf-airport)
        (at package9 sf-central)

        (at airplane1 pgh-airport)

        (at bos-truck bos-po)
        (at pgh-truck pgh-airport)
        (at la-truck la-po)
        (at ny-truck ny-central)
        (at sf-truck sf-airport)
    )
    (:goal (and
        (at package1 bos-po)
        (at package2 ny-po)
        (at package3 la-central)
        (at package4 la-airport)
        (at package5 pgh-po)
        (at package6 ny-central)
        (at package7 pgh-po)
        (at package8 ny-central)
        (at package9 sf-po)
    ))
)
;; original name logistics.d1
;; (:length (:parallel 14))
;; optimal
;;

(define (problem log09)
    (:domain logistics-strips)
    (:objects
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9

        airplane1
        airplane2

        pgh
        bos
        la
        ny
        sf

        pgh-truck
        bos-truck
        la-truck
        ny-truck
        sf-truck

        pgh-po
        bos-po
        la-po
        ny-po
        sf-po

        pgh-central
        bos-central
        la-central
        ny-central
        sf-central

        pgh-airport
        bos-airport
        la-airport
        ny-airport
        sf-airport
    )
    (:init
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (OBJ package7)
        (OBJ package8)
        (OBJ package9)

        (AIRPLANE airplane1)
        (AIRPLANE airplane2)

        (CITY pgh)
        (CITY bos)
        (CITY la)
        (CITY ny)
        (CITY sf)

        (TRUCK pgh-truck)
        (TRUCK bos-truck)
        (TRUCK la-truck)
        (TRUCK ny-truck)
        (TRUCK sf-truck)

        (LOCATION bos-po)
        (LOCATION la-po)
        (LOCATION pgh-po)
        (LOCATION ny-po)
        (LOCATION sf-po)

        (LOCATION bos-central)
        (LOCATION la-central)
        (LOCATION pgh-central)
        (LOCATION ny-central)
        (LOCATION sf-central)

        (AIRPORT bos-airport)
        (LOCATION bos-airport)
        (AIRPORT pgh-airport)
        (LOCATION pgh-airport)
        (AIRPORT la-airport)
        (LOCATION la-airport)
        (AIRPORT ny-airport)
        (LOCATION ny-airport)
        (AIRPORT sf-airport)
        (LOCATION sf-airport)

        (in-city pgh-po pgh)
        (in-city pgh-airport pgh)
        (in-city pgh-central pgh)

        (in-city bos-po bos)
        (in-city bos-airport bos)
        (in-city bos-central bos)

        (in-city la-po la)
        (in-city la-airport la)
        (in-city la-central la)

        (in-city ny-po ny)
        (in-city ny-airport ny)
        (in-city ny-central ny)

        (in-city sf-po sf)
        (in-city sf-airport sf)
        (in-city sf-central sf)

        (at package1 pgh-po)
        (at package2 pgh-central)
        (at package3 pgh-central)
        (at package4 ny-po)
        (at package5 bos-po)
        (at package6 bos-po)
        (at package7 ny-po)
        (at package8 sf-airport)
        (at package9 sf-central)

        (at airplane1 pgh-airport)
        (at airplane2 pgh-airport)

        (at bos-truck bos-po)
        (at pgh-truck pgh-airport)
        (at la-truck la-po)
        (at ny-truck ny-central)
        (at sf-truck sf-airport)
    )
    (:goal (and
       (at package1 bos-po)
       (at package2 ny-po)
       (at package3 la-central)
       (at package4 la-airport)
       (at package5 pgh-po)
       (at package6 ny-central)
       (at package7 pgh-po)
       (at package8 ny-central)
       (at package9 sf-po)
    ))
)
;; a logistics problem instance
;; name: log07
;; #packages: 10        #cities: 6  #planes: 2
;; #locs_per_city: 2   #trucks_per_city: 1
;; #goals: 10           seed: 76525784

(define (problem log10)
    (:domain logistics-strips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        package10
        plane1
        plane2
        truck1-1
        loc1-1
        loc1-2
        city1
        truck2-1
        loc2-1
        loc2-2
        city2
        truck3-1
        loc3-1
        loc3-2
        city3
        truck4-1
        loc4-1
        loc4-2
        city4
        truck5-1
        loc5-1
        loc5-2
        city5
        truck6-1
        loc6-1
        loc6-2
        city6
    )
    (:init 
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (OBJ package7)
        (OBJ package8)
        (OBJ package9)
        (OBJ package10)
        (AIRPLANE plane1)
        (AIRPLANE plane2)
        (TRUCK truck1-1)
        (LOCATION loc1-1)
        (LOCATION loc1-2)
        (CITY city1)
        (AIRPORT loc1-1)
        (TRUCK truck2-1)
        (LOCATION loc2-1)
        (LOCATION loc2-2)
        (CITY city2)
        (AIRPORT loc2-1)
        (TRUCK truck3-1)
        (LOCATION loc3-1)
        (LOCATION loc3-2)
        (CITY city3)
        (AIRPORT loc3-1)
        (TRUCK truck4-1)
        (LOCATION loc4-1)
        (LOCATION loc4-2)
        (CITY city4)
        (AIRPORT loc4-1)
        (TRUCK truck5-1)
        (LOCATION loc5-1)
        (LOCATION loc5-2)
        (CITY city5)
        (AIRPORT loc5-1)
        (TRUCK truck6-1)
        (LOCATION loc6-1)
        (LOCATION loc6-2)
        (CITY city6)
        (AIRPORT loc6-1)
        (in-city loc1-1 city1)
        (in-city loc1-2 city1)
        (in-city loc2-1 city2)
        (in-city loc2-2 city2)
        (in-city loc3-1 city3)
        (in-city loc3-2 city3)
        (in-city loc4-1 city4)
        (in-city loc4-2 city4)
        (in-city loc5-1 city5)
        (in-city loc5-2 city5)
        (in-city loc6-1 city6)
        (in-city loc6-2 city6)
        (at plane1 loc4-1)
        (at plane2 loc4-1)
        (at truck1-1 loc1-1)
        (at truck2-1 loc2-2)
        (at truck3-1 loc3-1)
        (at truck4-1 loc4-2)
        (at truck5-1 loc5-2)
        (at truck6-1 loc6-1)
        (at package1 loc5-1)
        (at package2 loc4-1)
        (at package3 loc6-2)
        (at package4 loc4-1)
        (at package5 loc4-2)
        (at package6 loc3-1)
        (at package7 loc2-2)
        (at package8 loc4-1)
        (at package9 loc3-2)
        (at package10 loc6-1)
    )
    (:goal (and
        (at package1 loc2-1)
        (at package2 loc5-1)
        (at package3 loc4-1)
        (at package4 loc2-1)
        (at package5 loc4-2)
        (at package6 loc3-2)
        (at package7 loc4-1)
        (at package8 loc5-2)
        (at package9 loc6-2)
        (at package10 loc6-1)
    ))
)
;; a logistics problem instance
;; name: log08
;; #packages: 9        #cities: 5  #planes: 2
;; #locs_per_city: 2   #trucks_per_city: 1
;; #goals: 9           seed: 82752309

(define (problem log11)
    (:domain logistics-strips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        plane1
        plane2
        truck1-1
        loc1-1
        loc1-2
        city1
        truck2-1
        loc2-1
        loc2-2
        city2
        truck3-1
        loc3-1
        loc3-2
        city3
        truck4-1
        loc4-1
        loc4-2
        city4
        truck5-1
        loc5-1
        loc5-2
        city5
    )
    (:init 
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (OBJ package7)
        (OBJ package8)
        (OBJ package9)
        (AIRPLANE plane1)
        (AIRPLANE plane2)
        (TRUCK truck1-1)
        (LOCATION loc1-1)
        (LOCATION loc1-2)
        (CITY city1)
        (AIRPORT loc1-1)
        (TRUCK truck2-1)
        (LOCATION loc2-1)
        (LOCATION loc2-2)
        (CITY city2)
        (AIRPORT loc2-1)
        (TRUCK truck3-1)
        (LOCATION loc3-1)
        (LOCATION loc3-2)
        (CITY city3)
        (AIRPORT loc3-1)
        (TRUCK truck4-1)
        (LOCATION loc4-1)
        (LOCATION loc4-2)
        (CITY city4)
        (AIRPORT loc4-1)
        (TRUCK truck5-1)
        (LOCATION loc5-1)
        (LOCATION loc5-2)
        (CITY city5)
        (AIRPORT loc5-1)
        (in-city loc1-1 city1)
        (in-city loc1-2 city1)
        (in-city loc2-1 city2)
        (in-city loc2-2 city2)
        (in-city loc3-1 city3)
        (in-city loc3-2 city3)
        (in-city loc4-1 city4)
        (in-city loc4-2 city4)
        (in-city loc5-1 city5)
        (in-city loc5-2 city5)
        (at plane1 loc4-1)
        (at plane2 loc5-1)
        (at truck1-1 loc1-2)
        (at truck2-1 loc2-1)
        (at truck3-1 loc3-2)
        (at truck4-1 loc4-2)
        (at truck5-1 loc5-1)
        (at package1 loc1-2)
        (at package2 loc1-2)
        (at package3 loc5-2)
        (at package4 loc3-2)
        (at package5 loc1-2)
        (at package6 loc3-1)
        (at package7 loc5-1)
        (at package8 loc1-1)
        (at package9 loc5-2)
    )
    (:goal (and
        (at package1 loc1-2)
        (at package2 loc5-1)
        (at package3 loc1-1)
        (at package4 loc5-2)
        (at package5 loc2-1)
        (at package6 loc2-2)
        (at package7 loc3-1)
        (at package8 loc3-1)
        (at package9 loc3-2)
    ))
)
;; a logistics problem instance
;; name: log09
;; #packages: 9        #cities: 4  #planes: 3
;; #locs_per_city: 2   #trucks_per_city: 1
;; #goals: 9           seed: 21736079

(define (problem log12)
    (:domain logistics-strips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        plane1
        plane2
        plane3
        truck1-1
        loc1-1
        loc1-2
        city1
        truck2-1
        loc2-1
        loc2-2
        city2
        truck3-1
        loc3-1
        loc3-2
        city3
        truck4-1
        loc4-1
        loc4-2
        city4
    )
    (:init 
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (OBJ package7)
        (OBJ package8)
        (OBJ package9)
        (AIRPLANE plane1)
        (AIRPLANE plane2)
        (AIRPLANE plane3)
        (TRUCK truck1-1)
        (LOCATION loc1-1)
        (LOCATION loc1-2)
        (CITY city1)
        (AIRPORT loc1-1)
        (TRUCK truck2-1)
        (LOCATION loc2-1)
        (LOCATION loc2-2)
        (CITY city2)
        (AIRPORT loc2-1)
        (TRUCK truck3-1)
        (LOCATION loc3-1)
        (LOCATION loc3-2)
        (CITY city3)
        (AIRPORT loc3-1)
        (TRUCK truck4-1)
        (LOCATION loc4-1)
        (LOCATION loc4-2)
        (CITY city4)
        (AIRPORT loc4-1)
        (in-city loc1-1 city1)
        (in-city loc1-2 city1)
        (in-city loc2-1 city2)
        (in-city loc2-2 city2)
        (in-city loc3-1 city3)
        (in-city loc3-2 city3)
        (in-city loc4-1 city4)
        (in-city loc4-2 city4)
        (at plane1 loc1-1)
        (at plane2 loc1-1)
        (at plane3 loc1-1)
        (at truck1-1 loc1-1)
        (at truck2-1 loc2-2)
        (at truck3-1 loc3-1)
        (at truck4-1 loc4-1)
        (at package1 loc2-1)
        (at package2 loc4-1)
        (at package3 loc3-1)
        (at package4 loc3-1)
        (at package5 loc2-1)
        (at package6 loc2-2)
        (at package7 loc2-2)
        (at package8 loc2-1)
        (at package9 loc1-2)
    )
    (:goal (and
        (at package1 loc2-1)
        (at package2 loc1-1)
        (at package3 loc2-2)
        (at package4 loc1-2)
        (at package5 loc1-2)
        (at package6 loc4-1)
        (at package7 loc2-1)
        (at package8 loc3-1)
        (at package9 loc1-1)
    ))
)
;; a logistics problem instance
;; name: log10
;; #packages: 9        #cities: 6  #planes: 3
;; #locs_per_city: 2   #trucks_per_city: 1
;; #goals: 9           seed: 82947632

(define (problem log13)
    (:domain logistics-strips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        plane1
        plane2
        plane3
        truck1-1
        loc1-1
        loc1-2
        city1
        truck2-1
        loc2-1
        loc2-2
        city2
        truck3-1
        loc3-1
        loc3-2
        city3
        truck4-1
        loc4-1
        loc4-2
        city4
        truck5-1
        loc5-1
        loc5-2
        city5
        truck6-1
        loc6-1
        loc6-2
        city6
    )
    (:init 
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (OBJ package7)
        (OBJ package8)
        (OBJ package9)
        (AIRPLANE plane1)
        (AIRPLANE plane2)
        (AIRPLANE plane3)
        (TRUCK truck1-1)
        (LOCATION loc1-1)
        (LOCATION loc1-2)
        (CITY city1)
        (AIRPORT loc1-1)
        (TRUCK truck2-1)
        (LOCATION loc2-1)
        (LOCATION loc2-2)
        (CITY city2)
        (AIRPORT loc2-1)
        (TRUCK truck3-1)
        (LOCATION loc3-1)
        (LOCATION loc3-2)
        (CITY city3)
        (AIRPORT loc3-1)
        (TRUCK truck4-1)
        (LOCATION loc4-1)
        (LOCATION loc4-2)
        (CITY city4)
        (AIRPORT loc4-1)
        (TRUCK truck5-1)
        (LOCATION loc5-1)
        (LOCATION loc5-2)
        (CITY city5)
        (AIRPORT loc5-1)
        (TRUCK truck6-1)
        (LOCATION loc6-1)
        (LOCATION loc6-2)
        (CITY city6)
        (AIRPORT loc6-1)
        (in-city loc1-1 city1)
        (in-city loc1-2 city1)
        (in-city loc2-1 city2)
        (in-city loc2-2 city2)
        (in-city loc3-1 city3)
        (in-city loc3-2 city3)
        (in-city loc4-1 city4)
        (in-city loc4-2 city4)
        (in-city loc5-1 city5)
        (in-city loc5-2 city5)
        (in-city loc6-1 city6)
        (in-city loc6-2 city6)
        (at plane1 loc6-1)
        (at plane2 loc6-1)
        (at plane3 loc3-1)
        (at truck1-1 loc1-2)
        (at truck2-1 loc2-1)
        (at truck3-1 loc3-2)
        (at truck4-1 loc4-2)
        (at truck5-1 loc5-1)
        (at truck6-1 loc6-1)
        (at package1 loc3-2)
        (at package2 loc3-2)
        (at package3 loc4-2)
        (at package4 loc5-2)
        (at package5 loc2-1)
        (at package6 loc5-2)
        (at package7 loc4-2)
        (at package8 loc1-1)
        (at package9 loc2-2)
    )
    (:goal (and
        (at package1 loc5-2)
        (at package2 loc1-1)
        (at package3 loc5-2)
        (at package4 loc1-2)
        (at package5 loc3-2)
        (at package6 loc6-1)
        (at package7 loc6-2)
        (at package8 loc3-1)
        (at package9 loc6-2)
    ))
)
;; a logistics problem instance
;; name: log11
;; #packages: 11        #cities: 6  #planes: 3
;; #locs_per_city: 2   #trucks_per_city: 1
;; #goals: 11           seed: 121386628

(define (problem log14)
    (:domain logistics-strips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        package10
        package11
        plane1
        plane2
        plane3
        truck1-1
        loc1-1
        loc1-2
        city1
        truck2-1
        loc2-1
        loc2-2
        city2
        truck3-1
        loc3-1
        loc3-2
        city3
        truck4-1
        loc4-1
        loc4-2
        city4
        truck5-1
        loc5-1
        loc5-2
        city5
        truck6-1
        loc6-1
        loc6-2
        city6
    )
    (:init 
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (OBJ package7)
        (OBJ package8)
        (OBJ package9)
        (OBJ package10)
        (OBJ package11)
        (AIRPLANE plane1)
        (AIRPLANE plane2)
        (AIRPLANE plane3)
        (TRUCK truck1-1)
        (LOCATION loc1-1)
        (LOCATION loc1-2)
        (CITY city1)
        (AIRPORT loc1-1)
        (TRUCK truck2-1)
        (LOCATION loc2-1)
        (LOCATION loc2-2)
        (CITY city2)
        (AIRPORT loc2-1)
        (TRUCK truck3-1)
        (LOCATION loc3-1)
        (LOCATION loc3-2)
        (CITY city3)
        (AIRPORT loc3-1)
        (TRUCK truck4-1)
        (LOCATION loc4-1)
        (LOCATION loc4-2)
        (CITY city4)
        (AIRPORT loc4-1)
        (TRUCK truck5-1)
        (LOCATION loc5-1)
        (LOCATION loc5-2)
        (CITY city5)
        (AIRPORT loc5-1)
        (TRUCK truck6-1)
        (LOCATION loc6-1)
        (LOCATION loc6-2)
        (CITY city6)
        (AIRPORT loc6-1)
        (in-city loc1-1 city1)
        (in-city loc1-2 city1)
        (in-city loc2-1 city2)
        (in-city loc2-2 city2)
        (in-city loc3-1 city3)
        (in-city loc3-2 city3)
        (in-city loc4-1 city4)
        (in-city loc4-2 city4)
        (in-city loc5-1 city5)
        (in-city loc5-2 city5)
        (in-city loc6-1 city6)
        (in-city loc6-2 city6)
        (at plane1 loc4-1)
        (at plane2 loc2-1)
        (at plane3 loc5-1)
        (at truck1-1 loc1-2)
        (at truck2-1 loc2-1)
        (at truck3-1 loc3-2)
        (at truck4-1 loc4-2)
        (at truck5-1 loc5-1)
        (at truck6-1 loc6-1)
        (at package1 loc5-2)
        (at package2 loc5-2)
        (at package3 loc2-2)
        (at package4 loc3-2)
        (at package5 loc6-1)
        (at package6 loc3-2)
        (at package7 loc2-2)
        (at package8 loc3-1)
        (at package9 loc2-2)
        (at package10 loc3-2)
        (at package11 loc1-1)
    )
    (:goal (and
        (at package1 loc3-2)
        (at package2 loc3-2)
        (at package3 loc3-2)
        (at package4 loc6-1)
        (at package5 loc4-2)
        (at package6 loc1-1)
        (at package7 loc4-2)
        (at package8 loc2-2)
        (at package9 loc3-2)
        (at package10 loc3-1)
        (at package11 loc1-2)
    ))
)
;; a logistics problem instance
;; name: log12
;; #packages: 11        #cities: 6  #planes: 2
;; #locs_per_city: 2   #trucks_per_city: 1
;; #goals: 11           seed: 69437334

(define (problem log15)
    (:domain logistics-strips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        package10
        package11
        plane1
        plane2
        truck1-1
        loc1-1
        loc1-2
        city1
        truck2-1
        loc2-1
        loc2-2
        city2
        truck3-1
        loc3-1
        loc3-2
        city3
        truck4-1
        loc4-1
        loc4-2
        city4
        truck5-1
        loc5-1
        loc5-2
        city5
        truck6-1
        loc6-1
        loc6-2
        city6
    )
    (:init 
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (OBJ package7)
        (OBJ package8)
        (OBJ package9)
        (OBJ package10)
        (OBJ package11)
        (AIRPLANE plane1)
        (AIRPLANE plane2)
        (TRUCK truck1-1)
        (LOCATION loc1-1)
        (LOCATION loc1-2)
        (CITY city1)
        (AIRPORT loc1-1)
        (TRUCK truck2-1)
        (LOCATION loc2-1)
        (LOCATION loc2-2)
        (CITY city2)
        (AIRPORT loc2-1)
        (TRUCK truck3-1)
        (LOCATION loc3-1)
        (LOCATION loc3-2)
        (CITY city3)
        (AIRPORT loc3-1)
        (TRUCK truck4-1)
        (LOCATION loc4-1)
        (LOCATION loc4-2)
        (CITY city4)
        (AIRPORT loc4-1)
        (TRUCK truck5-1)
        (LOCATION loc5-1)
        (LOCATION loc5-2)
        (CITY city5)
        (AIRPORT loc5-1)
        (TRUCK truck6-1)
        (LOCATION loc6-1)
        (LOCATION loc6-2)
        (CITY city6)
        (AIRPORT loc6-1)
        (in-city loc1-1 city1)
        (in-city loc1-2 city1)
        (in-city loc2-1 city2)
        (in-city loc2-2 city2)
        (in-city loc3-1 city3)
        (in-city loc3-2 city3)
        (in-city loc4-1 city4)
        (in-city loc4-2 city4)
        (in-city loc5-1 city5)
        (in-city loc5-2 city5)
        (in-city loc6-1 city6)
        (in-city loc6-2 city6)
        (at plane1 loc3-1)
        (at plane2 loc4-1)
        (at truck1-1 loc1-2)
        (at truck2-1 loc2-2)
        (at truck3-1 loc3-1)
        (at truck4-1 loc4-1)
        (at truck5-1 loc5-2)
        (at truck6-1 loc6-1)
        (at package1 loc4-2)
        (at package2 loc1-2)
        (at package3 loc3-2)
        (at package4 loc3-1)
        (at package5 loc5-1)
        (at package6 loc2-2)
        (at package7 loc1-2)
        (at package8 loc6-1)
        (at package9 loc5-2)
        (at package10 loc3-2)
        (at package11 loc4-1)
    )
    (:goal (and
        (at package1 loc6-2)
        (at package2 loc4-1)
        (at package3 loc5-1)
        (at package4 loc5-1)
        (at package5 loc5-2)
        (at package6 loc6-2)
        (at package7 loc4-1)
        (at package8 loc3-2)
        (at package9 loc3-1)
        (at package10 loc1-1)
        (at package11 loc2-1)
    ))
)
;; a logistics problem instance
;; name: log13
;; #packages: 6        #cities: 6  #planes: 1
;; #locs_per_city: 2   #trucks_per_city: 1
;; #goals: 6           seed: 68345397

(define (problem log16)
    (:domain logistics-strips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        plane1
        truck1-1
        loc1-1
        loc1-2
        city1
        truck2-1
        loc2-1
        loc2-2
        city2
        truck3-1
        loc3-1
        loc3-2
        city3
        truck4-1
        loc4-1
        loc4-2
        city4
        truck5-1
        loc5-1
        loc5-2
        city5
        truck6-1
        loc6-1
        loc6-2
        city6
    )
    (:init 
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (AIRPLANE plane1)
        (TRUCK truck1-1)
        (LOCATION loc1-1)
        (LOCATION loc1-2)
        (CITY city1)
        (AIRPORT loc1-1)
        (TRUCK truck2-1)
        (LOCATION loc2-1)
        (LOCATION loc2-2)
        (CITY city2)
        (AIRPORT loc2-1)
        (TRUCK truck3-1)
        (LOCATION loc3-1)
        (LOCATION loc3-2)
        (CITY city3)
        (AIRPORT loc3-1)
        (TRUCK truck4-1)
        (LOCATION loc4-1)
        (LOCATION loc4-2)
        (CITY city4)
        (AIRPORT loc4-1)
        (TRUCK truck5-1)
        (LOCATION loc5-1)
        (LOCATION loc5-2)
        (CITY city5)
        (AIRPORT loc5-1)
        (TRUCK truck6-1)
        (LOCATION loc6-1)
        (LOCATION loc6-2)
        (CITY city6)
        (AIRPORT loc6-1)
        (in-city loc1-1 city1)
        (in-city loc1-2 city1)
        (in-city loc2-1 city2)
        (in-city loc2-2 city2)
        (in-city loc3-1 city3)
        (in-city loc3-2 city3)
        (in-city loc4-1 city4)
        (in-city loc4-2 city4)
        (in-city loc5-1 city5)
        (in-city loc5-2 city5)
        (in-city loc6-1 city6)
        (in-city loc6-2 city6)
        (at plane1 loc2-1)
        (at truck1-1 loc1-1)
        (at truck2-1 loc2-2)
        (at truck3-1 loc3-1)
        (at truck4-1 loc4-2)
        (at truck5-1 loc5-2)
        (at truck6-1 loc6-1)
        (at package1 loc2-2)
        (at package2 loc3-2)
        (at package3 loc4-2)
        (at package4 loc5-2)
        (at package5 loc6-2)
        (at package6 loc5-1)
    )
    (:goal (and
        (at package1 loc1-1)
        (at package2 loc4-1)
        (at package3 loc5-2)
        (at package4 loc4-2)
        (at package5 loc6-1)
        (at package6 loc6-1)
    ))
)
;; a logistics problem instance
;; name: log14
;; #packages: 6        #cities: 6  #planes: 1
;; #locs_per_city: 2   #trucks_per_city: 1
;; #goals: 6           seed: 68345397
;; modified by hand from log13.
;; placed packages in circle & one destination

(define (problem log17)
    (:domain logistics-strips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        plane1
        truck1-1
        loc1-1
        loc1-2
        city1
        truck2-1
        loc2-1
        loc2-2
        city2
        truck3-1
        loc3-1
        loc3-2
        city3
        truck4-1
        loc4-1
        loc4-2
        city4
        truck5-1
        loc5-1
        loc5-2
        city5
        truck6-1
        loc6-1
        loc6-2
        city6
    )
    (:init 
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (AIRPLANE plane1)
        (TRUCK truck1-1)
        (LOCATION loc1-1)
        (LOCATION loc1-2)
        (CITY city1)
        (AIRPORT loc1-1)
        (TRUCK truck2-1)
        (LOCATION loc2-1)
        (LOCATION loc2-2)
        (CITY city2)
        (AIRPORT loc2-1)
        (TRUCK truck3-1)
        (LOCATION loc3-1)
        (LOCATION loc3-2)
        (CITY city3)
        (AIRPORT loc3-1)
        (TRUCK truck4-1)
        (LOCATION loc4-1)
        (LOCATION loc4-2)
        (CITY city4)
        (AIRPORT loc4-1)
        (TRUCK truck5-1)
        (LOCATION loc5-1)
        (LOCATION loc5-2)
        (CITY city5)
        (AIRPORT loc5-1)
        (TRUCK truck6-1)
        (LOCATION loc6-1)
        (LOCATION loc6-2)
        (CITY city6)
        (AIRPORT loc6-1)
        (in-city loc1-1 city1)
        (in-city loc1-2 city1)
        (in-city loc2-1 city2)
        (in-city loc2-2 city2)
        (in-city loc3-1 city3)
        (in-city loc3-2 city3)
        (in-city loc4-1 city4)
        (in-city loc4-2 city4)
        (in-city loc5-1 city5)
        (in-city loc5-2 city5)
        (in-city loc6-1 city6)
        (in-city loc6-2 city6)
        (at plane1 loc2-1)
        (at truck1-1 loc1-1)
        (at truck2-1 loc2-2)
        (at truck3-1 loc3-1)
        (at truck4-1 loc4-2)
        (at truck5-1 loc5-2)
        (at truck6-1 loc6-1)
        (at package1 loc1-2)
        (at package2 loc2-2)
        (at package3 loc3-2)
        (at package4 loc4-2)
        (at package5 loc5-2)
        (at package6 loc6-2)
    )
    (:goal (and
        (at package1 loc6-2)
        (at package2 loc6-2)
        (at package3 loc6-2)
        (at package4 loc6-2)
        (at package5 loc6-2)
        (at package6 loc6-2)
    ))
)
;; a logistics problem instance
;; name: log15
;; #packages: 8        #cities: 6  #planes: 2
;; #locs_per_city: 3   #trucks_per_city: 2
;; #goals: 8           seed: 112000697

(define (problem log18)
    (:domain logistics-strips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        plane1
        plane2
        truck1-1
        truck1-2
        loc1-1
        loc1-2
        loc1-3
        city1
        truck2-1
        truck2-2
        loc2-1
        loc2-2
        loc2-3
        city2
        truck3-1
        truck3-2
        loc3-1
        loc3-2
        loc3-3
        city3
        truck4-1
        truck4-2
        loc4-1
        loc4-2
        loc4-3
        city4
        truck5-1
        truck5-2
        loc5-1
        loc5-2
        loc5-3
        city5
        truck6-1
        truck6-2
        loc6-1
        loc6-2
        loc6-3
        city6
    )
    (:init 
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (OBJ package7)
        (OBJ package8)
        (AIRPLANE plane1)
        (AIRPLANE plane2)
        (TRUCK truck1-1)
        (TRUCK truck1-2)
        (LOCATION loc1-1)
        (LOCATION loc1-2)
        (LOCATION loc1-3)
        (CITY city1)
        (AIRPORT loc1-1)
        (TRUCK truck2-1)
        (TRUCK truck2-2)
        (LOCATION loc2-1)
        (LOCATION loc2-2)
        (LOCATION loc2-3)
        (CITY city2)
        (AIRPORT loc2-1)
        (TRUCK truck3-1)
        (TRUCK truck3-2)
        (LOCATION loc3-1)
        (LOCATION loc3-2)
        (LOCATION loc3-3)
        (CITY city3)
        (AIRPORT loc3-1)
        (TRUCK truck4-1)
        (TRUCK truck4-2)
        (LOCATION loc4-1)
        (LOCATION loc4-2)
        (LOCATION loc4-3)
        (CITY city4)
        (AIRPORT loc4-1)
        (TRUCK truck5-1)
        (TRUCK truck5-2)
        (LOCATION loc5-1)
        (LOCATION loc5-2)
        (LOCATION loc5-3)
        (CITY city5)
        (AIRPORT loc5-1)
        (TRUCK truck6-1)
        (TRUCK truck6-2)
        (LOCATION loc6-1)
        (LOCATION loc6-2)
        (LOCATION loc6-3)
        (CITY city6)
        (AIRPORT loc6-1)
        (in-city loc1-1 city1)
        (in-city loc1-2 city1)
        (in-city loc1-3 city1)
        (in-city loc2-1 city2)
        (in-city loc2-2 city2)
        (in-city loc2-3 city2)
        (in-city loc3-1 city3)
        (in-city loc3-2 city3)
        (in-city loc3-3 city3)
        (in-city loc4-1 city4)
        (in-city loc4-2 city4)
        (in-city loc4-3 city4)
        (in-city loc5-1 city5)
        (in-city loc5-2 city5)
        (in-city loc5-3 city5)
        (in-city loc6-1 city6)
        (in-city loc6-2 city6)
        (in-city loc6-3 city6)
        (at plane1 loc2-1)
        (at plane2 loc3-1)
        (at truck1-1 loc1-1)
        (at truck1-2 loc1-1)
        (at truck2-1 loc2-1)
        (at truck2-2 loc2-1)
        (at truck3-1 loc3-3)
        (at truck3-2 loc3-2)
        (at truck4-1 loc4-2)
        (at truck4-2 loc4-3)
        (at truck5-1 loc5-2)
        (at truck5-2 loc5-1)
        (at truck6-1 loc6-3)
        (at truck6-2 loc6-2)
        (at package1 loc2-3)
        (at package2 loc4-2)
        (at package3 loc5-3)
        (at package4 loc1-2)
        (at package5 loc5-1)
        (at package6 loc4-2)
        (at package7 loc2-1)
        (at package8 loc1-2)
    )
    (:goal (and
        (at package1 loc5-3)
        (at package2 loc4-3)
        (at package3 loc5-3)
        (at package4 loc4-1)
        (at package5 loc1-2)
        (at package6 loc1-3)
        (at package7 loc2-3)
        (at package8 loc2-3)
    ))
)
;; a logistics problem instance
;; name: log16
;; #packages: 9        #cities: 6  #planes: 2
;; #locs_per_city: 2   #trucks_per_city: 1
;; #goals: 9           seed: 70842326

(define (problem log19)
    (:domain logistics-strips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        plane1
        plane2
        truck1-1
        loc1-1
        loc1-2
        city1
        truck2-1
        loc2-1
        loc2-2
        city2
        truck3-1
        loc3-1
        loc3-2
        city3
        truck4-1
        loc4-1
        loc4-2
        city4
        truck5-1
        loc5-1
        loc5-2
        city5
        truck6-1
        loc6-1
        loc6-2
        city6
    )
    (:init 
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (OBJ package7)
        (OBJ package8)
        (OBJ package9)
        (AIRPLANE plane1)
        (AIRPLANE plane2)
        (TRUCK truck1-1)
        (LOCATION loc1-1)
        (LOCATION loc1-2)
        (CITY city1)
        (AIRPORT loc1-1)
        (TRUCK truck2-1)
        (LOCATION loc2-1)
        (LOCATION loc2-2)
        (CITY city2)
        (AIRPORT loc2-1)
        (TRUCK truck3-1)
        (LOCATION loc3-1)
        (LOCATION loc3-2)
        (CITY city3)
        (AIRPORT loc3-1)
        (TRUCK truck4-1)
        (LOCATION loc4-1)
        (LOCATION loc4-2)
        (CITY city4)
        (AIRPORT loc4-1)
        (TRUCK truck5-1)
        (LOCATION loc5-1)
        (LOCATION loc5-2)
        (CITY city5)
        (AIRPORT loc5-1)
        (TRUCK truck6-1)
        (LOCATION loc6-1)
        (LOCATION loc6-2)
        (CITY city6)
        (AIRPORT loc6-1)
        (in-city loc1-1 city1)
        (in-city loc1-2 city1)
        (in-city loc2-1 city2)
        (in-city loc2-2 city2)
        (in-city loc3-1 city3)
        (in-city loc3-2 city3)
        (in-city loc4-1 city4)
        (in-city loc4-2 city4)
        (in-city loc5-1 city5)
        (in-city loc5-2 city5)
        (in-city loc6-1 city6)
        (in-city loc6-2 city6)
        (at plane1 loc5-1)
        (at plane2 loc4-1)
        (at truck1-1 loc1-2)
        (at truck2-1 loc2-2)
        (at truck3-1 loc3-1)
        (at truck4-1 loc4-1)
        (at truck5-1 loc5-2)
        (at truck6-1 loc6-1)
        (at package1 loc6-2)
        (at package2 loc5-2)
        (at package3 loc3-2)
        (at package4 loc3-1)
        (at package5 loc1-1)
        (at package6 loc6-2)
        (at package7 loc1-2)
        (at package8 loc4-1)
        (at package9 loc5-2)
    )
    (:goal (and
        (at package1 loc5-2)
        (at package2 loc4-1)
        (at package3 loc6-2)
        (at package4 loc2-1)
        (at package5 loc1-1)
        (at package6 loc5-1)
        (at package7 loc1-2)
        (at package8 loc2-2)
        (at package9 loc6-1)
    ))
)
;; a logistics problem instance
;; name: log17
;; #packages: 10        #cities: 7  #planes: 2
;; #locs_per_city: 2   #trucks_per_city: 1
;; #goals: 10           seed: 62880555
;; modified by hand to increase regularity
;;    force more sharing in solution; harder to solve

(define (problem log20)
    (:domain logistics-strips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        package10
        plane1
        plane2
        truck1-1
        loc1-1
        loc1-2
        city1
        truck2-1
        loc2-1
        loc2-2
        city2
        truck3-1
        loc3-1
        loc3-2
        city3
        truck4-1
        loc4-1
        loc4-2
        city4
        truck5-1
        loc5-1
        loc5-2
        city5
        truck6-1
        loc6-1
        loc6-2
        city6
        truck7-1
        loc7-1
        loc7-2
        city7
    )
    (:init 
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (OBJ package7)
        (OBJ package8)
        (OBJ package9)
        (OBJ package10)
        (AIRPLANE plane1)
        (AIRPLANE plane2)
        (TRUCK truck1-1)
        (LOCATION loc1-1)
        (LOCATION loc1-2)
        (CITY city1)
        (AIRPORT loc1-1)
        (TRUCK truck2-1)
        (LOCATION loc2-1)
        (LOCATION loc2-2)
        (CITY city2)
        (AIRPORT loc2-1)
        (TRUCK truck3-1)
        (LOCATION loc3-1)
        (LOCATION loc3-2)
        (CITY city3)
        (AIRPORT loc3-1)
        (TRUCK truck4-1)
        (LOCATION loc4-1)
        (LOCATION loc4-2)
        (CITY city4)
        (AIRPORT loc4-1)
        (TRUCK truck5-1)
        (LOCATION loc5-1)
        (LOCATION loc5-2)
        (CITY city5)
        (AIRPORT loc5-1)
        (TRUCK truck6-1)
        (LOCATION loc6-1)
        (LOCATION loc6-2)
        (CITY city6)
        (AIRPORT loc6-1)
        (TRUCK truck7-1)
        (LOCATION loc7-1)
        (LOCATION loc7-2)
        (CITY city7)
        (AIRPORT loc7-1)
        (in-city loc1-1 city1)
        (in-city loc1-2 city1)
        (in-city loc2-1 city2)
        (in-city loc2-2 city2)
        (in-city loc3-1 city3)
        (in-city loc3-2 city3)
        (in-city loc4-1 city4)
        (in-city loc4-2 city4)
        (in-city loc5-1 city5)
        (in-city loc5-2 city5)
        (in-city loc6-1 city6)
        (in-city loc6-2 city6)
        (in-city loc7-1 city7)
        (in-city loc7-2 city7)
        (at plane1 loc1-1)
        (at plane2 loc1-1)
        (at truck1-1 loc1-1)
        (at truck2-1 loc2-1)
        (at truck3-1 loc3-2)
        (at truck4-1 loc4-1)
        (at truck5-1 loc5-1)
        (at truck6-1 loc6-2)
        (at truck7-1 loc7-1)

        (at package1 loc1-2)
        (at package2 loc2-2)
        (at package3 loc3-2)
        (at package4 loc4-2)
        (at package5 loc5-2)
        (at package6 loc6-2)
        (at package7 loc7-2)
        (at package8 loc1-2)
        (at package9 loc2-2)
        (at package10 loc3-2)
    )
    (:goal (and
        (at package1 loc3-2)
        (at package2 loc4-2)
        (at package3 loc5-2)
        (at package4 loc6-2)
        (at package5 loc6-2)
        (at package6 loc5-2)
        (at package7 loc4-2)
        (at package8 loc5-2)
        (at package9 loc6-2)
        (at package10 loc7-2)
    ))
)

;; a logistics problem instance
;; name: log06
;; #packages: 10        #cities: 6  #planes: 3
;; #locs_per_city: 2   #trucks_per_city: 1
;; #goals: 10           seed: 12268313

(define (problem log21)
    (:domain logistics-strips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        package10
        plane1
        plane2
        plane3
        truck1-1
        loc1-1
        loc1-2
        city1
        truck2-1
        loc2-1
        loc2-2
        city2
        truck3-1
        loc3-1
        loc3-2
        city3
        truck4-1
        loc4-1
        loc4-2
        city4
        truck5-1
        loc5-1
        loc5-2
        city5
        truck6-1
        loc6-1
        loc6-2
        city6
    )
    (:init 
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (OBJ package7)
        (OBJ package8)
        (OBJ package9)
        (OBJ package10)
        (AIRPLANE plane1)
        (AIRPLANE plane2)
        (AIRPLANE plane3)
        (TRUCK truck1-1)
        (LOCATION loc1-1)
        (LOCATION loc1-2)
        (CITY city1)
        (AIRPORT loc1-1)
        (TRUCK truck2-1)
        (LOCATION loc2-1)
        (LOCATION loc2-2)
        (CITY city2)
        (AIRPORT loc2-1)
        (TRUCK truck3-1)
        (LOCATION loc3-1)
        (LOCATION loc3-2)
        (CITY city3)
        (AIRPORT loc3-1)
        (TRUCK truck4-1)
        (LOCATION loc4-1)
        (LOCATION loc4-2)
        (CITY city4)
        (AIRPORT loc4-1)
        (TRUCK truck5-1)
        (LOCATION loc5-1)
        (LOCATION loc5-2)
        (CITY city5)
        (AIRPORT loc5-1)
        (TRUCK truck6-1)
        (LOCATION loc6-1)
        (LOCATION loc6-2)
        (CITY city6)
        (AIRPORT loc6-1)
        (in-city loc1-1 city1)
        (in-city loc1-2 city1)
        (in-city loc2-1 city2)
        (in-city loc2-2 city2)
        (in-city loc3-1 city3)
        (in-city loc3-2 city3)
        (in-city loc4-1 city4)
        (in-city loc4-2 city4)
        (in-city loc5-1 city5)
        (in-city loc5-2 city5)
        (in-city loc6-1 city6)
        (in-city loc6-2 city6)
        (at plane1 loc6-1)
        (at plane2 loc5-1)
        (at plane3 loc4-1)
        (at truck1-1 loc1-1)
        (at truck2-1 loc2-2)
        (at truck3-1 loc3-2)
        (at truck4-1 loc4-1)
        (at truck5-1 loc5-2)
        (at truck6-1 loc6-2)
        (at package1 loc1-2)
        (at package2 loc6-2)
        (at package3 loc5-2)
        (at package4 loc6-2)
        (at package5 loc1-1)
        (at package6 loc5-1)
        (at package7 loc2-1)
        (at package8 loc1-2)
        (at package9 loc4-2)
        (at package10 loc4-1)
    )
    (:goal (and
        (at package1 loc6-1)
        (at package2 loc4-2)
        (at package3 loc3-1)
        (at package4 loc2-2)
        (at package5 loc3-1)
        (at package6 loc1-1)
        (at package7 loc4-2)
        (at package8 loc4-2)
        (at package9 loc3-2)
        (at package10 loc4-1)
    ))
)
;; a logistics problem instance
;; name: log19
;; #packages: 9        #cities: 5  #planes: 2
;; #locs_per_city: 3   #trucks_per_city: 1
;; #goals: 9           seed: 74368277

(define (problem log22)
    (:domain logistics-strips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        plane1
        plane2
        truck1-1
        loc1-1
        loc1-2
        loc1-3
        city1
        truck2-1
        loc2-1
        loc2-2
        loc2-3
        city2
        truck3-1
        loc3-1
        loc3-2
        loc3-3
        city3
        truck4-1
        loc4-1
        loc4-2
        loc4-3
        city4
        truck5-1
        loc5-1
        loc5-2
        loc5-3
        city5
    )
    (:init 
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (OBJ package7)
        (OBJ package8)
        (OBJ package9)
        (AIRPLANE plane1)
        (AIRPLANE plane2)
        (TRUCK truck1-1)
        (LOCATION loc1-1)
        (LOCATION loc1-2)
        (LOCATION loc1-3)
        (CITY city1)
        (AIRPORT loc1-1)
        (TRUCK truck2-1)
        (LOCATION loc2-1)
        (LOCATION loc2-2)
        (LOCATION loc2-3)
        (CITY city2)
        (AIRPORT loc2-1)
        (TRUCK truck3-1)
        (LOCATION loc3-1)
        (LOCATION loc3-2)
        (LOCATION loc3-3)
        (CITY city3)
        (AIRPORT loc3-1)
        (TRUCK truck4-1)
        (LOCATION loc4-1)
        (LOCATION loc4-2)
        (LOCATION loc4-3)
        (CITY city4)
        (AIRPORT loc4-1)
        (TRUCK truck5-1)
        (LOCATION loc5-1)
        (LOCATION loc5-2)
        (LOCATION loc5-3)
        (CITY city5)
        (AIRPORT loc5-1)
        (in-city loc1-1 city1)
        (in-city loc1-2 city1)
        (in-city loc1-3 city1)
        (in-city loc2-1 city2)
        (in-city loc2-2 city2)
        (in-city loc2-3 city2)
        (in-city loc3-1 city3)
        (in-city loc3-2 city3)
        (in-city loc3-3 city3)
        (in-city loc4-1 city4)
        (in-city loc4-2 city4)
        (in-city loc4-3 city4)
        (in-city loc5-1 city5)
        (in-city loc5-2 city5)
        (in-city loc5-3 city5)
        (at plane1 loc1-1)
        (at plane2 loc1-1)
        (at truck1-1 loc1-3)
        (at truck2-1 loc2-3)
        (at truck3-1 loc3-3)
        (at truck4-1 loc4-1)
        (at truck5-1 loc5-2)
        (at package1 loc5-3)
        (at package2 loc2-3)
        (at package3 loc4-1)
        (at package4 loc3-3)
        (at package5 loc4-3)
        (at package6 loc2-2)
        (at package7 loc1-2)
        (at package8 loc5-1)
        (at package9 loc5-1)
    )
    (:goal (and
        (at package1 loc4-3)
        (at package2 loc4-2)
        (at package3 loc2-3)
        (at package4 loc5-2)
        (at package5 loc1-2)
        (at package6 loc5-3)
        (at package7 loc3-3)
        (at package8 loc2-2)
        (at package9 loc1-1)
    ))
)
;; a logistics problem instance
;; name: log20
;; #packages: 9        #cities: 5  #planes: 2
;; #locs_per_city: 3   #trucks_per_city: 1
;; #goals: 9           seed: 79224903

(define (problem log23)
    (:domain logistics-strips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        plane1
        plane2
        truck1-1
        loc1-1
        loc1-2
        loc1-3
        city1
        truck2-1
        loc2-1
        loc2-2
        loc2-3
        city2
        truck3-1
        loc3-1
        loc3-2
        loc3-3
        city3
        truck4-1
        loc4-1
        loc4-2
        loc4-3
        city4
        truck5-1
        loc5-1
        loc5-2
        loc5-3
        city5
    )
    (:init 
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (OBJ package7)
        (OBJ package8)
        (OBJ package9)
        (AIRPLANE plane1)
        (AIRPLANE plane2)
        (TRUCK truck1-1)
        (LOCATION loc1-1)
        (LOCATION loc1-2)
        (LOCATION loc1-3)
        (CITY city1)
        (AIRPORT loc1-1)
        (TRUCK truck2-1)
        (LOCATION loc2-1)
        (LOCATION loc2-2)
        (LOCATION loc2-3)
        (CITY city2)
        (AIRPORT loc2-1)
        (TRUCK truck3-1)
        (LOCATION loc3-1)
        (LOCATION loc3-2)
        (LOCATION loc3-3)
        (CITY city3)
        (AIRPORT loc3-1)
        (TRUCK truck4-1)
        (LOCATION loc4-1)
        (LOCATION loc4-2)
        (LOCATION loc4-3)
        (CITY city4)
        (AIRPORT loc4-1)
        (TRUCK truck5-1)
        (LOCATION loc5-1)
        (LOCATION loc5-2)
        (LOCATION loc5-3)
        (CITY city5)
        (AIRPORT loc5-1)
        (in-city loc1-1 city1)
        (in-city loc1-2 city1)
        (in-city loc1-3 city1)
        (in-city loc2-1 city2)
        (in-city loc2-2 city2)
        (in-city loc2-3 city2)
        (in-city loc3-1 city3)
        (in-city loc3-2 city3)
        (in-city loc3-3 city3)
        (in-city loc4-1 city4)
        (in-city loc4-2 city4)
        (in-city loc4-3 city4)
        (in-city loc5-1 city5)
        (in-city loc5-2 city5)
        (in-city loc5-3 city5)
        (at plane1 loc3-1)
        (at plane2 loc1-1)
        (at truck1-1 loc1-1)
        (at truck2-1 loc2-1)
        (at truck3-1 loc3-3)
        (at truck4-1 loc4-3)
        (at truck5-1 loc5-3)
        (at package1 loc5-1)
        (at package2 loc2-3)
        (at package3 loc2-3)
        (at package4 loc4-2)
        (at package5 loc5-2)
        (at package6 loc5-3)
        (at package7 loc5-3)
        (at package8 loc2-1)
        (at package9 loc5-1)
    )
    (:goal (and
        (at package1 loc5-1)
        (at package2 loc1-2)
        (at package3 loc2-1)
        (at package4 loc5-1)
        (at package5 loc4-3)
        (at package6 loc2-2)
        (at package7 loc1-3)
        (at package8 loc4-2)
        (at package9 loc3-2)
    ))
)
;; a logistics problem instance
;; name: log21
;; #packages: 9        #cities: 5  #planes: 2
;; #locs_per_city: 3   #trucks_per_city: 1
;; #goals: 9           seed: 70675221

(define (problem log24)
    (:domain logistics-strips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        plane1
        plane2
        truck1-1
        loc1-1
        loc1-2
        loc1-3
        city1
        truck2-1
        loc2-1
        loc2-2
        loc2-3
        city2
        truck3-1
        loc3-1
        loc3-2
        loc3-3
        city3
        truck4-1
        loc4-1
        loc4-2
        loc4-3
        city4
        truck5-1
        loc5-1
        loc5-2
        loc5-3
        city5
    )
    (:init 
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (OBJ package7)
        (OBJ package8)
        (OBJ package9)
        (AIRPLANE plane1)
        (AIRPLANE plane2)
        (TRUCK truck1-1)
        (LOCATION loc1-1)
        (LOCATION loc1-2)
        (LOCATION loc1-3)
        (CITY city1)
        (AIRPORT loc1-1)
        (TRUCK truck2-1)
        (LOCATION loc2-1)
        (LOCATION loc2-2)
        (LOCATION loc2-3)
        (CITY city2)
        (AIRPORT loc2-1)
        (TRUCK truck3-1)
        (LOCATION loc3-1)
        (LOCATION loc3-2)
        (LOCATION loc3-3)
        (CITY city3)
        (AIRPORT loc3-1)
        (TRUCK truck4-1)
        (LOCATION loc4-1)
        (LOCATION loc4-2)
        (LOCATION loc4-3)
        (CITY city4)
        (AIRPORT loc4-1)
        (TRUCK truck5-1)
        (LOCATION loc5-1)
        (LOCATION loc5-2)
        (LOCATION loc5-3)
        (CITY city5)
        (AIRPORT loc5-1)
        (in-city loc1-1 city1)
        (in-city loc1-2 city1)
        (in-city loc1-3 city1)
        (in-city loc2-1 city2)
        (in-city loc2-2 city2)
        (in-city loc2-3 city2)
        (in-city loc3-1 city3)
        (in-city loc3-2 city3)
        (in-city loc3-3 city3)
        (in-city loc4-1 city4)
        (in-city loc4-2 city4)
        (in-city loc4-3 city4)
        (in-city loc5-1 city5)
        (in-city loc5-2 city5)
        (in-city loc5-3 city5)
        (at plane1 loc4-1)
        (at plane2 loc5-1)
        (at truck1-1 loc1-1)
        (at truck2-1 loc2-3)
        (at truck3-1 loc3-2)
        (at truck4-1 loc4-1)
        (at truck5-1 loc5-2)
        (at package1 loc4-1)
        (at package2 loc4-3)
        (at package3 loc3-2)
        (at package4 loc2-2)
        (at package5 loc5-3)
        (at package6 loc4-3)
        (at package7 loc3-2)
        (at package8 loc2-3)
        (at package9 loc3-1)
    )
    (:goal (and
        (at package1 loc3-2)
        (at package2 loc5-3)
        (at package3 loc5-2)
        (at package4 loc2-3)
        (at package5 loc4-1)
        (at package6 loc1-2)
        (at package7 loc4-2)
        (at package8 loc5-1)
        (at package9 loc1-2)
    ))
)
;; a logistics problem instance
;; name: log22
;; #packages: 9        #cities: 5  #planes: 2
;; #locs_per_city: 3   #trucks_per_city: 1
;; #goals: 9           seed: 76638317

(define (problem log25)
    (:domain logistics-strips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        plane1
        plane2
        truck1-1
        loc1-1
        loc1-2
        loc1-3
        city1
        truck2-1
        loc2-1
        loc2-2
        loc2-3
        city2
        truck3-1
        loc3-1
        loc3-2
        loc3-3
        city3
        truck4-1
        loc4-1
        loc4-2
        loc4-3
        city4
        truck5-1
        loc5-1
        loc5-2
        loc5-3
        city5
    )
    (:init 
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (OBJ package7)
        (OBJ package8)
        (OBJ package9)
        (AIRPLANE plane1)
        (AIRPLANE plane2)
        (TRUCK truck1-1)
        (LOCATION loc1-1)
        (LOCATION loc1-2)
        (LOCATION loc1-3)
        (CITY city1)
        (AIRPORT loc1-1)
        (TRUCK truck2-1)
        (LOCATION loc2-1)
        (LOCATION loc2-2)
        (LOCATION loc2-3)
        (CITY city2)
        (AIRPORT loc2-1)
        (TRUCK truck3-1)
        (LOCATION loc3-1)
        (LOCATION loc3-2)
        (LOCATION loc3-3)
        (CITY city3)
        (AIRPORT loc3-1)
        (TRUCK truck4-1)
        (LOCATION loc4-1)
        (LOCATION loc4-2)
        (LOCATION loc4-3)
        (CITY city4)
        (AIRPORT loc4-1)
        (TRUCK truck5-1)
        (LOCATION loc5-1)
        (LOCATION loc5-2)
        (LOCATION loc5-3)
        (CITY city5)
        (AIRPORT loc5-1)
        (in-city loc1-1 city1)
        (in-city loc1-2 city1)
        (in-city loc1-3 city1)
        (in-city loc2-1 city2)
        (in-city loc2-2 city2)
        (in-city loc2-3 city2)
        (in-city loc3-1 city3)
        (in-city loc3-2 city3)
        (in-city loc3-3 city3)
        (in-city loc4-1 city4)
        (in-city loc4-2 city4)
        (in-city loc4-3 city4)
        (in-city loc5-1 city5)
        (in-city loc5-2 city5)
        (in-city loc5-3 city5)
        (at plane1 loc4-1)
        (at plane2 loc5-1)
        (at truck1-1 loc1-1)
        (at truck2-1 loc2-2)
        (at truck3-1 loc3-1)
        (at truck4-1 loc4-1)
        (at truck5-1 loc5-2)
        (at package1 loc5-1)
        (at package2 loc5-3)
        (at package3 loc1-3)
        (at package4 loc1-1)
        (at package5 loc5-3)
        (at package6 loc5-3)
        (at package7 loc5-2)
        (at package8 loc5-2)
        (at package9 loc2-3)
    )
    (:goal (and
        (at package1 loc2-3)
        (at package2 loc3-3)
        (at package3 loc3-1)
        (at package4 loc2-3)
        (at package5 loc2-1)
        (at package6 loc4-3)
        (at package7 loc5-1)
        (at package8 loc5-2)
        (at package9 loc4-2)
    ))
)
;; a logistics problem instance
;; name: log23
;; #packages: 9        #cities: 5  #planes: 2
;; #locs_per_city: 3   #trucks_per_city: 1
;; #goals: 9           seed: 84823437

(define (problem log26)
    (:domain logistics-strips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        plane1
        plane2
        truck1-1
        loc1-1
        loc1-2
        loc1-3
        city1
        truck2-1
        loc2-1
        loc2-2
        loc2-3
        city2
        truck3-1
        loc3-1
        loc3-2
        loc3-3
        city3
        truck4-1
        loc4-1
        loc4-2
        loc4-3
        city4
        truck5-1
        loc5-1
        loc5-2
        loc5-3
        city5
    )
    (:init 
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (OBJ package7)
        (OBJ package8)
        (OBJ package9)
        (AIRPLANE plane1)
        (AIRPLANE plane2)
        (TRUCK truck1-1)
        (LOCATION loc1-1)
        (LOCATION loc1-2)
        (LOCATION loc1-3)
        (CITY city1)
        (AIRPORT loc1-1)
        (TRUCK truck2-1)
        (LOCATION loc2-1)
        (LOCATION loc2-2)
        (LOCATION loc2-3)
        (CITY city2)
        (AIRPORT loc2-1)
        (TRUCK truck3-1)
        (LOCATION loc3-1)
        (LOCATION loc3-2)
        (LOCATION loc3-3)
        (CITY city3)
        (AIRPORT loc3-1)
        (TRUCK truck4-1)
        (LOCATION loc4-1)
        (LOCATION loc4-2)
        (LOCATION loc4-3)
        (CITY city4)
        (AIRPORT loc4-1)
        (TRUCK truck5-1)
        (LOCATION loc5-1)
        (LOCATION loc5-2)
        (LOCATION loc5-3)
        (CITY city5)
        (AIRPORT loc5-1)
        (in-city loc1-1 city1)
        (in-city loc1-2 city1)
        (in-city loc1-3 city1)
        (in-city loc2-1 city2)
        (in-city loc2-2 city2)
        (in-city loc2-3 city2)
        (in-city loc3-1 city3)
        (in-city loc3-2 city3)
        (in-city loc3-3 city3)
        (in-city loc4-1 city4)
        (in-city loc4-2 city4)
        (in-city loc4-3 city4)
        (in-city loc5-1 city5)
        (in-city loc5-2 city5)
        (in-city loc5-3 city5)
        (at plane1 loc2-1)
        (at plane2 loc1-1)
        (at truck1-1 loc1-1)
        (at truck2-1 loc2-2)
        (at truck3-1 loc3-3)
        (at truck4-1 loc4-1)
        (at truck5-1 loc5-1)
        (at package1 loc5-2)
        (at package2 loc3-1)
        (at package3 loc4-3)
        (at package4 loc2-3)
        (at package5 loc3-1)
        (at package6 loc1-1)
        (at package7 loc4-3)
        (at package8 loc4-3)
        (at package9 loc4-3)
    )
    (:goal (and
        (at package1 loc3-2)
        (at package2 loc5-2)
        (at package3 loc4-3)
        (at package4 loc3-2)
        (at package5 loc3-1)
        (at package6 loc3-3)
        (at package7 loc3-2)
        (at package8 loc2-3)
        (at package9 loc4-3)
    ))
)
;; a logistics problem instance
;; name: log24
;; #packages: 9        #cities: 5  #planes: 2
;; #locs_per_city: 3   #trucks_per_city: 1
;; #goals: 9           seed: 93568004

(define (problem log27)
    (:domain logistics-strips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        plane1
        plane2
        truck1-1
        loc1-1
        loc1-2
        loc1-3
        city1
        truck2-1
        loc2-1
        loc2-2
        loc2-3
        city2
        truck3-1
        loc3-1
        loc3-2
        loc3-3
        city3
        truck4-1
        loc4-1
        loc4-2
        loc4-3
        city4
        truck5-1
        loc5-1
        loc5-2
        loc5-3
        city5
    )
    (:init 
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (OBJ package7)
        (OBJ package8)
        (OBJ package9)
        (AIRPLANE plane1)
        (AIRPLANE plane2)
        (TRUCK truck1-1)
        (LOCATION loc1-1)
        (LOCATION loc1-2)
        (LOCATION loc1-3)
        (CITY city1)
        (AIRPORT loc1-1)
        (TRUCK truck2-1)
        (LOCATION loc2-1)
        (LOCATION loc2-2)
        (LOCATION loc2-3)
        (CITY city2)
        (AIRPORT loc2-1)
        (TRUCK truck3-1)
        (LOCATION loc3-1)
        (LOCATION loc3-2)
        (LOCATION loc3-3)
        (CITY city3)
        (AIRPORT loc3-1)
        (TRUCK truck4-1)
        (LOCATION loc4-1)
        (LOCATION loc4-2)
        (LOCATION loc4-3)
        (CITY city4)
        (AIRPORT loc4-1)
        (TRUCK truck5-1)
        (LOCATION loc5-1)
        (LOCATION loc5-2)
        (LOCATION loc5-3)
        (CITY city5)
        (AIRPORT loc5-1)
        (in-city loc1-1 city1)
        (in-city loc1-2 city1)
        (in-city loc1-3 city1)
        (in-city loc2-1 city2)
        (in-city loc2-2 city2)
        (in-city loc2-3 city2)
        (in-city loc3-1 city3)
        (in-city loc3-2 city3)
        (in-city loc3-3 city3)
        (in-city loc4-1 city4)
        (in-city loc4-2 city4)
        (in-city loc4-3 city4)
        (in-city loc5-1 city5)
        (in-city loc5-2 city5)
        (in-city loc5-3 city5)
        (at plane1 loc2-1)
        (at plane2 loc2-1)
        (at truck1-1 loc1-1)
        (at truck2-1 loc2-3)
        (at truck3-1 loc3-3)
        (at truck4-1 loc4-3)
        (at truck5-1 loc5-3)
        (at package1 loc5-3)
        (at package2 loc2-1)
        (at package3 loc1-2)
        (at package4 loc3-3)
        (at package5 loc3-2)
        (at package6 loc4-1)
        (at package7 loc1-1)
        (at package8 loc5-2)
        (at package9 loc2-3)
    )
    (:goal (and
        (at package1 loc3-2)
        (at package2 loc5-3)
        (at package3 loc3-3)
        (at package4 loc2-2)
        (at package5 loc5-3)
        (at package6 loc2-3)
        (at package7 loc4-1)
        (at package8 loc3-2)
        (at package9 loc1-3)
    ))
)
;; a logistics problem instance
;; name: log25
;; #packages: 10        #cities: 6  #planes: 3
;; #locs_per_city: 3   #trucks_per_city: 1
;; #goals: 10           seed: 15940243

(define (problem log28)
    (:domain logistics-strips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        package10
        plane1
        plane2
        plane3
        truck1-1
        loc1-1
        loc1-2
        loc1-3
        city1
        truck2-1
        loc2-1
        loc2-2
        loc2-3
        city2
        truck3-1
        loc3-1
        loc3-2
        loc3-3
        city3
        truck4-1
        loc4-1
        loc4-2
        loc4-3
        city4
        truck5-1
        loc5-1
        loc5-2
        loc5-3
        city5
        truck6-1
        loc6-1
        loc6-2
        loc6-3
        city6
    )
    (:init 
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (OBJ package7)
        (OBJ package8)
        (OBJ package9)
        (OBJ package10)
        (AIRPLANE plane1)
        (AIRPLANE plane2)
        (AIRPLANE plane3)
        (TRUCK truck1-1)
        (LOCATION loc1-1)
        (LOCATION loc1-2)
        (LOCATION loc1-3)
        (CITY city1)
        (AIRPORT loc1-1)
        (TRUCK truck2-1)
        (LOCATION loc2-1)
        (LOCATION loc2-2)
        (LOCATION loc2-3)
        (CITY city2)
        (AIRPORT loc2-1)
        (TRUCK truck3-1)
        (LOCATION loc3-1)
        (LOCATION loc3-2)
        (LOCATION loc3-3)
        (CITY city3)
        (AIRPORT loc3-1)
        (TRUCK truck4-1)
        (LOCATION loc4-1)
        (LOCATION loc4-2)
        (LOCATION loc4-3)
        (CITY city4)
        (AIRPORT loc4-1)
        (TRUCK truck5-1)
        (LOCATION loc5-1)
        (LOCATION loc5-2)
        (LOCATION loc5-3)
        (CITY city5)
        (AIRPORT loc5-1)
        (TRUCK truck6-1)
        (LOCATION loc6-1)
        (LOCATION loc6-2)
        (LOCATION loc6-3)
        (CITY city6)
        (AIRPORT loc6-1)
        (in-city loc1-1 city1)
        (in-city loc1-2 city1)
        (in-city loc1-3 city1)
        (in-city loc2-1 city2)
        (in-city loc2-2 city2)
        (in-city loc2-3 city2)
        (in-city loc3-1 city3)
        (in-city loc3-2 city3)
        (in-city loc3-3 city3)
        (in-city loc4-1 city4)
        (in-city loc4-2 city4)
        (in-city loc4-3 city4)
        (in-city loc5-1 city5)
        (in-city loc5-2 city5)
        (in-city loc5-3 city5)
        (in-city loc6-1 city6)
        (in-city loc6-2 city6)
        (in-city loc6-3 city6)
        (at plane1 loc1-1)
        (at plane2 loc1-1)
        (at plane3 loc3-1)
        (at truck1-1 loc1-2)
        (at truck2-1 loc2-1)
        (at truck3-1 loc3-3)
        (at truck4-1 loc4-1)
        (at truck5-1 loc5-3)
        (at truck6-1 loc6-3)
        (at package1 loc4-3)
        (at package2 loc1-2)
        (at package3 loc3-1)
        (at package4 loc4-1)
        (at package5 loc4-1)
        (at package6 loc4-3)
        (at package7 loc2-3)
        (at package8 loc5-3)
        (at package9 loc6-2)
        (at package10 loc5-2)
    )
    (:goal (and
        (at package1 loc2-2)
        (at package2 loc5-2)
        (at package3 loc3-1)
        (at package4 loc4-2)
        (at package5 loc2-1)
        (at package6 loc5-2)
        (at package7 loc3-3)
        (at package8 loc1-2)
        (at package9 loc3-2)
        (at package10 loc4-3)
    ))
)
;; a logistics problem instance
;; name: log26
;; #packages: 10        #cities: 6  #planes: 3
;; #locs_per_city: 3   #trucks_per_city: 1
;; #goals: 10           seed: 3967928

(define (problem log29)
    (:domain logistics-strips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        package10
        plane1
        plane2
        plane3
        truck1-1
        loc1-1
        loc1-2
        loc1-3
        city1
        truck2-1
        loc2-1
        loc2-2
        loc2-3
        city2
        truck3-1
        loc3-1
        loc3-2
        loc3-3
        city3
        truck4-1
        loc4-1
        loc4-2
        loc4-3
        city4
        truck5-1
        loc5-1
        loc5-2
        loc5-3
        city5
        truck6-1
        loc6-1
        loc6-2
        loc6-3
        city6
    )
    (:init 
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (OBJ package7)
        (OBJ package8)
        (OBJ package9)
        (OBJ package10)
        (AIRPLANE plane1)
        (AIRPLANE plane2)
        (AIRPLANE plane3)
        (TRUCK truck1-1)
        (LOCATION loc1-1)
        (LOCATION loc1-2)
        (LOCATION loc1-3)
        (CITY city1)
        (AIRPORT loc1-1)
        (TRUCK truck2-1)
        (LOCATION loc2-1)
        (LOCATION loc2-2)
        (LOCATION loc2-3)
        (CITY city2)
        (AIRPORT loc2-1)
        (TRUCK truck3-1)
        (LOCATION loc3-1)
        (LOCATION loc3-2)
        (LOCATION loc3-3)
        (CITY city3)
        (AIRPORT loc3-1)
        (TRUCK truck4-1)
        (LOCATION loc4-1)
        (LOCATION loc4-2)
        (LOCATION loc4-3)
        (CITY city4)
        (AIRPORT loc4-1)
        (TRUCK truck5-1)
        (LOCATION loc5-1)
        (LOCATION loc5-2)
        (LOCATION loc5-3)
        (CITY city5)
        (AIRPORT loc5-1)
        (TRUCK truck6-1)
        (LOCATION loc6-1)
        (LOCATION loc6-2)
        (LOCATION loc6-3)
        (CITY city6)
        (AIRPORT loc6-1)
        (in-city loc1-1 city1)
        (in-city loc1-2 city1)
        (in-city loc1-3 city1)
        (in-city loc2-1 city2)
        (in-city loc2-2 city2)
        (in-city loc2-3 city2)
        (in-city loc3-1 city3)
        (in-city loc3-2 city3)
        (in-city loc3-3 city3)
        (in-city loc4-1 city4)
        (in-city loc4-2 city4)
        (in-city loc4-3 city4)
        (in-city loc5-1 city5)
        (in-city loc5-2 city5)
        (in-city loc5-3 city5)
        (in-city loc6-1 city6)
        (in-city loc6-2 city6)
        (in-city loc6-3 city6)
        (at plane1 loc4-1)
        (at plane2 loc4-1)
        (at plane3 loc5-1)
        (at truck1-1 loc1-1)
        (at truck2-1 loc2-3)
        (at truck3-1 loc3-3)
        (at truck4-1 loc4-1)
        (at truck5-1 loc5-1)
        (at truck6-1 loc6-3)
        (at package1 loc3-3)
        (at package2 loc1-3)
        (at package3 loc6-1)
        (at package4 loc3-2)
        (at package5 loc6-1)
        (at package6 loc3-2)
        (at package7 loc6-1)
        (at package8 loc1-1)
        (at package9 loc4-1)
        (at package10 loc3-1)
    )
    (:goal (and
        (at package1 loc3-3)
        (at package2 loc1-3)
        (at package3 loc5-2)
        (at package4 loc1-1)
        (at package5 loc6-2)
        (at package6 loc4-3)
        (at package7 loc5-2)
        (at package8 loc6-1)
        (at package9 loc2-3)
        (at package10 loc3-3)
    ))
)
;; a logistics problem instance
;; name: log27
;; #packages: 9        #cities: 5  #planes: 2
;; #locs_per_city: 3   #trucks_per_city: 1
;; #goals: 9           seed: 85419287

(define (problem log30)
    (:domain logistics-strips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        plane1
        plane2
        truck1-1
        loc1-1
        loc1-2
        loc1-3
        city1
        truck2-1
        loc2-1
        loc2-2
        loc2-3
        city2
        truck3-1
        loc3-1
        loc3-2
        loc3-3
        city3
        truck4-1
        loc4-1
        loc4-2
        loc4-3
        city4
        truck5-1
        loc5-1
        loc5-2
        loc5-3
        city5
    )
    (:init 
        (OBJ package1)
        (OBJ package2)
        (OBJ package3)
        (OBJ package4)
        (OBJ package5)
        (OBJ package6)
        (OBJ package7)
        (OBJ package8)
        (OBJ package9)
        (AIRPLANE plane1)
        (AIRPLANE plane2)
        (TRUCK truck1-1)
        (LOCATION loc1-1)
        (LOCATION loc1-2)
        (LOCATION loc1-3)
        (CITY city1)
        (AIRPORT loc1-1)
        (TRUCK truck2-1)
        (LOCATION loc2-1)
        (LOCATION loc2-2)
        (LOCATION loc2-3)
        (CITY city2)
        (AIRPORT loc2-1)
        (TRUCK truck3-1)
        (LOCATION loc3-1)
        (LOCATION loc3-2)
        (LOCATION loc3-3)
        (CITY city3)
        (AIRPORT loc3-1)
        (TRUCK truck4-1)
        (LOCATION loc4-1)
        (LOCATION loc4-2)
        (LOCATION loc4-3)
        (CITY city4)
        (AIRPORT loc4-1)
        (TRUCK truck5-1)
        (LOCATION loc5-1)
        (LOCATION loc5-2)
        (LOCATION loc5-3)
        (CITY city5)
        (AIRPORT loc5-1)
        (in-city loc1-1 city1)
        (in-city loc1-2 city1)
        (in-city loc1-3 city1)
        (in-city loc2-1 city2)
        (in-city loc2-2 city2)
        (in-city loc2-3 city2)
        (in-city loc3-1 city3)
        (in-city loc3-2 city3)
        (in-city loc3-3 city3)
        (in-city loc4-1 city4)
        (in-city loc4-2 city4)
        (in-city loc4-3 city4)
        (in-city loc5-1 city5)
        (in-city loc5-2 city5)
        (in-city loc5-3 city5)
        (at plane1 loc1-1)
        (at plane2 loc3-1)
        (at truck1-1 loc1-1)
        (at truck2-1 loc2-1)
        (at truck3-1 loc3-1)
        (at truck4-1 loc4-1)
        (at truck5-1 loc5-1)
        (at package1 loc4-2)
        (at package2 loc5-3)
        (at package3 loc5-1)
        (at package4 loc5-2)
        (at package5 loc5-2)
        (at package6 loc4-3)
        (at package7 loc3-3)
        (at package8 loc2-3)
        (at package9 loc3-1)
    )
    (:goal (and
        (at package1 loc5-2)
        (at package2 loc2-2)
        (at package3 loc1-3)
        (at package4 loc1-2)
        (at package5 loc5-2)
        (at package6 loc4-1)
        (at package7 loc5-2)
        (at package8 loc2-3)
        (at package9 loc3-1)
    ))
)

; The remaining problems are from the AIPS-98 Competition
; X problems are Round 1, Y problems are Round 2.

(define (problem log-x-1)
   (:domain logistics-adl)
   (:objects package6 package5 package4 package3 package2 package1
             - obj
             city6 city5 city4 city3 city2 city1 - city
             truck6 truck5 truck4 truck3 truck2 truck1 - truck
             plane2 plane1 - airplane
             city6-1 city5-1 city4-1 city3-1 city2-1 city1-1 - location
             city6-2 city5-2 city4-2 city3-2 city2-2 city1-2 - airport)
   (:init (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane2 city4-2)
          (at plane1 city4-2)
          (at truck6 city6-1)
          (at truck5 city5-1)
          (at truck4 city4-1)
          (at truck3 city3-1)
          (at truck2 city2-1)
          (at truck1 city1-1)
          (at package6 city3-1)
          (at package5 city4-2)
          (at package4 city1-1)
          (at package3 city1-1)
          (at package2 city1-2)
          (at package1 city2-1))
   (:goal (and (at package6 city1-2)
               (at package5 city6-2)
               (at package4 city3-2)
               (at package3 city6-1)
               (at package2 city6-2)
               (at package1 city2-1))))

(define (problem log-x-2)
   (:domain logistics-adl)
   (:objects package5 package4 package3 package2 package1 - obj
             city10 city9 city8 city7 city6 city5 city4 city3 city2 city1
             - city
             truck10 truck9 truck8 truck7 truck6 truck5 truck4 truck3 truck2
             truck1 - truck
             plane4 plane3 plane2 plane1 - airplane
             city10-1 city9-1 city8-1 city7-1 city6-1 city5-1 city4-1
             city3-1 city2-1 city1-1 - location
             city10-2 city9-2 city8-2 city7-2 city6-2 city5-2 city4-2
             city3-2 city2-2 city1-2 - airport)
   (:init (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane4 city3-2)
          (at plane3 city7-2)
          (at plane2 city3-2)
          (at plane1 city6-2)
          (at truck10 city10-1)
          (at truck9 city9-1)
          (at truck8 city8-1)
          (at truck7 city7-1)
          (at truck6 city6-1)
          (at truck5 city5-1)
          (at truck4 city4-1)
          (at truck3 city3-1)
          (at truck2 city2-1)
          (at truck1 city1-1)
          (at package5 city1-2)
          (at package4 city7-2)
          (at package3 city3-2)
          (at package2 city10-1)
          (at package1 city2-2))
   (:goal (and (at package5 city4-2)
               (at package4 city6-1)
               (at package3 city1-1)
               (at package2 city9-2)
               (at package1 city3-1))))

(define (problem log-x-3)
   (:domain logistics-adl)
   (:objects package9 package8 package7 package6 package5 package4
             package3 package2 package1 - obj
             city14 city13 city12 city11 city10 city9 city8 city7 city6
             city5 city4 city3 city2 city1 - city
             truck14 truck13 truck12 truck11 truck10 truck9 truck8 truck7
             truck6 truck5 truck4 truck3 truck2 truck1 - truck
             plane4 plane3 plane2 plane1 - airplane
             city14-2 city14-1 city13-2 city13-1 city12-2 city12-1 city11-2
             city11-1 city10-2 city10-1 city9-2 city9-1 city8-2 city8-1
             city7-2 city7-1 city6-2 city6-1 city5-2 city5-1 city4-2
             city4-1 city3-2 city3-1 city2-2 city2-1 city1-2 city1-1
             - location
             city14-3 city13-3 city12-3 city11-3 city10-3 city9-3 city8-3
             city7-3 city6-3 city5-3 city4-3 city3-3 city2-3 city1-3
             - airport)
   (:init (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane4 city10-3)
          (at plane3 city1-3)
          (at plane2 city11-3)
          (at plane1 city11-3)
          (at truck14 city14-1)
          (at truck13 city13-1)
          (at truck12 city12-1)
          (at truck11 city11-1)
          (at truck10 city10-1)
          (at truck9 city9-2)
          (at truck8 city8-2)
          (at truck7 city7-1)
          (at truck6 city6-2)
          (at truck5 city5-1)
          (at truck4 city4-2)
          (at truck3 city3-2)
          (at truck2 city2-1)
          (at truck1 city1-1)
          (at package9 city4-2)
          (at package8 city9-1)
          (at package7 city1-2)
          (at package6 city9-1)
          (at package5 city12-2)
          (at package4 city8-1)
          (at package3 city12-3)
          (at package2 city12-2)
          (at package1 city8-3))
   (:goal (and (at package9 city11-2)
               (at package8 city5-3)
               (at package7 city10-3)
               (at package6 city9-3)
               (at package5 city10-1)
               (at package4 city13-1)
               (at package3 city1-3))))

(define (problem log-x-4)
   (:domain logistics-adl)
   (:objects package7 package6 package5 package4 package3 package2
             package1 - obj
             city13 city12 city11 city10 city9 city8 city7 city6 city5 city4
             city3 city2 city1 - city
             truck23 truck22 truck21 truck20 truck19 truck18 truck17
             truck16 truck15 truck14 truck13 truck12 truck11 truck10 truck9
             truck8 truck7 truck6 truck5 truck4 truck3 truck2 truck1
             - truck
             plane5 plane4 plane3 plane2 plane1 - airplane
             city13-3 city13-2 city13-1 city12-3 city12-2 city12-1 city11-3
             city11-2 city11-1 city10-3 city10-2 city10-1 city9-3 city9-2
             city9-1 city8-3 city8-2 city8-1 city7-3 city7-2 city7-1
             city6-3 city6-2 city6-1 city5-3 city5-2 city5-1 city4-3
             city4-2 city4-1 city3-3 city3-2 city3-1 city2-3 city2-2
             city2-1 city1-3 city1-2 city1-1 - location
             city13-4 city12-4 city11-4 city10-4 city9-4 city8-4 city7-4
             city6-4 city5-4 city4-4 city3-4 city2-4 city1-4 - airport)
   (:init (in-city city13-4 city13)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-4 city12)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-4 city11)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-4 city10)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-4 city9)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane5 city12-4)
          (at plane4 city8-4)
          (at plane3 city6-4)
          (at plane2 city13-4)
          (at plane1 city2-4)
          (at truck23 city13-2)
          (at truck22 city12-3)
          (at truck21 city11-3)
          (at truck20 city10-1)
          (at truck19 city9-1)
          (at truck18 city8-2)
          (at truck17 city7-3)
          (at truck16 city6-3)
          (at truck15 city5-2)
          (at truck14 city4-1)
          (at truck13 city3-3)
          (at truck12 city2-1)
          (at truck11 city1-1)
          (at truck10 city10-3)
          (at truck9 city8-1)
          (at truck8 city2-2)
          (at truck7 city9-4)
          (at truck6 city9-2)
          (at truck5 city8-2)
          (at truck4 city7-3)
          (at truck3 city7-1)
          (at truck2 city8-1)
          (at truck1 city5-4)
          (at package7 city1-4)
          (at package6 city2-3)
          (at package5 city10-1)
          (at package4 city5-4)
          (at package3 city11-1)
          (at package2 city11-3)
          (at package1 city4-2))
   (:goal (and (at package7 city12-3)
               (at package6 city9-3)
               (at package5 city12-3)
               (at package4 city8-4)
               (at package3 city13-4)
               (at package2 city7-1)
               (at package1 city13-1))))

(define (problem log-x-5)
   (:domain logistics-adl)
   (:objects package4 package3 package2 package1 - obj
             city9 city8 city7 city6 city5 city4 city3 city2 city1 - city
             truck11 truck10 truck9 truck8 truck7 truck6 truck5 truck4
             truck3 truck2 truck1 - truck
             plane1 - airplane
             city9-1 city8-1 city7-1 city6-1 city5-1 city4-1 city3-1
             city2-1 city1-1 - location
             city9-2 city8-2 city7-2 city6-2 city5-2 city4-2 city3-2
             city2-2 city1-2 - airport)
   (:init (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane1 city8-2)
          (at truck11 city9-1)
          (at truck10 city8-1)
          (at truck9 city7-1)
          (at truck8 city6-1)
          (at truck7 city5-1)
          (at truck6 city4-1)
          (at truck5 city3-1)
          (at truck4 city2-1)
          (at truck3 city1-1)
          (at truck2 city8-1)
          (at truck1 city3-2)
          (at package4 city8-1)
          (at package3 city9-1)
          (at package2 city8-2)
          (at package1 city6-2))
   (:goal (and (at package4 city2-2)
               (at package3 city7-2)
               (at package2 city3-1)
               (at package1 city9-2))))

(define (problem log-x-6)
   (:domain logistics-adl)
   (:objects package16 package15 package14 package13 package12
             package11 package10 package9 package8 package7 package6
             package5 package4 package3 package2 package1 - obj
             city18 city17 city16 city15 city14 city13 city12 city11 city10
             city9 city8 city7 city6 city5 city4 city3 city2 city1 - city
             truck26 truck25 truck24 truck23 truck22 truck21 truck20
             truck19 truck18 truck17 truck16 truck15 truck14 truck13
             truck12 truck11 truck10 truck9 truck8 truck7 truck6 truck5
             truck4 truck3 truck2 truck1 - truck
             plane2 plane1 - airplane
             city18-3 city18-2 city18-1 city17-3 city17-2 city17-1 city16-3
             city16-2 city16-1 city15-3 city15-2 city15-1 city14-3 city14-2
             city14-1 city13-3 city13-2 city13-1 city12-3 city12-2 city12-1
             city11-3 city11-2 city11-1 city10-3 city10-2 city10-1 city9-3
             city9-2 city9-1 city8-3 city8-2 city8-1 city7-3 city7-2
             city7-1 city6-3 city6-2 city6-1 city5-3 city5-2 city5-1
             city4-3 city4-2 city4-1 city3-3 city3-2 city3-1 city2-3
             city2-2 city2-1 city1-3 city1-2 city1-1 - location
             city18-4 city17-4 city16-4 city15-4 city14-4 city13-4 city12-4
             city11-4 city10-4 city9-4 city8-4 city7-4 city6-4 city5-4
             city4-4 city3-4 city2-4 city1-4 - airport)
   (:init (in-city city18-4 city18)
          (in-city city18-3 city18)
          (in-city city18-2 city18)
          (in-city city18-1 city18)
          (in-city city17-4 city17)
          (in-city city17-3 city17)
          (in-city city17-2 city17)
          (in-city city17-1 city17)
          (in-city city16-4 city16)
          (in-city city16-3 city16)
          (in-city city16-2 city16)
          (in-city city16-1 city16)
          (in-city city15-4 city15)
          (in-city city15-3 city15)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-4 city14)
          (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-4 city13)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-4 city12)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-4 city11)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-4 city10)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-4 city9)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane2 city10-4)
          (at plane1 city18-4)
          (at truck26 city18-2)
          (at truck25 city17-1)
          (at truck24 city16-1)
          (at truck23 city15-2)
          (at truck22 city14-2)
          (at truck21 city13-1)
          (at truck20 city12-3)
          (at truck19 city11-1)
          (at truck18 city10-1)
          (at truck17 city9-1)
          (at truck16 city8-2)
          (at truck15 city7-1)
          (at truck14 city6-1)
          (at truck13 city5-1)
          (at truck12 city4-2)
          (at truck11 city3-2)
          (at truck10 city2-2)
          (at truck9 city1-2)
          (at truck8 city14-1)
          (at truck7 city3-4)
          (at truck6 city1-1)
          (at truck5 city14-1)
          (at truck4 city8-1)
          (at truck3 city10-3)
          (at truck2 city4-3)
          (at truck1 city14-3)
          (at package16 city16-2)
          (at package15 city14-3)
          (at package14 city14-1)
          (at package13 city14-4)
          (at package12 city6-1)
          (at package11 city3-1)
          (at package10 city9-4)
          (at package9 city17-3)
          (at package8 city15-2)
          (at package7 city8-4)
          (at package6 city6-1)
          (at package5 city10-3)
          (at package4 city15-2)
          (at package3 city16-3)
          (at package2 city11-2)
          (at package1 city7-3))
   (:goal (and (at package16 city14-3)
               (at package15 city14-2)
               (at package14 city8-4)
               (at package13 city4-3)
               (at package12 city13-4)
               (at package11 city12-2)
               (at package10 city16-2)
               (at package9 city17-4)
               (at package8 city8-1)
               (at package7 city8-2))))

(define (problem log-x-7)
   (:domain logistics-adl)
   (:objects package10 package9 package8 package7 package6
             package5 package4 package3 package2 package1 - obj
             city11 city10 city9 city8 city7 city6 city5 city4 city3 city2
             city1 - city
             truck11 truck10 truck9 truck8 truck7 truck6 truck5 truck4
             truck3 truck2 truck1 - truck
             plane6 plane5 plane4 plane3 plane2 plane1 - airplane
             city11-1 city10-1 city9-1 city8-1 city7-1 city6-1 city5-1
             city4-1 city3-1 city2-1 city1-1 - location
             city11-2 city10-2 city9-2 city8-2 city7-2 city6-2 city5-2
             city4-2 city3-2 city2-2 city1-2 - airport)
   (:init (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane6 city2-2)
          (at plane5 city5-2)
          (at plane4 city6-2)
          (at plane3 city9-2)
          (at plane2 city8-2)
          (at plane1 city1-2)
          (at truck11 city11-1)
          (at truck10 city10-1)
          (at truck9 city9-1)
          (at truck8 city8-1)
          (at truck7 city7-1)
          (at truck6 city6-1)
          (at truck5 city5-1)
          (at truck4 city4-1)
          (at truck3 city3-1)
          (at truck2 city2-1)
          (at truck1 city1-1)
          (at package10 city6-2)
          (at package9 city5-2)
          (at package8 city10-2)
          (at package7 city6-2)
          (at package6 city1-2)
          (at package5 city4-1)
          (at package4 city4-2)
          (at package3 city1-2)
          (at package2 city10-2)
          (at package1 city8-1))
   (:goal (and (at package10 city9-1)
               (at package9 city9-2)
               (at package8 city1-2)
               (at package7 city5-1)
               (at package6 city10-2)
               (at package5 city7-1))))

(define (problem log-x-8)
   (:domain logistics-adl)
   (:objects package24 package23 package22 package21 package20
             package19 package18 package17 package16 package15 package14
             package13 package12 package11 package10 package9 package8
             package7 package6 package5 package4 package3 package2 package1
             - obj
             city20 city19 city18 city17 city16 city15 city14 city13 city12
             city11 city10 city9 city8 city7 city6 city5 city4 city3 city2
             city1 - city
             truck33 truck32 truck31 truck30 truck29 truck28 truck27
             truck26 truck25 truck24 truck23 truck22 truck21 truck20
             truck19 truck18 truck17 truck16 truck15 truck14 truck13
             truck12 truck11 truck10 truck9 truck8 truck7 truck6 truck5
             truck4 truck3 truck2 truck1 - truck
             plane4 plane3 plane2 plane1 - airplane
             city20-2 city20-1 city19-2 city19-1 city18-2 city18-1 city17-2
             city17-1 city16-2 city16-1 city15-2 city15-1 city14-2 city14-1
             city13-2 city13-1 city12-2 city12-1 city11-2 city11-1 city10-2
             city10-1 city9-2 city9-1 city8-2 city8-1 city7-2 city7-1
             city6-2 city6-1 city5-2 city5-1 city4-2 city4-1 city3-2
             city3-1 city2-2 city2-1 city1-2 city1-1 - location
             city20-3 city19-3 city18-3 city17-3 city16-3 city15-3 city14-3
             city13-3 city12-3 city11-3 city10-3 city9-3 city8-3 city7-3
             city6-3 city5-3 city4-3 city3-3 city2-3 city1-3 - airport)
   (:init (in-city city20-3 city20)
          (in-city city20-2 city20)
          (in-city city20-1 city20)
          (in-city city19-3 city19)
          (in-city city19-2 city19)
          (in-city city19-1 city19)
          (in-city city18-3 city18)
          (in-city city18-2 city18)
          (in-city city18-1 city18)
          (in-city city17-3 city17)
          (in-city city17-2 city17)
          (in-city city17-1 city17)
          (in-city city16-3 city16)
          (in-city city16-2 city16)
          (in-city city16-1 city16)
          (in-city city15-3 city15)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane4 city7-3)
          (at plane3 city2-3)
          (at plane2 city16-3)
          (at plane1 city5-3)
          (at truck33 city20-1)
          (at truck32 city19-1)
          (at truck31 city18-2)
          (at truck30 city17-2)
          (at truck29 city16-2)
          (at truck28 city15-2)
          (at truck27 city14-1)
          (at truck26 city13-1)
          (at truck25 city12-2)
          (at truck24 city11-2)
          (at truck23 city10-2)
          (at truck22 city9-1)
          (at truck21 city8-1)
          (at truck20 city7-2)
          (at truck19 city6-2)
          (at truck18 city5-1)
          (at truck17 city4-1)
          (at truck16 city3-2)
          (at truck15 city2-2)
          (at truck14 city1-1)
          (at truck13 city1-3)
          (at truck12 city12-1)
          (at truck11 city5-3)
          (at truck10 city20-3)
          (at truck9 city4-1)
          (at truck8 city10-3)
          (at truck7 city4-2)
          (at truck6 city1-1)
          (at truck5 city5-3)
          (at truck4 city17-2)
          (at truck3 city8-2)
          (at truck2 city2-1)
          (at truck1 city17-2)
          (at package24 city13-1)
          (at package23 city13-3)
          (at package22 city15-3)
          (at package21 city20-3)
          (at package20 city20-2)
          (at package19 city3-3)
          (at package18 city16-1)
          (at package17 city5-2)
          (at package16 city13-1)
          (at package15 city18-2)
          (at package14 city13-1)
          (at package13 city14-1)
          (at package12 city7-2)
          (at package11 city18-3)
          (at package10 city7-1)
          (at package9 city11-3)
          (at package8 city11-3)
          (at package7 city3-3)
          (at package6 city4-2)
          (at package5 city7-3)
          (at package4 city5-2)
          (at package3 city1-1)
          (at package2 city20-3)
          (at package1 city13-1))
   (:goal (and (at package24 city7-1)
               (at package23 city2-1)
               (at package22 city1-3)
               (at package21 city6-3)
               (at package20 city7-1)
               (at package19 city1-2))))

(define (problem log-x-9)
   (:domain logistics-adl)
   (:objects package12 package11 package10 package9 package8
             package7 package6 package5 package4 package3 package2 package1
             - obj
             city11 city10 city9 city8 city7 city6 city5 city4 city3 city2
             city1 - city
             truck28 truck27 truck26 truck25 truck24 truck23 truck22
             truck21 truck20 truck19 truck18 truck17 truck16 truck15
             truck14 truck13 truck12 truck11 truck10 truck9 truck8 truck7
             truck6 truck5 truck4 truck3 truck2 truck1 - truck
             plane4 plane3 plane2 plane1 - airplane
             city11-5 city11-4 city11-3 city11-2 city11-1 city10-5 city10-4
             city10-3 city10-2 city10-1 city9-5 city9-4 city9-3 city9-2
             city9-1 city8-5 city8-4 city8-3 city8-2 city8-1 city7-5
             city7-4 city7-3 city7-2 city7-1 city6-5 city6-4 city6-3
             city6-2 city6-1 city5-5 city5-4 city5-3 city5-2 city5-1
             city4-5 city4-4 city4-3 city4-2 city4-1 city3-5 city3-4
             city3-3 city3-2 city3-1 city2-5 city2-4 city2-3 city2-2
             city2-1 city1-5 city1-4 city1-3 city1-2 city1-1 - location
             city11-6 city10-6 city9-6 city8-6 city7-6 city6-6 city5-6
             city4-6 city3-6 city2-6 city1-6 - airport)
   (:init (in-city city11-6 city11)
          (in-city city11-5 city11)
          (in-city city11-4 city11)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-6 city10)
          (in-city city10-5 city10)
          (in-city city10-4 city10)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-6 city9)
          (in-city city9-5 city9)
          (in-city city9-4 city9)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-6 city8)
          (in-city city8-5 city8)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-6 city7)
          (in-city city7-5 city7)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-6 city6)
          (in-city city6-5 city6)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-6 city5)
          (in-city city5-5 city5)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-6 city4)
          (in-city city4-5 city4)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-6 city3)
          (in-city city3-5 city3)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-6 city2)
          (in-city city2-5 city2)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-6 city1)
          (in-city city1-5 city1)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane4 city5-6)
          (at plane3 city6-6)
          (at plane2 city7-6)
          (at plane1 city10-6)
          (at truck28 city11-2)
          (at truck27 city10-2)
          (at truck26 city9-1)
          (at truck25 city8-2)
          (at truck24 city7-5)
          (at truck23 city6-1)
          (at truck22 city5-2)
          (at truck21 city4-2)
          (at truck20 city3-3)
          (at truck19 city2-1)
          (at truck18 city1-1)
          (at truck17 city7-3)
          (at truck16 city6-3)
          (at truck15 city8-5)
          (at truck14 city11-6)
          (at truck13 city9-6)
          (at truck12 city7-1)
          (at truck11 city8-6)
          (at truck10 city1-1)
          (at truck9 city4-1)
          (at truck8 city2-5)
          (at truck7 city9-1)
          (at truck6 city2-6)
          (at truck5 city8-6)
          (at truck4 city4-1)
          (at truck3 city4-1)
          (at truck2 city8-2)
          (at truck1 city1-5)
          (at package12 city1-2)
          (at package11 city9-1)
          (at package10 city4-6)
          (at package9 city8-4)
          (at package8 city11-5)
          (at package7 city2-4)
          (at package6 city4-1)
          (at package5 city2-6)
          (at package4 city4-4)
          (at package3 city4-5)
          (at package2 city2-6)
          (at package1 city6-6))
   (:goal (and (at package12 city5-4)
               (at package11 city4-1)
               (at package10 city6-2)
               (at package9 city8-4)
               (at package8 city2-3)
               (at package7 city9-6)
               (at package6 city2-4)
               (at package5 city10-3)
               (at package4 city4-4)
               (at package3 city8-1)
               (at package2 city9-2)
               (at package1 city5-1))))

(define (problem log-x-10)
   (:domain logistics-adl)
   (:objects package17 package16 package15 package14 package13
             package12 package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 - obj
             city23 city22 city21 city20 city19 city18 city17 city16 city15
             city14 city13 city12 city11 city10 city9 city8 city7 city6
             city5 city4 city3 city2 city1 - city
             truck23 truck22 truck21 truck20 truck19 truck18 truck17
             truck16 truck15 truck14 truck13 truck12 truck11 truck10 truck9
             truck8 truck7 truck6 truck5 truck4 truck3 truck2 truck1
             - truck
             plane4 plane3 plane2 plane1 - airplane
             city23-1 city22-1 city21-1 city20-1 city19-1 city18-1 city17-1
             city16-1 city15-1 city14-1 city13-1 city12-1 city11-1 city10-1
             city9-1 city8-1 city7-1 city6-1 city5-1 city4-1 city3-1
             city2-1 city1-1 - location
             city23-2 city22-2 city21-2 city20-2 city19-2 city18-2 city17-2
             city16-2 city15-2 city14-2 city13-2 city12-2 city11-2 city10-2
             city9-2 city8-2 city7-2 city6-2 city5-2 city4-2 city3-2
             city2-2 city1-2 - airport)
   (:init (in-city city23-2 city23)
          (in-city city23-1 city23)
          (in-city city22-2 city22)
          (in-city city22-1 city22)
          (in-city city21-2 city21)
          (in-city city21-1 city21)
          (in-city city20-2 city20)
          (in-city city20-1 city20)
          (in-city city19-2 city19)
          (in-city city19-1 city19)
          (in-city city18-2 city18)
          (in-city city18-1 city18)
          (in-city city17-2 city17)
          (in-city city17-1 city17)
          (in-city city16-2 city16)
          (in-city city16-1 city16)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane4 city11-2)
          (at plane3 city13-2)
          (at plane2 city18-2)
          (at plane1 city16-2)
          (at truck23 city23-1)
          (at truck22 city22-1)
          (at truck21 city21-1)
          (at truck20 city20-1)
          (at truck19 city19-1)
          (at truck18 city18-1)
          (at truck17 city17-1)
          (at truck16 city16-1)
          (at truck15 city15-1)
          (at truck14 city14-1)
          (at truck13 city13-1)
          (at truck12 city12-1)
          (at truck11 city11-1)
          (at truck10 city10-1)
          (at truck9 city9-1)
          (at truck8 city8-1)
          (at truck7 city7-1)
          (at truck6 city6-1)
          (at truck5 city5-1)
          (at truck4 city4-1)
          (at truck3 city3-1)
          (at truck2 city2-1)
          (at truck1 city1-1)
          (at package17 city8-2)
          (at package16 city13-2)
          (at package15 city15-2)
          (at package14 city3-2)
          (at package13 city14-2)
          (at package12 city5-1)
          (at package11 city16-1)
          (at package10 city3-2)
          (at package9 city21-1)
          (at package8 city8-1)
          (at package7 city11-1)
          (at package6 city15-2)
          (at package5 city6-1)
          (at package4 city7-1)
          (at package3 city19-1)
          (at package2 city22-1)
          (at package1 city13-1))
   (:goal (and (at package17 city3-1)
               (at package16 city4-2)
               (at package15 city19-1)
               (at package14 city9-1)
               (at package13 city3-2)
               (at package12 city21-1)
               (at package11 city21-2)
               (at package10 city9-2)
               (at package9 city20-2)
               (at package8 city13-2)
               (at package7 city3-1)
               (at package6 city15-2)
               (at package5 city8-1)
               (at package4 city1-1)
               (at package3 city9-2)
               (at package2 city2-1)
               (at package1 city13-1))))

(define (problem log-x-11)
   (:domain logistics-adl)
   (:objects package8 package7 package6 package5 package4 package3
             package2 package1 - obj
             city3 city2 city1 - city
             truck22 truck21 truck20 truck19 truck18 truck17 truck16
             truck15 truck14 truck13 truck12 truck11 truck10 truck9 truck8
             truck7 truck6 truck5 truck4 truck3 truck2 truck1 - truck
             plane6 plane5 plane4 plane3 plane2 plane1 - airplane
             city3-2 city3-1 city2-2 city2-1 city1-2 city1-1 - location
             city3-3 city2-3 city1-3 - airport)
   (:init (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane6 city2-3)
          (at plane5 city1-3)
          (at plane4 city3-3)
          (at plane3 city2-3)
          (at plane2 city2-3)
          (at plane1 city1-3)
          (at truck22 city3-2)
          (at truck21 city2-1)
          (at truck20 city1-2)
          (at truck19 city2-3)
          (at truck18 city1-2)
          (at truck17 city2-2)
          (at truck16 city2-1)
          (at truck15 city2-3)
          (at truck14 city2-2)
          (at truck13 city1-2)
          (at truck12 city2-2)
          (at truck11 city3-3)
          (at truck10 city3-1)
          (at truck9 city2-3)
          (at truck8 city3-3)
          (at truck7 city2-3)
          (at truck6 city2-3)
          (at truck5 city2-3)
          (at truck4 city3-2)
          (at truck3 city2-2)
          (at truck2 city1-1)
          (at truck1 city2-3)
          (at package8 city1-2)
          (at package7 city2-1)
          (at package6 city3-2)
          (at package5 city1-3)
          (at package4 city3-3)
          (at package3 city2-2)
          (at package2 city3-2)
          (at package1 city1-3))
   (:goal (and (at package8 city3-3)
               (at package7 city3-3)
               (at package6 city3-2)
               (at package5 city1-3)
               (at package4 city3-3)
               (at package3 city1-2)
               (at package2 city2-3)
               (at package1 city1-1))))

(define (problem log-x-12)
   (:domain logistics-adl)
   (:objects package5 package4 package3 package2 package1 - obj
             city27 city26 city25 city24 city23 city22 city21 city20 city19
             city18 city17 city16 city15 city14 city13 city12 city11 city10
             city9 city8 city7 city6 city5 city4 city3 city2 city1 - city
             truck55 truck54 truck53 truck52 truck51 truck50 truck49
             truck48 truck47 truck46 truck45 truck44 truck43 truck42
             truck41 truck40 truck39 truck38 truck37 truck36 truck35
             truck34 truck33 truck32 truck31 truck30 truck29 truck28
             truck27 truck26 truck25 truck24 truck23 truck22 truck21
             truck20 truck19 truck18 truck17 truck16 truck15 truck14
             truck13 truck12 truck11 truck10 truck9 truck8 truck7 truck6
             truck5 truck4 truck3 truck2 truck1 - truck
             plane9 plane8 plane7 plane6 plane5 plane4 plane3 plane2 plane1
             - airplane
             city27-3 city27-2 city27-1 city26-3 city26-2 city26-1 city25-3
             city25-2 city25-1 city24-3 city24-2 city24-1 city23-3 city23-2
             city23-1 city22-3 city22-2 city22-1 city21-3 city21-2 city21-1
             city20-3 city20-2 city20-1 city19-3 city19-2 city19-1 city18-3
             city18-2 city18-1 city17-3 city17-2 city17-1 city16-3 city16-2
             city16-1 city15-3 city15-2 city15-1 city14-3 city14-2 city14-1
             city13-3 city13-2 city13-1 city12-3 city12-2 city12-1 city11-3
             city11-2 city11-1 city10-3 city10-2 city10-1 city9-3 city9-2
             city9-1 city8-3 city8-2 city8-1 city7-3 city7-2 city7-1
             city6-3 city6-2 city6-1 city5-3 city5-2 city5-1 city4-3
             city4-2 city4-1 city3-3 city3-2 city3-1 city2-3 city2-2
             city2-1 city1-3 city1-2 city1-1 - location
             city27-4 city26-4 city25-4 city24-4 city23-4 city22-4 city21-4
             city20-4 city19-4 city18-4 city17-4 city16-4 city15-4 city14-4
             city13-4 city12-4 city11-4 city10-4 city9-4 city8-4 city7-4
             city6-4 city5-4 city4-4 city3-4 city2-4 city1-4 - airport)
   (:init (in-city city27-4 city27)
          (in-city city27-3 city27)
          (in-city city27-2 city27)
          (in-city city27-1 city27)
          (in-city city26-4 city26)
          (in-city city26-3 city26)
          (in-city city26-2 city26)
          (in-city city26-1 city26)
          (in-city city25-4 city25)
          (in-city city25-3 city25)
          (in-city city25-2 city25)
          (in-city city25-1 city25)
          (in-city city24-4 city24)
          (in-city city24-3 city24)
          (in-city city24-2 city24)
          (in-city city24-1 city24)
          (in-city city23-4 city23)
          (in-city city23-3 city23)
          (in-city city23-2 city23)
          (in-city city23-1 city23)
          (in-city city22-4 city22)
          (in-city city22-3 city22)
          (in-city city22-2 city22)
          (in-city city22-1 city22)
          (in-city city21-4 city21)
          (in-city city21-3 city21)
          (in-city city21-2 city21)
          (in-city city21-1 city21)
          (in-city city20-4 city20)
          (in-city city20-3 city20)
          (in-city city20-2 city20)
          (in-city city20-1 city20)
          (in-city city19-4 city19)
          (in-city city19-3 city19)
          (in-city city19-2 city19)
          (in-city city19-1 city19)
          (in-city city18-4 city18)
          (in-city city18-3 city18)
          (in-city city18-2 city18)
          (in-city city18-1 city18)
          (in-city city17-4 city17)
          (in-city city17-3 city17)
          (in-city city17-2 city17)
          (in-city city17-1 city17)
          (in-city city16-4 city16)
          (in-city city16-3 city16)
          (in-city city16-2 city16)
          (in-city city16-1 city16)
          (in-city city15-4 city15)
          (in-city city15-3 city15)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-4 city14)
          (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-4 city13)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-4 city12)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-4 city11)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-4 city10)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-4 city9)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane9 city7-4)
          (at plane8 city2-4)
          (at plane7 city14-4)
          (at plane6 city25-4)
          (at plane5 city23-4)
          (at plane4 city2-4)
          (at plane3 city13-4)
          (at plane2 city1-4)
          (at plane1 city23-4)
          (at truck55 city27-2)
          (at truck54 city26-3)
          (at truck53 city25-2)
          (at truck52 city24-3)
          (at truck51 city23-1)
          (at truck50 city22-2)
          (at truck49 city21-1)
          (at truck48 city20-2)
          (at truck47 city19-1)
          (at truck46 city18-3)
          (at truck45 city17-1)
          (at truck44 city16-3)
          (at truck43 city15-1)
          (at truck42 city14-3)
          (at truck41 city13-1)
          (at truck40 city12-3)
          (at truck39 city11-2)
          (at truck38 city10-1)
          (at truck37 city9-2)
          (at truck36 city8-1)
          (at truck35 city7-2)
          (at truck34 city6-1)
          (at truck33 city5-1)
          (at truck32 city4-1)
          (at truck31 city3-3)
          (at truck30 city2-2)
          (at truck29 city1-2)
          (at truck28 city10-4)
          (at truck27 city7-3)
          (at truck26 city12-4)
          (at truck25 city7-1)
          (at truck24 city11-3)
          (at truck23 city15-3)
          (at truck22 city8-4)
          (at truck21 city8-3)
          (at truck20 city10-1)
          (at truck19 city22-4)
          (at truck18 city25-2)
          (at truck17 city14-2)
          (at truck16 city15-3)
          (at truck15 city25-3)
          (at truck14 city2-3)
          (at truck13 city12-3)
          (at truck12 city19-4)
          (at truck11 city14-2)
          (at truck10 city11-3)
          (at truck9 city24-2)
          (at truck8 city3-3)
          (at truck7 city22-2)
          (at truck6 city25-2)
          (at truck5 city23-3)
          (at truck4 city8-4)
          (at truck3 city3-4)
          (at truck2 city3-3)
          (at truck1 city15-4)
          (at package5 city12-1)
          (at package4 city7-2)
          (at package3 city8-1)
          (at package2 city23-3)
          (at package1 city1-4))
   (:goal (and (at package5 city18-4)
               (at package4 city10-3)
               (at package3 city1-4)
               (at package2 city14-3)
               (at package1 city9-2))))

(define (problem log-x-13)
   (:domain logistics-adl)
   (:objects package23 package22 package21 package20 package19
             package18 package17 package16 package15 package14 package13
             package12 package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 - obj
             city29 city28 city27 city26 city25 city24 city23 city22 city21
             city20 city19 city18 city17 city16 city15 city14 city13 city12
             city11 city10 city9 city8 city7 city6 city5 city4 city3 city2
             city1 - city
             truck29 truck28 truck27 truck26 truck25 truck24 truck23
             truck22 truck21 truck20 truck19 truck18 truck17 truck16
             truck15 truck14 truck13 truck12 truck11 truck10 truck9 truck8
             truck7 truck6 truck5 truck4 truck3 truck2 truck1 - truck
             plane9 plane8 plane7 plane6 plane5 plane4 plane3 plane2 plane1
             - airplane
             city29-3 city29-2 city29-1 city28-3 city28-2 city28-1 city27-3
             city27-2 city27-1 city26-3 city26-2 city26-1 city25-3 city25-2
             city25-1 city24-3 city24-2 city24-1 city23-3 city23-2 city23-1
             city22-3 city22-2 city22-1 city21-3 city21-2 city21-1 city20-3
             city20-2 city20-1 city19-3 city19-2 city19-1 city18-3 city18-2
             city18-1 city17-3 city17-2 city17-1 city16-3 city16-2 city16-1
             city15-3 city15-2 city15-1 city14-3 city14-2 city14-1 city13-3
             city13-2 city13-1 city12-3 city12-2 city12-1 city11-3 city11-2
             city11-1 city10-3 city10-2 city10-1 city9-3 city9-2 city9-1
             city8-3 city8-2 city8-1 city7-3 city7-2 city7-1 city6-3
             city6-2 city6-1 city5-3 city5-2 city5-1 city4-3 city4-2
             city4-1 city3-3 city3-2 city3-1 city2-3 city2-2 city2-1
             city1-3 city1-2 city1-1 - location
             city29-4 city28-4 city27-4 city26-4 city25-4 city24-4 city23-4
             city22-4 city21-4 city20-4 city19-4 city18-4 city17-4 city16-4
             city15-4 city14-4 city13-4 city12-4 city11-4 city10-4 city9-4
             city8-4 city7-4 city6-4 city5-4 city4-4 city3-4 city2-4
             city1-4 - airport)
   (:init (in-city city29-4 city29)
          (in-city city29-3 city29)
          (in-city city29-2 city29)
          (in-city city29-1 city29)
          (in-city city28-4 city28)
          (in-city city28-3 city28)
          (in-city city28-2 city28)
          (in-city city28-1 city28)
          (in-city city27-4 city27)
          (in-city city27-3 city27)
          (in-city city27-2 city27)
          (in-city city27-1 city27)
          (in-city city26-4 city26)
          (in-city city26-3 city26)
          (in-city city26-2 city26)
          (in-city city26-1 city26)
          (in-city city25-4 city25)
          (in-city city25-3 city25)
          (in-city city25-2 city25)
          (in-city city25-1 city25)
          (in-city city24-4 city24)
          (in-city city24-3 city24)
          (in-city city24-2 city24)
          (in-city city24-1 city24)
          (in-city city23-4 city23)
          (in-city city23-3 city23)
          (in-city city23-2 city23)
          (in-city city23-1 city23)
          (in-city city22-4 city22)
          (in-city city22-3 city22)
          (in-city city22-2 city22)
          (in-city city22-1 city22)
          (in-city city21-4 city21)
          (in-city city21-3 city21)
          (in-city city21-2 city21)
          (in-city city21-1 city21)
          (in-city city20-4 city20)
          (in-city city20-3 city20)
          (in-city city20-2 city20)
          (in-city city20-1 city20)
          (in-city city19-4 city19)
          (in-city city19-3 city19)
          (in-city city19-2 city19)
          (in-city city19-1 city19)
          (in-city city18-4 city18)
          (in-city city18-3 city18)
          (in-city city18-2 city18)
          (in-city city18-1 city18)
          (in-city city17-4 city17)
          (in-city city17-3 city17)
          (in-city city17-2 city17)
          (in-city city17-1 city17)
          (in-city city16-4 city16)
          (in-city city16-3 city16)
          (in-city city16-2 city16)
          (in-city city16-1 city16)
          (in-city city15-4 city15)
          (in-city city15-3 city15)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-4 city14)
          (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-4 city13)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-4 city12)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-4 city11)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-4 city10)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-4 city9)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane9 city28-4)
          (at plane8 city23-4)
          (at plane7 city27-4)
          (at plane6 city29-4)
          (at plane5 city13-4)
          (at plane4 city4-4)
          (at plane3 city14-4)
          (at plane2 city14-4)
          (at plane1 city13-4)
          (at truck29 city29-1)
          (at truck28 city28-2)
          (at truck27 city27-3)
          (at truck26 city26-1)
          (at truck25 city25-2)
          (at truck24 city24-3)
          (at truck23 city23-3)
          (at truck22 city22-3)
          (at truck21 city21-1)
          (at truck20 city20-1)
          (at truck19 city19-3)
          (at truck18 city18-2)
          (at truck17 city17-3)
          (at truck16 city16-2)
          (at truck15 city15-3)
          (at truck14 city14-3)
          (at truck13 city13-2)
          (at truck12 city12-3)
          (at truck11 city11-1)
          (at truck10 city10-2)
          (at truck9 city9-3)
          (at truck8 city8-2)
          (at truck7 city7-3)
          (at truck6 city6-3)
          (at truck5 city5-3)
          (at truck4 city4-2)
          (at truck3 city3-2)
          (at truck2 city2-3)
          (at truck1 city1-1)
          (at package23 city26-2)
          (at package22 city1-1)
          (at package21 city3-1)
          (at package20 city18-2)
          (at package19 city17-2)
          (at package18 city21-1)
          (at package17 city1-4)
          (at package16 city29-4)
          (at package15 city1-2)
          (at package14 city4-4)
          (at package13 city10-1)
          (at package12 city13-1)
          (at package11 city24-3)
          (at package10 city5-4)
          (at package9 city9-4)
          (at package8 city3-4)
          (at package7 city13-1)
          (at package6 city7-3)
          (at package5 city16-1)
          (at package4 city3-2)
          (at package3 city17-1)
          (at package2 city11-1)
          (at package1 city21-4))
   (:goal (and (at package23 city7-4)
               (at package22 city11-3)
               (at package21 city16-4)
               (at package20 city4-4)
               (at package19 city21-2)
               (at package18 city22-1)
               (at package17 city18-3)
               (at package16 city14-3))))

(define (problem log-x-14)
   (:domain logistics-adl)
   (:objects package29 package28 package27 package26 package25
             package24 package23 package22 package21 package20 package19
             package18 package17 package16 package15 package14 package13
             package12 package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 - obj
             city11 city10 city9 city8 city7 city6 city5 city4 city3 city2
             city1 - city
             truck47 truck46 truck45 truck44 truck43 truck42 truck41
             truck40 truck39 truck38 truck37 truck36 truck35 truck34
             truck33 truck32 truck31 truck30 truck29 truck28 truck27
             truck26 truck25 truck24 truck23 truck22 truck21 truck20
             truck19 truck18 truck17 truck16 truck15 truck14 truck13
             truck12 truck11 truck10 truck9 truck8 truck7 truck6 truck5
             truck4 truck3 truck2 truck1 - truck
             plane8 plane7 plane6 plane5 plane4 plane3 plane2 plane1
             - airplane
             city11-1 city10-1 city9-1 city8-1 city7-1 city6-1 city5-1
             city4-1 city3-1 city2-1 city1-1 - location
             city11-2 city10-2 city9-2 city8-2 city7-2 city6-2 city5-2
             city4-2 city3-2 city2-2 city1-2 - airport)
   (:init (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane8 city9-2)
          (at plane7 city4-2)
          (at plane6 city1-2)
          (at plane5 city2-2)
          (at plane4 city4-2)
          (at plane3 city11-2)
          (at plane2 city2-2)
          (at plane1 city6-2)
          (at truck47 city11-1)
          (at truck46 city10-1)
          (at truck45 city9-1)
          (at truck44 city8-1)
          (at truck43 city7-1)
          (at truck42 city6-1)
          (at truck41 city5-1)
          (at truck40 city4-1)
          (at truck39 city3-1)
          (at truck38 city2-1)
          (at truck37 city1-1)
          (at truck36 city1-1)
          (at truck35 city4-1)
          (at truck34 city7-1)
          (at truck33 city7-1)
          (at truck32 city10-2)
          (at truck31 city3-2)
          (at truck30 city6-2)
          (at truck29 city6-2)
          (at truck28 city10-1)
          (at truck27 city10-1)
          (at truck26 city8-1)
          (at truck25 city10-1)
          (at truck24 city6-1)
          (at truck23 city5-2)
          (at truck22 city9-2)
          (at truck21 city4-2)
          (at truck20 city2-2)
          (at truck19 city8-1)
          (at truck18 city4-2)
          (at truck17 city3-1)
          (at truck16 city2-1)
          (at truck15 city2-2)
          (at truck14 city6-2)
          (at truck13 city10-2)
          (at truck12 city10-2)
          (at truck11 city7-2)
          (at truck10 city2-1)
          (at truck9 city3-2)
          (at truck8 city1-2)
          (at truck7 city3-1)
          (at truck6 city8-2)
          (at truck5 city7-1)
          (at truck4 city8-2)
          (at truck3 city1-2)
          (at truck2 city1-1)
          (at truck1 city2-1)
          (at package29 city10-1)
          (at package28 city4-2)
          (at package27 city10-2)
          (at package26 city6-1)
          (at package25 city6-2)
          (at package24 city8-2)
          (at package23 city1-1)
          (at package22 city9-1)
          (at package21 city9-2)
          (at package20 city6-2)
          (at package19 city9-1)
          (at package18 city2-2)
          (at package17 city4-2)
          (at package16 city2-2)
          (at package15 city1-2)
          (at package14 city9-1)
          (at package13 city7-1)
          (at package12 city9-2)
          (at package11 city6-2)
          (at package10 city8-2)
          (at package9 city1-2)
          (at package8 city8-1)
          (at package7 city8-2)
          (at package6 city1-2)
          (at package5 city2-2)
          (at package4 city10-2)
          (at package3 city11-1)
          (at package2 city11-1)
          (at package1 city11-2))
   (:goal (and (at package29 city5-2)
               (at package28 city11-2)
               (at package27 city10-1)
               (at package26 city9-1)
               (at package25 city4-1)
               (at package24 city8-2)
               (at package23 city10-2)
               (at package22 city1-2)
               (at package21 city1-1)
               (at package20 city4-1)
               (at package19 city6-1)
               (at package18 city9-1)
               (at package17 city4-1)
               (at package16 city11-1)
               (at package15 city2-2)
               (at package14 city8-2)
               (at package13 city10-2)
               (at package12 city11-2)
               (at package11 city2-2))))

(define (problem log-x-15)
   (:domain logistics-adl)
   (:objects package23 package22 package21 package20 package19
             package18 package17 package16 package15 package14 package13
             package12 package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 - obj
             city3 city2 city1 - city
             truck5 truck4 truck3 truck2 truck1 - truck
             plane7 plane6 plane5 plane4 plane3 plane2 plane1 - airplane
             city3-5 city3-4 city3-3 city3-2 city3-1 city2-5 city2-4
             city2-3 city2-2 city2-1 city1-5 city1-4 city1-3 city1-2
             city1-1 - location
             city3-6 city2-6 city1-6 - airport)
   (:init (in-city city3-6 city3)
          (in-city city3-5 city3)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-6 city2)
          (in-city city2-5 city2)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-6 city1)
          (in-city city1-5 city1)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane7 city1-6)
          (at plane6 city2-6)
          (at plane5 city1-6)
          (at plane4 city1-6)
          (at plane3 city3-6)
          (at plane2 city1-6)
          (at plane1 city2-6)
          (at truck5 city3-4)
          (at truck4 city2-3)
          (at truck3 city1-5)
          (at truck2 city1-3)
          (at truck1 city1-6)
          (at package23 city1-5)
          (at package22 city1-5)
          (at package21 city2-4)
          (at package20 city2-3)
          (at package19 city1-2)
          (at package18 city3-3)
          (at package17 city2-3)
          (at package16 city3-5)
          (at package15 city2-2)
          (at package14 city2-1)
          (at package13 city3-4)
          (at package12 city1-6)
          (at package11 city1-4)
          (at package10 city3-3)
          (at package9 city3-3)
          (at package8 city1-2)
          (at package7 city1-4)
          (at package6 city1-4)
          (at package5 city3-1)
          (at package4 city2-1)
          (at package3 city1-5)
          (at package2 city3-3)
          (at package1 city1-2))
   (:goal (and (at package23 city2-3)
               (at package22 city1-5)
               (at package21 city1-6)
               (at package20 city1-1)
               (at package19 city1-3)
               (at package18 city1-3)
               (at package17 city1-5)
               (at package16 city1-1)
               (at package15 city3-3)
               (at package14 city1-5)
               (at package13 city2-5)
               (at package12 city3-2)
               (at package11 city2-6)
               (at package10 city1-6))))

(define (problem log-x-16)
   (:domain logistics-adl)
   (:objects package7 package6 package5 package4 package3 package2
             package1 - obj
             city11 city10 city9 city8 city7 city6 city5 city4 city3 city2
             city1 - city
             truck52 truck51 truck50 truck49 truck48 truck47 truck46
             truck45 truck44 truck43 truck42 truck41 truck40 truck39
             truck38 truck37 truck36 truck35 truck34 truck33 truck32
             truck31 truck30 truck29 truck28 truck27 truck26 truck25
             truck24 truck23 truck22 truck21 truck20 truck19 truck18
             truck17 truck16 truck15 truck14 truck13 truck12 truck11
             truck10 truck9 truck8 truck7 truck6 truck5 truck4 truck3 truck2
             truck1 - truck
             plane13 plane12 plane11 plane10 plane9 plane8 plane7 plane6
             plane5 plane4 plane3 plane2 plane1 - airplane
             city11-2 city11-1 city10-2 city10-1 city9-2 city9-1 city8-2
             city8-1 city7-2 city7-1 city6-2 city6-1 city5-2 city5-1
             city4-2 city4-1 city3-2 city3-1 city2-2 city2-1 city1-2
             city1-1 - location
             city11-3 city10-3 city9-3 city8-3 city7-3 city6-3 city5-3
             city4-3 city3-3 city2-3 city1-3 - airport)
   (:init (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane13 city10-3)
          (at plane12 city5-3)
          (at plane11 city11-3)
          (at plane10 city1-3)
          (at plane9 city9-3)
          (at plane8 city7-3)
          (at plane7 city1-3)
          (at plane6 city8-3)
          (at plane5 city7-3)
          (at plane4 city9-3)
          (at plane3 city1-3)
          (at plane2 city11-3)
          (at plane1 city6-3)
          (at truck52 city11-2)
          (at truck51 city10-1)
          (at truck50 city9-2)
          (at truck49 city8-1)
          (at truck48 city7-1)
          (at truck47 city6-1)
          (at truck46 city5-2)
          (at truck45 city4-1)
          (at truck44 city3-2)
          (at truck43 city2-2)
          (at truck42 city1-2)
          (at truck41 city7-2)
          (at truck40 city6-1)
          (at truck39 city2-3)
          (at truck38 city3-1)
          (at truck37 city2-3)
          (at truck36 city7-1)
          (at truck35 city8-2)
          (at truck34 city8-2)
          (at truck33 city7-2)
          (at truck32 city6-3)
          (at truck31 city2-2)
          (at truck30 city11-3)
          (at truck29 city1-2)
          (at truck28 city3-1)
          (at truck27 city9-2)
          (at truck26 city7-2)
          (at truck25 city1-3)
          (at truck24 city4-1)
          (at truck23 city9-2)
          (at truck22 city3-1)
          (at truck21 city1-1)
          (at truck20 city7-3)
          (at truck19 city4-3)
          (at truck18 city1-1)
          (at truck17 city4-3)
          (at truck16 city11-3)
          (at truck15 city6-2)
          (at truck14 city5-3)
          (at truck13 city5-1)
          (at truck12 city8-1)
          (at truck11 city8-1)
          (at truck10 city5-2)
          (at truck9 city8-3)
          (at truck8 city1-1)
          (at truck7 city8-2)
          (at truck6 city9-3)
          (at truck5 city10-2)
          (at truck4 city6-3)
          (at truck3 city11-1)
          (at truck2 city5-3)
          (at truck1 city5-2)
          (at package7 city4-2)
          (at package6 city4-1)
          (at package5 city11-2)
          (at package4 city2-2)
          (at package3 city7-2)
          (at package2 city7-2)
          (at package1 city7-2))
   (:goal (and (at package7 city5-1)
               (at package6 city5-2)
               (at package5 city2-1)
               (at package4 city5-3)
               (at package3 city5-1)
               (at package2 city5-2)
               (at package1 city4-1))))

(define (problem log-x-17)
   (:domain logistics-adl)
   (:objects package15 package14 package13 package12 package11
             package10 package9 package8 package7 package6 package5 package4
             package3 package2 package1 - obj
             city4 city3 city2 city1 - city
             truck45 truck44 truck43 truck42 truck41 truck40 truck39
             truck38 truck37 truck36 truck35 truck34 truck33 truck32
             truck31 truck30 truck29 truck28 truck27 truck26 truck25
             truck24 truck23 truck22 truck21 truck20 truck19 truck18
             truck17 truck16 truck15 truck14 truck13 truck12 truck11
             truck10 truck9 truck8 truck7 truck6 truck5 truck4 truck3 truck2
             truck1 - truck
             plane5 plane4 plane3 plane2 plane1 - airplane
             city4-2 city4-1 city3-2 city3-1 city2-2 city2-1 city1-2
             city1-1 - location
             city4-3 city3-3 city2-3 city1-3 - airport)
   (:init (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane5 city1-3)
          (at plane4 city4-3)
          (at plane3 city4-3)
          (at plane2 city3-3)
          (at plane1 city4-3)
          (at truck45 city4-2)
          (at truck44 city3-2)
          (at truck43 city2-2)
          (at truck42 city1-1)
          (at truck41 city1-3)
          (at truck40 city3-2)
          (at truck39 city2-1)
          (at truck38 city2-3)
          (at truck37 city4-2)
          (at truck36 city3-2)
          (at truck35 city1-1)
          (at truck34 city3-3)
          (at truck33 city3-3)
          (at truck32 city2-1)
          (at truck31 city3-1)
          (at truck30 city3-2)
          (at truck29 city2-2)
          (at truck28 city1-3)
          (at truck27 city4-1)
          (at truck26 city3-2)
          (at truck25 city4-3)
          (at truck24 city2-1)
          (at truck23 city4-1)
          (at truck22 city1-1)
          (at truck21 city3-2)
          (at truck20 city4-3)
          (at truck19 city3-3)
          (at truck18 city1-2)
          (at truck17 city4-2)
          (at truck16 city3-1)
          (at truck15 city3-2)
          (at truck14 city4-3)
          (at truck13 city2-2)
          (at truck12 city2-1)
          (at truck11 city1-1)
          (at truck10 city1-2)
          (at truck9 city1-2)
          (at truck8 city1-1)
          (at truck7 city1-2)
          (at truck6 city2-2)
          (at truck5 city3-1)
          (at truck4 city4-1)
          (at truck3 city1-3)
          (at truck2 city1-3)
          (at truck1 city4-2)
          (at package15 city1-2)
          (at package14 city3-1)
          (at package13 city1-1)
          (at package12 city1-1)
          (at package11 city3-3)
          (at package10 city4-2)
          (at package9 city3-2)
          (at package8 city4-2)
          (at package7 city4-3)
          (at package6 city3-2)
          (at package5 city2-2)
          (at package4 city2-3)
          (at package3 city1-3)
          (at package2 city4-2)
          (at package1 city2-1))
   (:goal (and (at package15 city4-2)
               (at package14 city4-2)
               (at package13 city4-3)
               (at package12 city2-2)
               (at package11 city2-1)
               (at package10 city4-2)
               (at package9 city4-2)
               (at package8 city4-2))))

(define (problem log-x-18)
   (:domain logistics-adl)
   (:objects package20 package19 package18 package17 package16
             package15 package14 package13 package12 package11 package10
             package9 package8 package7 package6 package5 package4 package3
             package2 package1 - obj
             city30 city29 city28 city27 city26 city25 city24 city23 city22
             city21 city20 city19 city18 city17 city16 city15 city14 city13
             city12 city11 city10 city9 city8 city7 city6 city5 city4 city3
             city2 city1 - city
             truck30 truck29 truck28 truck27 truck26 truck25 truck24
             truck23 truck22 truck21 truck20 truck19 truck18 truck17
             truck16 truck15 truck14 truck13 truck12 truck11 truck10 truck9
             truck8 truck7 truck6 truck5 truck4 truck3 truck2 truck1
             - truck
             plane10 plane9 plane8 plane7 plane6 plane5 plane4 plane3 plane2
             plane1 - airplane
             city30-2 city30-1 city29-2 city29-1 city28-2 city28-1 city27-2
             city27-1 city26-2 city26-1 city25-2 city25-1 city24-2 city24-1
             city23-2 city23-1 city22-2 city22-1 city21-2 city21-1 city20-2
             city20-1 city19-2 city19-1 city18-2 city18-1 city17-2 city17-1
             city16-2 city16-1 city15-2 city15-1 city14-2 city14-1 city13-2
             city13-1 city12-2 city12-1 city11-2 city11-1 city10-2 city10-1
             city9-2 city9-1 city8-2 city8-1 city7-2 city7-1 city6-2
             city6-1 city5-2 city5-1 city4-2 city4-1 city3-2 city3-1
             city2-2 city2-1 city1-2 city1-1 - location
             city30-3 city29-3 city28-3 city27-3 city26-3 city25-3 city24-3
             city23-3 city22-3 city21-3 city20-3 city19-3 city18-3 city17-3
             city16-3 city15-3 city14-3 city13-3 city12-3 city11-3 city10-3
             city9-3 city8-3 city7-3 city6-3 city5-3 city4-3 city3-3
             city2-3 city1-3 - airport)
   (:init (in-city city30-3 city30)
          (in-city city30-2 city30)
          (in-city city30-1 city30)
          (in-city city29-3 city29)
          (in-city city29-2 city29)
          (in-city city29-1 city29)
          (in-city city28-3 city28)
          (in-city city28-2 city28)
          (in-city city28-1 city28)
          (in-city city27-3 city27)
          (in-city city27-2 city27)
          (in-city city27-1 city27)
          (in-city city26-3 city26)
          (in-city city26-2 city26)
          (in-city city26-1 city26)
          (in-city city25-3 city25)
          (in-city city25-2 city25)
          (in-city city25-1 city25)
          (in-city city24-3 city24)
          (in-city city24-2 city24)
          (in-city city24-1 city24)
          (in-city city23-3 city23)
          (in-city city23-2 city23)
          (in-city city23-1 city23)
          (in-city city22-3 city22)
          (in-city city22-2 city22)
          (in-city city22-1 city22)
          (in-city city21-3 city21)
          (in-city city21-2 city21)
          (in-city city21-1 city21)
          (in-city city20-3 city20)
          (in-city city20-2 city20)
          (in-city city20-1 city20)
          (in-city city19-3 city19)
          (in-city city19-2 city19)
          (in-city city19-1 city19)
          (in-city city18-3 city18)
          (in-city city18-2 city18)
          (in-city city18-1 city18)
          (in-city city17-3 city17)
          (in-city city17-2 city17)
          (in-city city17-1 city17)
          (in-city city16-3 city16)
          (in-city city16-2 city16)
          (in-city city16-1 city16)
          (in-city city15-3 city15)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane10 city6-3)
          (at plane9 city10-3)
          (at plane8 city9-3)
          (at plane7 city23-3)
          (at plane6 city15-3)
          (at plane5 city6-3)
          (at plane4 city8-3)
          (at plane3 city28-3)
          (at plane2 city12-3)
          (at plane1 city19-3)
          (at truck30 city30-1)
          (at truck29 city29-2)
          (at truck28 city28-2)
          (at truck27 city27-2)
          (at truck26 city26-2)
          (at truck25 city25-1)
          (at truck24 city24-2)
          (at truck23 city23-2)
          (at truck22 city22-2)
          (at truck21 city21-1)
          (at truck20 city20-1)
          (at truck19 city19-2)
          (at truck18 city18-1)
          (at truck17 city17-1)
          (at truck16 city16-1)
          (at truck15 city15-2)
          (at truck14 city14-1)
          (at truck13 city13-2)
          (at truck12 city12-2)
          (at truck11 city11-1)
          (at truck10 city10-1)
          (at truck9 city9-2)
          (at truck8 city8-2)
          (at truck7 city7-1)
          (at truck6 city6-1)
          (at truck5 city5-2)
          (at truck4 city4-2)
          (at truck3 city3-2)
          (at truck2 city2-1)
          (at truck1 city1-1)
          (at package20 city28-1)
          (at package19 city19-2)
          (at package18 city10-2)
          (at package17 city20-1)
          (at package16 city20-1)
          (at package15 city13-1)
          (at package14 city8-1)
          (at package13 city17-1)
          (at package12 city9-1)
          (at package11 city7-3)
          (at package10 city4-2)
          (at package9 city7-1)
          (at package8 city15-1)
          (at package7 city23-1)
          (at package6 city22-1)
          (at package5 city12-2)
          (at package4 city28-3)
          (at package3 city6-3)
          (at package2 city28-3)
          (at package1 city16-1))
   (:goal (and (at package20 city6-2)
               (at package19 city12-2)
               (at package18 city2-1)
               (at package17 city25-1)
               (at package16 city22-2)
               (at package15 city4-1)
               (at package14 city6-3)
               (at package13 city1-3)
               (at package12 city29-1)
               (at package11 city6-1)
               (at package10 city30-3)
               (at package9 city17-3)
               (at package8 city10-1)
               (at package7 city14-1)
               (at package6 city28-1)
               (at package5 city25-2)
               (at package4 city10-1)
               (at package3 city10-3)
               (at package2 city9-2)
               (at package1 city29-3))))

(define (problem log-x-19)
   (:domain logistics-adl)
   (:objects package19 package18 package17 package16 package15
             package14 package13 package12 package11 package10 package9
             package8 package7 package6 package5 package4 package3 package2
             package1 - obj
             city8 city7 city6 city5 city4 city3 city2 city1 - city
             truck30 truck29 truck28 truck27 truck26 truck25 truck24
             truck23 truck22 truck21 truck20 truck19 truck18 truck17
             truck16 truck15 truck14 truck13 truck12 truck11 truck10 truck9
             truck8 truck7 truck6 truck5 truck4 truck3 truck2 truck1
             - truck
             plane11 plane10 plane9 plane8 plane7 plane6 plane5 plane4
             plane3 plane2 plane1 - airplane
             city8-7 city8-6 city8-5 city8-4 city8-3 city8-2 city8-1
             city7-7 city7-6 city7-5 city7-4 city7-3 city7-2 city7-1
             city6-7 city6-6 city6-5 city6-4 city6-3 city6-2 city6-1
             city5-7 city5-6 city5-5 city5-4 city5-3 city5-2 city5-1
             city4-7 city4-6 city4-5 city4-4 city4-3 city4-2 city4-1
             city3-7 city3-6 city3-5 city3-4 city3-3 city3-2 city3-1
             city2-7 city2-6 city2-5 city2-4 city2-3 city2-2 city2-1
             city1-7 city1-6 city1-5 city1-4 city1-3 city1-2 city1-1
             - location
             city8-8 city7-8 city6-8 city5-8 city4-8 city3-8 city2-8
             city1-8 - airport)
   (:init (in-city city8-8 city8)
          (in-city city8-7 city8)
          (in-city city8-6 city8)
          (in-city city8-5 city8)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-8 city7)
          (in-city city7-7 city7)
          (in-city city7-6 city7)
          (in-city city7-5 city7)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-8 city6)
          (in-city city6-7 city6)
          (in-city city6-6 city6)
          (in-city city6-5 city6)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-8 city5)
          (in-city city5-7 city5)
          (in-city city5-6 city5)
          (in-city city5-5 city5)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-8 city4)
          (in-city city4-7 city4)
          (in-city city4-6 city4)
          (in-city city4-5 city4)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-8 city3)
          (in-city city3-7 city3)
          (in-city city3-6 city3)
          (in-city city3-5 city3)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-8 city2)
          (in-city city2-7 city2)
          (in-city city2-6 city2)
          (in-city city2-5 city2)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-8 city1)
          (in-city city1-7 city1)
          (in-city city1-6 city1)
          (in-city city1-5 city1)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane11 city3-8)
          (at plane10 city7-8)
          (at plane9 city3-8)
          (at plane8 city4-8)
          (at plane7 city2-8)
          (at plane6 city1-8)
          (at plane5 city1-8)
          (at plane4 city2-8)
          (at plane3 city3-8)
          (at plane2 city2-8)
          (at plane1 city7-8)
          (at truck30 city8-5)
          (at truck29 city7-3)
          (at truck28 city6-2)
          (at truck27 city5-6)
          (at truck26 city4-3)
          (at truck25 city3-5)
          (at truck24 city2-1)
          (at truck23 city1-7)
          (at truck22 city2-4)
          (at truck21 city3-8)
          (at truck20 city4-7)
          (at truck19 city6-7)
          (at truck18 city7-6)
          (at truck17 city6-6)
          (at truck16 city7-3)
          (at truck15 city1-8)
          (at truck14 city8-8)
          (at truck13 city1-8)
          (at truck12 city5-7)
          (at truck11 city2-6)
          (at truck10 city1-5)
          (at truck9 city2-7)
          (at truck8 city8-5)
          (at truck7 city4-1)
          (at truck6 city3-5)
          (at truck5 city3-8)
          (at truck4 city2-1)
          (at truck3 city3-1)
          (at truck2 city1-8)
          (at truck1 city5-6)
          (at package19 city7-7)
          (at package18 city4-5)
          (at package17 city3-6)
          (at package16 city1-5)
          (at package15 city8-2)
          (at package14 city8-3)
          (at package13 city6-8)
          (at package12 city8-1)
          (at package11 city2-6)
          (at package10 city6-5)
          (at package9 city7-2)
          (at package8 city6-1)
          (at package7 city4-8)
          (at package6 city6-3)
          (at package5 city4-3)
          (at package4 city1-5)
          (at package3 city2-2)
          (at package2 city4-5)
          (at package1 city7-3))
   (:goal (and (at package19 city6-1)
               (at package18 city2-2)
               (at package17 city1-8)
               (at package16 city2-5)
               (at package15 city3-6)
               (at package14 city7-6)
               (at package13 city8-2)
               (at package12 city7-4)
               (at package11 city8-5)
               (at package10 city1-7)
               (at package9 city1-7)
               (at package8 city6-4)
               (at package7 city4-5)
               (at package6 city2-7)
               (at package5 city3-8)
               (at package4 city7-5)
               (at package3 city2-1)
               (at package2 city7-4)
               (at package1 city5-2))))

(define (problem log-x-20)
   (:domain logistics-adl)
   (:objects package16 package15 package14 package13 package12
             package11 package10 package9 package8 package7 package6
             package5 package4 package3 package2 package1 - obj
             city15 city14 city13 city12 city11 city10 city9 city8 city7
             city6 city5 city4 city3 city2 city1 - city
             truck19 truck18 truck17 truck16 truck15 truck14 truck13
             truck12 truck11 truck10 truck9 truck8 truck7 truck6 truck5
             truck4 truck3 truck2 truck1 - truck
             plane15 plane14 plane13 plane12 plane11 plane10 plane9 plane8
             plane7 plane6 plane5 plane4 plane3 plane2 plane1 - airplane
             city15-11 city15-10 city15-9 city15-8 city15-7 city15-6
             city15-5 city15-4 city15-3 city15-2 city15-1 city14-11
             city14-10 city14-9 city14-8 city14-7 city14-6 city14-5 city14-4
             city14-3 city14-2 city14-1 city13-11 city13-10 city13-9
             city13-8 city13-7 city13-6 city13-5 city13-4 city13-3 city13-2
             city13-1 city12-11 city12-10 city12-9 city12-8 city12-7
             city12-6 city12-5 city12-4 city12-3 city12-2 city12-1
             city11-11 city11-10 city11-9 city11-8 city11-7 city11-6
             city11-5 city11-4 city11-3 city11-2 city11-1 city10-11
             city10-10 city10-9 city10-8 city10-7 city10-6 city10-5 city10-4
             city10-3 city10-2 city10-1 city9-11 city9-10 city9-9 city9-8
             city9-7 city9-6 city9-5 city9-4 city9-3 city9-2 city9-1
             city8-11 city8-10 city8-9 city8-8 city8-7 city8-6 city8-5
             city8-4 city8-3 city8-2 city8-1 city7-11 city7-10 city7-9
             city7-8 city7-7 city7-6 city7-5 city7-4 city7-3 city7-2
             city7-1 city6-11 city6-10 city6-9 city6-8 city6-7 city6-6
             city6-5 city6-4 city6-3 city6-2 city6-1 city5-11 city5-10
             city5-9 city5-8 city5-7 city5-6 city5-5 city5-4 city5-3
             city5-2 city5-1 city4-11 city4-10 city4-9 city4-8 city4-7
             city4-6 city4-5 city4-4 city4-3 city4-2 city4-1 city3-11
             city3-10 city3-9 city3-8 city3-7 city3-6 city3-5 city3-4
             city3-3 city3-2 city3-1 city2-11 city2-10 city2-9 city2-8
             city2-7 city2-6 city2-5 city2-4 city2-3 city2-2 city2-1
             city1-11 city1-10 city1-9 city1-8 city1-7 city1-6 city1-5
             city1-4 city1-3 city1-2 city1-1 - location
             city15-12 city14-12 city13-12 city12-12 city11-12 city10-12
             city9-12 city8-12 city7-12 city6-12 city5-12 city4-12 city3-12
             city2-12 city1-12 - airport)
   (:init (in-city city15-12 city15)
          (in-city city15-11 city15)
          (in-city city15-10 city15)
          (in-city city15-9 city15)
          (in-city city15-8 city15)
          (in-city city15-7 city15)
          (in-city city15-6 city15)
          (in-city city15-5 city15)
          (in-city city15-4 city15)
          (in-city city15-3 city15)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-12 city14)
          (in-city city14-11 city14)
          (in-city city14-10 city14)
          (in-city city14-9 city14)
          (in-city city14-8 city14)
          (in-city city14-7 city14)
          (in-city city14-6 city14)
          (in-city city14-5 city14)
          (in-city city14-4 city14)
          (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-12 city13)
          (in-city city13-11 city13)
          (in-city city13-10 city13)
          (in-city city13-9 city13)
          (in-city city13-8 city13)
          (in-city city13-7 city13)
          (in-city city13-6 city13)
          (in-city city13-5 city13)
          (in-city city13-4 city13)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-12 city12)
          (in-city city12-11 city12)
          (in-city city12-10 city12)
          (in-city city12-9 city12)
          (in-city city12-8 city12)
          (in-city city12-7 city12)
          (in-city city12-6 city12)
          (in-city city12-5 city12)
          (in-city city12-4 city12)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-12 city11)
          (in-city city11-11 city11)
          (in-city city11-10 city11)
          (in-city city11-9 city11)
          (in-city city11-8 city11)
          (in-city city11-7 city11)
          (in-city city11-6 city11)
          (in-city city11-5 city11)
          (in-city city11-4 city11)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-12 city10)
          (in-city city10-11 city10)
          (in-city city10-10 city10)
          (in-city city10-9 city10)
          (in-city city10-8 city10)
          (in-city city10-7 city10)
          (in-city city10-6 city10)
          (in-city city10-5 city10)
          (in-city city10-4 city10)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-12 city9)
          (in-city city9-11 city9)
          (in-city city9-10 city9)
          (in-city city9-9 city9)
          (in-city city9-8 city9)
          (in-city city9-7 city9)
          (in-city city9-6 city9)
          (in-city city9-5 city9)
          (in-city city9-4 city9)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-12 city8)
          (in-city city8-11 city8)
          (in-city city8-10 city8)
          (in-city city8-9 city8)
          (in-city city8-8 city8)
          (in-city city8-7 city8)
          (in-city city8-6 city8)
          (in-city city8-5 city8)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-12 city7)
          (in-city city7-11 city7)
          (in-city city7-10 city7)
          (in-city city7-9 city7)
          (in-city city7-8 city7)
          (in-city city7-7 city7)
          (in-city city7-6 city7)
          (in-city city7-5 city7)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-12 city6)
          (in-city city6-11 city6)
          (in-city city6-10 city6)
          (in-city city6-9 city6)
          (in-city city6-8 city6)
          (in-city city6-7 city6)
          (in-city city6-6 city6)
          (in-city city6-5 city6)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-12 city5)
          (in-city city5-11 city5)
          (in-city city5-10 city5)
          (in-city city5-9 city5)
          (in-city city5-8 city5)
          (in-city city5-7 city5)
          (in-city city5-6 city5)
          (in-city city5-5 city5)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-12 city4)
          (in-city city4-11 city4)
          (in-city city4-10 city4)
          (in-city city4-9 city4)
          (in-city city4-8 city4)
          (in-city city4-7 city4)
          (in-city city4-6 city4)
          (in-city city4-5 city4)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-12 city3)
          (in-city city3-11 city3)
          (in-city city3-10 city3)
          (in-city city3-9 city3)
          (in-city city3-8 city3)
          (in-city city3-7 city3)
          (in-city city3-6 city3)
          (in-city city3-5 city3)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-12 city2)
          (in-city city2-11 city2)
          (in-city city2-10 city2)
          (in-city city2-9 city2)
          (in-city city2-8 city2)
          (in-city city2-7 city2)
          (in-city city2-6 city2)
          (in-city city2-5 city2)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-12 city1)
          (in-city city1-11 city1)
          (in-city city1-10 city1)
          (in-city city1-9 city1)
          (in-city city1-8 city1)
          (in-city city1-7 city1)
          (in-city city1-6 city1)
          (in-city city1-5 city1)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane15 city5-12)
          (at plane14 city6-12)
          (at plane13 city4-12)
          (at plane12 city7-12)
          (at plane11 city10-12)
          (at plane10 city3-12)
          (at plane9 city9-12)
          (at plane8 city9-12)
          (at plane7 city14-12)
          (at plane6 city8-12)
          (at plane5 city7-12)
          (at plane4 city11-12)
          (at plane3 city11-12)
          (at plane2 city14-12)
          (at plane1 city13-12)
          (at truck19 city15-6)
          (at truck18 city14-5)
          (at truck17 city13-6)
          (at truck16 city12-10)
          (at truck15 city11-5)
          (at truck14 city10-11)
          (at truck13 city9-3)
          (at truck12 city8-7)
          (at truck11 city7-4)
          (at truck10 city6-9)
          (at truck9 city5-11)
          (at truck8 city4-9)
          (at truck7 city3-8)
          (at truck6 city2-11)
          (at truck5 city1-11)
          (at truck4 city4-9)
          (at truck3 city2-9)
          (at truck2 city10-5)
          (at truck1 city6-6)
          (at package16 city1-12)
          (at package15 city3-10)
          (at package14 city9-8)
          (at package13 city5-2)
          (at package12 city15-5)
          (at package11 city13-3)
          (at package10 city2-3)
          (at package9 city10-1)
          (at package8 city4-9)
          (at package7 city3-4)
          (at package6 city9-2)
          (at package5 city8-1)
          (at package4 city7-5)
          (at package3 city12-5)
          (at package2 city9-7)
          (at package1 city12-11))
   (:goal (and (at package16 city9-10)
               (at package15 city5-12)
               (at package14 city10-4)
               (at package13 city3-4)
               (at package12 city10-10)
               (at package11 city7-4)
               (at package10 city8-5)
               (at package9 city4-2)
               (at package8 city15-6)
               (at package7 city4-9)
               (at package6 city5-10)
               (at package5 city8-10)
               (at package4 city3-11)
               (at package3 city3-7)
               (at package2 city9-12)
               (at package1 city10-10))))

(define (problem log-x-21)
   (:domain logistics-adl)
   (:objects package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 - obj
             city14 city13 city12 city11 city10 city9 city8 city7 city6
             city5 city4 city3 city2 city1 - city
             truck40 truck39 truck38 truck37 truck36 truck35 truck34
             truck33 truck32 truck31 truck30 truck29 truck28 truck27
             truck26 truck25 truck24 truck23 truck22 truck21 truck20
             truck19 truck18 truck17 truck16 truck15 truck14 truck13
             truck12 truck11 truck10 truck9 truck8 truck7 truck6 truck5
             truck4 truck3 truck2 truck1 - truck
             plane13 plane12 plane11 plane10 plane9 plane8 plane7 plane6
             plane5 plane4 plane3 plane2 plane1 - airplane
             city14-8 city14-7 city14-6 city14-5 city14-4 city14-3 city14-2
             city14-1 city13-8 city13-7 city13-6 city13-5 city13-4 city13-3
             city13-2 city13-1 city12-8 city12-7 city12-6 city12-5 city12-4
             city12-3 city12-2 city12-1 city11-8 city11-7 city11-6 city11-5
             city11-4 city11-3 city11-2 city11-1 city10-8 city10-7 city10-6
             city10-5 city10-4 city10-3 city10-2 city10-1 city9-8 city9-7
             city9-6 city9-5 city9-4 city9-3 city9-2 city9-1 city8-8
             city8-7 city8-6 city8-5 city8-4 city8-3 city8-2 city8-1
             city7-8 city7-7 city7-6 city7-5 city7-4 city7-3 city7-2
             city7-1 city6-8 city6-7 city6-6 city6-5 city6-4 city6-3
             city6-2 city6-1 city5-8 city5-7 city5-6 city5-5 city5-4
             city5-3 city5-2 city5-1 city4-8 city4-7 city4-6 city4-5
             city4-4 city4-3 city4-2 city4-1 city3-8 city3-7 city3-6
             city3-5 city3-4 city3-3 city3-2 city3-1 city2-8 city2-7
             city2-6 city2-5 city2-4 city2-3 city2-2 city2-1 city1-8
             city1-7 city1-6 city1-5 city1-4 city1-3 city1-2 city1-1
             - location
             city14-9 city13-9 city12-9 city11-9 city10-9 city9-9 city8-9
             city7-9 city6-9 city5-9 city4-9 city3-9 city2-9 city1-9
             - airport)
   (:init (in-city city14-9 city14)
          (in-city city14-8 city14)
          (in-city city14-7 city14)
          (in-city city14-6 city14)
          (in-city city14-5 city14)
          (in-city city14-4 city14)
          (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-9 city13)
          (in-city city13-8 city13)
          (in-city city13-7 city13)
          (in-city city13-6 city13)
          (in-city city13-5 city13)
          (in-city city13-4 city13)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-9 city12)
          (in-city city12-8 city12)
          (in-city city12-7 city12)
          (in-city city12-6 city12)
          (in-city city12-5 city12)
          (in-city city12-4 city12)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-9 city11)
          (in-city city11-8 city11)
          (in-city city11-7 city11)
          (in-city city11-6 city11)
          (in-city city11-5 city11)
          (in-city city11-4 city11)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-9 city10)
          (in-city city10-8 city10)
          (in-city city10-7 city10)
          (in-city city10-6 city10)
          (in-city city10-5 city10)
          (in-city city10-4 city10)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-9 city9)
          (in-city city9-8 city9)
          (in-city city9-7 city9)
          (in-city city9-6 city9)
          (in-city city9-5 city9)
          (in-city city9-4 city9)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-9 city8)
          (in-city city8-8 city8)
          (in-city city8-7 city8)
          (in-city city8-6 city8)
          (in-city city8-5 city8)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-9 city7)
          (in-city city7-8 city7)
          (in-city city7-7 city7)
          (in-city city7-6 city7)
          (in-city city7-5 city7)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-9 city6)
          (in-city city6-8 city6)
          (in-city city6-7 city6)
          (in-city city6-6 city6)
          (in-city city6-5 city6)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-9 city5)
          (in-city city5-8 city5)
          (in-city city5-7 city5)
          (in-city city5-6 city5)
          (in-city city5-5 city5)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-9 city4)
          (in-city city4-8 city4)
          (in-city city4-7 city4)
          (in-city city4-6 city4)
          (in-city city4-5 city4)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-9 city3)
          (in-city city3-8 city3)
          (in-city city3-7 city3)
          (in-city city3-6 city3)
          (in-city city3-5 city3)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-9 city2)
          (in-city city2-8 city2)
          (in-city city2-7 city2)
          (in-city city2-6 city2)
          (in-city city2-5 city2)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-9 city1)
          (in-city city1-8 city1)
          (in-city city1-7 city1)
          (in-city city1-6 city1)
          (in-city city1-5 city1)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane13 city8-9)
          (at plane12 city4-9)
          (at plane11 city2-9)
          (at plane10 city5-9)
          (at plane9 city2-9)
          (at plane8 city7-9)
          (at plane7 city5-9)
          (at plane6 city3-9)
          (at plane5 city11-9)
          (at plane4 city7-9)
          (at plane3 city6-9)
          (at plane2 city11-9)
          (at plane1 city2-9)
          (at truck40 city14-3)
          (at truck39 city13-7)
          (at truck38 city12-7)
          (at truck37 city11-5)
          (at truck36 city10-1)
          (at truck35 city9-3)
          (at truck34 city8-8)
          (at truck33 city7-1)
          (at truck32 city6-3)
          (at truck31 city5-7)
          (at truck30 city4-4)
          (at truck29 city3-1)
          (at truck28 city2-7)
          (at truck27 city1-5)
          (at truck26 city4-6)
          (at truck25 city9-1)
          (at truck24 city9-7)
          (at truck23 city4-4)
          (at truck22 city3-3)
          (at truck21 city7-8)
          (at truck20 city2-6)
          (at truck19 city13-3)
          (at truck18 city5-5)
          (at truck17 city4-5)
          (at truck16 city7-1)
          (at truck15 city7-8)
          (at truck14 city4-9)
          (at truck13 city2-1)
          (at truck12 city2-8)
          (at truck11 city6-2)
          (at truck10 city8-3)
          (at truck9 city3-1)
          (at truck8 city11-7)
          (at truck7 city8-5)
          (at truck6 city4-7)
          (at truck5 city1-3)
          (at truck4 city1-3)
          (at truck3 city2-6)
          (at truck2 city2-9)
          (at truck1 city12-9)
          (at package11 city3-8)
          (at package10 city3-1)
          (at package9 city2-5)
          (at package8 city6-6)
          (at package7 city9-8)
          (at package6 city1-6)
          (at package5 city1-1)
          (at package4 city8-8)
          (at package3 city5-8)
          (at package2 city10-1)
          (at package1 city12-1))
   (:goal (and (at package11 city9-8)
               (at package10 city12-9)
               (at package9 city2-3)
               (at package8 city10-7)
               (at package7 city2-2)
               (at package6 city12-6)
               (at package5 city14-8)
               (at package4 city13-2)
               (at package3 city2-8)
               (at package2 city6-2)
               (at package1 city11-6))))

(define (problem log-x-22)
   (:domain logistics-adl)
   (:objects package44 package43 package42 package41 package40
             package39 package38 package37 package36 package35 package34
             package33 package32 package31 package30 package29 package28
             package27 package26 package25 package24 package23 package22
             package21 package20 package19 package18 package17 package16
             package15 package14 package13 package12 package11 package10
             package9 package8 package7 package6 package5 package4 package3
             package2 package1 - obj
             city30 city29 city28 city27 city26 city25 city24 city23 city22
             city21 city20 city19 city18 city17 city16 city15 city14 city13
             city12 city11 city10 city9 city8 city7 city6 city5 city4 city3
             city2 city1 - city
             truck74 truck73 truck72 truck71 truck70 truck69 truck68
             truck67 truck66 truck65 truck64 truck63 truck62 truck61
             truck60 truck59 truck58 truck57 truck56 truck55 truck54
             truck53 truck52 truck51 truck50 truck49 truck48 truck47
             truck46 truck45 truck44 truck43 truck42 truck41 truck40
             truck39 truck38 truck37 truck36 truck35 truck34 truck33
             truck32 truck31 truck30 truck29 truck28 truck27 truck26
             truck25 truck24 truck23 truck22 truck21 truck20 truck19
             truck18 truck17 truck16 truck15 truck14 truck13 truck12
             truck11 truck10 truck9 truck8 truck7 truck6 truck5 truck4
             truck3 truck2 truck1 - truck
             plane6 plane5 plane4 plane3 plane2 plane1 - airplane
             city30-3 city30-2 city30-1 city29-3 city29-2 city29-1 city28-3
             city28-2 city28-1 city27-3 city27-2 city27-1 city26-3 city26-2
             city26-1 city25-3 city25-2 city25-1 city24-3 city24-2 city24-1
             city23-3 city23-2 city23-1 city22-3 city22-2 city22-1 city21-3
             city21-2 city21-1 city20-3 city20-2 city20-1 city19-3 city19-2
             city19-1 city18-3 city18-2 city18-1 city17-3 city17-2 city17-1
             city16-3 city16-2 city16-1 city15-3 city15-2 city15-1 city14-3
             city14-2 city14-1 city13-3 city13-2 city13-1 city12-3 city12-2
             city12-1 city11-3 city11-2 city11-1 city10-3 city10-2 city10-1
             city9-3 city9-2 city9-1 city8-3 city8-2 city8-1 city7-3
             city7-2 city7-1 city6-3 city6-2 city6-1 city5-3 city5-2
             city5-1 city4-3 city4-2 city4-1 city3-3 city3-2 city3-1
             city2-3 city2-2 city2-1 city1-3 city1-2 city1-1 - location
             city30-4 city29-4 city28-4 city27-4 city26-4 city25-4 city24-4
             city23-4 city22-4 city21-4 city20-4 city19-4 city18-4 city17-4
             city16-4 city15-4 city14-4 city13-4 city12-4 city11-4 city10-4
             city9-4 city8-4 city7-4 city6-4 city5-4 city4-4 city3-4
             city2-4 city1-4 - airport)
   (:init (in-city city30-4 city30)
          (in-city city30-3 city30)
          (in-city city30-2 city30)
          (in-city city30-1 city30)
          (in-city city29-4 city29)
          (in-city city29-3 city29)
          (in-city city29-2 city29)
          (in-city city29-1 city29)
          (in-city city28-4 city28)
          (in-city city28-3 city28)
          (in-city city28-2 city28)
          (in-city city28-1 city28)
          (in-city city27-4 city27)
          (in-city city27-3 city27)
          (in-city city27-2 city27)
          (in-city city27-1 city27)
          (in-city city26-4 city26)
          (in-city city26-3 city26)
          (in-city city26-2 city26)
          (in-city city26-1 city26)
          (in-city city25-4 city25)
          (in-city city25-3 city25)
          (in-city city25-2 city25)
          (in-city city25-1 city25)
          (in-city city24-4 city24)
          (in-city city24-3 city24)
          (in-city city24-2 city24)
          (in-city city24-1 city24)
          (in-city city23-4 city23)
          (in-city city23-3 city23)
          (in-city city23-2 city23)
          (in-city city23-1 city23)
          (in-city city22-4 city22)
          (in-city city22-3 city22)
          (in-city city22-2 city22)
          (in-city city22-1 city22)
          (in-city city21-4 city21)
          (in-city city21-3 city21)
          (in-city city21-2 city21)
          (in-city city21-1 city21)
          (in-city city20-4 city20)
          (in-city city20-3 city20)
          (in-city city20-2 city20)
          (in-city city20-1 city20)
          (in-city city19-4 city19)
          (in-city city19-3 city19)
          (in-city city19-2 city19)
          (in-city city19-1 city19)
          (in-city city18-4 city18)
          (in-city city18-3 city18)
          (in-city city18-2 city18)
          (in-city city18-1 city18)
          (in-city city17-4 city17)
          (in-city city17-3 city17)
          (in-city city17-2 city17)
          (in-city city17-1 city17)
          (in-city city16-4 city16)
          (in-city city16-3 city16)
          (in-city city16-2 city16)
          (in-city city16-1 city16)
          (in-city city15-4 city15)
          (in-city city15-3 city15)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-4 city14)
          (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-4 city13)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-4 city12)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-4 city11)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-4 city10)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-4 city9)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane6 city11-4)
          (at plane5 city24-4)
          (at plane4 city30-4)
          (at plane3 city9-4)
          (at plane2 city20-4)
          (at plane1 city2-4)
          (at truck74 city30-2)
          (at truck73 city29-2)
          (at truck72 city28-2)
          (at truck71 city27-3)
          (at truck70 city26-1)
          (at truck69 city25-2)
          (at truck68 city24-1)
          (at truck67 city23-3)
          (at truck66 city22-2)
          (at truck65 city21-3)
          (at truck64 city20-1)
          (at truck63 city19-2)
          (at truck62 city18-3)
          (at truck61 city17-1)
          (at truck60 city16-1)
          (at truck59 city15-1)
          (at truck58 city14-2)
          (at truck57 city13-3)
          (at truck56 city12-3)
          (at truck55 city11-2)
          (at truck54 city10-3)
          (at truck53 city9-2)
          (at truck52 city8-3)
          (at truck51 city7-2)
          (at truck50 city6-1)
          (at truck49 city5-1)
          (at truck48 city4-3)
          (at truck47 city3-3)
          (at truck46 city2-3)
          (at truck45 city1-2)
          (at truck44 city7-3)
          (at truck43 city1-4)
          (at truck42 city29-3)
          (at truck41 city9-2)
          (at truck40 city26-2)
          (at truck39 city12-1)
          (at truck38 city28-3)
          (at truck37 city6-4)
          (at truck36 city8-3)
          (at truck35 city14-4)
          (at truck34 city29-4)
          (at truck33 city4-4)
          (at truck32 city17-1)
          (at truck31 city29-1)
          (at truck30 city14-2)
          (at truck29 city9-2)
          (at truck28 city28-1)
          (at truck27 city18-2)
          (at truck26 city17-2)
          (at truck25 city15-4)
          (at truck24 city28-2)
          (at truck23 city7-3)
          (at truck22 city6-2)
          (at truck21 city29-3)
          (at truck20 city18-2)
          (at truck19 city28-3)
          (at truck18 city26-2)
          (at truck17 city1-4)
          (at truck16 city5-1)
          (at truck15 city18-1)
          (at truck14 city29-1)
          (at truck13 city12-4)
          (at truck12 city30-3)
          (at truck11 city7-3)
          (at truck10 city29-1)
          (at truck9 city26-4)
          (at truck8 city2-4)
          (at truck7 city13-1)
          (at truck6 city3-4)
          (at truck5 city8-4)
          (at truck4 city20-4)
          (at truck3 city10-1)
          (at truck2 city10-1)
          (at truck1 city21-2)
          (at package44 city13-1)
          (at package43 city20-2)
          (at package42 city30-4)
          (at package41 city14-4)
          (at package40 city10-3)
          (at package39 city3-3)
          (at package38 city27-3)
          (at package37 city30-3)
          (at package36 city22-1)
          (at package35 city10-3)
          (at package34 city2-4)
          (at package33 city22-2)
          (at package32 city1-4)
          (at package31 city6-3)
          (at package30 city7-3)
          (at package29 city5-3)
          (at package28 city23-2)
          (at package27 city21-3)
          (at package26 city9-4)
          (at package25 city11-2)
          (at package24 city12-3)
          (at package23 city30-2)
          (at package22 city22-1)
          (at package21 city18-2)
          (at package20 city22-1)
          (at package19 city4-1)
          (at package18 city19-2)
          (at package17 city6-4)
          (at package16 city9-1)
          (at package15 city1-1)
          (at package14 city3-2)
          (at package13 city28-2)
          (at package12 city9-3)
          (at package11 city26-2)
          (at package10 city30-2)
          (at package9 city20-3)
          (at package8 city27-4)
          (at package7 city2-2)
          (at package6 city18-3)
          (at package5 city20-1)
          (at package4 city10-3)
          (at package3 city20-1)
          (at package2 city8-2)
          (at package1 city22-1))
   (:goal (and (at package44 city29-3)
               (at package43 city28-3)
               (at package42 city30-3)
               (at package41 city29-3)
               (at package40 city4-2)
               (at package39 city15-3)
               (at package38 city6-4)
               (at package37 city10-1)
               (at package36 city28-2)
               (at package35 city20-2)
               (at package34 city10-4)
               (at package33 city21-2)
               (at package32 city26-4)
               (at package31 city17-4)
               (at package30 city13-4)
               (at package29 city30-4)
               (at package28 city12-3)
               (at package27 city10-1)
               (at package26 city29-2)
               (at package25 city22-1)
               (at package24 city30-3)
               (at package23 city20-3)
               (at package22 city28-4)
               (at package21 city22-2)
               (at package20 city16-2)
               (at package19 city5-3)
               (at package18 city16-2)
               (at package17 city22-2)
               (at package16 city14-4)
               (at package15 city18-3)
               (at package14 city13-2)
               (at package13 city2-3)
               (at package12 city28-1)
               (at package11 city22-2)
               (at package10 city5-4)
               (at package9 city12-3))))

(define (problem log-x-23)
   (:domain logistics-adl)
   (:objects package21 package20 package19 package18 package17
             package16 package15 package14 package13 package12 package11
             package10 package9 package8 package7 package6 package5 package4
             package3 package2 package1 - obj
             city8 city7 city6 city5 city4 city3 city2 city1 - city
             truck28 truck27 truck26 truck25 truck24 truck23 truck22
             truck21 truck20 truck19 truck18 truck17 truck16 truck15
             truck14 truck13 truck12 truck11 truck10 truck9 truck8 truck7
             truck6 truck5 truck4 truck3 truck2 truck1 - truck
             plane4 plane3 plane2 plane1 - airplane
             city8-1 city7-1 city6-1 city5-1 city4-1 city3-1 city2-1
             city1-1 - location
             city8-2 city7-2 city6-2 city5-2 city4-2 city3-2 city2-2
             city1-2 - airport)
   (:init (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane4 city5-2)
          (at plane3 city7-2)
          (at plane2 city3-2)
          (at plane1 city1-2)
          (at truck28 city8-1)
          (at truck27 city7-1)
          (at truck26 city6-1)
          (at truck25 city5-1)
          (at truck24 city4-1)
          (at truck23 city3-1)
          (at truck22 city2-1)
          (at truck21 city1-1)
          (at truck20 city2-2)
          (at truck19 city1-1)
          (at truck18 city2-1)
          (at truck17 city7-1)
          (at truck16 city2-2)
          (at truck15 city3-1)
          (at truck14 city5-2)
          (at truck13 city5-1)
          (at truck12 city5-2)
          (at truck11 city6-2)
          (at truck10 city2-2)
          (at truck9 city2-2)
          (at truck8 city1-1)
          (at truck7 city1-1)
          (at truck6 city4-1)
          (at truck5 city6-2)
          (at truck4 city4-1)
          (at truck3 city4-1)
          (at truck2 city2-1)
          (at truck1 city5-2)
          (at package21 city3-1)
          (at package20 city3-1)
          (at package19 city8-1)
          (at package18 city5-1)
          (at package17 city1-2)
          (at package16 city6-1)
          (at package15 city7-2)
          (at package14 city4-2)
          (at package13 city1-1)
          (at package12 city1-2)
          (at package11 city1-2)
          (at package10 city1-2)
          (at package9 city1-1)
          (at package8 city6-1)
          (at package7 city1-1)
          (at package6 city7-1)
          (at package5 city3-1)
          (at package4 city3-2)
          (at package3 city3-1)
          (at package2 city1-2)
          (at package1 city1-1))
   (:goal (and (at package21 city5-2)
               (at package20 city2-2)
               (at package19 city2-1)
               (at package18 city2-2)
               (at package17 city6-1)
               (at package16 city1-1)
               (at package15 city3-2)
               (at package14 city3-1)
               (at package13 city6-1)
               (at package12 city8-1)
               (at package11 city1-2)
               (at package10 city4-1)
               (at package9 city7-1)
               (at package8 city2-1)
               (at package7 city3-2)
               (at package6 city2-2)
               (at package5 city8-2)
               (at package4 city8-2)
               (at package3 city1-2)
               (at package2 city6-2)
               (at package1 city8-2))))

(define (problem log-x-24)
   (:domain logistics-adl)
   (:objects package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 - obj
             city9 city8 city7 city6 city5 city4 city3 city2 city1 - city
             truck54 truck53 truck52 truck51 truck50 truck49 truck48
             truck47 truck46 truck45 truck44 truck43 truck42 truck41
             truck40 truck39 truck38 truck37 truck36 truck35 truck34
             truck33 truck32 truck31 truck30 truck29 truck28 truck27
             truck26 truck25 truck24 truck23 truck22 truck21 truck20
             truck19 truck18 truck17 truck16 truck15 truck14 truck13
             truck12 truck11 truck10 truck9 truck8 truck7 truck6 truck5
             truck4 truck3 truck2 truck1 - truck
             plane8 plane7 plane6 plane5 plane4 plane3 plane2 plane1
             - airplane
             city9-11 city9-10 city9-9 city9-8 city9-7 city9-6 city9-5
             city9-4 city9-3 city9-2 city9-1 city8-11 city8-10 city8-9
             city8-8 city8-7 city8-6 city8-5 city8-4 city8-3 city8-2
             city8-1 city7-11 city7-10 city7-9 city7-8 city7-7 city7-6
             city7-5 city7-4 city7-3 city7-2 city7-1 city6-11 city6-10
             city6-9 city6-8 city6-7 city6-6 city6-5 city6-4 city6-3
             city6-2 city6-1 city5-11 city5-10 city5-9 city5-8 city5-7
             city5-6 city5-5 city5-4 city5-3 city5-2 city5-1 city4-11
             city4-10 city4-9 city4-8 city4-7 city4-6 city4-5 city4-4
             city4-3 city4-2 city4-1 city3-11 city3-10 city3-9 city3-8
             city3-7 city3-6 city3-5 city3-4 city3-3 city3-2 city3-1
             city2-11 city2-10 city2-9 city2-8 city2-7 city2-6 city2-5
             city2-4 city2-3 city2-2 city2-1 city1-11 city1-10 city1-9
             city1-8 city1-7 city1-6 city1-5 city1-4 city1-3 city1-2
             city1-1 - location
             city9-12 city8-12 city7-12 city6-12 city5-12 city4-12 city3-12
             city2-12 city1-12 - airport)
   (:init (in-city city9-12 city9)
          (in-city city9-11 city9)
          (in-city city9-10 city9)
          (in-city city9-9 city9)
          (in-city city9-8 city9)
          (in-city city9-7 city9)
          (in-city city9-6 city9)
          (in-city city9-5 city9)
          (in-city city9-4 city9)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-12 city8)
          (in-city city8-11 city8)
          (in-city city8-10 city8)
          (in-city city8-9 city8)
          (in-city city8-8 city8)
          (in-city city8-7 city8)
          (in-city city8-6 city8)
          (in-city city8-5 city8)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-12 city7)
          (in-city city7-11 city7)
          (in-city city7-10 city7)
          (in-city city7-9 city7)
          (in-city city7-8 city7)
          (in-city city7-7 city7)
          (in-city city7-6 city7)
          (in-city city7-5 city7)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-12 city6)
          (in-city city6-11 city6)
          (in-city city6-10 city6)
          (in-city city6-9 city6)
          (in-city city6-8 city6)
          (in-city city6-7 city6)
          (in-city city6-6 city6)
          (in-city city6-5 city6)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-12 city5)
          (in-city city5-11 city5)
          (in-city city5-10 city5)
          (in-city city5-9 city5)
          (in-city city5-8 city5)
          (in-city city5-7 city5)
          (in-city city5-6 city5)
          (in-city city5-5 city5)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-12 city4)
          (in-city city4-11 city4)
          (in-city city4-10 city4)
          (in-city city4-9 city4)
          (in-city city4-8 city4)
          (in-city city4-7 city4)
          (in-city city4-6 city4)
          (in-city city4-5 city4)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-12 city3)
          (in-city city3-11 city3)
          (in-city city3-10 city3)
          (in-city city3-9 city3)
          (in-city city3-8 city3)
          (in-city city3-7 city3)
          (in-city city3-6 city3)
          (in-city city3-5 city3)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-12 city2)
          (in-city city2-11 city2)
          (in-city city2-10 city2)
          (in-city city2-9 city2)
          (in-city city2-8 city2)
          (in-city city2-7 city2)
          (in-city city2-6 city2)
          (in-city city2-5 city2)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-12 city1)
          (in-city city1-11 city1)
          (in-city city1-10 city1)
          (in-city city1-9 city1)
          (in-city city1-8 city1)
          (in-city city1-7 city1)
          (in-city city1-6 city1)
          (in-city city1-5 city1)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane8 city6-12)
          (at plane7 city6-12)
          (at plane6 city9-12)
          (at plane5 city3-12)
          (at plane4 city9-12)
          (at plane3 city2-12)
          (at plane2 city7-12)
          (at plane1 city6-12)
          (at truck54 city9-4)
          (at truck53 city8-5)
          (at truck52 city7-11)
          (at truck51 city6-1)
          (at truck50 city5-4)
          (at truck49 city4-5)
          (at truck48 city3-2)
          (at truck47 city2-8)
          (at truck46 city1-9)
          (at truck45 city5-4)
          (at truck44 city7-6)
          (at truck43 city8-5)
          (at truck42 city3-2)
          (at truck41 city6-8)
          (at truck40 city2-3)
          (at truck39 city2-10)
          (at truck38 city2-12)
          (at truck37 city2-5)
          (at truck36 city5-7)
          (at truck35 city1-3)
          (at truck34 city1-11)
          (at truck33 city6-10)
          (at truck32 city1-2)
          (at truck31 city3-3)
          (at truck30 city5-12)
          (at truck29 city2-4)
          (at truck28 city3-3)
          (at truck27 city2-3)
          (at truck26 city3-3)
          (at truck25 city4-1)
          (at truck24 city1-12)
          (at truck23 city1-1)
          (at truck22 city7-11)
          (at truck21 city4-5)
          (at truck20 city8-6)
          (at truck19 city1-4)
          (at truck18 city4-7)
          (at truck17 city4-10)
          (at truck16 city1-11)
          (at truck15 city9-7)
          (at truck14 city3-3)
          (at truck13 city1-4)
          (at truck12 city4-8)
          (at truck11 city8-9)
          (at truck10 city6-7)
          (at truck9 city6-10)
          (at truck8 city1-1)
          (at truck7 city4-3)
          (at truck6 city4-5)
          (at truck5 city4-5)
          (at truck4 city9-8)
          (at truck3 city4-8)
          (at truck2 city1-5)
          (at truck1 city9-7)
          (at package11 city5-4)
          (at package10 city2-5)
          (at package9 city6-5)
          (at package8 city1-5)
          (at package7 city3-9)
          (at package6 city6-9)
          (at package5 city4-12)
          (at package4 city7-1)
          (at package3 city6-6)
          (at package2 city2-7)
          (at package1 city8-1))
   (:goal (and (at package11 city8-8)
               (at package10 city3-2)
               (at package9 city1-11)
               (at package8 city3-4))))

(define (problem log-x-25)
   (:domain logistics-adl)
   (:objects package18 package17 package16 package15 package14
             package13 package12 package11 package10 package9 package8
             package7 package6 package5 package4 package3 package2 package1
             - obj
             city27 city26 city25 city24 city23 city22 city21 city20 city19
             city18 city17 city16 city15 city14 city13 city12 city11 city10
             city9 city8 city7 city6 city5 city4 city3 city2 city1 - city
             truck29 truck28 truck27 truck26 truck25 truck24 truck23
             truck22 truck21 truck20 truck19 truck18 truck17 truck16
             truck15 truck14 truck13 truck12 truck11 truck10 truck9 truck8
             truck7 truck6 truck5 truck4 truck3 truck2 truck1 - truck
             plane13 plane12 plane11 plane10 plane9 plane8 plane7 plane6
             plane5 plane4 plane3 plane2 plane1 - airplane
             city27-12 city27-11 city27-10 city27-9 city27-8 city27-7
             city27-6 city27-5 city27-4 city27-3 city27-2 city27-1
             city26-12 city26-11 city26-10 city26-9 city26-8 city26-7
             city26-6 city26-5 city26-4 city26-3 city26-2 city26-1
             city25-12 city25-11 city25-10 city25-9 city25-8 city25-7
             city25-6 city25-5 city25-4 city25-3 city25-2 city25-1
             city24-12 city24-11 city24-10 city24-9 city24-8 city24-7
             city24-6 city24-5 city24-4 city24-3 city24-2 city24-1
             city23-12 city23-11 city23-10 city23-9 city23-8 city23-7
             city23-6 city23-5 city23-4 city23-3 city23-2 city23-1
             city22-12 city22-11 city22-10 city22-9 city22-8 city22-7
             city22-6 city22-5 city22-4 city22-3 city22-2 city22-1
             city21-12 city21-11 city21-10 city21-9 city21-8 city21-7
             city21-6 city21-5 city21-4 city21-3 city21-2 city21-1
             city20-12 city20-11 city20-10 city20-9 city20-8 city20-7
             city20-6 city20-5 city20-4 city20-3 city20-2 city20-1
             city19-12 city19-11 city19-10 city19-9 city19-8 city19-7
             city19-6 city19-5 city19-4 city19-3 city19-2 city19-1
             city18-12 city18-11 city18-10 city18-9 city18-8 city18-7
             city18-6 city18-5 city18-4 city18-3 city18-2 city18-1
             city17-12 city17-11 city17-10 city17-9 city17-8 city17-7
             city17-6 city17-5 city17-4 city17-3 city17-2 city17-1
             city16-12 city16-11 city16-10 city16-9 city16-8 city16-7
             city16-6 city16-5 city16-4 city16-3 city16-2 city16-1
             city15-12 city15-11 city15-10 city15-9 city15-8 city15-7
             city15-6 city15-5 city15-4 city15-3 city15-2 city15-1
             city14-12 city14-11 city14-10 city14-9 city14-8 city14-7
             city14-6 city14-5 city14-4 city14-3 city14-2 city14-1
             city13-12 city13-11 city13-10 city13-9 city13-8 city13-7
             city13-6 city13-5 city13-4 city13-3 city13-2 city13-1
             city12-12 city12-11 city12-10 city12-9 city12-8 city12-7
             city12-6 city12-5 city12-4 city12-3 city12-2 city12-1
             city11-12 city11-11 city11-10 city11-9 city11-8 city11-7
             city11-6 city11-5 city11-4 city11-3 city11-2 city11-1
             city10-12 city10-11 city10-10 city10-9 city10-8 city10-7
             city10-6 city10-5 city10-4 city10-3 city10-2 city10-1 city9-12
             city9-11 city9-10 city9-9 city9-8 city9-7 city9-6 city9-5
             city9-4 city9-3 city9-2 city9-1 city8-12 city8-11 city8-10
             city8-9 city8-8 city8-7 city8-6 city8-5 city8-4 city8-3
             city8-2 city8-1 city7-12 city7-11 city7-10 city7-9 city7-8
             city7-7 city7-6 city7-5 city7-4 city7-3 city7-2 city7-1
             city6-12 city6-11 city6-10 city6-9 city6-8 city6-7 city6-6
             city6-5 city6-4 city6-3 city6-2 city6-1 city5-12 city5-11
             city5-10 city5-9 city5-8 city5-7 city5-6 city5-5 city5-4
             city5-3 city5-2 city5-1 city4-12 city4-11 city4-10 city4-9
             city4-8 city4-7 city4-6 city4-5 city4-4 city4-3 city4-2
             city4-1 city3-12 city3-11 city3-10 city3-9 city3-8 city3-7
             city3-6 city3-5 city3-4 city3-3 city3-2 city3-1 city2-12
             city2-11 city2-10 city2-9 city2-8 city2-7 city2-6 city2-5
             city2-4 city2-3 city2-2 city2-1 city1-12 city1-11 city1-10
             city1-9 city1-8 city1-7 city1-6 city1-5 city1-4 city1-3
             city1-2 city1-1 - location
             city27-13 city26-13 city25-13 city24-13 city23-13 city22-13
             city21-13 city20-13 city19-13 city18-13 city17-13 city16-13
             city15-13 city14-13 city13-13 city12-13 city11-13 city10-13
             city9-13 city8-13 city7-13 city6-13 city5-13 city4-13 city3-13
             city2-13 city1-13 - airport)
   (:init (in-city city27-13 city27)
          (in-city city27-12 city27)
          (in-city city27-11 city27)
          (in-city city27-10 city27)
          (in-city city27-9 city27)
          (in-city city27-8 city27)
          (in-city city27-7 city27)
          (in-city city27-6 city27)
          (in-city city27-5 city27)
          (in-city city27-4 city27)
          (in-city city27-3 city27)
          (in-city city27-2 city27)
          (in-city city27-1 city27)
          (in-city city26-13 city26)
          (in-city city26-12 city26)
          (in-city city26-11 city26)
          (in-city city26-10 city26)
          (in-city city26-9 city26)
          (in-city city26-8 city26)
          (in-city city26-7 city26)
          (in-city city26-6 city26)
          (in-city city26-5 city26)
          (in-city city26-4 city26)
          (in-city city26-3 city26)
          (in-city city26-2 city26)
          (in-city city26-1 city26)
          (in-city city25-13 city25)
          (in-city city25-12 city25)
          (in-city city25-11 city25)
          (in-city city25-10 city25)
          (in-city city25-9 city25)
          (in-city city25-8 city25)
          (in-city city25-7 city25)
          (in-city city25-6 city25)
          (in-city city25-5 city25)
          (in-city city25-4 city25)
          (in-city city25-3 city25)
          (in-city city25-2 city25)
          (in-city city25-1 city25)
          (in-city city24-13 city24)
          (in-city city24-12 city24)
          (in-city city24-11 city24)
          (in-city city24-10 city24)
          (in-city city24-9 city24)
          (in-city city24-8 city24)
          (in-city city24-7 city24)
          (in-city city24-6 city24)
          (in-city city24-5 city24)
          (in-city city24-4 city24)
          (in-city city24-3 city24)
          (in-city city24-2 city24)
          (in-city city24-1 city24)
          (in-city city23-13 city23)
          (in-city city23-12 city23)
          (in-city city23-11 city23)
          (in-city city23-10 city23)
          (in-city city23-9 city23)
          (in-city city23-8 city23)
          (in-city city23-7 city23)
          (in-city city23-6 city23)
          (in-city city23-5 city23)
          (in-city city23-4 city23)
          (in-city city23-3 city23)
          (in-city city23-2 city23)
          (in-city city23-1 city23)
          (in-city city22-13 city22)
          (in-city city22-12 city22)
          (in-city city22-11 city22)
          (in-city city22-10 city22)
          (in-city city22-9 city22)
          (in-city city22-8 city22)
          (in-city city22-7 city22)
          (in-city city22-6 city22)
          (in-city city22-5 city22)
          (in-city city22-4 city22)
          (in-city city22-3 city22)
          (in-city city22-2 city22)
          (in-city city22-1 city22)
          (in-city city21-13 city21)
          (in-city city21-12 city21)
          (in-city city21-11 city21)
          (in-city city21-10 city21)
          (in-city city21-9 city21)
          (in-city city21-8 city21)
          (in-city city21-7 city21)
          (in-city city21-6 city21)
          (in-city city21-5 city21)
          (in-city city21-4 city21)
          (in-city city21-3 city21)
          (in-city city21-2 city21)
          (in-city city21-1 city21)
          (in-city city20-13 city20)
          (in-city city20-12 city20)
          (in-city city20-11 city20)
          (in-city city20-10 city20)
          (in-city city20-9 city20)
          (in-city city20-8 city20)
          (in-city city20-7 city20)
          (in-city city20-6 city20)
          (in-city city20-5 city20)
          (in-city city20-4 city20)
          (in-city city20-3 city20)
          (in-city city20-2 city20)
          (in-city city20-1 city20)
          (in-city city19-13 city19)
          (in-city city19-12 city19)
          (in-city city19-11 city19)
          (in-city city19-10 city19)
          (in-city city19-9 city19)
          (in-city city19-8 city19)
          (in-city city19-7 city19)
          (in-city city19-6 city19)
          (in-city city19-5 city19)
          (in-city city19-4 city19)
          (in-city city19-3 city19)
          (in-city city19-2 city19)
          (in-city city19-1 city19)
          (in-city city18-13 city18)
          (in-city city18-12 city18)
          (in-city city18-11 city18)
          (in-city city18-10 city18)
          (in-city city18-9 city18)
          (in-city city18-8 city18)
          (in-city city18-7 city18)
          (in-city city18-6 city18)
          (in-city city18-5 city18)
          (in-city city18-4 city18)
          (in-city city18-3 city18)
          (in-city city18-2 city18)
          (in-city city18-1 city18)
          (in-city city17-13 city17)
          (in-city city17-12 city17)
          (in-city city17-11 city17)
          (in-city city17-10 city17)
          (in-city city17-9 city17)
          (in-city city17-8 city17)
          (in-city city17-7 city17)
          (in-city city17-6 city17)
          (in-city city17-5 city17)
          (in-city city17-4 city17)
          (in-city city17-3 city17)
          (in-city city17-2 city17)
          (in-city city17-1 city17)
          (in-city city16-13 city16)
          (in-city city16-12 city16)
          (in-city city16-11 city16)
          (in-city city16-10 city16)
          (in-city city16-9 city16)
          (in-city city16-8 city16)
          (in-city city16-7 city16)
          (in-city city16-6 city16)
          (in-city city16-5 city16)
          (in-city city16-4 city16)
          (in-city city16-3 city16)
          (in-city city16-2 city16)
          (in-city city16-1 city16)
          (in-city city15-13 city15)
          (in-city city15-12 city15)
          (in-city city15-11 city15)
          (in-city city15-10 city15)
          (in-city city15-9 city15)
          (in-city city15-8 city15)
          (in-city city15-7 city15)
          (in-city city15-6 city15)
          (in-city city15-5 city15)
          (in-city city15-4 city15)
          (in-city city15-3 city15)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-13 city14)
          (in-city city14-12 city14)
          (in-city city14-11 city14)
          (in-city city14-10 city14)
          (in-city city14-9 city14)
          (in-city city14-8 city14)
          (in-city city14-7 city14)
          (in-city city14-6 city14)
          (in-city city14-5 city14)
          (in-city city14-4 city14)
          (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-13 city13)
          (in-city city13-12 city13)
          (in-city city13-11 city13)
          (in-city city13-10 city13)
          (in-city city13-9 city13)
          (in-city city13-8 city13)
          (in-city city13-7 city13)
          (in-city city13-6 city13)
          (in-city city13-5 city13)
          (in-city city13-4 city13)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-13 city12)
          (in-city city12-12 city12)
          (in-city city12-11 city12)
          (in-city city12-10 city12)
          (in-city city12-9 city12)
          (in-city city12-8 city12)
          (in-city city12-7 city12)
          (in-city city12-6 city12)
          (in-city city12-5 city12)
          (in-city city12-4 city12)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-13 city11)
          (in-city city11-12 city11)
          (in-city city11-11 city11)
          (in-city city11-10 city11)
          (in-city city11-9 city11)
          (in-city city11-8 city11)
          (in-city city11-7 city11)
          (in-city city11-6 city11)
          (in-city city11-5 city11)
          (in-city city11-4 city11)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-13 city10)
          (in-city city10-12 city10)
          (in-city city10-11 city10)
          (in-city city10-10 city10)
          (in-city city10-9 city10)
          (in-city city10-8 city10)
          (in-city city10-7 city10)
          (in-city city10-6 city10)
          (in-city city10-5 city10)
          (in-city city10-4 city10)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-13 city9)
          (in-city city9-12 city9)
          (in-city city9-11 city9)
          (in-city city9-10 city9)
          (in-city city9-9 city9)
          (in-city city9-8 city9)
          (in-city city9-7 city9)
          (in-city city9-6 city9)
          (in-city city9-5 city9)
          (in-city city9-4 city9)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-13 city8)
          (in-city city8-12 city8)
          (in-city city8-11 city8)
          (in-city city8-10 city8)
          (in-city city8-9 city8)
          (in-city city8-8 city8)
          (in-city city8-7 city8)
          (in-city city8-6 city8)
          (in-city city8-5 city8)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-13 city7)
          (in-city city7-12 city7)
          (in-city city7-11 city7)
          (in-city city7-10 city7)
          (in-city city7-9 city7)
          (in-city city7-8 city7)
          (in-city city7-7 city7)
          (in-city city7-6 city7)
          (in-city city7-5 city7)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-13 city6)
          (in-city city6-12 city6)
          (in-city city6-11 city6)
          (in-city city6-10 city6)
          (in-city city6-9 city6)
          (in-city city6-8 city6)
          (in-city city6-7 city6)
          (in-city city6-6 city6)
          (in-city city6-5 city6)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-13 city5)
          (in-city city5-12 city5)
          (in-city city5-11 city5)
          (in-city city5-10 city5)
          (in-city city5-9 city5)
          (in-city city5-8 city5)
          (in-city city5-7 city5)
          (in-city city5-6 city5)
          (in-city city5-5 city5)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-13 city4)
          (in-city city4-12 city4)
          (in-city city4-11 city4)
          (in-city city4-10 city4)
          (in-city city4-9 city4)
          (in-city city4-8 city4)
          (in-city city4-7 city4)
          (in-city city4-6 city4)
          (in-city city4-5 city4)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-13 city3)
          (in-city city3-12 city3)
          (in-city city3-11 city3)
          (in-city city3-10 city3)
          (in-city city3-9 city3)
          (in-city city3-8 city3)
          (in-city city3-7 city3)
          (in-city city3-6 city3)
          (in-city city3-5 city3)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-13 city2)
          (in-city city2-12 city2)
          (in-city city2-11 city2)
          (in-city city2-10 city2)
          (in-city city2-9 city2)
          (in-city city2-8 city2)
          (in-city city2-7 city2)
          (in-city city2-6 city2)
          (in-city city2-5 city2)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-13 city1)
          (in-city city1-12 city1)
          (in-city city1-11 city1)
          (in-city city1-10 city1)
          (in-city city1-9 city1)
          (in-city city1-8 city1)
          (in-city city1-7 city1)
          (in-city city1-6 city1)
          (in-city city1-5 city1)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane13 city16-13)
          (at plane12 city7-13)
          (at plane11 city3-13)
          (at plane10 city6-13)
          (at plane9 city3-13)
          (at plane8 city8-13)
          (at plane7 city21-13)
          (at plane6 city9-13)
          (at plane5 city26-13)
          (at plane4 city20-13)
          (at plane3 city23-13)
          (at plane2 city22-13)
          (at plane1 city1-13)
          (at truck29 city27-2)
          (at truck28 city26-6)
          (at truck27 city25-6)
          (at truck26 city24-9)
          (at truck25 city23-3)
          (at truck24 city22-5)
          (at truck23 city21-8)
          (at truck22 city20-5)
          (at truck21 city19-9)
          (at truck20 city18-9)
          (at truck19 city17-8)
          (at truck18 city16-9)
          (at truck17 city15-2)
          (at truck16 city14-9)
          (at truck15 city13-8)
          (at truck14 city12-1)
          (at truck13 city11-4)
          (at truck12 city10-5)
          (at truck11 city9-1)
          (at truck10 city8-9)
          (at truck9 city7-3)
          (at truck8 city6-10)
          (at truck7 city5-5)
          (at truck6 city4-10)
          (at truck5 city3-4)
          (at truck4 city2-10)
          (at truck3 city1-7)
          (at truck2 city11-7)
          (at truck1 city14-7)
          (at package18 city27-2)
          (at package17 city5-11)
          (at package16 city7-11)
          (at package15 city6-7)
          (at package14 city9-5)
          (at package13 city1-12)
          (at package12 city8-7)
          (at package11 city21-11)
          (at package10 city24-12)
          (at package9 city2-1)
          (at package8 city6-13)
          (at package7 city20-7)
          (at package6 city5-2)
          (at package5 city13-4)
          (at package4 city15-10)
          (at package3 city15-5)
          (at package2 city5-7)
          (at package1 city20-7))
   (:goal (and (at package18 city11-8)
               (at package17 city21-6)
               (at package16 city26-12)
               (at package15 city16-11)
               (at package14 city10-8)
               (at package13 city7-2)
               (at package12 city24-6)
               (at package11 city23-12)
               (at package10 city14-3)
               (at package9 city22-1)
               (at package8 city3-11)
               (at package7 city11-11)
               (at package6 city9-1)
               (at package5 city6-3)
               (at package4 city9-4)
               (at package3 city19-5)
               (at package2 city16-11)
               (at package1 city26-3))))

(define (problem log-x-26)
   (:domain logistics-adl)
   (:objects package33 package32 package31 package30 package29
             package28 package27 package26 package25 package24 package23
             package22 package21 package20 package19 package18 package17
             package16 package15 package14 package13 package12 package11
             package10 package9 package8 package7 package6 package5 package4
             package3 package2 package1 - obj
             city47 city46 city45 city44 city43 city42 city41 city40 city39
             city38 city37 city36 city35 city34 city33 city32 city31 city30
             city29 city28 city27 city26 city25 city24 city23 city22 city21
             city20 city19 city18 city17 city16 city15 city14 city13 city12
             city11 city10 city9 city8 city7 city6 city5 city4 city3 city2
             city1 - city
             truck106 truck105 truck104 truck103 truck102 truck101 truck100
             truck99 truck98 truck97 truck96 truck95 truck94 truck93
             truck92 truck91 truck90 truck89 truck88 truck87 truck86
             truck85 truck84 truck83 truck82 truck81 truck80 truck79
             truck78 truck77 truck76 truck75 truck74 truck73 truck72
             truck71 truck70 truck69 truck68 truck67 truck66 truck65
             truck64 truck63 truck62 truck61 truck60 truck59 truck58
             truck57 truck56 truck55 truck54 truck53 truck52 truck51
             truck50 truck49 truck48 truck47 truck46 truck45 truck44
             truck43 truck42 truck41 truck40 truck39 truck38 truck37
             truck36 truck35 truck34 truck33 truck32 truck31 truck30
             truck29 truck28 truck27 truck26 truck25 truck24 truck23
             truck22 truck21 truck20 truck19 truck18 truck17 truck16
             truck15 truck14 truck13 truck12 truck11 truck10 truck9 truck8
             truck7 truck6 truck5 truck4 truck3 truck2 truck1 - truck
             plane2 plane1 - airplane
             city47-1 city46-1 city45-1 city44-1 city43-1 city42-1 city41-1
             city40-1 city39-1 city38-1 city37-1 city36-1 city35-1 city34-1
             city33-1 city32-1 city31-1 city30-1 city29-1 city28-1 city27-1
             city26-1 city25-1 city24-1 city23-1 city22-1 city21-1 city20-1
             city19-1 city18-1 city17-1 city16-1 city15-1 city14-1 city13-1
             city12-1 city11-1 city10-1 city9-1 city8-1 city7-1 city6-1
             city5-1 city4-1 city3-1 city2-1 city1-1 - location
             city47-2 city46-2 city45-2 city44-2 city43-2 city42-2 city41-2
             city40-2 city39-2 city38-2 city37-2 city36-2 city35-2 city34-2
             city33-2 city32-2 city31-2 city30-2 city29-2 city28-2 city27-2
             city26-2 city25-2 city24-2 city23-2 city22-2 city21-2 city20-2
             city19-2 city18-2 city17-2 city16-2 city15-2 city14-2 city13-2
             city12-2 city11-2 city10-2 city9-2 city8-2 city7-2 city6-2
             city5-2 city4-2 city3-2 city2-2 city1-2 - airport)
   (:init (in-city city47-2 city47)
          (in-city city47-1 city47)
          (in-city city46-2 city46)
          (in-city city46-1 city46)
          (in-city city45-2 city45)
          (in-city city45-1 city45)
          (in-city city44-2 city44)
          (in-city city44-1 city44)
          (in-city city43-2 city43)
          (in-city city43-1 city43)
          (in-city city42-2 city42)
          (in-city city42-1 city42)
          (in-city city41-2 city41)
          (in-city city41-1 city41)
          (in-city city40-2 city40)
          (in-city city40-1 city40)
          (in-city city39-2 city39)
          (in-city city39-1 city39)
          (in-city city38-2 city38)
          (in-city city38-1 city38)
          (in-city city37-2 city37)
          (in-city city37-1 city37)
          (in-city city36-2 city36)
          (in-city city36-1 city36)
          (in-city city35-2 city35)
          (in-city city35-1 city35)
          (in-city city34-2 city34)
          (in-city city34-1 city34)
          (in-city city33-2 city33)
          (in-city city33-1 city33)
          (in-city city32-2 city32)
          (in-city city32-1 city32)
          (in-city city31-2 city31)
          (in-city city31-1 city31)
          (in-city city30-2 city30)
          (in-city city30-1 city30)
          (in-city city29-2 city29)
          (in-city city29-1 city29)
          (in-city city28-2 city28)
          (in-city city28-1 city28)
          (in-city city27-2 city27)
          (in-city city27-1 city27)
          (in-city city26-2 city26)
          (in-city city26-1 city26)
          (in-city city25-2 city25)
          (in-city city25-1 city25)
          (in-city city24-2 city24)
          (in-city city24-1 city24)
          (in-city city23-2 city23)
          (in-city city23-1 city23)
          (in-city city22-2 city22)
          (in-city city22-1 city22)
          (in-city city21-2 city21)
          (in-city city21-1 city21)
          (in-city city20-2 city20)
          (in-city city20-1 city20)
          (in-city city19-2 city19)
          (in-city city19-1 city19)
          (in-city city18-2 city18)
          (in-city city18-1 city18)
          (in-city city17-2 city17)
          (in-city city17-1 city17)
          (in-city city16-2 city16)
          (in-city city16-1 city16)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane2 city37-2)
          (at plane1 city33-2)
          (at truck106 city47-1)
          (at truck105 city46-1)
          (at truck104 city45-1)
          (at truck103 city44-1)
          (at truck102 city43-1)
          (at truck101 city42-1)
          (at truck100 city41-1)
          (at truck99 city40-1)
          (at truck98 city39-1)
          (at truck97 city38-1)
          (at truck96 city37-1)
          (at truck95 city36-1)
          (at truck94 city35-1)
          (at truck93 city34-1)
          (at truck92 city33-1)
          (at truck91 city32-1)
          (at truck90 city31-1)
          (at truck89 city30-1)
          (at truck88 city29-1)
          (at truck87 city28-1)
          (at truck86 city27-1)
          (at truck85 city26-1)
          (at truck84 city25-1)
          (at truck83 city24-1)
          (at truck82 city23-1)
          (at truck81 city22-1)
          (at truck80 city21-1)
          (at truck79 city20-1)
          (at truck78 city19-1)
          (at truck77 city18-1)
          (at truck76 city17-1)
          (at truck75 city16-1)
          (at truck74 city15-1)
          (at truck73 city14-1)
          (at truck72 city13-1)
          (at truck71 city12-1)
          (at truck70 city11-1)
          (at truck69 city10-1)
          (at truck68 city9-1)
          (at truck67 city8-1)
          (at truck66 city7-1)
          (at truck65 city6-1)
          (at truck64 city5-1)
          (at truck63 city4-1)
          (at truck62 city3-1)
          (at truck61 city2-1)
          (at truck60 city1-1)
          (at truck59 city1-2)
          (at truck58 city12-1)
          (at truck57 city15-2)
          (at truck56 city28-2)
          (at truck55 city7-1)
          (at truck54 city36-1)
          (at truck53 city15-1)
          (at truck52 city45-2)
          (at truck51 city3-1)
          (at truck50 city44-2)
          (at truck49 city42-1)
          (at truck48 city42-2)
          (at truck47 city23-1)
          (at truck46 city5-1)
          (at truck45 city11-1)
          (at truck44 city23-2)
          (at truck43 city19-2)
          (at truck42 city17-2)
          (at truck41 city42-1)
          (at truck40 city25-2)
          (at truck39 city14-1)
          (at truck38 city9-1)
          (at truck37 city32-2)
          (at truck36 city3-1)
          (at truck35 city13-2)
          (at truck34 city47-2)
          (at truck33 city1-2)
          (at truck32 city10-2)
          (at truck31 city35-1)
          (at truck30 city44-2)
          (at truck29 city14-2)
          (at truck28 city23-1)
          (at truck27 city24-1)
          (at truck26 city24-2)
          (at truck25 city23-1)
          (at truck24 city5-2)
          (at truck23 city4-1)
          (at truck22 city30-1)
          (at truck21 city6-2)
          (at truck20 city31-2)
          (at truck19 city7-1)
          (at truck18 city35-2)
          (at truck17 city40-1)
          (at truck16 city45-2)
          (at truck15 city35-2)
          (at truck14 city12-2)
          (at truck13 city2-2)
          (at truck12 city29-1)
          (at truck11 city1-1)
          (at truck10 city25-1)
          (at truck9 city1-2)
          (at truck8 city30-1)
          (at truck7 city16-2)
          (at truck6 city25-2)
          (at truck5 city37-1)
          (at truck4 city41-2)
          (at truck3 city36-2)
          (at truck2 city39-2)
          (at truck1 city4-2)
          (at package33 city29-2)
          (at package32 city10-2)
          (at package31 city45-2)
          (at package30 city21-2)
          (at package29 city34-1)
          (at package28 city4-2)
          (at package27 city30-2)
          (at package26 city5-2)
          (at package25 city38-1)
          (at package24 city10-1)
          (at package23 city23-1)
          (at package22 city42-1)
          (at package21 city18-1)
          (at package20 city35-2)
          (at package19 city37-2)
          (at package18 city43-1)
          (at package17 city14-2)
          (at package16 city42-2)
          (at package15 city27-2)
          (at package14 city40-2)
          (at package13 city7-1)
          (at package12 city6-1)
          (at package11 city40-2)
          (at package10 city14-2)
          (at package9 city34-1)
          (at package8 city7-1)
          (at package7 city12-1)
          (at package6 city44-1)
          (at package5 city11-1)
          (at package4 city28-2)
          (at package3 city6-2)
          (at package2 city27-1)
          (at package1 city12-2))
   (:goal (and (at package33 city40-2)
               (at package32 city46-2)
               (at package31 city26-2)
               (at package30 city25-2)
               (at package29 city23-1)
               (at package28 city30-2)
               (at package27 city11-2)
               (at package26 city2-1)
               (at package25 city7-1)
               (at package24 city46-1)
               (at package23 city39-1)
               (at package22 city25-1)
               (at package21 city31-2)
               (at package20 city11-2)
               (at package19 city14-1)
               (at package18 city3-2)
               (at package17 city2-1)
               (at package16 city19-2)
               (at package15 city8-2)
               (at package14 city17-1)
               (at package13 city37-2)
               (at package12 city27-1)
               (at package11 city9-2)
               (at package10 city22-2)
               (at package9 city38-1)
               (at package8 city20-1)
               (at package7 city30-1)
               (at package6 city46-1)
               (at package5 city6-2)
               (at package4 city5-2)
               (at package3 city2-2))))

(define (problem log-x-27)
   (:domain logistics-adl)
   (:objects package57 package56 package55 package54 package53
             package52 package51 package50 package49 package48 package47
             package46 package45 package44 package43 package42 package41
             package40 package39 package38 package37 package36 package35
             package34 package33 package32 package31 package30 package29
             package28 package27 package26 package25 package24 package23
             package22 package21 package20 package19 package18 package17
             package16 package15 package14 package13 package12 package11
             package10 package9 package8 package7 package6 package5 package4
             package3 package2 package1 - obj
             city15 city14 city13 city12 city11 city10 city9 city8 city7
             city6 city5 city4 city3 city2 city1 - city
             truck28 truck27 truck26 truck25 truck24 truck23 truck22
             truck21 truck20 truck19 truck18 truck17 truck16 truck15
             truck14 truck13 truck12 truck11 truck10 truck9 truck8 truck7
             truck6 truck5 truck4 truck3 truck2 truck1 - truck
             plane9 plane8 plane7 plane6 plane5 plane4 plane3 plane2 plane1
             - airplane
             city15-13 city15-12 city15-11 city15-10 city15-9 city15-8
             city15-7 city15-6 city15-5 city15-4 city15-3 city15-2 city15-1
             city14-13 city14-12 city14-11 city14-10 city14-9 city14-8
             city14-7 city14-6 city14-5 city14-4 city14-3 city14-2 city14-1
             city13-13 city13-12 city13-11 city13-10 city13-9 city13-8
             city13-7 city13-6 city13-5 city13-4 city13-3 city13-2 city13-1
             city12-13 city12-12 city12-11 city12-10 city12-9 city12-8
             city12-7 city12-6 city12-5 city12-4 city12-3 city12-2 city12-1
             city11-13 city11-12 city11-11 city11-10 city11-9 city11-8
             city11-7 city11-6 city11-5 city11-4 city11-3 city11-2 city11-1
             city10-13 city10-12 city10-11 city10-10 city10-9 city10-8
             city10-7 city10-6 city10-5 city10-4 city10-3 city10-2 city10-1
             city9-13 city9-12 city9-11 city9-10 city9-9 city9-8 city9-7
             city9-6 city9-5 city9-4 city9-3 city9-2 city9-1 city8-13
             city8-12 city8-11 city8-10 city8-9 city8-8 city8-7 city8-6
             city8-5 city8-4 city8-3 city8-2 city8-1 city7-13 city7-12
             city7-11 city7-10 city7-9 city7-8 city7-7 city7-6 city7-5
             city7-4 city7-3 city7-2 city7-1 city6-13 city6-12 city6-11
             city6-10 city6-9 city6-8 city6-7 city6-6 city6-5 city6-4
             city6-3 city6-2 city6-1 city5-13 city5-12 city5-11 city5-10
             city5-9 city5-8 city5-7 city5-6 city5-5 city5-4 city5-3
             city5-2 city5-1 city4-13 city4-12 city4-11 city4-10 city4-9
             city4-8 city4-7 city4-6 city4-5 city4-4 city4-3 city4-2
             city4-1 city3-13 city3-12 city3-11 city3-10 city3-9 city3-8
             city3-7 city3-6 city3-5 city3-4 city3-3 city3-2 city3-1
             city2-13 city2-12 city2-11 city2-10 city2-9 city2-8 city2-7
             city2-6 city2-5 city2-4 city2-3 city2-2 city2-1 city1-13
             city1-12 city1-11 city1-10 city1-9 city1-8 city1-7 city1-6
             city1-5 city1-4 city1-3 city1-2 city1-1 - location
             city15-14 city14-14 city13-14 city12-14 city11-14 city10-14
             city9-14 city8-14 city7-14 city6-14 city5-14 city4-14 city3-14
             city2-14 city1-14 - airport)
   (:init (in-city city15-14 city15)
          (in-city city15-13 city15)
          (in-city city15-12 city15)
          (in-city city15-11 city15)
          (in-city city15-10 city15)
          (in-city city15-9 city15)
          (in-city city15-8 city15)
          (in-city city15-7 city15)
          (in-city city15-6 city15)
          (in-city city15-5 city15)
          (in-city city15-4 city15)
          (in-city city15-3 city15)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-14 city14)
          (in-city city14-13 city14)
          (in-city city14-12 city14)
          (in-city city14-11 city14)
          (in-city city14-10 city14)
          (in-city city14-9 city14)
          (in-city city14-8 city14)
          (in-city city14-7 city14)
          (in-city city14-6 city14)
          (in-city city14-5 city14)
          (in-city city14-4 city14)
          (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-14 city13)
          (in-city city13-13 city13)
          (in-city city13-12 city13)
          (in-city city13-11 city13)
          (in-city city13-10 city13)
          (in-city city13-9 city13)
          (in-city city13-8 city13)
          (in-city city13-7 city13)
          (in-city city13-6 city13)
          (in-city city13-5 city13)
          (in-city city13-4 city13)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-14 city12)
          (in-city city12-13 city12)
          (in-city city12-12 city12)
          (in-city city12-11 city12)
          (in-city city12-10 city12)
          (in-city city12-9 city12)
          (in-city city12-8 city12)
          (in-city city12-7 city12)
          (in-city city12-6 city12)
          (in-city city12-5 city12)
          (in-city city12-4 city12)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-14 city11)
          (in-city city11-13 city11)
          (in-city city11-12 city11)
          (in-city city11-11 city11)
          (in-city city11-10 city11)
          (in-city city11-9 city11)
          (in-city city11-8 city11)
          (in-city city11-7 city11)
          (in-city city11-6 city11)
          (in-city city11-5 city11)
          (in-city city11-4 city11)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-14 city10)
          (in-city city10-13 city10)
          (in-city city10-12 city10)
          (in-city city10-11 city10)
          (in-city city10-10 city10)
          (in-city city10-9 city10)
          (in-city city10-8 city10)
          (in-city city10-7 city10)
          (in-city city10-6 city10)
          (in-city city10-5 city10)
          (in-city city10-4 city10)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-14 city9)
          (in-city city9-13 city9)
          (in-city city9-12 city9)
          (in-city city9-11 city9)
          (in-city city9-10 city9)
          (in-city city9-9 city9)
          (in-city city9-8 city9)
          (in-city city9-7 city9)
          (in-city city9-6 city9)
          (in-city city9-5 city9)
          (in-city city9-4 city9)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-14 city8)
          (in-city city8-13 city8)
          (in-city city8-12 city8)
          (in-city city8-11 city8)
          (in-city city8-10 city8)
          (in-city city8-9 city8)
          (in-city city8-8 city8)
          (in-city city8-7 city8)
          (in-city city8-6 city8)
          (in-city city8-5 city8)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-14 city7)
          (in-city city7-13 city7)
          (in-city city7-12 city7)
          (in-city city7-11 city7)
          (in-city city7-10 city7)
          (in-city city7-9 city7)
          (in-city city7-8 city7)
          (in-city city7-7 city7)
          (in-city city7-6 city7)
          (in-city city7-5 city7)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-14 city6)
          (in-city city6-13 city6)
          (in-city city6-12 city6)
          (in-city city6-11 city6)
          (in-city city6-10 city6)
          (in-city city6-9 city6)
          (in-city city6-8 city6)
          (in-city city6-7 city6)
          (in-city city6-6 city6)
          (in-city city6-5 city6)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-14 city5)
          (in-city city5-13 city5)
          (in-city city5-12 city5)
          (in-city city5-11 city5)
          (in-city city5-10 city5)
          (in-city city5-9 city5)
          (in-city city5-8 city5)
          (in-city city5-7 city5)
          (in-city city5-6 city5)
          (in-city city5-5 city5)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-14 city4)
          (in-city city4-13 city4)
          (in-city city4-12 city4)
          (in-city city4-11 city4)
          (in-city city4-10 city4)
          (in-city city4-9 city4)
          (in-city city4-8 city4)
          (in-city city4-7 city4)
          (in-city city4-6 city4)
          (in-city city4-5 city4)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-14 city3)
          (in-city city3-13 city3)
          (in-city city3-12 city3)
          (in-city city3-11 city3)
          (in-city city3-10 city3)
          (in-city city3-9 city3)
          (in-city city3-8 city3)
          (in-city city3-7 city3)
          (in-city city3-6 city3)
          (in-city city3-5 city3)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-14 city2)
          (in-city city2-13 city2)
          (in-city city2-12 city2)
          (in-city city2-11 city2)
          (in-city city2-10 city2)
          (in-city city2-9 city2)
          (in-city city2-8 city2)
          (in-city city2-7 city2)
          (in-city city2-6 city2)
          (in-city city2-5 city2)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-14 city1)
          (in-city city1-13 city1)
          (in-city city1-12 city1)
          (in-city city1-11 city1)
          (in-city city1-10 city1)
          (in-city city1-9 city1)
          (in-city city1-8 city1)
          (in-city city1-7 city1)
          (in-city city1-6 city1)
          (in-city city1-5 city1)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane9 city11-14)
          (at plane8 city2-14)
          (at plane7 city6-14)
          (at plane6 city4-14)
          (at plane5 city6-14)
          (at plane4 city13-14)
          (at plane3 city7-14)
          (at plane2 city8-14)
          (at plane1 city9-14)
          (at truck28 city15-5)
          (at truck27 city14-8)
          (at truck26 city13-2)
          (at truck25 city12-8)
          (at truck24 city11-7)
          (at truck23 city10-10)
          (at truck22 city9-8)
          (at truck21 city8-6)
          (at truck20 city7-1)
          (at truck19 city6-13)
          (at truck18 city5-9)
          (at truck17 city4-8)
          (at truck16 city3-6)
          (at truck15 city2-12)
          (at truck14 city1-11)
          (at truck13 city7-9)
          (at truck12 city2-12)
          (at truck11 city9-12)
          (at truck10 city12-9)
          (at truck9 city14-9)
          (at truck8 city14-4)
          (at truck7 city10-6)
          (at truck6 city14-10)
          (at truck5 city10-11)
          (at truck4 city7-10)
          (at truck3 city5-2)
          (at truck2 city3-2)
          (at truck1 city15-1)
          (at package57 city6-7)
          (at package56 city2-4)
          (at package55 city2-8)
          (at package54 city15-7)
          (at package53 city6-14)
          (at package52 city11-4)
          (at package51 city11-14)
          (at package50 city14-13)
          (at package49 city2-7)
          (at package48 city5-14)
          (at package47 city14-13)
          (at package46 city2-2)
          (at package45 city3-5)
          (at package44 city2-1)
          (at package43 city15-12)
          (at package42 city15-1)
          (at package41 city13-14)
          (at package40 city4-14)
          (at package39 city13-6)
          (at package38 city2-12)
          (at package37 city9-7)
          (at package36 city7-10)
          (at package35 city7-3)
          (at package34 city10-4)
          (at package33 city6-14)
          (at package32 city13-6)
          (at package31 city15-13)
          (at package30 city11-5)
          (at package29 city12-12)
          (at package28 city14-1)
          (at package27 city7-8)
          (at package26 city15-7)
          (at package25 city4-6)
          (at package24 city7-8)
          (at package23 city10-14)
          (at package22 city9-11)
          (at package21 city8-14)
          (at package20 city3-8)
          (at package19 city9-4)
          (at package18 city8-2)
          (at package17 city11-9)
          (at package16 city10-14)
          (at package15 city7-8)
          (at package14 city5-13)
          (at package13 city5-12)
          (at package12 city6-12)
          (at package11 city5-12)
          (at package10 city11-1)
          (at package9 city10-12)
          (at package8 city12-3)
          (at package7 city13-4)
          (at package6 city5-8)
          (at package5 city2-1)
          (at package4 city3-9)
          (at package3 city9-2)
          (at package2 city8-7)
          (at package1 city6-12))
   (:goal (and (at package57 city12-11)
               (at package56 city2-8)
               (at package55 city10-4)
               (at package54 city11-12)
               (at package53 city4-6)
               (at package52 city8-4)
               (at package51 city13-4)
               (at package50 city14-7)
               (at package49 city15-10)
               (at package48 city9-12)
               (at package47 city9-7)
               (at package46 city8-2)
               (at package45 city9-4)
               (at package44 city4-13)
               (at package43 city14-7)
               (at package42 city11-3)
               (at package41 city9-9))))

(define (problem log-x-28)
   (:domain logistics-adl)
   (:objects package42 package41 package40 package39 package38
             package37 package36 package35 package34 package33 package32
             package31 package30 package29 package28 package27 package26
             package25 package24 package23 package22 package21 package20
             package19 package18 package17 package16 package15 package14
             package13 package12 package11 package10 package9 package8
             package7 package6 package5 package4 package3 package2 package1
             - obj
             city20 city19 city18 city17 city16 city15 city14 city13 city12
             city11 city10 city9 city8 city7 city6 city5 city4 city3 city2
             city1 - city
             truck83 truck82 truck81 truck80 truck79 truck78 truck77
             truck76 truck75 truck74 truck73 truck72 truck71 truck70
             truck69 truck68 truck67 truck66 truck65 truck64 truck63
             truck62 truck61 truck60 truck59 truck58 truck57 truck56
             truck55 truck54 truck53 truck52 truck51 truck50 truck49
             truck48 truck47 truck46 truck45 truck44 truck43 truck42
             truck41 truck40 truck39 truck38 truck37 truck36 truck35
             truck34 truck33 truck32 truck31 truck30 truck29 truck28
             truck27 truck26 truck25 truck24 truck23 truck22 truck21
             truck20 truck19 truck18 truck17 truck16 truck15 truck14
             truck13 truck12 truck11 truck10 truck9 truck8 truck7 truck6
             truck5 truck4 truck3 truck2 truck1 - truck
             plane5 plane4 plane3 plane2 plane1 - airplane
             city20-16 city20-15 city20-14 city20-13 city20-12 city20-11
             city20-10 city20-9 city20-8 city20-7 city20-6 city20-5 city20-4
             city20-3 city20-2 city20-1 city19-16 city19-15 city19-14
             city19-13 city19-12 city19-11 city19-10 city19-9 city19-8
             city19-7 city19-6 city19-5 city19-4 city19-3 city19-2 city19-1
             city18-16 city18-15 city18-14 city18-13 city18-12 city18-11
             city18-10 city18-9 city18-8 city18-7 city18-6 city18-5 city18-4
             city18-3 city18-2 city18-1 city17-16 city17-15 city17-14
             city17-13 city17-12 city17-11 city17-10 city17-9 city17-8
             city17-7 city17-6 city17-5 city17-4 city17-3 city17-2 city17-1
             city16-16 city16-15 city16-14 city16-13 city16-12 city16-11
             city16-10 city16-9 city16-8 city16-7 city16-6 city16-5 city16-4
             city16-3 city16-2 city16-1 city15-16 city15-15 city15-14
             city15-13 city15-12 city15-11 city15-10 city15-9 city15-8
             city15-7 city15-6 city15-5 city15-4 city15-3 city15-2 city15-1
             city14-16 city14-15 city14-14 city14-13 city14-12 city14-11
             city14-10 city14-9 city14-8 city14-7 city14-6 city14-5 city14-4
             city14-3 city14-2 city14-1 city13-16 city13-15 city13-14
             city13-13 city13-12 city13-11 city13-10 city13-9 city13-8
             city13-7 city13-6 city13-5 city13-4 city13-3 city13-2 city13-1
             city12-16 city12-15 city12-14 city12-13 city12-12 city12-11
             city12-10 city12-9 city12-8 city12-7 city12-6 city12-5 city12-4
             city12-3 city12-2 city12-1 city11-16 city11-15 city11-14
             city11-13 city11-12 city11-11 city11-10 city11-9 city11-8
             city11-7 city11-6 city11-5 city11-4 city11-3 city11-2 city11-1
             city10-16 city10-15 city10-14 city10-13 city10-12 city10-11
             city10-10 city10-9 city10-8 city10-7 city10-6 city10-5 city10-4
             city10-3 city10-2 city10-1 city9-16 city9-15 city9-14 city9-13
             city9-12 city9-11 city9-10 city9-9 city9-8 city9-7 city9-6
             city9-5 city9-4 city9-3 city9-2 city9-1 city8-16 city8-15
             city8-14 city8-13 city8-12 city8-11 city8-10 city8-9 city8-8
             city8-7 city8-6 city8-5 city8-4 city8-3 city8-2 city8-1
             city7-16 city7-15 city7-14 city7-13 city7-12 city7-11 city7-10
             city7-9 city7-8 city7-7 city7-6 city7-5 city7-4 city7-3
             city7-2 city7-1 city6-16 city6-15 city6-14 city6-13 city6-12
             city6-11 city6-10 city6-9 city6-8 city6-7 city6-6 city6-5
             city6-4 city6-3 city6-2 city6-1 city5-16 city5-15 city5-14
             city5-13 city5-12 city5-11 city5-10 city5-9 city5-8 city5-7
             city5-6 city5-5 city5-4 city5-3 city5-2 city5-1 city4-16
             city4-15 city4-14 city4-13 city4-12 city4-11 city4-10 city4-9
             city4-8 city4-7 city4-6 city4-5 city4-4 city4-3 city4-2
             city4-1 city3-16 city3-15 city3-14 city3-13 city3-12 city3-11
             city3-10 city3-9 city3-8 city3-7 city3-6 city3-5 city3-4
             city3-3 city3-2 city3-1 city2-16 city2-15 city2-14 city2-13
             city2-12 city2-11 city2-10 city2-9 city2-8 city2-7 city2-6
             city2-5 city2-4 city2-3 city2-2 city2-1 city1-16 city1-15
             city1-14 city1-13 city1-12 city1-11 city1-10 city1-9 city1-8
             city1-7 city1-6 city1-5 city1-4 city1-3 city1-2 city1-1
             - location
             city20-17 city19-17 city18-17 city17-17 city16-17 city15-17
             city14-17 city13-17 city12-17 city11-17 city10-17 city9-17
             city8-17 city7-17 city6-17 city5-17 city4-17 city3-17 city2-17
             city1-17 - airport)
   (:init (in-city city20-17 city20)
          (in-city city20-16 city20)
          (in-city city20-15 city20)
          (in-city city20-14 city20)
          (in-city city20-13 city20)
          (in-city city20-12 city20)
          (in-city city20-11 city20)
          (in-city city20-10 city20)
          (in-city city20-9 city20)
          (in-city city20-8 city20)
          (in-city city20-7 city20)
          (in-city city20-6 city20)
          (in-city city20-5 city20)
          (in-city city20-4 city20)
          (in-city city20-3 city20)
          (in-city city20-2 city20)
          (in-city city20-1 city20)
          (in-city city19-17 city19)
          (in-city city19-16 city19)
          (in-city city19-15 city19)
          (in-city city19-14 city19)
          (in-city city19-13 city19)
          (in-city city19-12 city19)
          (in-city city19-11 city19)
          (in-city city19-10 city19)
          (in-city city19-9 city19)
          (in-city city19-8 city19)
          (in-city city19-7 city19)
          (in-city city19-6 city19)
          (in-city city19-5 city19)
          (in-city city19-4 city19)
          (in-city city19-3 city19)
          (in-city city19-2 city19)
          (in-city city19-1 city19)
          (in-city city18-17 city18)
          (in-city city18-16 city18)
          (in-city city18-15 city18)
          (in-city city18-14 city18)
          (in-city city18-13 city18)
          (in-city city18-12 city18)
          (in-city city18-11 city18)
          (in-city city18-10 city18)
          (in-city city18-9 city18)
          (in-city city18-8 city18)
          (in-city city18-7 city18)
          (in-city city18-6 city18)
          (in-city city18-5 city18)
          (in-city city18-4 city18)
          (in-city city18-3 city18)
          (in-city city18-2 city18)
          (in-city city18-1 city18)
          (in-city city17-17 city17)
          (in-city city17-16 city17)
          (in-city city17-15 city17)
          (in-city city17-14 city17)
          (in-city city17-13 city17)
          (in-city city17-12 city17)
          (in-city city17-11 city17)
          (in-city city17-10 city17)
          (in-city city17-9 city17)
          (in-city city17-8 city17)
          (in-city city17-7 city17)
          (in-city city17-6 city17)
          (in-city city17-5 city17)
          (in-city city17-4 city17)
          (in-city city17-3 city17)
          (in-city city17-2 city17)
          (in-city city17-1 city17)
          (in-city city16-17 city16)
          (in-city city16-16 city16)
          (in-city city16-15 city16)
          (in-city city16-14 city16)
          (in-city city16-13 city16)
          (in-city city16-12 city16)
          (in-city city16-11 city16)
          (in-city city16-10 city16)
          (in-city city16-9 city16)
          (in-city city16-8 city16)
          (in-city city16-7 city16)
          (in-city city16-6 city16)
          (in-city city16-5 city16)
          (in-city city16-4 city16)
          (in-city city16-3 city16)
          (in-city city16-2 city16)
          (in-city city16-1 city16)
          (in-city city15-17 city15)
          (in-city city15-16 city15)
          (in-city city15-15 city15)
          (in-city city15-14 city15)
          (in-city city15-13 city15)
          (in-city city15-12 city15)
          (in-city city15-11 city15)
          (in-city city15-10 city15)
          (in-city city15-9 city15)
          (in-city city15-8 city15)
          (in-city city15-7 city15)
          (in-city city15-6 city15)
          (in-city city15-5 city15)
          (in-city city15-4 city15)
          (in-city city15-3 city15)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-17 city14)
          (in-city city14-16 city14)
          (in-city city14-15 city14)
          (in-city city14-14 city14)
          (in-city city14-13 city14)
          (in-city city14-12 city14)
          (in-city city14-11 city14)
          (in-city city14-10 city14)
          (in-city city14-9 city14)
          (in-city city14-8 city14)
          (in-city city14-7 city14)
          (in-city city14-6 city14)
          (in-city city14-5 city14)
          (in-city city14-4 city14)
          (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-17 city13)
          (in-city city13-16 city13)
          (in-city city13-15 city13)
          (in-city city13-14 city13)
          (in-city city13-13 city13)
          (in-city city13-12 city13)
          (in-city city13-11 city13)
          (in-city city13-10 city13)
          (in-city city13-9 city13)
          (in-city city13-8 city13)
          (in-city city13-7 city13)
          (in-city city13-6 city13)
          (in-city city13-5 city13)
          (in-city city13-4 city13)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-17 city12)
          (in-city city12-16 city12)
          (in-city city12-15 city12)
          (in-city city12-14 city12)
          (in-city city12-13 city12)
          (in-city city12-12 city12)
          (in-city city12-11 city12)
          (in-city city12-10 city12)
          (in-city city12-9 city12)
          (in-city city12-8 city12)
          (in-city city12-7 city12)
          (in-city city12-6 city12)
          (in-city city12-5 city12)
          (in-city city12-4 city12)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-17 city11)
          (in-city city11-16 city11)
          (in-city city11-15 city11)
          (in-city city11-14 city11)
          (in-city city11-13 city11)
          (in-city city11-12 city11)
          (in-city city11-11 city11)
          (in-city city11-10 city11)
          (in-city city11-9 city11)
          (in-city city11-8 city11)
          (in-city city11-7 city11)
          (in-city city11-6 city11)
          (in-city city11-5 city11)
          (in-city city11-4 city11)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-17 city10)
          (in-city city10-16 city10)
          (in-city city10-15 city10)
          (in-city city10-14 city10)
          (in-city city10-13 city10)
          (in-city city10-12 city10)
          (in-city city10-11 city10)
          (in-city city10-10 city10)
          (in-city city10-9 city10)
          (in-city city10-8 city10)
          (in-city city10-7 city10)
          (in-city city10-6 city10)
          (in-city city10-5 city10)
          (in-city city10-4 city10)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-17 city9)
          (in-city city9-16 city9)
          (in-city city9-15 city9)
          (in-city city9-14 city9)
          (in-city city9-13 city9)
          (in-city city9-12 city9)
          (in-city city9-11 city9)
          (in-city city9-10 city9)
          (in-city city9-9 city9)
          (in-city city9-8 city9)
          (in-city city9-7 city9)
          (in-city city9-6 city9)
          (in-city city9-5 city9)
          (in-city city9-4 city9)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-17 city8)
          (in-city city8-16 city8)
          (in-city city8-15 city8)
          (in-city city8-14 city8)
          (in-city city8-13 city8)
          (in-city city8-12 city8)
          (in-city city8-11 city8)
          (in-city city8-10 city8)
          (in-city city8-9 city8)
          (in-city city8-8 city8)
          (in-city city8-7 city8)
          (in-city city8-6 city8)
          (in-city city8-5 city8)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-17 city7)
          (in-city city7-16 city7)
          (in-city city7-15 city7)
          (in-city city7-14 city7)
          (in-city city7-13 city7)
          (in-city city7-12 city7)
          (in-city city7-11 city7)
          (in-city city7-10 city7)
          (in-city city7-9 city7)
          (in-city city7-8 city7)
          (in-city city7-7 city7)
          (in-city city7-6 city7)
          (in-city city7-5 city7)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-17 city6)
          (in-city city6-16 city6)
          (in-city city6-15 city6)
          (in-city city6-14 city6)
          (in-city city6-13 city6)
          (in-city city6-12 city6)
          (in-city city6-11 city6)
          (in-city city6-10 city6)
          (in-city city6-9 city6)
          (in-city city6-8 city6)
          (in-city city6-7 city6)
          (in-city city6-6 city6)
          (in-city city6-5 city6)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-17 city5)
          (in-city city5-16 city5)
          (in-city city5-15 city5)
          (in-city city5-14 city5)
          (in-city city5-13 city5)
          (in-city city5-12 city5)
          (in-city city5-11 city5)
          (in-city city5-10 city5)
          (in-city city5-9 city5)
          (in-city city5-8 city5)
          (in-city city5-7 city5)
          (in-city city5-6 city5)
          (in-city city5-5 city5)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-17 city4)
          (in-city city4-16 city4)
          (in-city city4-15 city4)
          (in-city city4-14 city4)
          (in-city city4-13 city4)
          (in-city city4-12 city4)
          (in-city city4-11 city4)
          (in-city city4-10 city4)
          (in-city city4-9 city4)
          (in-city city4-8 city4)
          (in-city city4-7 city4)
          (in-city city4-6 city4)
          (in-city city4-5 city4)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-17 city3)
          (in-city city3-16 city3)
          (in-city city3-15 city3)
          (in-city city3-14 city3)
          (in-city city3-13 city3)
          (in-city city3-12 city3)
          (in-city city3-11 city3)
          (in-city city3-10 city3)
          (in-city city3-9 city3)
          (in-city city3-8 city3)
          (in-city city3-7 city3)
          (in-city city3-6 city3)
          (in-city city3-5 city3)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-17 city2)
          (in-city city2-16 city2)
          (in-city city2-15 city2)
          (in-city city2-14 city2)
          (in-city city2-13 city2)
          (in-city city2-12 city2)
          (in-city city2-11 city2)
          (in-city city2-10 city2)
          (in-city city2-9 city2)
          (in-city city2-8 city2)
          (in-city city2-7 city2)
          (in-city city2-6 city2)
          (in-city city2-5 city2)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-17 city1)
          (in-city city1-16 city1)
          (in-city city1-15 city1)
          (in-city city1-14 city1)
          (in-city city1-13 city1)
          (in-city city1-12 city1)
          (in-city city1-11 city1)
          (in-city city1-10 city1)
          (in-city city1-9 city1)
          (in-city city1-8 city1)
          (in-city city1-7 city1)
          (in-city city1-6 city1)
          (in-city city1-5 city1)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane5 city19-17)
          (at plane4 city9-17)
          (at plane3 city18-17)
          (at plane2 city18-17)
          (at plane1 city14-17)
          (at truck83 city20-7)
          (at truck82 city19-2)
          (at truck81 city18-5)
          (at truck80 city17-14)
          (at truck79 city16-15)
          (at truck78 city15-7)
          (at truck77 city14-14)
          (at truck76 city13-9)
          (at truck75 city12-8)
          (at truck74 city11-1)
          (at truck73 city10-13)
          (at truck72 city9-4)
          (at truck71 city8-3)
          (at truck70 city7-15)
          (at truck69 city6-2)
          (at truck68 city5-8)
          (at truck67 city4-5)
          (at truck66 city3-15)
          (at truck65 city2-7)
          (at truck64 city1-2)
          (at truck63 city1-16)
          (at truck62 city9-15)
          (at truck61 city19-9)
          (at truck60 city12-8)
          (at truck59 city7-10)
          (at truck58 city15-5)
          (at truck57 city7-13)
          (at truck56 city11-1)
          (at truck55 city2-11)
          (at truck54 city13-7)
          (at truck53 city18-13)
          (at truck52 city16-11)
          (at truck51 city19-10)
          (at truck50 city2-8)
          (at truck49 city19-8)
          (at truck48 city19-9)
          (at truck47 city11-2)
          (at truck46 city14-7)
          (at truck45 city2-17)
          (at truck44 city9-17)
          (at truck43 city2-8)
          (at truck42 city19-12)
          (at truck41 city7-15)
          (at truck40 city2-4)
          (at truck39 city18-1)
          (at truck38 city16-6)
          (at truck37 city7-7)
          (at truck36 city12-6)
          (at truck35 city15-17)
          (at truck34 city2-2)
          (at truck33 city13-16)
          (at truck32 city11-2)
          (at truck31 city3-13)
          (at truck30 city8-5)
          (at truck29 city5-7)
          (at truck28 city5-10)
          (at truck27 city4-8)
          (at truck26 city2-5)
          (at truck25 city10-17)
          (at truck24 city13-16)
          (at truck23 city3-13)
          (at truck22 city5-9)
          (at truck21 city11-11)
          (at truck20 city15-13)
          (at truck19 city8-1)
          (at truck18 city5-17)
          (at truck17 city17-15)
          (at truck16 city3-11)
          (at truck15 city10-16)
          (at truck14 city12-4)
          (at truck13 city15-15)
          (at truck12 city13-7)
          (at truck11 city13-2)
          (at truck10 city19-5)
          (at truck9 city6-10)
          (at truck8 city13-6)
          (at truck7 city15-16)
          (at truck6 city8-14)
          (at truck5 city18-3)
          (at truck4 city13-8)
          (at truck3 city17-17)
          (at truck2 city10-6)
          (at truck1 city13-11)
          (at package42 city16-15)
          (at package41 city19-8)
          (at package40 city3-6)
          (at package39 city7-6)
          (at package38 city16-7)
          (at package37 city10-13)
          (at package36 city13-17)
          (at package35 city18-8)
          (at package34 city15-1)
          (at package33 city6-7)
          (at package32 city12-6)
          (at package31 city16-8)
          (at package30 city16-3)
          (at package29 city11-14)
          (at package28 city8-4)
          (at package27 city11-2)
          (at package26 city12-7)
          (at package25 city13-6)
          (at package24 city16-9)
          (at package23 city11-9)
          (at package22 city16-7)
          (at package21 city5-3)
          (at package20 city3-6)
          (at package19 city3-13)
          (at package18 city1-12)
          (at package17 city8-13)
          (at package16 city9-1)
          (at package15 city15-4)
          (at package14 city3-17)
          (at package13 city15-6)
          (at package12 city3-3)
          (at package11 city13-8)
          (at package10 city2-17)
          (at package9 city12-4)
          (at package8 city3-1)
          (at package7 city13-5)
          (at package6 city5-4)
          (at package5 city14-3)
          (at package4 city5-3)
          (at package3 city15-1)
          (at package2 city2-7)
          (at package1 city4-10))
   (:goal (and (at package42 city13-8)
               (at package41 city3-16)
               (at package40 city8-9)
               (at package39 city3-8)
               (at package38 city12-4)
               (at package37 city19-7)
               (at package36 city19-16)
               (at package35 city17-15)
               (at package34 city8-4)
               (at package33 city9-12)
               (at package32 city2-16)
               (at package31 city4-12)
               (at package30 city17-2)
               (at package29 city11-7)
               (at package28 city10-17)
               (at package27 city15-14)
               (at package26 city12-11)
               (at package25 city8-12)
               (at package24 city18-5)
               (at package23 city16-16)
               (at package22 city4-11)
               (at package21 city11-2)
               (at package20 city9-2)
               (at package19 city17-4)
               (at package18 city10-16)
               (at package17 city1-3)
               (at package16 city20-11)
               (at package15 city11-16)
               (at package14 city2-6)
               (at package13 city10-14))))

(define (problem log-x-29)
   (:domain logistics-adl)
   (:objects package53 package52 package51 package50 package49
             package48 package47 package46 package45 package44 package43
             package42 package41 package40 package39 package38 package37
             package36 package35 package34 package33 package32 package31
             package30 package29 package28 package27 package26 package25
             package24 package23 package22 package21 package20 package19
             package18 package17 package16 package15 package14 package13
             package12 package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 - obj
             city27 city26 city25 city24 city23 city22 city21 city20 city19
             city18 city17 city16 city15 city14 city13 city12 city11 city10
             city9 city8 city7 city6 city5 city4 city3 city2 city1 - city
             truck46 truck45 truck44 truck43 truck42 truck41 truck40
             truck39 truck38 truck37 truck36 truck35 truck34 truck33
             truck32 truck31 truck30 truck29 truck28 truck27 truck26
             truck25 truck24 truck23 truck22 truck21 truck20 truck19
             truck18 truck17 truck16 truck15 truck14 truck13 truck12
             truck11 truck10 truck9 truck8 truck7 truck6 truck5 truck4
             truck3 truck2 truck1 - truck
             plane10 plane9 plane8 plane7 plane6 plane5 plane4 plane3 plane2
             plane1 - airplane
             city27-2 city27-1 city26-2 city26-1 city25-2 city25-1 city24-2
             city24-1 city23-2 city23-1 city22-2 city22-1 city21-2 city21-1
             city20-2 city20-1 city19-2 city19-1 city18-2 city18-1 city17-2
             city17-1 city16-2 city16-1 city15-2 city15-1 city14-2 city14-1
             city13-2 city13-1 city12-2 city12-1 city11-2 city11-1 city10-2
             city10-1 city9-2 city9-1 city8-2 city8-1 city7-2 city7-1
             city6-2 city6-1 city5-2 city5-1 city4-2 city4-1 city3-2
             city3-1 city2-2 city2-1 city1-2 city1-1 - location
             city27-3 city26-3 city25-3 city24-3 city23-3 city22-3 city21-3
             city20-3 city19-3 city18-3 city17-3 city16-3 city15-3 city14-3
             city13-3 city12-3 city11-3 city10-3 city9-3 city8-3 city7-3
             city6-3 city5-3 city4-3 city3-3 city2-3 city1-3 - airport)
   (:init (in-city city27-3 city27)
          (in-city city27-2 city27)
          (in-city city27-1 city27)
          (in-city city26-3 city26)
          (in-city city26-2 city26)
          (in-city city26-1 city26)
          (in-city city25-3 city25)
          (in-city city25-2 city25)
          (in-city city25-1 city25)
          (in-city city24-3 city24)
          (in-city city24-2 city24)
          (in-city city24-1 city24)
          (in-city city23-3 city23)
          (in-city city23-2 city23)
          (in-city city23-1 city23)
          (in-city city22-3 city22)
          (in-city city22-2 city22)
          (in-city city22-1 city22)
          (in-city city21-3 city21)
          (in-city city21-2 city21)
          (in-city city21-1 city21)
          (in-city city20-3 city20)
          (in-city city20-2 city20)
          (in-city city20-1 city20)
          (in-city city19-3 city19)
          (in-city city19-2 city19)
          (in-city city19-1 city19)
          (in-city city18-3 city18)
          (in-city city18-2 city18)
          (in-city city18-1 city18)
          (in-city city17-3 city17)
          (in-city city17-2 city17)
          (in-city city17-1 city17)
          (in-city city16-3 city16)
          (in-city city16-2 city16)
          (in-city city16-1 city16)
          (in-city city15-3 city15)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane10 city9-3)
          (at plane9 city18-3)
          (at plane8 city15-3)
          (at plane7 city6-3)
          (at plane6 city7-3)
          (at plane5 city15-3)
          (at plane4 city13-3)
          (at plane3 city25-3)
          (at plane2 city6-3)
          (at plane1 city4-3)
          (at truck46 city27-2)
          (at truck45 city26-1)
          (at truck44 city25-1)
          (at truck43 city24-1)
          (at truck42 city23-2)
          (at truck41 city22-1)
          (at truck40 city21-1)
          (at truck39 city20-1)
          (at truck38 city19-2)
          (at truck37 city18-2)
          (at truck36 city17-1)
          (at truck35 city16-2)
          (at truck34 city15-1)
          (at truck33 city14-2)
          (at truck32 city13-2)
          (at truck31 city12-1)
          (at truck30 city11-2)
          (at truck29 city10-1)
          (at truck28 city9-1)
          (at truck27 city8-1)
          (at truck26 city7-1)
          (at truck25 city6-1)
          (at truck24 city5-2)
          (at truck23 city4-2)
          (at truck22 city3-2)
          (at truck21 city2-2)
          (at truck20 city1-1)
          (at truck19 city16-3)
          (at truck18 city21-1)
          (at truck17 city1-3)
          (at truck16 city25-3)
          (at truck15 city15-3)
          (at truck14 city25-1)
          (at truck13 city16-2)
          (at truck12 city24-1)
          (at truck11 city7-1)
          (at truck10 city10-3)
          (at truck9 city4-3)
          (at truck8 city25-1)
          (at truck7 city19-3)
          (at truck6 city25-2)
          (at truck5 city4-2)
          (at truck4 city19-2)
          (at truck3 city3-2)
          (at truck2 city27-3)
          (at truck1 city9-1)
          (at package53 city6-3)
          (at package52 city6-3)
          (at package51 city16-2)
          (at package50 city25-1)
          (at package49 city24-1)
          (at package48 city1-2)
          (at package47 city6-2)
          (at package46 city7-3)
          (at package45 city15-1)
          (at package44 city20-2)
          (at package43 city25-3)
          (at package42 city20-2)
          (at package41 city18-1)
          (at package40 city20-2)
          (at package39 city6-1)
          (at package38 city27-3)
          (at package37 city8-2)
          (at package36 city14-3)
          (at package35 city20-2)
          (at package34 city25-1)
          (at package33 city23-3)
          (at package32 city4-1)
          (at package31 city27-1)
          (at package30 city17-3)
          (at package29 city13-2)
          (at package28 city25-3)
          (at package27 city19-1)
          (at package26 city26-3)
          (at package25 city8-2)
          (at package24 city3-1)
          (at package23 city10-2)
          (at package22 city11-2)
          (at package21 city8-2)
          (at package20 city4-2)
          (at package19 city22-2)
          (at package18 city23-1)
          (at package17 city24-1)
          (at package16 city14-1)
          (at package15 city6-2)
          (at package14 city11-1)
          (at package13 city16-1)
          (at package12 city5-3)
          (at package11 city9-2)
          (at package10 city21-2)
          (at package9 city18-2)
          (at package8 city9-1)
          (at package7 city27-1)
          (at package6 city12-3)
          (at package5 city23-1)
          (at package4 city21-3)
          (at package3 city18-3)
          (at package2 city6-3)
          (at package1 city25-1))
   (:goal (and (at package53 city16-2)
               (at package52 city6-3)
               (at package51 city12-2)
               (at package50 city9-2)
               (at package49 city9-3)
               (at package48 city20-1)
               (at package47 city17-2)
               (at package46 city22-3)
               (at package45 city8-3)
               (at package44 city8-1)
               (at package43 city19-3)
               (at package42 city7-1)
               (at package41 city26-3)
               (at package40 city2-2)
               (at package39 city12-1)
               (at package38 city11-2)
               (at package37 city1-3)
               (at package36 city22-3)
               (at package35 city14-2)
               (at package34 city1-3)
               (at package33 city3-3)
               (at package32 city9-3)
               (at package31 city1-2)
               (at package30 city1-2)
               (at package29 city14-1)
               (at package28 city23-3)
               (at package27 city23-3)
               (at package26 city22-1)
               (at package25 city23-2)
               (at package24 city7-3)
               (at package23 city23-3)
               (at package22 city12-1)
               (at package21 city12-2)
               (at package20 city10-3)
               (at package19 city18-1)
               (at package18 city24-2)
               (at package17 city16-3)
               (at package16 city18-3)
               (at package15 city8-2)
               (at package14 city18-3)
               (at package13 city7-1)
               (at package12 city22-1)
               (at package11 city1-1)
               (at package10 city6-3)
               (at package9 city9-1))))

(define (problem log-x-30)
   (:domain logistics-adl)
   (:objects package15 package14 package13 package12 package11
             package10 package9 package8 package7 package6 package5 package4
             package3 package2 package1 - obj
             city22 city21 city20 city19 city18 city17 city16 city15 city14
             city13 city12 city11 city10 city9 city8 city7 city6 city5 city4
             city3 city2 city1 - city
             truck80 truck79 truck78 truck77 truck76 truck75 truck74
             truck73 truck72 truck71 truck70 truck69 truck68 truck67
             truck66 truck65 truck64 truck63 truck62 truck61 truck60
             truck59 truck58 truck57 truck56 truck55 truck54 truck53
             truck52 truck51 truck50 truck49 truck48 truck47 truck46
             truck45 truck44 truck43 truck42 truck41 truck40 truck39
             truck38 truck37 truck36 truck35 truck34 truck33 truck32
             truck31 truck30 truck29 truck28 truck27 truck26 truck25
             truck24 truck23 truck22 truck21 truck20 truck19 truck18
             truck17 truck16 truck15 truck14 truck13 truck12 truck11
             truck10 truck9 truck8 truck7 truck6 truck5 truck4 truck3 truck2
             truck1 - truck
             plane3 plane2 plane1 - airplane
             city22-11 city22-10 city22-9 city22-8 city22-7 city22-6
             city22-5 city22-4 city22-3 city22-2 city22-1 city21-11
             city21-10 city21-9 city21-8 city21-7 city21-6 city21-5 city21-4
             city21-3 city21-2 city21-1 city20-11 city20-10 city20-9
             city20-8 city20-7 city20-6 city20-5 city20-4 city20-3 city20-2
             city20-1 city19-11 city19-10 city19-9 city19-8 city19-7
             city19-6 city19-5 city19-4 city19-3 city19-2 city19-1
             city18-11 city18-10 city18-9 city18-8 city18-7 city18-6
             city18-5 city18-4 city18-3 city18-2 city18-1 city17-11
             city17-10 city17-9 city17-8 city17-7 city17-6 city17-5 city17-4
             city17-3 city17-2 city17-1 city16-11 city16-10 city16-9
             city16-8 city16-7 city16-6 city16-5 city16-4 city16-3 city16-2
             city16-1 city15-11 city15-10 city15-9 city15-8 city15-7
             city15-6 city15-5 city15-4 city15-3 city15-2 city15-1
             city14-11 city14-10 city14-9 city14-8 city14-7 city14-6
             city14-5 city14-4 city14-3 city14-2 city14-1 city13-11
             city13-10 city13-9 city13-8 city13-7 city13-6 city13-5 city13-4
             city13-3 city13-2 city13-1 city12-11 city12-10 city12-9
             city12-8 city12-7 city12-6 city12-5 city12-4 city12-3 city12-2
             city12-1 city11-11 city11-10 city11-9 city11-8 city11-7
             city11-6 city11-5 city11-4 city11-3 city11-2 city11-1
             city10-11 city10-10 city10-9 city10-8 city10-7 city10-6
             city10-5 city10-4 city10-3 city10-2 city10-1 city9-11 city9-10
             city9-9 city9-8 city9-7 city9-6 city9-5 city9-4 city9-3
             city9-2 city9-1 city8-11 city8-10 city8-9 city8-8 city8-7
             city8-6 city8-5 city8-4 city8-3 city8-2 city8-1 city7-11
             city7-10 city7-9 city7-8 city7-7 city7-6 city7-5 city7-4
             city7-3 city7-2 city7-1 city6-11 city6-10 city6-9 city6-8
             city6-7 city6-6 city6-5 city6-4 city6-3 city6-2 city6-1
             city5-11 city5-10 city5-9 city5-8 city5-7 city5-6 city5-5
             city5-4 city5-3 city5-2 city5-1 city4-11 city4-10 city4-9
             city4-8 city4-7 city4-6 city4-5 city4-4 city4-3 city4-2
             city4-1 city3-11 city3-10 city3-9 city3-8 city3-7 city3-6
             city3-5 city3-4 city3-3 city3-2 city3-1 city2-11 city2-10
             city2-9 city2-8 city2-7 city2-6 city2-5 city2-4 city2-3
             city2-2 city2-1 city1-11 city1-10 city1-9 city1-8 city1-7
             city1-6 city1-5 city1-4 city1-3 city1-2 city1-1 - location
             city22-12 city21-12 city20-12 city19-12 city18-12 city17-12
             city16-12 city15-12 city14-12 city13-12 city12-12 city11-12
             city10-12 city9-12 city8-12 city7-12 city6-12 city5-12 city4-12
             city3-12 city2-12 city1-12 - airport)
   (:init (in-city city22-12 city22)
          (in-city city22-11 city22)
          (in-city city22-10 city22)
          (in-city city22-9 city22)
          (in-city city22-8 city22)
          (in-city city22-7 city22)
          (in-city city22-6 city22)
          (in-city city22-5 city22)
          (in-city city22-4 city22)
          (in-city city22-3 city22)
          (in-city city22-2 city22)
          (in-city city22-1 city22)
          (in-city city21-12 city21)
          (in-city city21-11 city21)
          (in-city city21-10 city21)
          (in-city city21-9 city21)
          (in-city city21-8 city21)
          (in-city city21-7 city21)
          (in-city city21-6 city21)
          (in-city city21-5 city21)
          (in-city city21-4 city21)
          (in-city city21-3 city21)
          (in-city city21-2 city21)
          (in-city city21-1 city21)
          (in-city city20-12 city20)
          (in-city city20-11 city20)
          (in-city city20-10 city20)
          (in-city city20-9 city20)
          (in-city city20-8 city20)
          (in-city city20-7 city20)
          (in-city city20-6 city20)
          (in-city city20-5 city20)
          (in-city city20-4 city20)
          (in-city city20-3 city20)
          (in-city city20-2 city20)
          (in-city city20-1 city20)
          (in-city city19-12 city19)
          (in-city city19-11 city19)
          (in-city city19-10 city19)
          (in-city city19-9 city19)
          (in-city city19-8 city19)
          (in-city city19-7 city19)
          (in-city city19-6 city19)
          (in-city city19-5 city19)
          (in-city city19-4 city19)
          (in-city city19-3 city19)
          (in-city city19-2 city19)
          (in-city city19-1 city19)
          (in-city city18-12 city18)
          (in-city city18-11 city18)
          (in-city city18-10 city18)
          (in-city city18-9 city18)
          (in-city city18-8 city18)
          (in-city city18-7 city18)
          (in-city city18-6 city18)
          (in-city city18-5 city18)
          (in-city city18-4 city18)
          (in-city city18-3 city18)
          (in-city city18-2 city18)
          (in-city city18-1 city18)
          (in-city city17-12 city17)
          (in-city city17-11 city17)
          (in-city city17-10 city17)
          (in-city city17-9 city17)
          (in-city city17-8 city17)
          (in-city city17-7 city17)
          (in-city city17-6 city17)
          (in-city city17-5 city17)
          (in-city city17-4 city17)
          (in-city city17-3 city17)
          (in-city city17-2 city17)
          (in-city city17-1 city17)
          (in-city city16-12 city16)
          (in-city city16-11 city16)
          (in-city city16-10 city16)
          (in-city city16-9 city16)
          (in-city city16-8 city16)
          (in-city city16-7 city16)
          (in-city city16-6 city16)
          (in-city city16-5 city16)
          (in-city city16-4 city16)
          (in-city city16-3 city16)
          (in-city city16-2 city16)
          (in-city city16-1 city16)
          (in-city city15-12 city15)
          (in-city city15-11 city15)
          (in-city city15-10 city15)
          (in-city city15-9 city15)
          (in-city city15-8 city15)
          (in-city city15-7 city15)
          (in-city city15-6 city15)
          (in-city city15-5 city15)
          (in-city city15-4 city15)
          (in-city city15-3 city15)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-12 city14)
          (in-city city14-11 city14)
          (in-city city14-10 city14)
          (in-city city14-9 city14)
          (in-city city14-8 city14)
          (in-city city14-7 city14)
          (in-city city14-6 city14)
          (in-city city14-5 city14)
          (in-city city14-4 city14)
          (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-12 city13)
          (in-city city13-11 city13)
          (in-city city13-10 city13)
          (in-city city13-9 city13)
          (in-city city13-8 city13)
          (in-city city13-7 city13)
          (in-city city13-6 city13)
          (in-city city13-5 city13)
          (in-city city13-4 city13)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-12 city12)
          (in-city city12-11 city12)
          (in-city city12-10 city12)
          (in-city city12-9 city12)
          (in-city city12-8 city12)
          (in-city city12-7 city12)
          (in-city city12-6 city12)
          (in-city city12-5 city12)
          (in-city city12-4 city12)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-12 city11)
          (in-city city11-11 city11)
          (in-city city11-10 city11)
          (in-city city11-9 city11)
          (in-city city11-8 city11)
          (in-city city11-7 city11)
          (in-city city11-6 city11)
          (in-city city11-5 city11)
          (in-city city11-4 city11)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-12 city10)
          (in-city city10-11 city10)
          (in-city city10-10 city10)
          (in-city city10-9 city10)
          (in-city city10-8 city10)
          (in-city city10-7 city10)
          (in-city city10-6 city10)
          (in-city city10-5 city10)
          (in-city city10-4 city10)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-12 city9)
          (in-city city9-11 city9)
          (in-city city9-10 city9)
          (in-city city9-9 city9)
          (in-city city9-8 city9)
          (in-city city9-7 city9)
          (in-city city9-6 city9)
          (in-city city9-5 city9)
          (in-city city9-4 city9)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-12 city8)
          (in-city city8-11 city8)
          (in-city city8-10 city8)
          (in-city city8-9 city8)
          (in-city city8-8 city8)
          (in-city city8-7 city8)
          (in-city city8-6 city8)
          (in-city city8-5 city8)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-12 city7)
          (in-city city7-11 city7)
          (in-city city7-10 city7)
          (in-city city7-9 city7)
          (in-city city7-8 city7)
          (in-city city7-7 city7)
          (in-city city7-6 city7)
          (in-city city7-5 city7)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-12 city6)
          (in-city city6-11 city6)
          (in-city city6-10 city6)
          (in-city city6-9 city6)
          (in-city city6-8 city6)
          (in-city city6-7 city6)
          (in-city city6-6 city6)
          (in-city city6-5 city6)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-12 city5)
          (in-city city5-11 city5)
          (in-city city5-10 city5)
          (in-city city5-9 city5)
          (in-city city5-8 city5)
          (in-city city5-7 city5)
          (in-city city5-6 city5)
          (in-city city5-5 city5)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-12 city4)
          (in-city city4-11 city4)
          (in-city city4-10 city4)
          (in-city city4-9 city4)
          (in-city city4-8 city4)
          (in-city city4-7 city4)
          (in-city city4-6 city4)
          (in-city city4-5 city4)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-12 city3)
          (in-city city3-11 city3)
          (in-city city3-10 city3)
          (in-city city3-9 city3)
          (in-city city3-8 city3)
          (in-city city3-7 city3)
          (in-city city3-6 city3)
          (in-city city3-5 city3)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-12 city2)
          (in-city city2-11 city2)
          (in-city city2-10 city2)
          (in-city city2-9 city2)
          (in-city city2-8 city2)
          (in-city city2-7 city2)
          (in-city city2-6 city2)
          (in-city city2-5 city2)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-12 city1)
          (in-city city1-11 city1)
          (in-city city1-10 city1)
          (in-city city1-9 city1)
          (in-city city1-8 city1)
          (in-city city1-7 city1)
          (in-city city1-6 city1)
          (in-city city1-5 city1)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane3 city20-12)
          (at plane2 city8-12)
          (at plane1 city14-12)
          (at truck80 city22-1)
          (at truck79 city21-7)
          (at truck78 city20-4)
          (at truck77 city19-7)
          (at truck76 city18-4)
          (at truck75 city17-5)
          (at truck74 city16-2)
          (at truck73 city15-9)
          (at truck72 city14-4)
          (at truck71 city13-9)
          (at truck70 city12-5)
          (at truck69 city11-1)
          (at truck68 city10-9)
          (at truck67 city9-8)
          (at truck66 city8-8)
          (at truck65 city7-1)
          (at truck64 city6-2)
          (at truck63 city5-4)
          (at truck62 city4-1)
          (at truck61 city3-7)
          (at truck60 city2-7)
          (at truck59 city1-10)
          (at truck58 city1-5)
          (at truck57 city20-9)
          (at truck56 city5-10)
          (at truck55 city19-5)
          (at truck54 city5-2)
          (at truck53 city11-8)
          (at truck52 city21-9)
          (at truck51 city3-4)
          (at truck50 city11-1)
          (at truck49 city9-6)
          (at truck48 city17-11)
          (at truck47 city6-6)
          (at truck46 city3-7)
          (at truck45 city14-6)
          (at truck44 city8-3)
          (at truck43 city5-2)
          (at truck42 city2-8)
          (at truck41 city15-11)
          (at truck40 city14-5)
          (at truck39 city7-2)
          (at truck38 city10-8)
          (at truck37 city21-6)
          (at truck36 city11-2)
          (at truck35 city21-6)
          (at truck34 city15-12)
          (at truck33 city7-12)
          (at truck32 city8-3)
          (at truck31 city22-9)
          (at truck30 city16-7)
          (at truck29 city8-6)
          (at truck28 city15-7)
          (at truck27 city12-12)
          (at truck26 city14-10)
          (at truck25 city8-7)
          (at truck24 city10-7)
          (at truck23 city10-10)
          (at truck22 city11-3)
          (at truck21 city9-5)
          (at truck20 city6-3)
          (at truck19 city4-4)
          (at truck18 city5-6)
          (at truck17 city5-10)
          (at truck16 city7-3)
          (at truck15 city21-7)
          (at truck14 city16-9)
          (at truck13 city1-10)
          (at truck12 city2-10)
          (at truck11 city4-9)
          (at truck10 city7-11)
          (at truck9 city8-9)
          (at truck8 city12-7)
          (at truck7 city19-5)
          (at truck6 city3-12)
          (at truck5 city13-2)
          (at truck4 city6-12)
          (at truck3 city2-6)
          (at truck2 city11-3)
          (at truck1 city14-1)
          (at package15 city5-7)
          (at package14 city15-7)
          (at package13 city11-12)
          (at package12 city8-3)
          (at package11 city10-7)
          (at package10 city14-11)
          (at package9 city16-1)
          (at package8 city21-12)
          (at package7 city13-4)
          (at package6 city2-3)
          (at package5 city6-10)
          (at package4 city11-2)
          (at package3 city7-7)
          (at package2 city8-6)
          (at package1 city6-12))
   (:goal (and (at package15 city14-12)
               (at package14 city20-9)
               (at package13 city5-8)
               (at package12 city20-4)
               (at package11 city1-4)
               (at package10 city20-7)
               (at package9 city2-5)
               (at package8 city11-10)
               (at package7 city4-12)
               (at package6 city3-11)
               (at package5 city9-3)
               (at package4 city9-6)
               (at package3 city5-12)
               (at package2 city11-8)
               (at package1 city5-5))))

(define (problem strips-log-x-1)
   (:domain logistics-strips)
   (:objects package6 package5 package4 package3 package2 package1
             city6 city5 city4 city3 city2 city1 truck6 truck5 truck4
             truck3 truck2 truck1 plane2 plane1 city6-1 city5-1 city4-1
             city3-1 city2-1 city1-1 city6-2 city5-2 city4-2 city3-2
             city2-2 city1-2)
   (:init (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane2)
          (airplane plane1)
          (location city6-1)
          (location city5-1)
          (location city4-1)
          (location city3-1)
          (location city2-1)
          (location city1-1)
          (airport city6-2)
          (location city6-2)
          (airport city5-2)
          (location city5-2)
          (airport city4-2)
          (location city4-2)
          (airport city3-2)
          (location city3-2)
          (airport city2-2)
          (location city2-2)
          (airport city1-2)
          (location city1-2)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane2 city4-2)
          (at plane1 city4-2)
          (at truck6 city6-1)
          (at truck5 city5-1)
          (at truck4 city4-1)
          (at truck3 city3-1)
          (at truck2 city2-1)
          (at truck1 city1-1)
          (at package6 city3-1)
          (at package5 city4-2)
          (at package4 city1-1)
          (at package3 city1-1)
          (at package2 city1-2)
          (at package1 city2-1))
   (:goal (and (at package6 city1-2)
               (at package5 city6-2)
               (at package4 city3-2)
               (at package3 city6-1)
               (at package2 city6-2)
               (at package1 city2-1))))

(define (problem strips-log-x-2)
   (:domain logistics-strips)
   (:objects package5 package4 package3 package2 package1 city10
             city9 city8 city7 city6 city5 city4 city3 city2 city1 truck10
             truck9 truck8 truck7 truck6 truck5 truck4 truck3 truck2 truck1
             plane4 plane3 plane2 plane1 city10-1 city9-1 city8-1 city7-1
             city6-1 city5-1 city4-1 city3-1 city2-1 city1-1 city10-2
             city9-2 city8-2 city7-2 city6-2 city5-2 city4-2 city3-2
             city2-2 city1-2)
   (:init (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city10-1)
          (location city9-1)
          (location city8-1)
          (location city7-1)
          (location city6-1)
          (location city5-1)
          (location city4-1)
          (location city3-1)
          (location city2-1)
          (location city1-1)
          (airport city10-2)
          (location city10-2)
          (airport city9-2)
          (location city9-2)
          (airport city8-2)
          (location city8-2)
          (airport city7-2)
          (location city7-2)
          (airport city6-2)
          (location city6-2)
          (airport city5-2)
          (location city5-2)
          (airport city4-2)
          (location city4-2)
          (airport city3-2)
          (location city3-2)
          (airport city2-2)
          (location city2-2)
          (airport city1-2)
          (location city1-2)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane4 city3-2)
          (at plane3 city7-2)
          (at plane2 city3-2)
          (at plane1 city6-2)
          (at truck10 city10-1)
          (at truck9 city9-1)
          (at truck8 city8-1)
          (at truck7 city7-1)
          (at truck6 city6-1)
          (at truck5 city5-1)
          (at truck4 city4-1)
          (at truck3 city3-1)
          (at truck2 city2-1)
          (at truck1 city1-1)
          (at package5 city1-2)
          (at package4 city7-2)
          (at package3 city3-2)
          (at package2 city10-1)
          (at package1 city2-2))
   (:goal (and (at package5 city4-2)
               (at package4 city6-1)
               (at package3 city1-1)
               (at package2 city9-2)
               (at package1 city3-1))))

(define (problem strips-log-x-3)
   (:domain logistics-strips)
   (:objects package9 package8 package7 package6 package5 package4
             package3 package2 package1 city14 city13 city12 city11 city10
             city9 city8 city7 city6 city5 city4 city3 city2 city1 truck14
             truck13 truck12 truck11 truck10 truck9 truck8 truck7 truck6
             truck5 truck4 truck3 truck2 truck1 plane4 plane3 plane2 plane1
             city14-2 city14-1 city13-2 city13-1 city12-2 city12-1 city11-2
             city11-1 city10-2 city10-1 city9-2 city9-1 city8-2 city8-1
             city7-2 city7-1 city6-2 city6-1 city5-2 city5-1 city4-2
             city4-1 city3-2 city3-1 city2-2 city2-1 city1-2 city1-1
             city14-3 city13-3 city12-3 city11-3 city10-3 city9-3 city8-3
             city7-3 city6-3 city5-3 city4-3 city3-3 city2-3 city1-3)
   (:init (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city14-2)
          (location city14-1)
          (location city13-2)
          (location city13-1)
          (location city12-2)
          (location city12-1)
          (location city11-2)
          (location city11-1)
          (location city10-2)
          (location city10-1)
          (location city9-2)
          (location city9-1)
          (location city8-2)
          (location city8-1)
          (location city7-2)
          (location city7-1)
          (location city6-2)
          (location city6-1)
          (location city5-2)
          (location city5-1)
          (location city4-2)
          (location city4-1)
          (location city3-2)
          (location city3-1)
          (location city2-2)
          (location city2-1)
          (location city1-2)
          (location city1-1)
          (airport city14-3)
          (location city14-3)
          (airport city13-3)
          (location city13-3)
          (airport city12-3)
          (location city12-3)
          (airport city11-3)
          (location city11-3)
          (airport city10-3)
          (location city10-3)
          (airport city9-3)
          (location city9-3)
          (airport city8-3)
          (location city8-3)
          (airport city7-3)
          (location city7-3)
          (airport city6-3)
          (location city6-3)
          (airport city5-3)
          (location city5-3)
          (airport city4-3)
          (location city4-3)
          (airport city3-3)
          (location city3-3)
          (airport city2-3)
          (location city2-3)
          (airport city1-3)
          (location city1-3)
          (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane4 city10-3)
          (at plane3 city1-3)
          (at plane2 city11-3)
          (at plane1 city11-3)
          (at truck14 city14-1)
          (at truck13 city13-1)
          (at truck12 city12-1)
          (at truck11 city11-1)
          (at truck10 city10-1)
          (at truck9 city9-2)
          (at truck8 city8-2)
          (at truck7 city7-1)
          (at truck6 city6-2)
          (at truck5 city5-1)
          (at truck4 city4-2)
          (at truck3 city3-2)
          (at truck2 city2-1)
          (at truck1 city1-1)
          (at package9 city4-2)
          (at package8 city9-1)
          (at package7 city1-2)
          (at package6 city9-1)
          (at package5 city12-2)
          (at package4 city8-1)
          (at package3 city12-3)
          (at package2 city12-2)
          (at package1 city8-3))
   (:goal (and (at package9 city11-2)
               (at package8 city5-3)
               (at package7 city10-3)
               (at package6 city9-3)
               (at package5 city10-1)
               (at package4 city13-1)
               (at package3 city1-3))))

(define (problem strips-log-x-4)
   (:domain logistics-strips)
   (:objects package7 package6 package5 package4 package3 package2
             package1 city13 city12 city11 city10 city9 city8 city7 city6
             city5 city4 city3 city2 city1 truck23 truck22 truck21 truck20
             truck19 truck18 truck17 truck16 truck15 truck14 truck13
             truck12 truck11 truck10 truck9 truck8 truck7 truck6 truck5
             truck4 truck3 truck2 truck1 plane5 plane4 plane3 plane2 plane1
             city13-3 city13-2 city13-1 city12-3 city12-2 city12-1 city11-3
             city11-2 city11-1 city10-3 city10-2 city10-1 city9-3 city9-2
             city9-1 city8-3 city8-2 city8-1 city7-3 city7-2 city7-1
             city6-3 city6-2 city6-1 city5-3 city5-2 city5-1 city4-3
             city4-2 city4-1 city3-3 city3-2 city3-1 city2-3 city2-2
             city2-1 city1-3 city1-2 city1-1 city13-4 city12-4 city11-4
             city10-4 city9-4 city8-4 city7-4 city6-4 city5-4 city4-4
             city3-4 city2-4 city1-4)
   (:init (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city13-3)
          (location city13-2)
          (location city13-1)
          (location city12-3)
          (location city12-2)
          (location city12-1)
          (location city11-3)
          (location city11-2)
          (location city11-1)
          (location city10-3)
          (location city10-2)
          (location city10-1)
          (location city9-3)
          (location city9-2)
          (location city9-1)
          (location city8-3)
          (location city8-2)
          (location city8-1)
          (location city7-3)
          (location city7-2)
          (location city7-1)
          (location city6-3)
          (location city6-2)
          (location city6-1)
          (location city5-3)
          (location city5-2)
          (location city5-1)
          (location city4-3)
          (location city4-2)
          (location city4-1)
          (location city3-3)
          (location city3-2)
          (location city3-1)
          (location city2-3)
          (location city2-2)
          (location city2-1)
          (location city1-3)
          (location city1-2)
          (location city1-1)
          (airport city13-4)
          (location city13-4)
          (airport city12-4)
          (location city12-4)
          (airport city11-4)
          (location city11-4)
          (airport city10-4)
          (location city10-4)
          (airport city9-4)
          (location city9-4)
          (airport city8-4)
          (location city8-4)
          (airport city7-4)
          (location city7-4)
          (airport city6-4)
          (location city6-4)
          (airport city5-4)
          (location city5-4)
          (airport city4-4)
          (location city4-4)
          (airport city3-4)
          (location city3-4)
          (airport city2-4)
          (location city2-4)
          (airport city1-4)
          (location city1-4)
          (in-city city13-4 city13)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-4 city12)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-4 city11)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-4 city10)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-4 city9)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane5 city12-4)
          (at plane4 city8-4)
          (at plane3 city6-4)
          (at plane2 city13-4)
          (at plane1 city2-4)
          (at truck23 city13-2)
          (at truck22 city12-3)
          (at truck21 city11-3)
          (at truck20 city10-1)
          (at truck19 city9-1)
          (at truck18 city8-2)
          (at truck17 city7-3)
          (at truck16 city6-3)
          (at truck15 city5-2)
          (at truck14 city4-1)
          (at truck13 city3-3)
          (at truck12 city2-1)
          (at truck11 city1-1)
          (at truck10 city10-3)
          (at truck9 city8-1)
          (at truck8 city2-2)
          (at truck7 city9-4)
          (at truck6 city9-2)
          (at truck5 city8-2)
          (at truck4 city7-3)
          (at truck3 city7-1)
          (at truck2 city8-1)
          (at truck1 city5-4)
          (at package7 city1-4)
          (at package6 city2-3)
          (at package5 city10-1)
          (at package4 city5-4)
          (at package3 city11-1)
          (at package2 city11-3)
          (at package1 city4-2))
   (:goal (and (at package7 city12-3)
               (at package6 city9-3)
               (at package5 city12-3)
               (at package4 city8-4)
               (at package3 city13-4)
               (at package2 city7-1)
               (at package1 city13-1))))

(define (problem strips-log-x-5)
   (:domain logistics-strips)
   (:objects package4 package3 package2 package1 city9 city8 city7
             city6 city5 city4 city3 city2 city1 truck11 truck10 truck9
             truck8 truck7 truck6 truck5 truck4 truck3 truck2 truck1 plane1
             city9-1 city8-1 city7-1 city6-1 city5-1 city4-1 city3-1
             city2-1 city1-1 city9-2 city8-2 city7-2 city6-2 city5-2
             city4-2 city3-2 city2-2 city1-2)
   (:init (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane1)
          (location city9-1)
          (location city8-1)
          (location city7-1)
          (location city6-1)
          (location city5-1)
          (location city4-1)
          (location city3-1)
          (location city2-1)
          (location city1-1)
          (airport city9-2)
          (location city9-2)
          (airport city8-2)
          (location city8-2)
          (airport city7-2)
          (location city7-2)
          (airport city6-2)
          (location city6-2)
          (airport city5-2)
          (location city5-2)
          (airport city4-2)
          (location city4-2)
          (airport city3-2)
          (location city3-2)
          (airport city2-2)
          (location city2-2)
          (airport city1-2)
          (location city1-2)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane1 city8-2)
          (at truck11 city9-1)
          (at truck10 city8-1)
          (at truck9 city7-1)
          (at truck8 city6-1)
          (at truck7 city5-1)
          (at truck6 city4-1)
          (at truck5 city3-1)
          (at truck4 city2-1)
          (at truck3 city1-1)
          (at truck2 city8-1)
          (at truck1 city3-2)
          (at package4 city8-1)
          (at package3 city9-1)
          (at package2 city8-2)
          (at package1 city6-2))
   (:goal (and (at package4 city2-2)
               (at package3 city7-2)
               (at package2 city3-1)
               (at package1 city9-2))))

(define (problem strips-log-x-6)
   (:domain logistics-strips)
   (:objects package16 package15 package14 package13 package12
             package11 package10 package9 package8 package7 package6
             package5 package4 package3 package2 package1 city18 city17
             city16 city15 city14 city13 city12 city11 city10 city9 city8
             city7 city6 city5 city4 city3 city2 city1 truck26 truck25
             truck24 truck23 truck22 truck21 truck20 truck19 truck18
             truck17 truck16 truck15 truck14 truck13 truck12 truck11
             truck10 truck9 truck8 truck7 truck6 truck5 truck4 truck3 truck2
             truck1 plane2 plane1 city18-3 city18-2 city18-1 city17-3
             city17-2 city17-1 city16-3 city16-2 city16-1 city15-3 city15-2
             city15-1 city14-3 city14-2 city14-1 city13-3 city13-2 city13-1
             city12-3 city12-2 city12-1 city11-3 city11-2 city11-1 city10-3
             city10-2 city10-1 city9-3 city9-2 city9-1 city8-3 city8-2
             city8-1 city7-3 city7-2 city7-1 city6-3 city6-2 city6-1
             city5-3 city5-2 city5-1 city4-3 city4-2 city4-1 city3-3
             city3-2 city3-1 city2-3 city2-2 city2-1 city1-3 city1-2
             city1-1 city18-4 city17-4 city16-4 city15-4 city14-4 city13-4
             city12-4 city11-4 city10-4 city9-4 city8-4 city7-4 city6-4
             city5-4 city4-4 city3-4 city2-4 city1-4)
   (:init (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city18)
          (city city17)
          (city city16)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane2)
          (airplane plane1)
          (location city18-3)
          (location city18-2)
          (location city18-1)
          (location city17-3)
          (location city17-2)
          (location city17-1)
          (location city16-3)
          (location city16-2)
          (location city16-1)
          (location city15-3)
          (location city15-2)
          (location city15-1)
          (location city14-3)
          (location city14-2)
          (location city14-1)
          (location city13-3)
          (location city13-2)
          (location city13-1)
          (location city12-3)
          (location city12-2)
          (location city12-1)
          (location city11-3)
          (location city11-2)
          (location city11-1)
          (location city10-3)
          (location city10-2)
          (location city10-1)
          (location city9-3)
          (location city9-2)
          (location city9-1)
          (location city8-3)
          (location city8-2)
          (location city8-1)
          (location city7-3)
          (location city7-2)
          (location city7-1)
          (location city6-3)
          (location city6-2)
          (location city6-1)
          (location city5-3)
          (location city5-2)
          (location city5-1)
          (location city4-3)
          (location city4-2)
          (location city4-1)
          (location city3-3)
          (location city3-2)
          (location city3-1)
          (location city2-3)
          (location city2-2)
          (location city2-1)
          (location city1-3)
          (location city1-2)
          (location city1-1)
          (airport city18-4)
          (location city18-4)
          (airport city17-4)
          (location city17-4)
          (airport city16-4)
          (location city16-4)
          (airport city15-4)
          (location city15-4)
          (airport city14-4)
          (location city14-4)
          (airport city13-4)
          (location city13-4)
          (airport city12-4)
          (location city12-4)
          (airport city11-4)
          (location city11-4)
          (airport city10-4)
          (location city10-4)
          (airport city9-4)
          (location city9-4)
          (airport city8-4)
          (location city8-4)
          (airport city7-4)
          (location city7-4)
          (airport city6-4)
          (location city6-4)
          (airport city5-4)
          (location city5-4)
          (airport city4-4)
          (location city4-4)
          (airport city3-4)
          (location city3-4)
          (airport city2-4)
          (location city2-4)
          (airport city1-4)
          (location city1-4)
          (in-city city18-4 city18)
          (in-city city18-3 city18)
          (in-city city18-2 city18)
          (in-city city18-1 city18)
          (in-city city17-4 city17)
          (in-city city17-3 city17)
          (in-city city17-2 city17)
          (in-city city17-1 city17)
          (in-city city16-4 city16)
          (in-city city16-3 city16)
          (in-city city16-2 city16)
          (in-city city16-1 city16)
          (in-city city15-4 city15)
          (in-city city15-3 city15)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-4 city14)
          (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-4 city13)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-4 city12)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-4 city11)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-4 city10)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-4 city9)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane2 city10-4)
          (at plane1 city18-4)
          (at truck26 city18-2)
          (at truck25 city17-1)
          (at truck24 city16-1)
          (at truck23 city15-2)
          (at truck22 city14-2)
          (at truck21 city13-1)
          (at truck20 city12-3)
          (at truck19 city11-1)
          (at truck18 city10-1)
          (at truck17 city9-1)
          (at truck16 city8-2)
          (at truck15 city7-1)
          (at truck14 city6-1)
          (at truck13 city5-1)
          (at truck12 city4-2)
          (at truck11 city3-2)
          (at truck10 city2-2)
          (at truck9 city1-2)
          (at truck8 city14-1)
          (at truck7 city3-4)
          (at truck6 city1-1)
          (at truck5 city14-1)
          (at truck4 city8-1)
          (at truck3 city10-3)
          (at truck2 city4-3)
          (at truck1 city14-3)
          (at package16 city16-2)
          (at package15 city14-3)
          (at package14 city14-1)
          (at package13 city14-4)
          (at package12 city6-1)
          (at package11 city3-1)
          (at package10 city9-4)
          (at package9 city17-3)
          (at package8 city15-2)
          (at package7 city8-4)
          (at package6 city6-1)
          (at package5 city10-3)
          (at package4 city15-2)
          (at package3 city16-3)
          (at package2 city11-2)
          (at package1 city7-3))
   (:goal (and (at package16 city14-3)
               (at package15 city14-2)
               (at package14 city8-4)
               (at package13 city4-3)
               (at package12 city13-4)
               (at package11 city12-2)
               (at package10 city16-2)
               (at package9 city17-4)
               (at package8 city8-1)
               (at package7 city8-2))))

(define (problem strips-log-x-7)
   (:domain logistics-strips)
   (:objects package10 package9 package8 package7 package6
             package5 package4 package3 package2 package1 city11 city10
             city9 city8 city7 city6 city5 city4 city3 city2 city1 truck11
             truck10 truck9 truck8 truck7 truck6 truck5 truck4 truck3 truck2
             truck1 plane6 plane5 plane4 plane3 plane2 plane1 city11-1
             city10-1 city9-1 city8-1 city7-1 city6-1 city5-1 city4-1
             city3-1 city2-1 city1-1 city11-2 city10-2 city9-2 city8-2
             city7-2 city6-2 city5-2 city4-2 city3-2 city2-2 city1-2)
   (:init (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city11-1)
          (location city10-1)
          (location city9-1)
          (location city8-1)
          (location city7-1)
          (location city6-1)
          (location city5-1)
          (location city4-1)
          (location city3-1)
          (location city2-1)
          (location city1-1)
          (airport city11-2)
          (location city11-2)
          (airport city10-2)
          (location city10-2)
          (airport city9-2)
          (location city9-2)
          (airport city8-2)
          (location city8-2)
          (airport city7-2)
          (location city7-2)
          (airport city6-2)
          (location city6-2)
          (airport city5-2)
          (location city5-2)
          (airport city4-2)
          (location city4-2)
          (airport city3-2)
          (location city3-2)
          (airport city2-2)
          (location city2-2)
          (airport city1-2)
          (location city1-2)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane6 city2-2)
          (at plane5 city5-2)
          (at plane4 city6-2)
          (at plane3 city9-2)
          (at plane2 city8-2)
          (at plane1 city1-2)
          (at truck11 city11-1)
          (at truck10 city10-1)
          (at truck9 city9-1)
          (at truck8 city8-1)
          (at truck7 city7-1)
          (at truck6 city6-1)
          (at truck5 city5-1)
          (at truck4 city4-1)
          (at truck3 city3-1)
          (at truck2 city2-1)
          (at truck1 city1-1)
          (at package10 city6-2)
          (at package9 city5-2)
          (at package8 city10-2)
          (at package7 city6-2)
          (at package6 city1-2)
          (at package5 city4-1)
          (at package4 city4-2)
          (at package3 city1-2)
          (at package2 city10-2)
          (at package1 city8-1))
   (:goal (and (at package10 city9-1)
               (at package9 city9-2)
               (at package8 city1-2)
               (at package7 city5-1)
               (at package6 city10-2)
               (at package5 city7-1))))

(define (problem strips-log-x-8)
   (:domain logistics-strips)
   (:objects package24 package23 package22 package21 package20
             package19 package18 package17 package16 package15 package14
             package13 package12 package11 package10 package9 package8
             package7 package6 package5 package4 package3 package2 package1
             city20 city19 city18 city17 city16 city15 city14 city13 city12
             city11 city10 city9 city8 city7 city6 city5 city4 city3 city2
             city1 truck33 truck32 truck31 truck30 truck29 truck28
             truck27 truck26 truck25 truck24 truck23 truck22 truck21
             truck20 truck19 truck18 truck17 truck16 truck15 truck14
             truck13 truck12 truck11 truck10 truck9 truck8 truck7 truck6
             truck5 truck4 truck3 truck2 truck1 plane4 plane3 plane2 plane1
             city20-2 city20-1 city19-2 city19-1 city18-2 city18-1 city17-2
             city17-1 city16-2 city16-1 city15-2 city15-1 city14-2 city14-1
             city13-2 city13-1 city12-2 city12-1 city11-2 city11-1 city10-2
             city10-1 city9-2 city9-1 city8-2 city8-1 city7-2 city7-1
             city6-2 city6-1 city5-2 city5-1 city4-2 city4-1 city3-2
             city3-1 city2-2 city2-1 city1-2 city1-1 city20-3 city19-3
             city18-3 city17-3 city16-3 city15-3 city14-3 city13-3 city12-3
             city11-3 city10-3 city9-3 city8-3 city7-3 city6-3 city5-3
             city4-3 city3-3 city2-3 city1-3)
   (:init (obj package24)
          (obj package23)
          (obj package22)
          (obj package21)
          (obj package20)
          (obj package19)
          (obj package18)
          (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city20)
          (city city19)
          (city city18)
          (city city17)
          (city city16)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck33)
          (truck truck32)
          (truck truck31)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city20-2)
          (location city20-1)
          (location city19-2)
          (location city19-1)
          (location city18-2)
          (location city18-1)
          (location city17-2)
          (location city17-1)
          (location city16-2)
          (location city16-1)
          (location city15-2)
          (location city15-1)
          (location city14-2)
          (location city14-1)
          (location city13-2)
          (location city13-1)
          (location city12-2)
          (location city12-1)
          (location city11-2)
          (location city11-1)
          (location city10-2)
          (location city10-1)
          (location city9-2)
          (location city9-1)
          (location city8-2)
          (location city8-1)
          (location city7-2)
          (location city7-1)
          (location city6-2)
          (location city6-1)
          (location city5-2)
          (location city5-1)
          (location city4-2)
          (location city4-1)
          (location city3-2)
          (location city3-1)
          (location city2-2)
          (location city2-1)
          (location city1-2)
          (location city1-1)
          (airport city20-3)
          (location city20-3)
          (airport city19-3)
          (location city19-3)
          (airport city18-3)
          (location city18-3)
          (airport city17-3)
          (location city17-3)
          (airport city16-3)
          (location city16-3)
          (airport city15-3)
          (location city15-3)
          (airport city14-3)
          (location city14-3)
          (airport city13-3)
          (location city13-3)
          (airport city12-3)
          (location city12-3)
          (airport city11-3)
          (location city11-3)
          (airport city10-3)
          (location city10-3)
          (airport city9-3)
          (location city9-3)
          (airport city8-3)
          (location city8-3)
          (airport city7-3)
          (location city7-3)
          (airport city6-3)
          (location city6-3)
          (airport city5-3)
          (location city5-3)
          (airport city4-3)
          (location city4-3)
          (airport city3-3)
          (location city3-3)
          (airport city2-3)
          (location city2-3)
          (airport city1-3)
          (location city1-3)
          (in-city city20-3 city20)
          (in-city city20-2 city20)
          (in-city city20-1 city20)
          (in-city city19-3 city19)
          (in-city city19-2 city19)
          (in-city city19-1 city19)
          (in-city city18-3 city18)
          (in-city city18-2 city18)
          (in-city city18-1 city18)
          (in-city city17-3 city17)
          (in-city city17-2 city17)
          (in-city city17-1 city17)
          (in-city city16-3 city16)
          (in-city city16-2 city16)
          (in-city city16-1 city16)
          (in-city city15-3 city15)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane4 city7-3)
          (at plane3 city2-3)
          (at plane2 city16-3)
          (at plane1 city5-3)
          (at truck33 city20-1)
          (at truck32 city19-1)
          (at truck31 city18-2)
          (at truck30 city17-2)
          (at truck29 city16-2)
          (at truck28 city15-2)
          (at truck27 city14-1)
          (at truck26 city13-1)
          (at truck25 city12-2)
          (at truck24 city11-2)
          (at truck23 city10-2)
          (at truck22 city9-1)
          (at truck21 city8-1)
          (at truck20 city7-2)
          (at truck19 city6-2)
          (at truck18 city5-1)
          (at truck17 city4-1)
          (at truck16 city3-2)
          (at truck15 city2-2)
          (at truck14 city1-1)
          (at truck13 city1-3)
          (at truck12 city12-1)
          (at truck11 city5-3)
          (at truck10 city20-3)
          (at truck9 city4-1)
          (at truck8 city10-3)
          (at truck7 city4-2)
          (at truck6 city1-1)
          (at truck5 city5-3)
          (at truck4 city17-2)
          (at truck3 city8-2)
          (at truck2 city2-1)
          (at truck1 city17-2)
          (at package24 city13-1)
          (at package23 city13-3)
          (at package22 city15-3)
          (at package21 city20-3)
          (at package20 city20-2)
          (at package19 city3-3)
          (at package18 city16-1)
          (at package17 city5-2)
          (at package16 city13-1)
          (at package15 city18-2)
          (at package14 city13-1)
          (at package13 city14-1)
          (at package12 city7-2)
          (at package11 city18-3)
          (at package10 city7-1)
          (at package9 city11-3)
          (at package8 city11-3)
          (at package7 city3-3)
          (at package6 city4-2)
          (at package5 city7-3)
          (at package4 city5-2)
          (at package3 city1-1)
          (at package2 city20-3)
          (at package1 city13-1))
   (:goal (and (at package24 city7-1)
               (at package23 city2-1)
               (at package22 city1-3)
               (at package21 city6-3)
               (at package20 city7-1)
               (at package19 city1-2))))

(define (problem strips-log-x-9)
   (:domain logistics-strips)
   (:objects package12 package11 package10 package9 package8
             package7 package6 package5 package4 package3 package2 package1
             city11 city10 city9 city8 city7 city6 city5 city4 city3 city2
             city1 truck28 truck27 truck26 truck25 truck24 truck23
             truck22 truck21 truck20 truck19 truck18 truck17 truck16
             truck15 truck14 truck13 truck12 truck11 truck10 truck9 truck8
             truck7 truck6 truck5 truck4 truck3 truck2 truck1 plane4 plane3
             plane2 plane1 city11-5 city11-4 city11-3 city11-2 city11-1
             city10-5 city10-4 city10-3 city10-2 city10-1 city9-5 city9-4
             city9-3 city9-2 city9-1 city8-5 city8-4 city8-3 city8-2
             city8-1 city7-5 city7-4 city7-3 city7-2 city7-1 city6-5
             city6-4 city6-3 city6-2 city6-1 city5-5 city5-4 city5-3
             city5-2 city5-1 city4-5 city4-4 city4-3 city4-2 city4-1
             city3-5 city3-4 city3-3 city3-2 city3-1 city2-5 city2-4
             city2-3 city2-2 city2-1 city1-5 city1-4 city1-3 city1-2
             city1-1 city11-6 city10-6 city9-6 city8-6 city7-6 city6-6
             city5-6 city4-6 city3-6 city2-6 city1-6)
   (:init (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city11-5)
          (location city11-4)
          (location city11-3)
          (location city11-2)
          (location city11-1)
          (location city10-5)
          (location city10-4)
          (location city10-3)
          (location city10-2)
          (location city10-1)
          (location city9-5)
          (location city9-4)
          (location city9-3)
          (location city9-2)
          (location city9-1)
          (location city8-5)
          (location city8-4)
          (location city8-3)
          (location city8-2)
          (location city8-1)
          (location city7-5)
          (location city7-4)
          (location city7-3)
          (location city7-2)
          (location city7-1)
          (location city6-5)
          (location city6-4)
          (location city6-3)
          (location city6-2)
          (location city6-1)
          (location city5-5)
          (location city5-4)
          (location city5-3)
          (location city5-2)
          (location city5-1)
          (location city4-5)
          (location city4-4)
          (location city4-3)
          (location city4-2)
          (location city4-1)
          (location city3-5)
          (location city3-4)
          (location city3-3)
          (location city3-2)
          (location city3-1)
          (location city2-5)
          (location city2-4)
          (location city2-3)
          (location city2-2)
          (location city2-1)
          (location city1-5)
          (location city1-4)
          (location city1-3)
          (location city1-2)
          (location city1-1)
          (airport city11-6)
          (location city11-6)
          (airport city10-6)
          (location city10-6)
          (airport city9-6)
          (location city9-6)
          (airport city8-6)
          (location city8-6)
          (airport city7-6)
          (location city7-6)
          (airport city6-6)
          (location city6-6)
          (airport city5-6)
          (location city5-6)
          (airport city4-6)
          (location city4-6)
          (airport city3-6)
          (location city3-6)
          (airport city2-6)
          (location city2-6)
          (airport city1-6)
          (location city1-6)
          (in-city city11-6 city11)
          (in-city city11-5 city11)
          (in-city city11-4 city11)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-6 city10)
          (in-city city10-5 city10)
          (in-city city10-4 city10)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-6 city9)
          (in-city city9-5 city9)
          (in-city city9-4 city9)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-6 city8)
          (in-city city8-5 city8)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-6 city7)
          (in-city city7-5 city7)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-6 city6)
          (in-city city6-5 city6)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-6 city5)
          (in-city city5-5 city5)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-6 city4)
          (in-city city4-5 city4)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-6 city3)
          (in-city city3-5 city3)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-6 city2)
          (in-city city2-5 city2)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-6 city1)
          (in-city city1-5 city1)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane4 city5-6)
          (at plane3 city6-6)
          (at plane2 city7-6)
          (at plane1 city10-6)
          (at truck28 city11-2)
          (at truck27 city10-2)
          (at truck26 city9-1)
          (at truck25 city8-2)
          (at truck24 city7-5)
          (at truck23 city6-1)
          (at truck22 city5-2)
          (at truck21 city4-2)
          (at truck20 city3-3)
          (at truck19 city2-1)
          (at truck18 city1-1)
          (at truck17 city7-3)
          (at truck16 city6-3)
          (at truck15 city8-5)
          (at truck14 city11-6)
          (at truck13 city9-6)
          (at truck12 city7-1)
          (at truck11 city8-6)
          (at truck10 city1-1)
          (at truck9 city4-1)
          (at truck8 city2-5)
          (at truck7 city9-1)
          (at truck6 city2-6)
          (at truck5 city8-6)
          (at truck4 city4-1)
          (at truck3 city4-1)
          (at truck2 city8-2)
          (at truck1 city1-5)
          (at package12 city1-2)
          (at package11 city9-1)
          (at package10 city4-6)
          (at package9 city8-4)
          (at package8 city11-5)
          (at package7 city2-4)
          (at package6 city4-1)
          (at package5 city2-6)
          (at package4 city4-4)
          (at package3 city4-5)
          (at package2 city2-6)
          (at package1 city6-6))
   (:goal (and (at package12 city5-4)
               (at package11 city4-1)
               (at package10 city6-2)
               (at package9 city8-4)
               (at package8 city2-3)
               (at package7 city9-6)
               (at package6 city2-4)
               (at package5 city10-3)
               (at package4 city4-4)
               (at package3 city8-1)
               (at package2 city9-2)
               (at package1 city5-1))))

(define (problem strips-log-x-10)
   (:domain logistics-strips)
   (:objects package17 package16 package15 package14 package13
             package12 package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 city23
             city22 city21 city20 city19 city18 city17 city16 city15 city14
             city13 city12 city11 city10 city9 city8 city7 city6 city5 city4
             city3 city2 city1 truck23 truck22 truck21 truck20 truck19
             truck18 truck17 truck16 truck15 truck14 truck13 truck12
             truck11 truck10 truck9 truck8 truck7 truck6 truck5 truck4
             truck3 truck2 truck1 plane4 plane3 plane2 plane1 city23-1
             city22-1 city21-1 city20-1 city19-1 city18-1 city17-1 city16-1
             city15-1 city14-1 city13-1 city12-1 city11-1 city10-1 city9-1
             city8-1 city7-1 city6-1 city5-1 city4-1 city3-1 city2-1
             city1-1 city23-2 city22-2 city21-2 city20-2 city19-2 city18-2
             city17-2 city16-2 city15-2 city14-2 city13-2 city12-2 city11-2
             city10-2 city9-2 city8-2 city7-2 city6-2 city5-2 city4-2
             city3-2 city2-2 city1-2)
   (:init (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city23)
          (city city22)
          (city city21)
          (city city20)
          (city city19)
          (city city18)
          (city city17)
          (city city16)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city23-1)
          (location city22-1)
          (location city21-1)
          (location city20-1)
          (location city19-1)
          (location city18-1)
          (location city17-1)
          (location city16-1)
          (location city15-1)
          (location city14-1)
          (location city13-1)
          (location city12-1)
          (location city11-1)
          (location city10-1)
          (location city9-1)
          (location city8-1)
          (location city7-1)
          (location city6-1)
          (location city5-1)
          (location city4-1)
          (location city3-1)
          (location city2-1)
          (location city1-1)
          (airport city23-2)
          (location city23-2)
          (airport city22-2)
          (location city22-2)
          (airport city21-2)
          (location city21-2)
          (airport city20-2)
          (location city20-2)
          (airport city19-2)
          (location city19-2)
          (airport city18-2)
          (location city18-2)
          (airport city17-2)
          (location city17-2)
          (airport city16-2)
          (location city16-2)
          (airport city15-2)
          (location city15-2)
          (airport city14-2)
          (location city14-2)
          (airport city13-2)
          (location city13-2)
          (airport city12-2)
          (location city12-2)
          (airport city11-2)
          (location city11-2)
          (airport city10-2)
          (location city10-2)
          (airport city9-2)
          (location city9-2)
          (airport city8-2)
          (location city8-2)
          (airport city7-2)
          (location city7-2)
          (airport city6-2)
          (location city6-2)
          (airport city5-2)
          (location city5-2)
          (airport city4-2)
          (location city4-2)
          (airport city3-2)
          (location city3-2)
          (airport city2-2)
          (location city2-2)
          (airport city1-2)
          (location city1-2)
          (in-city city23-2 city23)
          (in-city city23-1 city23)
          (in-city city22-2 city22)
          (in-city city22-1 city22)
          (in-city city21-2 city21)
          (in-city city21-1 city21)
          (in-city city20-2 city20)
          (in-city city20-1 city20)
          (in-city city19-2 city19)
          (in-city city19-1 city19)
          (in-city city18-2 city18)
          (in-city city18-1 city18)
          (in-city city17-2 city17)
          (in-city city17-1 city17)
          (in-city city16-2 city16)
          (in-city city16-1 city16)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane4 city11-2)
          (at plane3 city13-2)
          (at plane2 city18-2)
          (at plane1 city16-2)
          (at truck23 city23-1)
          (at truck22 city22-1)
          (at truck21 city21-1)
          (at truck20 city20-1)
          (at truck19 city19-1)
          (at truck18 city18-1)
          (at truck17 city17-1)
          (at truck16 city16-1)
          (at truck15 city15-1)
          (at truck14 city14-1)
          (at truck13 city13-1)
          (at truck12 city12-1)
          (at truck11 city11-1)
          (at truck10 city10-1)
          (at truck9 city9-1)
          (at truck8 city8-1)
          (at truck7 city7-1)
          (at truck6 city6-1)
          (at truck5 city5-1)
          (at truck4 city4-1)
          (at truck3 city3-1)
          (at truck2 city2-1)
          (at truck1 city1-1)
          (at package17 city8-2)
          (at package16 city13-2)
          (at package15 city15-2)
          (at package14 city3-2)
          (at package13 city14-2)
          (at package12 city5-1)
          (at package11 city16-1)
          (at package10 city3-2)
          (at package9 city21-1)
          (at package8 city8-1)
          (at package7 city11-1)
          (at package6 city15-2)
          (at package5 city6-1)
          (at package4 city7-1)
          (at package3 city19-1)
          (at package2 city22-1)
          (at package1 city13-1))
   (:goal (and (at package17 city3-1)
               (at package16 city4-2)
               (at package15 city19-1)
               (at package14 city9-1)
               (at package13 city3-2)
               (at package12 city21-1)
               (at package11 city21-2)
               (at package10 city9-2)
               (at package9 city20-2)
               (at package8 city13-2)
               (at package7 city3-1)
               (at package6 city15-2)
               (at package5 city8-1)
               (at package4 city1-1)
               (at package3 city9-2)
               (at package2 city2-1)
               (at package1 city13-1))))

(define (problem strips-log-x-11)
   (:domain logistics-strips)
   (:objects package8 package7 package6 package5 package4 package3
             package2 package1 city3 city2 city1 truck22 truck21 truck20
             truck19 truck18 truck17 truck16 truck15 truck14 truck13
             truck12 truck11 truck10 truck9 truck8 truck7 truck6 truck5
             truck4 truck3 truck2 truck1 plane6 plane5 plane4 plane3 plane2
             plane1 city3-2 city3-1 city2-2 city2-1 city1-2 city1-1
             city3-3 city2-3 city1-3)
   (:init (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city3)
          (city city2)
          (city city1)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city3-2)
          (location city3-1)
          (location city2-2)
          (location city2-1)
          (location city1-2)
          (location city1-1)
          (airport city3-3)
          (location city3-3)
          (airport city2-3)
          (location city2-3)
          (airport city1-3)
          (location city1-3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane6 city2-3)
          (at plane5 city1-3)
          (at plane4 city3-3)
          (at plane3 city2-3)
          (at plane2 city2-3)
          (at plane1 city1-3)
          (at truck22 city3-2)
          (at truck21 city2-1)
          (at truck20 city1-2)
          (at truck19 city2-3)
          (at truck18 city1-2)
          (at truck17 city2-2)
          (at truck16 city2-1)
          (at truck15 city2-3)
          (at truck14 city2-2)
          (at truck13 city1-2)
          (at truck12 city2-2)
          (at truck11 city3-3)
          (at truck10 city3-1)
          (at truck9 city2-3)
          (at truck8 city3-3)
          (at truck7 city2-3)
          (at truck6 city2-3)
          (at truck5 city2-3)
          (at truck4 city3-2)
          (at truck3 city2-2)
          (at truck2 city1-1)
          (at truck1 city2-3)
          (at package8 city1-2)
          (at package7 city2-1)
          (at package6 city3-2)
          (at package5 city1-3)
          (at package4 city3-3)
          (at package3 city2-2)
          (at package2 city3-2)
          (at package1 city1-3))
   (:goal (and (at package8 city3-3)
               (at package7 city3-3)
               (at package6 city3-2)
               (at package5 city1-3)
               (at package4 city3-3)
               (at package3 city1-2)
               (at package2 city2-3)
               (at package1 city1-1))))

(define (problem strips-log-x-12)
   (:domain logistics-strips)
   (:objects package5 package4 package3 package2 package1 city27
             city26 city25 city24 city23 city22 city21 city20 city19 city18
             city17 city16 city15 city14 city13 city12 city11 city10 city9
             city8 city7 city6 city5 city4 city3 city2 city1 truck55
             truck54 truck53 truck52 truck51 truck50 truck49 truck48
             truck47 truck46 truck45 truck44 truck43 truck42 truck41
             truck40 truck39 truck38 truck37 truck36 truck35 truck34
             truck33 truck32 truck31 truck30 truck29 truck28 truck27
             truck26 truck25 truck24 truck23 truck22 truck21 truck20
             truck19 truck18 truck17 truck16 truck15 truck14 truck13
             truck12 truck11 truck10 truck9 truck8 truck7 truck6 truck5
             truck4 truck3 truck2 truck1 plane9 plane8 plane7 plane6 plane5
             plane4 plane3 plane2 plane1 city27-3 city27-2 city27-1
             city26-3 city26-2 city26-1 city25-3 city25-2 city25-1 city24-3
             city24-2 city24-1 city23-3 city23-2 city23-1 city22-3 city22-2
             city22-1 city21-3 city21-2 city21-1 city20-3 city20-2 city20-1
             city19-3 city19-2 city19-1 city18-3 city18-2 city18-1 city17-3
             city17-2 city17-1 city16-3 city16-2 city16-1 city15-3 city15-2
             city15-1 city14-3 city14-2 city14-1 city13-3 city13-2 city13-1
             city12-3 city12-2 city12-1 city11-3 city11-2 city11-1 city10-3
             city10-2 city10-1 city9-3 city9-2 city9-1 city8-3 city8-2
             city8-1 city7-3 city7-2 city7-1 city6-3 city6-2 city6-1
             city5-3 city5-2 city5-1 city4-3 city4-2 city4-1 city3-3
             city3-2 city3-1 city2-3 city2-2 city2-1 city1-3 city1-2
             city1-1 city27-4 city26-4 city25-4 city24-4 city23-4 city22-4
             city21-4 city20-4 city19-4 city18-4 city17-4 city16-4 city15-4
             city14-4 city13-4 city12-4 city11-4 city10-4 city9-4 city8-4
             city7-4 city6-4 city5-4 city4-4 city3-4 city2-4 city1-4)
   (:init (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city27)
          (city city26)
          (city city25)
          (city city24)
          (city city23)
          (city city22)
          (city city21)
          (city city20)
          (city city19)
          (city city18)
          (city city17)
          (city city16)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck55)
          (truck truck54)
          (truck truck53)
          (truck truck52)
          (truck truck51)
          (truck truck50)
          (truck truck49)
          (truck truck48)
          (truck truck47)
          (truck truck46)
          (truck truck45)
          (truck truck44)
          (truck truck43)
          (truck truck42)
          (truck truck41)
          (truck truck40)
          (truck truck39)
          (truck truck38)
          (truck truck37)
          (truck truck36)
          (truck truck35)
          (truck truck34)
          (truck truck33)
          (truck truck32)
          (truck truck31)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane9)
          (airplane plane8)
          (airplane plane7)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city27-3)
          (location city27-2)
          (location city27-1)
          (location city26-3)
          (location city26-2)
          (location city26-1)
          (location city25-3)
          (location city25-2)
          (location city25-1)
          (location city24-3)
          (location city24-2)
          (location city24-1)
          (location city23-3)
          (location city23-2)
          (location city23-1)
          (location city22-3)
          (location city22-2)
          (location city22-1)
          (location city21-3)
          (location city21-2)
          (location city21-1)
          (location city20-3)
          (location city20-2)
          (location city20-1)
          (location city19-3)
          (location city19-2)
          (location city19-1)
          (location city18-3)
          (location city18-2)
          (location city18-1)
          (location city17-3)
          (location city17-2)
          (location city17-1)
          (location city16-3)
          (location city16-2)
          (location city16-1)
          (location city15-3)
          (location city15-2)
          (location city15-1)
          (location city14-3)
          (location city14-2)
          (location city14-1)
          (location city13-3)
          (location city13-2)
          (location city13-1)
          (location city12-3)
          (location city12-2)
          (location city12-1)
          (location city11-3)
          (location city11-2)
          (location city11-1)
          (location city10-3)
          (location city10-2)
          (location city10-1)
          (location city9-3)
          (location city9-2)
          (location city9-1)
          (location city8-3)
          (location city8-2)
          (location city8-1)
          (location city7-3)
          (location city7-2)
          (location city7-1)
          (location city6-3)
          (location city6-2)
          (location city6-1)
          (location city5-3)
          (location city5-2)
          (location city5-1)
          (location city4-3)
          (location city4-2)
          (location city4-1)
          (location city3-3)
          (location city3-2)
          (location city3-1)
          (location city2-3)
          (location city2-2)
          (location city2-1)
          (location city1-3)
          (location city1-2)
          (location city1-1)
          (airport city27-4)
          (location city27-4)
          (airport city26-4)
          (location city26-4)
          (airport city25-4)
          (location city25-4)
          (airport city24-4)
          (location city24-4)
          (airport city23-4)
          (location city23-4)
          (airport city22-4)
          (location city22-4)
          (airport city21-4)
          (location city21-4)
          (airport city20-4)
          (location city20-4)
          (airport city19-4)
          (location city19-4)
          (airport city18-4)
          (location city18-4)
          (airport city17-4)
          (location city17-4)
          (airport city16-4)
          (location city16-4)
          (airport city15-4)
          (location city15-4)
          (airport city14-4)
          (location city14-4)
          (airport city13-4)
          (location city13-4)
          (airport city12-4)
          (location city12-4)
          (airport city11-4)
          (location city11-4)
          (airport city10-4)
          (location city10-4)
          (airport city9-4)
          (location city9-4)
          (airport city8-4)
          (location city8-4)
          (airport city7-4)
          (location city7-4)
          (airport city6-4)
          (location city6-4)
          (airport city5-4)
          (location city5-4)
          (airport city4-4)
          (location city4-4)
          (airport city3-4)
          (location city3-4)
          (airport city2-4)
          (location city2-4)
          (airport city1-4)
          (location city1-4)
          (in-city city27-4 city27)
          (in-city city27-3 city27)
          (in-city city27-2 city27)
          (in-city city27-1 city27)
          (in-city city26-4 city26)
          (in-city city26-3 city26)
          (in-city city26-2 city26)
          (in-city city26-1 city26)
          (in-city city25-4 city25)
          (in-city city25-3 city25)
          (in-city city25-2 city25)
          (in-city city25-1 city25)
          (in-city city24-4 city24)
          (in-city city24-3 city24)
          (in-city city24-2 city24)
          (in-city city24-1 city24)
          (in-city city23-4 city23)
          (in-city city23-3 city23)
          (in-city city23-2 city23)
          (in-city city23-1 city23)
          (in-city city22-4 city22)
          (in-city city22-3 city22)
          (in-city city22-2 city22)
          (in-city city22-1 city22)
          (in-city city21-4 city21)
          (in-city city21-3 city21)
          (in-city city21-2 city21)
          (in-city city21-1 city21)
          (in-city city20-4 city20)
          (in-city city20-3 city20)
          (in-city city20-2 city20)
          (in-city city20-1 city20)
          (in-city city19-4 city19)
          (in-city city19-3 city19)
          (in-city city19-2 city19)
          (in-city city19-1 city19)
          (in-city city18-4 city18)
          (in-city city18-3 city18)
          (in-city city18-2 city18)
          (in-city city18-1 city18)
          (in-city city17-4 city17)
          (in-city city17-3 city17)
          (in-city city17-2 city17)
          (in-city city17-1 city17)
          (in-city city16-4 city16)
          (in-city city16-3 city16)
          (in-city city16-2 city16)
          (in-city city16-1 city16)
          (in-city city15-4 city15)
          (in-city city15-3 city15)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-4 city14)
          (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-4 city13)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-4 city12)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-4 city11)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-4 city10)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-4 city9)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane9 city7-4)
          (at plane8 city2-4)
          (at plane7 city14-4)
          (at plane6 city25-4)
          (at plane5 city23-4)
          (at plane4 city2-4)
          (at plane3 city13-4)
          (at plane2 city1-4)
          (at plane1 city23-4)
          (at truck55 city27-2)
          (at truck54 city26-3)
          (at truck53 city25-2)
          (at truck52 city24-3)
          (at truck51 city23-1)
          (at truck50 city22-2)
          (at truck49 city21-1)
          (at truck48 city20-2)
          (at truck47 city19-1)
          (at truck46 city18-3)
          (at truck45 city17-1)
          (at truck44 city16-3)
          (at truck43 city15-1)
          (at truck42 city14-3)
          (at truck41 city13-1)
          (at truck40 city12-3)
          (at truck39 city11-2)
          (at truck38 city10-1)
          (at truck37 city9-2)
          (at truck36 city8-1)
          (at truck35 city7-2)
          (at truck34 city6-1)
          (at truck33 city5-1)
          (at truck32 city4-1)
          (at truck31 city3-3)
          (at truck30 city2-2)
          (at truck29 city1-2)
          (at truck28 city10-4)
          (at truck27 city7-3)
          (at truck26 city12-4)
          (at truck25 city7-1)
          (at truck24 city11-3)
          (at truck23 city15-3)
          (at truck22 city8-4)
          (at truck21 city8-3)
          (at truck20 city10-1)
          (at truck19 city22-4)
          (at truck18 city25-2)
          (at truck17 city14-2)
          (at truck16 city15-3)
          (at truck15 city25-3)
          (at truck14 city2-3)
          (at truck13 city12-3)
          (at truck12 city19-4)
          (at truck11 city14-2)
          (at truck10 city11-3)
          (at truck9 city24-2)
          (at truck8 city3-3)
          (at truck7 city22-2)
          (at truck6 city25-2)
          (at truck5 city23-3)
          (at truck4 city8-4)
          (at truck3 city3-4)
          (at truck2 city3-3)
          (at truck1 city15-4)
          (at package5 city12-1)
          (at package4 city7-2)
          (at package3 city8-1)
          (at package2 city23-3)
          (at package1 city1-4))
   (:goal (and (at package5 city18-4)
               (at package4 city10-3)
               (at package3 city1-4)
               (at package2 city14-3)
               (at package1 city9-2))))

(define (problem strips-log-x-13)
   (:domain logistics-strips)
   (:objects package23 package22 package21 package20 package19
             package18 package17 package16 package15 package14 package13
             package12 package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 city29
             city28 city27 city26 city25 city24 city23 city22 city21 city20
             city19 city18 city17 city16 city15 city14 city13 city12 city11
             city10 city9 city8 city7 city6 city5 city4 city3 city2 city1
             truck29 truck28 truck27 truck26 truck25 truck24 truck23
             truck22 truck21 truck20 truck19 truck18 truck17 truck16
             truck15 truck14 truck13 truck12 truck11 truck10 truck9 truck8
             truck7 truck6 truck5 truck4 truck3 truck2 truck1 plane9 plane8
             plane7 plane6 plane5 plane4 plane3 plane2 plane1 city29-3
             city29-2 city29-1 city28-3 city28-2 city28-1 city27-3 city27-2
             city27-1 city26-3 city26-2 city26-1 city25-3 city25-2 city25-1
             city24-3 city24-2 city24-1 city23-3 city23-2 city23-1 city22-3
             city22-2 city22-1 city21-3 city21-2 city21-1 city20-3 city20-2
             city20-1 city19-3 city19-2 city19-1 city18-3 city18-2 city18-1
             city17-3 city17-2 city17-1 city16-3 city16-2 city16-1 city15-3
             city15-2 city15-1 city14-3 city14-2 city14-1 city13-3 city13-2
             city13-1 city12-3 city12-2 city12-1 city11-3 city11-2 city11-1
             city10-3 city10-2 city10-1 city9-3 city9-2 city9-1 city8-3
             city8-2 city8-1 city7-3 city7-2 city7-1 city6-3 city6-2
             city6-1 city5-3 city5-2 city5-1 city4-3 city4-2 city4-1
             city3-3 city3-2 city3-1 city2-3 city2-2 city2-1 city1-3
             city1-2 city1-1 city29-4 city28-4 city27-4 city26-4 city25-4
             city24-4 city23-4 city22-4 city21-4 city20-4 city19-4 city18-4
             city17-4 city16-4 city15-4 city14-4 city13-4 city12-4 city11-4
             city10-4 city9-4 city8-4 city7-4 city6-4 city5-4 city4-4
             city3-4 city2-4 city1-4)
   (:init (obj package23)
          (obj package22)
          (obj package21)
          (obj package20)
          (obj package19)
          (obj package18)
          (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city29)
          (city city28)
          (city city27)
          (city city26)
          (city city25)
          (city city24)
          (city city23)
          (city city22)
          (city city21)
          (city city20)
          (city city19)
          (city city18)
          (city city17)
          (city city16)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane9)
          (airplane plane8)
          (airplane plane7)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city29-3)
          (location city29-2)
          (location city29-1)
          (location city28-3)
          (location city28-2)
          (location city28-1)
          (location city27-3)
          (location city27-2)
          (location city27-1)
          (location city26-3)
          (location city26-2)
          (location city26-1)
          (location city25-3)
          (location city25-2)
          (location city25-1)
          (location city24-3)
          (location city24-2)
          (location city24-1)
          (location city23-3)
          (location city23-2)
          (location city23-1)
          (location city22-3)
          (location city22-2)
          (location city22-1)
          (location city21-3)
          (location city21-2)
          (location city21-1)
          (location city20-3)
          (location city20-2)
          (location city20-1)
          (location city19-3)
          (location city19-2)
          (location city19-1)
          (location city18-3)
          (location city18-2)
          (location city18-1)
          (location city17-3)
          (location city17-2)
          (location city17-1)
          (location city16-3)
          (location city16-2)
          (location city16-1)
          (location city15-3)
          (location city15-2)
          (location city15-1)
          (location city14-3)
          (location city14-2)
          (location city14-1)
          (location city13-3)
          (location city13-2)
          (location city13-1)
          (location city12-3)
          (location city12-2)
          (location city12-1)
          (location city11-3)
          (location city11-2)
          (location city11-1)
          (location city10-3)
          (location city10-2)
          (location city10-1)
          (location city9-3)
          (location city9-2)
          (location city9-1)
          (location city8-3)
          (location city8-2)
          (location city8-1)
          (location city7-3)
          (location city7-2)
          (location city7-1)
          (location city6-3)
          (location city6-2)
          (location city6-1)
          (location city5-3)
          (location city5-2)
          (location city5-1)
          (location city4-3)
          (location city4-2)
          (location city4-1)
          (location city3-3)
          (location city3-2)
          (location city3-1)
          (location city2-3)
          (location city2-2)
          (location city2-1)
          (location city1-3)
          (location city1-2)
          (location city1-1)
          (airport city29-4)
          (location city29-4)
          (airport city28-4)
          (location city28-4)
          (airport city27-4)
          (location city27-4)
          (airport city26-4)
          (location city26-4)
          (airport city25-4)
          (location city25-4)
          (airport city24-4)
          (location city24-4)
          (airport city23-4)
          (location city23-4)
          (airport city22-4)
          (location city22-4)
          (airport city21-4)
          (location city21-4)
          (airport city20-4)
          (location city20-4)
          (airport city19-4)
          (location city19-4)
          (airport city18-4)
          (location city18-4)
          (airport city17-4)
          (location city17-4)
          (airport city16-4)
          (location city16-4)
          (airport city15-4)
          (location city15-4)
          (airport city14-4)
          (location city14-4)
          (airport city13-4)
          (location city13-4)
          (airport city12-4)
          (location city12-4)
          (airport city11-4)
          (location city11-4)
          (airport city10-4)
          (location city10-4)
          (airport city9-4)
          (location city9-4)
          (airport city8-4)
          (location city8-4)
          (airport city7-4)
          (location city7-4)
          (airport city6-4)
          (location city6-4)
          (airport city5-4)
          (location city5-4)
          (airport city4-4)
          (location city4-4)
          (airport city3-4)
          (location city3-4)
          (airport city2-4)
          (location city2-4)
          (airport city1-4)
          (location city1-4)
          (in-city city29-4 city29)
          (in-city city29-3 city29)
          (in-city city29-2 city29)
          (in-city city29-1 city29)
          (in-city city28-4 city28)
          (in-city city28-3 city28)
          (in-city city28-2 city28)
          (in-city city28-1 city28)
          (in-city city27-4 city27)
          (in-city city27-3 city27)
          (in-city city27-2 city27)
          (in-city city27-1 city27)
          (in-city city26-4 city26)
          (in-city city26-3 city26)
          (in-city city26-2 city26)
          (in-city city26-1 city26)
          (in-city city25-4 city25)
          (in-city city25-3 city25)
          (in-city city25-2 city25)
          (in-city city25-1 city25)
          (in-city city24-4 city24)
          (in-city city24-3 city24)
          (in-city city24-2 city24)
          (in-city city24-1 city24)
          (in-city city23-4 city23)
          (in-city city23-3 city23)
          (in-city city23-2 city23)
          (in-city city23-1 city23)
          (in-city city22-4 city22)
          (in-city city22-3 city22)
          (in-city city22-2 city22)
          (in-city city22-1 city22)
          (in-city city21-4 city21)
          (in-city city21-3 city21)
          (in-city city21-2 city21)
          (in-city city21-1 city21)
          (in-city city20-4 city20)
          (in-city city20-3 city20)
          (in-city city20-2 city20)
          (in-city city20-1 city20)
          (in-city city19-4 city19)
          (in-city city19-3 city19)
          (in-city city19-2 city19)
          (in-city city19-1 city19)
          (in-city city18-4 city18)
          (in-city city18-3 city18)
          (in-city city18-2 city18)
          (in-city city18-1 city18)
          (in-city city17-4 city17)
          (in-city city17-3 city17)
          (in-city city17-2 city17)
          (in-city city17-1 city17)
          (in-city city16-4 city16)
          (in-city city16-3 city16)
          (in-city city16-2 city16)
          (in-city city16-1 city16)
          (in-city city15-4 city15)
          (in-city city15-3 city15)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-4 city14)
          (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-4 city13)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-4 city12)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-4 city11)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-4 city10)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-4 city9)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane9 city28-4)
          (at plane8 city23-4)
          (at plane7 city27-4)
          (at plane6 city29-4)
          (at plane5 city13-4)
          (at plane4 city4-4)
          (at plane3 city14-4)
          (at plane2 city14-4)
          (at plane1 city13-4)
          (at truck29 city29-1)
          (at truck28 city28-2)
          (at truck27 city27-3)
          (at truck26 city26-1)
          (at truck25 city25-2)
          (at truck24 city24-3)
          (at truck23 city23-3)
          (at truck22 city22-3)
          (at truck21 city21-1)
          (at truck20 city20-1)
          (at truck19 city19-3)
          (at truck18 city18-2)
          (at truck17 city17-3)
          (at truck16 city16-2)
          (at truck15 city15-3)
          (at truck14 city14-3)
          (at truck13 city13-2)
          (at truck12 city12-3)
          (at truck11 city11-1)
          (at truck10 city10-2)
          (at truck9 city9-3)
          (at truck8 city8-2)
          (at truck7 city7-3)
          (at truck6 city6-3)
          (at truck5 city5-3)
          (at truck4 city4-2)
          (at truck3 city3-2)
          (at truck2 city2-3)
          (at truck1 city1-1)
          (at package23 city26-2)
          (at package22 city1-1)
          (at package21 city3-1)
          (at package20 city18-2)
          (at package19 city17-2)
          (at package18 city21-1)
          (at package17 city1-4)
          (at package16 city29-4)
          (at package15 city1-2)
          (at package14 city4-4)
          (at package13 city10-1)
          (at package12 city13-1)
          (at package11 city24-3)
          (at package10 city5-4)
          (at package9 city9-4)
          (at package8 city3-4)
          (at package7 city13-1)
          (at package6 city7-3)
          (at package5 city16-1)
          (at package4 city3-2)
          (at package3 city17-1)
          (at package2 city11-1)
          (at package1 city21-4))
   (:goal (and (at package23 city7-4)
               (at package22 city11-3)
               (at package21 city16-4)
               (at package20 city4-4)
               (at package19 city21-2)
               (at package18 city22-1)
               (at package17 city18-3)
               (at package16 city14-3))))

(define (problem strips-log-x-14)
   (:domain logistics-strips)
   (:objects package29 package28 package27 package26 package25
             package24 package23 package22 package21 package20 package19
             package18 package17 package16 package15 package14 package13
             package12 package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 city11
             city10 city9 city8 city7 city6 city5 city4 city3 city2 city1
             truck47 truck46 truck45 truck44 truck43 truck42 truck41
             truck40 truck39 truck38 truck37 truck36 truck35 truck34
             truck33 truck32 truck31 truck30 truck29 truck28 truck27
             truck26 truck25 truck24 truck23 truck22 truck21 truck20
             truck19 truck18 truck17 truck16 truck15 truck14 truck13
             truck12 truck11 truck10 truck9 truck8 truck7 truck6 truck5
             truck4 truck3 truck2 truck1 plane8 plane7 plane6 plane5 plane4
             plane3 plane2 plane1 city11-1 city10-1 city9-1 city8-1
             city7-1 city6-1 city5-1 city4-1 city3-1 city2-1 city1-1
             city11-2 city10-2 city9-2 city8-2 city7-2 city6-2 city5-2
             city4-2 city3-2 city2-2 city1-2)
   (:init (obj package29)
          (obj package28)
          (obj package27)
          (obj package26)
          (obj package25)
          (obj package24)
          (obj package23)
          (obj package22)
          (obj package21)
          (obj package20)
          (obj package19)
          (obj package18)
          (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck47)
          (truck truck46)
          (truck truck45)
          (truck truck44)
          (truck truck43)
          (truck truck42)
          (truck truck41)
          (truck truck40)
          (truck truck39)
          (truck truck38)
          (truck truck37)
          (truck truck36)
          (truck truck35)
          (truck truck34)
          (truck truck33)
          (truck truck32)
          (truck truck31)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane8)
          (airplane plane7)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city11-1)
          (location city10-1)
          (location city9-1)
          (location city8-1)
          (location city7-1)
          (location city6-1)
          (location city5-1)
          (location city4-1)
          (location city3-1)
          (location city2-1)
          (location city1-1)
          (airport city11-2)
          (location city11-2)
          (airport city10-2)
          (location city10-2)
          (airport city9-2)
          (location city9-2)
          (airport city8-2)
          (location city8-2)
          (airport city7-2)
          (location city7-2)
          (airport city6-2)
          (location city6-2)
          (airport city5-2)
          (location city5-2)
          (airport city4-2)
          (location city4-2)
          (airport city3-2)
          (location city3-2)
          (airport city2-2)
          (location city2-2)
          (airport city1-2)
          (location city1-2)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane8 city9-2)
          (at plane7 city4-2)
          (at plane6 city1-2)
          (at plane5 city2-2)
          (at plane4 city4-2)
          (at plane3 city11-2)
          (at plane2 city2-2)
          (at plane1 city6-2)
          (at truck47 city11-1)
          (at truck46 city10-1)
          (at truck45 city9-1)
          (at truck44 city8-1)
          (at truck43 city7-1)
          (at truck42 city6-1)
          (at truck41 city5-1)
          (at truck40 city4-1)
          (at truck39 city3-1)
          (at truck38 city2-1)
          (at truck37 city1-1)
          (at truck36 city1-1)
          (at truck35 city4-1)
          (at truck34 city7-1)
          (at truck33 city7-1)
          (at truck32 city10-2)
          (at truck31 city3-2)
          (at truck30 city6-2)
          (at truck29 city6-2)
          (at truck28 city10-1)
          (at truck27 city10-1)
          (at truck26 city8-1)
          (at truck25 city10-1)
          (at truck24 city6-1)
          (at truck23 city5-2)
          (at truck22 city9-2)
          (at truck21 city4-2)
          (at truck20 city2-2)
          (at truck19 city8-1)
          (at truck18 city4-2)
          (at truck17 city3-1)
          (at truck16 city2-1)
          (at truck15 city2-2)
          (at truck14 city6-2)
          (at truck13 city10-2)
          (at truck12 city10-2)
          (at truck11 city7-2)
          (at truck10 city2-1)
          (at truck9 city3-2)
          (at truck8 city1-2)
          (at truck7 city3-1)
          (at truck6 city8-2)
          (at truck5 city7-1)
          (at truck4 city8-2)
          (at truck3 city1-2)
          (at truck2 city1-1)
          (at truck1 city2-1)
          (at package29 city10-1)
          (at package28 city4-2)
          (at package27 city10-2)
          (at package26 city6-1)
          (at package25 city6-2)
          (at package24 city8-2)
          (at package23 city1-1)
          (at package22 city9-1)
          (at package21 city9-2)
          (at package20 city6-2)
          (at package19 city9-1)
          (at package18 city2-2)
          (at package17 city4-2)
          (at package16 city2-2)
          (at package15 city1-2)
          (at package14 city9-1)
          (at package13 city7-1)
          (at package12 city9-2)
          (at package11 city6-2)
          (at package10 city8-2)
          (at package9 city1-2)
          (at package8 city8-1)
          (at package7 city8-2)
          (at package6 city1-2)
          (at package5 city2-2)
          (at package4 city10-2)
          (at package3 city11-1)
          (at package2 city11-1)
          (at package1 city11-2))
   (:goal (and (at package29 city5-2)
               (at package28 city11-2)
               (at package27 city10-1)
               (at package26 city9-1)
               (at package25 city4-1)
               (at package24 city8-2)
               (at package23 city10-2)
               (at package22 city1-2)
               (at package21 city1-1)
               (at package20 city4-1)
               (at package19 city6-1)
               (at package18 city9-1)
               (at package17 city4-1)
               (at package16 city11-1)
               (at package15 city2-2)
               (at package14 city8-2)
               (at package13 city10-2)
               (at package12 city11-2)
               (at package11 city2-2))))

(define (problem strips-log-x-15)
   (:domain logistics-strips)
   (:objects package23 package22 package21 package20 package19
             package18 package17 package16 package15 package14 package13
             package12 package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 city3
             city2 city1 truck5 truck4 truck3 truck2 truck1 plane7 plane6
             plane5 plane4 plane3 plane2 plane1 city3-5 city3-4 city3-3
             city3-2 city3-1 city2-5 city2-4 city2-3 city2-2 city2-1
             city1-5 city1-4 city1-3 city1-2 city1-1 city3-6 city2-6
             city1-6)
   (:init (obj package23)
          (obj package22)
          (obj package21)
          (obj package20)
          (obj package19)
          (obj package18)
          (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city3)
          (city city2)
          (city city1)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane7)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city3-5)
          (location city3-4)
          (location city3-3)
          (location city3-2)
          (location city3-1)
          (location city2-5)
          (location city2-4)
          (location city2-3)
          (location city2-2)
          (location city2-1)
          (location city1-5)
          (location city1-4)
          (location city1-3)
          (location city1-2)
          (location city1-1)
          (airport city3-6)
          (location city3-6)
          (airport city2-6)
          (location city2-6)
          (airport city1-6)
          (location city1-6)
          (in-city city3-6 city3)
          (in-city city3-5 city3)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-6 city2)
          (in-city city2-5 city2)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-6 city1)
          (in-city city1-5 city1)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane7 city1-6)
          (at plane6 city2-6)
          (at plane5 city1-6)
          (at plane4 city1-6)
          (at plane3 city3-6)
          (at plane2 city1-6)
          (at plane1 city2-6)
          (at truck5 city3-4)
          (at truck4 city2-3)
          (at truck3 city1-5)
          (at truck2 city1-3)
          (at truck1 city1-6)
          (at package23 city1-5)
          (at package22 city1-5)
          (at package21 city2-4)
          (at package20 city2-3)
          (at package19 city1-2)
          (at package18 city3-3)
          (at package17 city2-3)
          (at package16 city3-5)
          (at package15 city2-2)
          (at package14 city2-1)
          (at package13 city3-4)
          (at package12 city1-6)
          (at package11 city1-4)
          (at package10 city3-3)
          (at package9 city3-3)
          (at package8 city1-2)
          (at package7 city1-4)
          (at package6 city1-4)
          (at package5 city3-1)
          (at package4 city2-1)
          (at package3 city1-5)
          (at package2 city3-3)
          (at package1 city1-2))
   (:goal (and (at package23 city2-3)
               (at package22 city1-5)
               (at package21 city1-6)
               (at package20 city1-1)
               (at package19 city1-3)
               (at package18 city1-3)
               (at package17 city1-5)
               (at package16 city1-1)
               (at package15 city3-3)
               (at package14 city1-5)
               (at package13 city2-5)
               (at package12 city3-2)
               (at package11 city2-6)
               (at package10 city1-6))))

(define (problem strips-log-x-16)
   (:domain logistics-strips)
   (:objects package7 package6 package5 package4 package3 package2
             package1 city11 city10 city9 city8 city7 city6 city5 city4 city3
             city2 city1 truck52 truck51 truck50 truck49 truck48 truck47
             truck46 truck45 truck44 truck43 truck42 truck41 truck40
             truck39 truck38 truck37 truck36 truck35 truck34 truck33
             truck32 truck31 truck30 truck29 truck28 truck27 truck26
             truck25 truck24 truck23 truck22 truck21 truck20 truck19
             truck18 truck17 truck16 truck15 truck14 truck13 truck12
             truck11 truck10 truck9 truck8 truck7 truck6 truck5 truck4
             truck3 truck2 truck1 plane13 plane12 plane11 plane10 plane9
             plane8 plane7 plane6 plane5 plane4 plane3 plane2 plane1
             city11-2 city11-1 city10-2 city10-1 city9-2 city9-1 city8-2
             city8-1 city7-2 city7-1 city6-2 city6-1 city5-2 city5-1
             city4-2 city4-1 city3-2 city3-1 city2-2 city2-1 city1-2
             city1-1 city11-3 city10-3 city9-3 city8-3 city7-3 city6-3
             city5-3 city4-3 city3-3 city2-3 city1-3)
   (:init (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck52)
          (truck truck51)
          (truck truck50)
          (truck truck49)
          (truck truck48)
          (truck truck47)
          (truck truck46)
          (truck truck45)
          (truck truck44)
          (truck truck43)
          (truck truck42)
          (truck truck41)
          (truck truck40)
          (truck truck39)
          (truck truck38)
          (truck truck37)
          (truck truck36)
          (truck truck35)
          (truck truck34)
          (truck truck33)
          (truck truck32)
          (truck truck31)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane13)
          (airplane plane12)
          (airplane plane11)
          (airplane plane10)
          (airplane plane9)
          (airplane plane8)
          (airplane plane7)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city11-2)
          (location city11-1)
          (location city10-2)
          (location city10-1)
          (location city9-2)
          (location city9-1)
          (location city8-2)
          (location city8-1)
          (location city7-2)
          (location city7-1)
          (location city6-2)
          (location city6-1)
          (location city5-2)
          (location city5-1)
          (location city4-2)
          (location city4-1)
          (location city3-2)
          (location city3-1)
          (location city2-2)
          (location city2-1)
          (location city1-2)
          (location city1-1)
          (airport city11-3)
          (location city11-3)
          (airport city10-3)
          (location city10-3)
          (airport city9-3)
          (location city9-3)
          (airport city8-3)
          (location city8-3)
          (airport city7-3)
          (location city7-3)
          (airport city6-3)
          (location city6-3)
          (airport city5-3)
          (location city5-3)
          (airport city4-3)
          (location city4-3)
          (airport city3-3)
          (location city3-3)
          (airport city2-3)
          (location city2-3)
          (airport city1-3)
          (location city1-3)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane13 city10-3)
          (at plane12 city5-3)
          (at plane11 city11-3)
          (at plane10 city1-3)
          (at plane9 city9-3)
          (at plane8 city7-3)
          (at plane7 city1-3)
          (at plane6 city8-3)
          (at plane5 city7-3)
          (at plane4 city9-3)
          (at plane3 city1-3)
          (at plane2 city11-3)
          (at plane1 city6-3)
          (at truck52 city11-2)
          (at truck51 city10-1)
          (at truck50 city9-2)
          (at truck49 city8-1)
          (at truck48 city7-1)
          (at truck47 city6-1)
          (at truck46 city5-2)
          (at truck45 city4-1)
          (at truck44 city3-2)
          (at truck43 city2-2)
          (at truck42 city1-2)
          (at truck41 city7-2)
          (at truck40 city6-1)
          (at truck39 city2-3)
          (at truck38 city3-1)
          (at truck37 city2-3)
          (at truck36 city7-1)
          (at truck35 city8-2)
          (at truck34 city8-2)
          (at truck33 city7-2)
          (at truck32 city6-3)
          (at truck31 city2-2)
          (at truck30 city11-3)
          (at truck29 city1-2)
          (at truck28 city3-1)
          (at truck27 city9-2)
          (at truck26 city7-2)
          (at truck25 city1-3)
          (at truck24 city4-1)
          (at truck23 city9-2)
          (at truck22 city3-1)
          (at truck21 city1-1)
          (at truck20 city7-3)
          (at truck19 city4-3)
          (at truck18 city1-1)
          (at truck17 city4-3)
          (at truck16 city11-3)
          (at truck15 city6-2)
          (at truck14 city5-3)
          (at truck13 city5-1)
          (at truck12 city8-1)
          (at truck11 city8-1)
          (at truck10 city5-2)
          (at truck9 city8-3)
          (at truck8 city1-1)
          (at truck7 city8-2)
          (at truck6 city9-3)
          (at truck5 city10-2)
          (at truck4 city6-3)
          (at truck3 city11-1)
          (at truck2 city5-3)
          (at truck1 city5-2)
          (at package7 city4-2)
          (at package6 city4-1)
          (at package5 city11-2)
          (at package4 city2-2)
          (at package3 city7-2)
          (at package2 city7-2)
          (at package1 city7-2))
   (:goal (and (at package7 city5-1)
               (at package6 city5-2)
               (at package5 city2-1)
               (at package4 city5-3)
               (at package3 city5-1)
               (at package2 city5-2)
               (at package1 city4-1))))

(define (problem strips-log-x-17)
   (:domain logistics-strips)
   (:objects package15 package14 package13 package12 package11
             package10 package9 package8 package7 package6 package5 package4
             package3 package2 package1 city4 city3 city2 city1 truck45
             truck44 truck43 truck42 truck41 truck40 truck39 truck38
             truck37 truck36 truck35 truck34 truck33 truck32 truck31
             truck30 truck29 truck28 truck27 truck26 truck25 truck24
             truck23 truck22 truck21 truck20 truck19 truck18 truck17
             truck16 truck15 truck14 truck13 truck12 truck11 truck10 truck9
             truck8 truck7 truck6 truck5 truck4 truck3 truck2 truck1 plane5
             plane4 plane3 plane2 plane1 city4-2 city4-1 city3-2 city3-1
             city2-2 city2-1 city1-2 city1-1 city4-3 city3-3 city2-3
             city1-3)
   (:init (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck45)
          (truck truck44)
          (truck truck43)
          (truck truck42)
          (truck truck41)
          (truck truck40)
          (truck truck39)
          (truck truck38)
          (truck truck37)
          (truck truck36)
          (truck truck35)
          (truck truck34)
          (truck truck33)
          (truck truck32)
          (truck truck31)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city4-2)
          (location city4-1)
          (location city3-2)
          (location city3-1)
          (location city2-2)
          (location city2-1)
          (location city1-2)
          (location city1-1)
          (airport city4-3)
          (location city4-3)
          (airport city3-3)
          (location city3-3)
          (airport city2-3)
          (location city2-3)
          (airport city1-3)
          (location city1-3)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane5 city1-3)
          (at plane4 city4-3)
          (at plane3 city4-3)
          (at plane2 city3-3)
          (at plane1 city4-3)
          (at truck45 city4-2)
          (at truck44 city3-2)
          (at truck43 city2-2)
          (at truck42 city1-1)
          (at truck41 city1-3)
          (at truck40 city3-2)
          (at truck39 city2-1)
          (at truck38 city2-3)
          (at truck37 city4-2)
          (at truck36 city3-2)
          (at truck35 city1-1)
          (at truck34 city3-3)
          (at truck33 city3-3)
          (at truck32 city2-1)
          (at truck31 city3-1)
          (at truck30 city3-2)
          (at truck29 city2-2)
          (at truck28 city1-3)
          (at truck27 city4-1)
          (at truck26 city3-2)
          (at truck25 city4-3)
          (at truck24 city2-1)
          (at truck23 city4-1)
          (at truck22 city1-1)
          (at truck21 city3-2)
          (at truck20 city4-3)
          (at truck19 city3-3)
          (at truck18 city1-2)
          (at truck17 city4-2)
          (at truck16 city3-1)
          (at truck15 city3-2)
          (at truck14 city4-3)
          (at truck13 city2-2)
          (at truck12 city2-1)
          (at truck11 city1-1)
          (at truck10 city1-2)
          (at truck9 city1-2)
          (at truck8 city1-1)
          (at truck7 city1-2)
          (at truck6 city2-2)
          (at truck5 city3-1)
          (at truck4 city4-1)
          (at truck3 city1-3)
          (at truck2 city1-3)
          (at truck1 city4-2)
          (at package15 city1-2)
          (at package14 city3-1)
          (at package13 city1-1)
          (at package12 city1-1)
          (at package11 city3-3)
          (at package10 city4-2)
          (at package9 city3-2)
          (at package8 city4-2)
          (at package7 city4-3)
          (at package6 city3-2)
          (at package5 city2-2)
          (at package4 city2-3)
          (at package3 city1-3)
          (at package2 city4-2)
          (at package1 city2-1))
   (:goal (and (at package15 city4-2)
               (at package14 city4-2)
               (at package13 city4-3)
               (at package12 city2-2)
               (at package11 city2-1)
               (at package10 city4-2)
               (at package9 city4-2)
               (at package8 city4-2))))

(define (problem strips-log-x-18)
   (:domain logistics-strips)
   (:objects package20 package19 package18 package17 package16
             package15 package14 package13 package12 package11 package10
             package9 package8 package7 package6 package5 package4 package3
             package2 package1 city30 city29 city28 city27 city26 city25
             city24 city23 city22 city21 city20 city19 city18 city17 city16
             city15 city14 city13 city12 city11 city10 city9 city8 city7
             city6 city5 city4 city3 city2 city1 truck30 truck29 truck28
             truck27 truck26 truck25 truck24 truck23 truck22 truck21
             truck20 truck19 truck18 truck17 truck16 truck15 truck14
             truck13 truck12 truck11 truck10 truck9 truck8 truck7 truck6
             truck5 truck4 truck3 truck2 truck1 plane10 plane9 plane8
             plane7 plane6 plane5 plane4 plane3 plane2 plane1 city30-2
             city30-1 city29-2 city29-1 city28-2 city28-1 city27-2 city27-1
             city26-2 city26-1 city25-2 city25-1 city24-2 city24-1 city23-2
             city23-1 city22-2 city22-1 city21-2 city21-1 city20-2 city20-1
             city19-2 city19-1 city18-2 city18-1 city17-2 city17-1 city16-2
             city16-1 city15-2 city15-1 city14-2 city14-1 city13-2 city13-1
             city12-2 city12-1 city11-2 city11-1 city10-2 city10-1 city9-2
             city9-1 city8-2 city8-1 city7-2 city7-1 city6-2 city6-1
             city5-2 city5-1 city4-2 city4-1 city3-2 city3-1 city2-2
             city2-1 city1-2 city1-1 city30-3 city29-3 city28-3 city27-3
             city26-3 city25-3 city24-3 city23-3 city22-3 city21-3 city20-3
             city19-3 city18-3 city17-3 city16-3 city15-3 city14-3 city13-3
             city12-3 city11-3 city10-3 city9-3 city8-3 city7-3 city6-3
             city5-3 city4-3 city3-3 city2-3 city1-3)
   (:init (obj package20)
          (obj package19)
          (obj package18)
          (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city30)
          (city city29)
          (city city28)
          (city city27)
          (city city26)
          (city city25)
          (city city24)
          (city city23)
          (city city22)
          (city city21)
          (city city20)
          (city city19)
          (city city18)
          (city city17)
          (city city16)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane10)
          (airplane plane9)
          (airplane plane8)
          (airplane plane7)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city30-2)
          (location city30-1)
          (location city29-2)
          (location city29-1)
          (location city28-2)
          (location city28-1)
          (location city27-2)
          (location city27-1)
          (location city26-2)
          (location city26-1)
          (location city25-2)
          (location city25-1)
          (location city24-2)
          (location city24-1)
          (location city23-2)
          (location city23-1)
          (location city22-2)
          (location city22-1)
          (location city21-2)
          (location city21-1)
          (location city20-2)
          (location city20-1)
          (location city19-2)
          (location city19-1)
          (location city18-2)
          (location city18-1)
          (location city17-2)
          (location city17-1)
          (location city16-2)
          (location city16-1)
          (location city15-2)
          (location city15-1)
          (location city14-2)
          (location city14-1)
          (location city13-2)
          (location city13-1)
          (location city12-2)
          (location city12-1)
          (location city11-2)
          (location city11-1)
          (location city10-2)
          (location city10-1)
          (location city9-2)
          (location city9-1)
          (location city8-2)
          (location city8-1)
          (location city7-2)
          (location city7-1)
          (location city6-2)
          (location city6-1)
          (location city5-2)
          (location city5-1)
          (location city4-2)
          (location city4-1)
          (location city3-2)
          (location city3-1)
          (location city2-2)
          (location city2-1)
          (location city1-2)
          (location city1-1)
          (airport city30-3)
          (location city30-3)
          (airport city29-3)
          (location city29-3)
          (airport city28-3)
          (location city28-3)
          (airport city27-3)
          (location city27-3)
          (airport city26-3)
          (location city26-3)
          (airport city25-3)
          (location city25-3)
          (airport city24-3)
          (location city24-3)
          (airport city23-3)
          (location city23-3)
          (airport city22-3)
          (location city22-3)
          (airport city21-3)
          (location city21-3)
          (airport city20-3)
          (location city20-3)
          (airport city19-3)
          (location city19-3)
          (airport city18-3)
          (location city18-3)
          (airport city17-3)
          (location city17-3)
          (airport city16-3)
          (location city16-3)
          (airport city15-3)
          (location city15-3)
          (airport city14-3)
          (location city14-3)
          (airport city13-3)
          (location city13-3)
          (airport city12-3)
          (location city12-3)
          (airport city11-3)
          (location city11-3)
          (airport city10-3)
          (location city10-3)
          (airport city9-3)
          (location city9-3)
          (airport city8-3)
          (location city8-3)
          (airport city7-3)
          (location city7-3)
          (airport city6-3)
          (location city6-3)
          (airport city5-3)
          (location city5-3)
          (airport city4-3)
          (location city4-3)
          (airport city3-3)
          (location city3-3)
          (airport city2-3)
          (location city2-3)
          (airport city1-3)
          (location city1-3)
          (in-city city30-3 city30)
          (in-city city30-2 city30)
          (in-city city30-1 city30)
          (in-city city29-3 city29)
          (in-city city29-2 city29)
          (in-city city29-1 city29)
          (in-city city28-3 city28)
          (in-city city28-2 city28)
          (in-city city28-1 city28)
          (in-city city27-3 city27)
          (in-city city27-2 city27)
          (in-city city27-1 city27)
          (in-city city26-3 city26)
          (in-city city26-2 city26)
          (in-city city26-1 city26)
          (in-city city25-3 city25)
          (in-city city25-2 city25)
          (in-city city25-1 city25)
          (in-city city24-3 city24)
          (in-city city24-2 city24)
          (in-city city24-1 city24)
          (in-city city23-3 city23)
          (in-city city23-2 city23)
          (in-city city23-1 city23)
          (in-city city22-3 city22)
          (in-city city22-2 city22)
          (in-city city22-1 city22)
          (in-city city21-3 city21)
          (in-city city21-2 city21)
          (in-city city21-1 city21)
          (in-city city20-3 city20)
          (in-city city20-2 city20)
          (in-city city20-1 city20)
          (in-city city19-3 city19)
          (in-city city19-2 city19)
          (in-city city19-1 city19)
          (in-city city18-3 city18)
          (in-city city18-2 city18)
          (in-city city18-1 city18)
          (in-city city17-3 city17)
          (in-city city17-2 city17)
          (in-city city17-1 city17)
          (in-city city16-3 city16)
          (in-city city16-2 city16)
          (in-city city16-1 city16)
          (in-city city15-3 city15)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane10 city6-3)
          (at plane9 city10-3)
          (at plane8 city9-3)
          (at plane7 city23-3)
          (at plane6 city15-3)
          (at plane5 city6-3)
          (at plane4 city8-3)
          (at plane3 city28-3)
          (at plane2 city12-3)
          (at plane1 city19-3)
          (at truck30 city30-1)
          (at truck29 city29-2)
          (at truck28 city28-2)
          (at truck27 city27-2)
          (at truck26 city26-2)
          (at truck25 city25-1)
          (at truck24 city24-2)
          (at truck23 city23-2)
          (at truck22 city22-2)
          (at truck21 city21-1)
          (at truck20 city20-1)
          (at truck19 city19-2)
          (at truck18 city18-1)
          (at truck17 city17-1)
          (at truck16 city16-1)
          (at truck15 city15-2)
          (at truck14 city14-1)
          (at truck13 city13-2)
          (at truck12 city12-2)
          (at truck11 city11-1)
          (at truck10 city10-1)
          (at truck9 city9-2)
          (at truck8 city8-2)
          (at truck7 city7-1)
          (at truck6 city6-1)
          (at truck5 city5-2)
          (at truck4 city4-2)
          (at truck3 city3-2)
          (at truck2 city2-1)
          (at truck1 city1-1)
          (at package20 city28-1)
          (at package19 city19-2)
          (at package18 city10-2)
          (at package17 city20-1)
          (at package16 city20-1)
          (at package15 city13-1)
          (at package14 city8-1)
          (at package13 city17-1)
          (at package12 city9-1)
          (at package11 city7-3)
          (at package10 city4-2)
          (at package9 city7-1)
          (at package8 city15-1)
          (at package7 city23-1)
          (at package6 city22-1)
          (at package5 city12-2)
          (at package4 city28-3)
          (at package3 city6-3)
          (at package2 city28-3)
          (at package1 city16-1))
   (:goal (and (at package20 city6-2)
               (at package19 city12-2)
               (at package18 city2-1)
               (at package17 city25-1)
               (at package16 city22-2)
               (at package15 city4-1)
               (at package14 city6-3)
               (at package13 city1-3)
               (at package12 city29-1)
               (at package11 city6-1)
               (at package10 city30-3)
               (at package9 city17-3)
               (at package8 city10-1)
               (at package7 city14-1)
               (at package6 city28-1)
               (at package5 city25-2)
               (at package4 city10-1)
               (at package3 city10-3)
               (at package2 city9-2)
               (at package1 city29-3))))

(define (problem strips-log-x-19)
   (:domain logistics-strips)
   (:objects package19 package18 package17 package16 package15
             package14 package13 package12 package11 package10 package9
             package8 package7 package6 package5 package4 package3 package2
             package1 city8 city7 city6 city5 city4 city3 city2 city1 truck30
             truck29 truck28 truck27 truck26 truck25 truck24 truck23
             truck22 truck21 truck20 truck19 truck18 truck17 truck16
             truck15 truck14 truck13 truck12 truck11 truck10 truck9 truck8
             truck7 truck6 truck5 truck4 truck3 truck2 truck1 plane11
             plane10 plane9 plane8 plane7 plane6 plane5 plane4 plane3 plane2
             plane1 city8-7 city8-6 city8-5 city8-4 city8-3 city8-2
             city8-1 city7-7 city7-6 city7-5 city7-4 city7-3 city7-2
             city7-1 city6-7 city6-6 city6-5 city6-4 city6-3 city6-2
             city6-1 city5-7 city5-6 city5-5 city5-4 city5-3 city5-2
             city5-1 city4-7 city4-6 city4-5 city4-4 city4-3 city4-2
             city4-1 city3-7 city3-6 city3-5 city3-4 city3-3 city3-2
             city3-1 city2-7 city2-6 city2-5 city2-4 city2-3 city2-2
             city2-1 city1-7 city1-6 city1-5 city1-4 city1-3 city1-2
             city1-1 city8-8 city7-8 city6-8 city5-8 city4-8 city3-8
             city2-8 city1-8)
   (:init (obj package19)
          (obj package18)
          (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane11)
          (airplane plane10)
          (airplane plane9)
          (airplane plane8)
          (airplane plane7)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city8-7)
          (location city8-6)
          (location city8-5)
          (location city8-4)
          (location city8-3)
          (location city8-2)
          (location city8-1)
          (location city7-7)
          (location city7-6)
          (location city7-5)
          (location city7-4)
          (location city7-3)
          (location city7-2)
          (location city7-1)
          (location city6-7)
          (location city6-6)
          (location city6-5)
          (location city6-4)
          (location city6-3)
          (location city6-2)
          (location city6-1)
          (location city5-7)
          (location city5-6)
          (location city5-5)
          (location city5-4)
          (location city5-3)
          (location city5-2)
          (location city5-1)
          (location city4-7)
          (location city4-6)
          (location city4-5)
          (location city4-4)
          (location city4-3)
          (location city4-2)
          (location city4-1)
          (location city3-7)
          (location city3-6)
          (location city3-5)
          (location city3-4)
          (location city3-3)
          (location city3-2)
          (location city3-1)
          (location city2-7)
          (location city2-6)
          (location city2-5)
          (location city2-4)
          (location city2-3)
          (location city2-2)
          (location city2-1)
          (location city1-7)
          (location city1-6)
          (location city1-5)
          (location city1-4)
          (location city1-3)
          (location city1-2)
          (location city1-1)
          (airport city8-8)
          (location city8-8)
          (airport city7-8)
          (location city7-8)
          (airport city6-8)
          (location city6-8)
          (airport city5-8)
          (location city5-8)
          (airport city4-8)
          (location city4-8)
          (airport city3-8)
          (location city3-8)
          (airport city2-8)
          (location city2-8)
          (airport city1-8)
          (location city1-8)
          (in-city city8-8 city8)
          (in-city city8-7 city8)
          (in-city city8-6 city8)
          (in-city city8-5 city8)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-8 city7)
          (in-city city7-7 city7)
          (in-city city7-6 city7)
          (in-city city7-5 city7)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-8 city6)
          (in-city city6-7 city6)
          (in-city city6-6 city6)
          (in-city city6-5 city6)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-8 city5)
          (in-city city5-7 city5)
          (in-city city5-6 city5)
          (in-city city5-5 city5)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-8 city4)
          (in-city city4-7 city4)
          (in-city city4-6 city4)
          (in-city city4-5 city4)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-8 city3)
          (in-city city3-7 city3)
          (in-city city3-6 city3)
          (in-city city3-5 city3)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-8 city2)
          (in-city city2-7 city2)
          (in-city city2-6 city2)
          (in-city city2-5 city2)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-8 city1)
          (in-city city1-7 city1)
          (in-city city1-6 city1)
          (in-city city1-5 city1)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane11 city3-8)
          (at plane10 city7-8)
          (at plane9 city3-8)
          (at plane8 city4-8)
          (at plane7 city2-8)
          (at plane6 city1-8)
          (at plane5 city1-8)
          (at plane4 city2-8)
          (at plane3 city3-8)
          (at plane2 city2-8)
          (at plane1 city7-8)
          (at truck30 city8-5)
          (at truck29 city7-3)
          (at truck28 city6-2)
          (at truck27 city5-6)
          (at truck26 city4-3)
          (at truck25 city3-5)
          (at truck24 city2-1)
          (at truck23 city1-7)
          (at truck22 city2-4)
          (at truck21 city3-8)
          (at truck20 city4-7)
          (at truck19 city6-7)
          (at truck18 city7-6)
          (at truck17 city6-6)
          (at truck16 city7-3)
          (at truck15 city1-8)
          (at truck14 city8-8)
          (at truck13 city1-8)
          (at truck12 city5-7)
          (at truck11 city2-6)
          (at truck10 city1-5)
          (at truck9 city2-7)
          (at truck8 city8-5)
          (at truck7 city4-1)
          (at truck6 city3-5)
          (at truck5 city3-8)
          (at truck4 city2-1)
          (at truck3 city3-1)
          (at truck2 city1-8)
          (at truck1 city5-6)
          (at package19 city7-7)
          (at package18 city4-5)
          (at package17 city3-6)
          (at package16 city1-5)
          (at package15 city8-2)
          (at package14 city8-3)
          (at package13 city6-8)
          (at package12 city8-1)
          (at package11 city2-6)
          (at package10 city6-5)
          (at package9 city7-2)
          (at package8 city6-1)
          (at package7 city4-8)
          (at package6 city6-3)
          (at package5 city4-3)
          (at package4 city1-5)
          (at package3 city2-2)
          (at package2 city4-5)
          (at package1 city7-3))
   (:goal (and (at package19 city6-1)
               (at package18 city2-2)
               (at package17 city1-8)
               (at package16 city2-5)
               (at package15 city3-6)
               (at package14 city7-6)
               (at package13 city8-2)
               (at package12 city7-4)
               (at package11 city8-5)
               (at package10 city1-7)
               (at package9 city1-7)
               (at package8 city6-4)
               (at package7 city4-5)
               (at package6 city2-7)
               (at package5 city3-8)
               (at package4 city7-5)
               (at package3 city2-1)
               (at package2 city7-4)
               (at package1 city5-2))))

(define (problem strips-log-x-20)
   (:domain logistics-strips)
   (:objects package16 package15 package14 package13 package12
             package11 package10 package9 package8 package7 package6
             package5 package4 package3 package2 package1 city15 city14
             city13 city12 city11 city10 city9 city8 city7 city6 city5 city4
             city3 city2 city1 truck19 truck18 truck17 truck16 truck15
             truck14 truck13 truck12 truck11 truck10 truck9 truck8 truck7
             truck6 truck5 truck4 truck3 truck2 truck1 plane15 plane14
             plane13 plane12 plane11 plane10 plane9 plane8 plane7 plane6
             plane5 plane4 plane3 plane2 plane1 city15-11 city15-10
             city15-9 city15-8 city15-7 city15-6 city15-5 city15-4 city15-3
             city15-2 city15-1 city14-11 city14-10 city14-9 city14-8
             city14-7 city14-6 city14-5 city14-4 city14-3 city14-2 city14-1
             city13-11 city13-10 city13-9 city13-8 city13-7 city13-6
             city13-5 city13-4 city13-3 city13-2 city13-1 city12-11
             city12-10 city12-9 city12-8 city12-7 city12-6 city12-5 city12-4
             city12-3 city12-2 city12-1 city11-11 city11-10 city11-9
             city11-8 city11-7 city11-6 city11-5 city11-4 city11-3 city11-2
             city11-1 city10-11 city10-10 city10-9 city10-8 city10-7
             city10-6 city10-5 city10-4 city10-3 city10-2 city10-1 city9-11
             city9-10 city9-9 city9-8 city9-7 city9-6 city9-5 city9-4
             city9-3 city9-2 city9-1 city8-11 city8-10 city8-9 city8-8
             city8-7 city8-6 city8-5 city8-4 city8-3 city8-2 city8-1
             city7-11 city7-10 city7-9 city7-8 city7-7 city7-6 city7-5
             city7-4 city7-3 city7-2 city7-1 city6-11 city6-10 city6-9
             city6-8 city6-7 city6-6 city6-5 city6-4 city6-3 city6-2
             city6-1 city5-11 city5-10 city5-9 city5-8 city5-7 city5-6
             city5-5 city5-4 city5-3 city5-2 city5-1 city4-11 city4-10
             city4-9 city4-8 city4-7 city4-6 city4-5 city4-4 city4-3
             city4-2 city4-1 city3-11 city3-10 city3-9 city3-8 city3-7
             city3-6 city3-5 city3-4 city3-3 city3-2 city3-1 city2-11
             city2-10 city2-9 city2-8 city2-7 city2-6 city2-5 city2-4
             city2-3 city2-2 city2-1 city1-11 city1-10 city1-9 city1-8
             city1-7 city1-6 city1-5 city1-4 city1-3 city1-2 city1-1
             city15-12 city14-12 city13-12 city12-12 city11-12 city10-12
             city9-12 city8-12 city7-12 city6-12 city5-12 city4-12 city3-12
             city2-12 city1-12)
   (:init (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane15)
          (airplane plane14)
          (airplane plane13)
          (airplane plane12)
          (airplane plane11)
          (airplane plane10)
          (airplane plane9)
          (airplane plane8)
          (airplane plane7)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city15-11)
          (location city15-10)
          (location city15-9)
          (location city15-8)
          (location city15-7)
          (location city15-6)
          (location city15-5)
          (location city15-4)
          (location city15-3)
          (location city15-2)
          (location city15-1)
          (location city14-11)
          (location city14-10)
          (location city14-9)
          (location city14-8)
          (location city14-7)
          (location city14-6)
          (location city14-5)
          (location city14-4)
          (location city14-3)
          (location city14-2)
          (location city14-1)
          (location city13-11)
          (location city13-10)
          (location city13-9)
          (location city13-8)
          (location city13-7)
          (location city13-6)
          (location city13-5)
          (location city13-4)
          (location city13-3)
          (location city13-2)
          (location city13-1)
          (location city12-11)
          (location city12-10)
          (location city12-9)
          (location city12-8)
          (location city12-7)
          (location city12-6)
          (location city12-5)
          (location city12-4)
          (location city12-3)
          (location city12-2)
          (location city12-1)
          (location city11-11)
          (location city11-10)
          (location city11-9)
          (location city11-8)
          (location city11-7)
          (location city11-6)
          (location city11-5)
          (location city11-4)
          (location city11-3)
          (location city11-2)
          (location city11-1)
          (location city10-11)
          (location city10-10)
          (location city10-9)
          (location city10-8)
          (location city10-7)
          (location city10-6)
          (location city10-5)
          (location city10-4)
          (location city10-3)
          (location city10-2)
          (location city10-1)
          (location city9-11)
          (location city9-10)
          (location city9-9)
          (location city9-8)
          (location city9-7)
          (location city9-6)
          (location city9-5)
          (location city9-4)
          (location city9-3)
          (location city9-2)
          (location city9-1)
          (location city8-11)
          (location city8-10)
          (location city8-9)
          (location city8-8)
          (location city8-7)
          (location city8-6)
          (location city8-5)
          (location city8-4)
          (location city8-3)
          (location city8-2)
          (location city8-1)
          (location city7-11)
          (location city7-10)
          (location city7-9)
          (location city7-8)
          (location city7-7)
          (location city7-6)
          (location city7-5)
          (location city7-4)
          (location city7-3)
          (location city7-2)
          (location city7-1)
          (location city6-11)
          (location city6-10)
          (location city6-9)
          (location city6-8)
          (location city6-7)
          (location city6-6)
          (location city6-5)
          (location city6-4)
          (location city6-3)
          (location city6-2)
          (location city6-1)
          (location city5-11)
          (location city5-10)
          (location city5-9)
          (location city5-8)
          (location city5-7)
          (location city5-6)
          (location city5-5)
          (location city5-4)
          (location city5-3)
          (location city5-2)
          (location city5-1)
          (location city4-11)
          (location city4-10)
          (location city4-9)
          (location city4-8)
          (location city4-7)
          (location city4-6)
          (location city4-5)
          (location city4-4)
          (location city4-3)
          (location city4-2)
          (location city4-1)
          (location city3-11)
          (location city3-10)
          (location city3-9)
          (location city3-8)
          (location city3-7)
          (location city3-6)
          (location city3-5)
          (location city3-4)
          (location city3-3)
          (location city3-2)
          (location city3-1)
          (location city2-11)
          (location city2-10)
          (location city2-9)
          (location city2-8)
          (location city2-7)
          (location city2-6)
          (location city2-5)
          (location city2-4)
          (location city2-3)
          (location city2-2)
          (location city2-1)
          (location city1-11)
          (location city1-10)
          (location city1-9)
          (location city1-8)
          (location city1-7)
          (location city1-6)
          (location city1-5)
          (location city1-4)
          (location city1-3)
          (location city1-2)
          (location city1-1)
          (airport city15-12)
          (location city15-12)
          (airport city14-12)
          (location city14-12)
          (airport city13-12)
          (location city13-12)
          (airport city12-12)
          (location city12-12)
          (airport city11-12)
          (location city11-12)
          (airport city10-12)
          (location city10-12)
          (airport city9-12)
          (location city9-12)
          (airport city8-12)
          (location city8-12)
          (airport city7-12)
          (location city7-12)
          (airport city6-12)
          (location city6-12)
          (airport city5-12)
          (location city5-12)
          (airport city4-12)
          (location city4-12)
          (airport city3-12)
          (location city3-12)
          (airport city2-12)
          (location city2-12)
          (airport city1-12)
          (location city1-12)
          (in-city city15-12 city15)
          (in-city city15-11 city15)
          (in-city city15-10 city15)
          (in-city city15-9 city15)
          (in-city city15-8 city15)
          (in-city city15-7 city15)
          (in-city city15-6 city15)
          (in-city city15-5 city15)
          (in-city city15-4 city15)
          (in-city city15-3 city15)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-12 city14)
          (in-city city14-11 city14)
          (in-city city14-10 city14)
          (in-city city14-9 city14)
          (in-city city14-8 city14)
          (in-city city14-7 city14)
          (in-city city14-6 city14)
          (in-city city14-5 city14)
          (in-city city14-4 city14)
          (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-12 city13)
          (in-city city13-11 city13)
          (in-city city13-10 city13)
          (in-city city13-9 city13)
          (in-city city13-8 city13)
          (in-city city13-7 city13)
          (in-city city13-6 city13)
          (in-city city13-5 city13)
          (in-city city13-4 city13)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-12 city12)
          (in-city city12-11 city12)
          (in-city city12-10 city12)
          (in-city city12-9 city12)
          (in-city city12-8 city12)
          (in-city city12-7 city12)
          (in-city city12-6 city12)
          (in-city city12-5 city12)
          (in-city city12-4 city12)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-12 city11)
          (in-city city11-11 city11)
          (in-city city11-10 city11)
          (in-city city11-9 city11)
          (in-city city11-8 city11)
          (in-city city11-7 city11)
          (in-city city11-6 city11)
          (in-city city11-5 city11)
          (in-city city11-4 city11)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-12 city10)
          (in-city city10-11 city10)
          (in-city city10-10 city10)
          (in-city city10-9 city10)
          (in-city city10-8 city10)
          (in-city city10-7 city10)
          (in-city city10-6 city10)
          (in-city city10-5 city10)
          (in-city city10-4 city10)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-12 city9)
          (in-city city9-11 city9)
          (in-city city9-10 city9)
          (in-city city9-9 city9)
          (in-city city9-8 city9)
          (in-city city9-7 city9)
          (in-city city9-6 city9)
          (in-city city9-5 city9)
          (in-city city9-4 city9)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-12 city8)
          (in-city city8-11 city8)
          (in-city city8-10 city8)
          (in-city city8-9 city8)
          (in-city city8-8 city8)
          (in-city city8-7 city8)
          (in-city city8-6 city8)
          (in-city city8-5 city8)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-12 city7)
          (in-city city7-11 city7)
          (in-city city7-10 city7)
          (in-city city7-9 city7)
          (in-city city7-8 city7)
          (in-city city7-7 city7)
          (in-city city7-6 city7)
          (in-city city7-5 city7)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-12 city6)
          (in-city city6-11 city6)
          (in-city city6-10 city6)
          (in-city city6-9 city6)
          (in-city city6-8 city6)
          (in-city city6-7 city6)
          (in-city city6-6 city6)
          (in-city city6-5 city6)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-12 city5)
          (in-city city5-11 city5)
          (in-city city5-10 city5)
          (in-city city5-9 city5)
          (in-city city5-8 city5)
          (in-city city5-7 city5)
          (in-city city5-6 city5)
          (in-city city5-5 city5)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-12 city4)
          (in-city city4-11 city4)
          (in-city city4-10 city4)
          (in-city city4-9 city4)
          (in-city city4-8 city4)
          (in-city city4-7 city4)
          (in-city city4-6 city4)
          (in-city city4-5 city4)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-12 city3)
          (in-city city3-11 city3)
          (in-city city3-10 city3)
          (in-city city3-9 city3)
          (in-city city3-8 city3)
          (in-city city3-7 city3)
          (in-city city3-6 city3)
          (in-city city3-5 city3)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-12 city2)
          (in-city city2-11 city2)
          (in-city city2-10 city2)
          (in-city city2-9 city2)
          (in-city city2-8 city2)
          (in-city city2-7 city2)
          (in-city city2-6 city2)
          (in-city city2-5 city2)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-12 city1)
          (in-city city1-11 city1)
          (in-city city1-10 city1)
          (in-city city1-9 city1)
          (in-city city1-8 city1)
          (in-city city1-7 city1)
          (in-city city1-6 city1)
          (in-city city1-5 city1)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane15 city5-12)
          (at plane14 city6-12)
          (at plane13 city4-12)
          (at plane12 city7-12)
          (at plane11 city10-12)
          (at plane10 city3-12)
          (at plane9 city9-12)
          (at plane8 city9-12)
          (at plane7 city14-12)
          (at plane6 city8-12)
          (at plane5 city7-12)
          (at plane4 city11-12)
          (at plane3 city11-12)
          (at plane2 city14-12)
          (at plane1 city13-12)
          (at truck19 city15-6)
          (at truck18 city14-5)
          (at truck17 city13-6)
          (at truck16 city12-10)
          (at truck15 city11-5)
          (at truck14 city10-11)
          (at truck13 city9-3)
          (at truck12 city8-7)
          (at truck11 city7-4)
          (at truck10 city6-9)
          (at truck9 city5-11)
          (at truck8 city4-9)
          (at truck7 city3-8)
          (at truck6 city2-11)
          (at truck5 city1-11)
          (at truck4 city4-9)
          (at truck3 city2-9)
          (at truck2 city10-5)
          (at truck1 city6-6)
          (at package16 city1-12)
          (at package15 city3-10)
          (at package14 city9-8)
          (at package13 city5-2)
          (at package12 city15-5)
          (at package11 city13-3)
          (at package10 city2-3)
          (at package9 city10-1)
          (at package8 city4-9)
          (at package7 city3-4)
          (at package6 city9-2)
          (at package5 city8-1)
          (at package4 city7-5)
          (at package3 city12-5)
          (at package2 city9-7)
          (at package1 city12-11))
   (:goal (and (at package16 city9-10)
               (at package15 city5-12)
               (at package14 city10-4)
               (at package13 city3-4)
               (at package12 city10-10)
               (at package11 city7-4)
               (at package10 city8-5)
               (at package9 city4-2)
               (at package8 city15-6)
               (at package7 city4-9)
               (at package6 city5-10)
               (at package5 city8-10)
               (at package4 city3-11)
               (at package3 city3-7)
               (at package2 city9-12)
               (at package1 city10-10))))

(define (problem strips-log-x-21)
   (:domain logistics-strips)
   (:objects package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 city14
             city13 city12 city11 city10 city9 city8 city7 city6 city5 city4
             city3 city2 city1 truck40 truck39 truck38 truck37 truck36
             truck35 truck34 truck33 truck32 truck31 truck30 truck29
             truck28 truck27 truck26 truck25 truck24 truck23 truck22
             truck21 truck20 truck19 truck18 truck17 truck16 truck15
             truck14 truck13 truck12 truck11 truck10 truck9 truck8 truck7
             truck6 truck5 truck4 truck3 truck2 truck1 plane13 plane12
             plane11 plane10 plane9 plane8 plane7 plane6 plane5 plane4
             plane3 plane2 plane1 city14-8 city14-7 city14-6 city14-5
             city14-4 city14-3 city14-2 city14-1 city13-8 city13-7 city13-6
             city13-5 city13-4 city13-3 city13-2 city13-1 city12-8 city12-7
             city12-6 city12-5 city12-4 city12-3 city12-2 city12-1 city11-8
             city11-7 city11-6 city11-5 city11-4 city11-3 city11-2 city11-1
             city10-8 city10-7 city10-6 city10-5 city10-4 city10-3 city10-2
             city10-1 city9-8 city9-7 city9-6 city9-5 city9-4 city9-3
             city9-2 city9-1 city8-8 city8-7 city8-6 city8-5 city8-4
             city8-3 city8-2 city8-1 city7-8 city7-7 city7-6 city7-5
             city7-4 city7-3 city7-2 city7-1 city6-8 city6-7 city6-6
             city6-5 city6-4 city6-3 city6-2 city6-1 city5-8 city5-7
             city5-6 city5-5 city5-4 city5-3 city5-2 city5-1 city4-8
             city4-7 city4-6 city4-5 city4-4 city4-3 city4-2 city4-1
             city3-8 city3-7 city3-6 city3-5 city3-4 city3-3 city3-2
             city3-1 city2-8 city2-7 city2-6 city2-5 city2-4 city2-3
             city2-2 city2-1 city1-8 city1-7 city1-6 city1-5 city1-4
             city1-3 city1-2 city1-1 city14-9 city13-9 city12-9 city11-9
             city10-9 city9-9 city8-9 city7-9 city6-9 city5-9 city4-9
             city3-9 city2-9 city1-9)
   (:init (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck40)
          (truck truck39)
          (truck truck38)
          (truck truck37)
          (truck truck36)
          (truck truck35)
          (truck truck34)
          (truck truck33)
          (truck truck32)
          (truck truck31)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane13)
          (airplane plane12)
          (airplane plane11)
          (airplane plane10)
          (airplane plane9)
          (airplane plane8)
          (airplane plane7)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city14-8)
          (location city14-7)
          (location city14-6)
          (location city14-5)
          (location city14-4)
          (location city14-3)
          (location city14-2)
          (location city14-1)
          (location city13-8)
          (location city13-7)
          (location city13-6)
          (location city13-5)
          (location city13-4)
          (location city13-3)
          (location city13-2)
          (location city13-1)
          (location city12-8)
          (location city12-7)
          (location city12-6)
          (location city12-5)
          (location city12-4)
          (location city12-3)
          (location city12-2)
          (location city12-1)
          (location city11-8)
          (location city11-7)
          (location city11-6)
          (location city11-5)
          (location city11-4)
          (location city11-3)
          (location city11-2)
          (location city11-1)
          (location city10-8)
          (location city10-7)
          (location city10-6)
          (location city10-5)
          (location city10-4)
          (location city10-3)
          (location city10-2)
          (location city10-1)
          (location city9-8)
          (location city9-7)
          (location city9-6)
          (location city9-5)
          (location city9-4)
          (location city9-3)
          (location city9-2)
          (location city9-1)
          (location city8-8)
          (location city8-7)
          (location city8-6)
          (location city8-5)
          (location city8-4)
          (location city8-3)
          (location city8-2)
          (location city8-1)
          (location city7-8)
          (location city7-7)
          (location city7-6)
          (location city7-5)
          (location city7-4)
          (location city7-3)
          (location city7-2)
          (location city7-1)
          (location city6-8)
          (location city6-7)
          (location city6-6)
          (location city6-5)
          (location city6-4)
          (location city6-3)
          (location city6-2)
          (location city6-1)
          (location city5-8)
          (location city5-7)
          (location city5-6)
          (location city5-5)
          (location city5-4)
          (location city5-3)
          (location city5-2)
          (location city5-1)
          (location city4-8)
          (location city4-7)
          (location city4-6)
          (location city4-5)
          (location city4-4)
          (location city4-3)
          (location city4-2)
          (location city4-1)
          (location city3-8)
          (location city3-7)
          (location city3-6)
          (location city3-5)
          (location city3-4)
          (location city3-3)
          (location city3-2)
          (location city3-1)
          (location city2-8)
          (location city2-7)
          (location city2-6)
          (location city2-5)
          (location city2-4)
          (location city2-3)
          (location city2-2)
          (location city2-1)
          (location city1-8)
          (location city1-7)
          (location city1-6)
          (location city1-5)
          (location city1-4)
          (location city1-3)
          (location city1-2)
          (location city1-1)
          (airport city14-9)
          (location city14-9)
          (airport city13-9)
          (location city13-9)
          (airport city12-9)
          (location city12-9)
          (airport city11-9)
          (location city11-9)
          (airport city10-9)
          (location city10-9)
          (airport city9-9)
          (location city9-9)
          (airport city8-9)
          (location city8-9)
          (airport city7-9)
          (location city7-9)
          (airport city6-9)
          (location city6-9)
          (airport city5-9)
          (location city5-9)
          (airport city4-9)
          (location city4-9)
          (airport city3-9)
          (location city3-9)
          (airport city2-9)
          (location city2-9)
          (airport city1-9)
          (location city1-9)
          (in-city city14-9 city14)
          (in-city city14-8 city14)
          (in-city city14-7 city14)
          (in-city city14-6 city14)
          (in-city city14-5 city14)
          (in-city city14-4 city14)
          (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-9 city13)
          (in-city city13-8 city13)
          (in-city city13-7 city13)
          (in-city city13-6 city13)
          (in-city city13-5 city13)
          (in-city city13-4 city13)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-9 city12)
          (in-city city12-8 city12)
          (in-city city12-7 city12)
          (in-city city12-6 city12)
          (in-city city12-5 city12)
          (in-city city12-4 city12)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-9 city11)
          (in-city city11-8 city11)
          (in-city city11-7 city11)
          (in-city city11-6 city11)
          (in-city city11-5 city11)
          (in-city city11-4 city11)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-9 city10)
          (in-city city10-8 city10)
          (in-city city10-7 city10)
          (in-city city10-6 city10)
          (in-city city10-5 city10)
          (in-city city10-4 city10)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-9 city9)
          (in-city city9-8 city9)
          (in-city city9-7 city9)
          (in-city city9-6 city9)
          (in-city city9-5 city9)
          (in-city city9-4 city9)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-9 city8)
          (in-city city8-8 city8)
          (in-city city8-7 city8)
          (in-city city8-6 city8)
          (in-city city8-5 city8)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-9 city7)
          (in-city city7-8 city7)
          (in-city city7-7 city7)
          (in-city city7-6 city7)
          (in-city city7-5 city7)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-9 city6)
          (in-city city6-8 city6)
          (in-city city6-7 city6)
          (in-city city6-6 city6)
          (in-city city6-5 city6)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-9 city5)
          (in-city city5-8 city5)
          (in-city city5-7 city5)
          (in-city city5-6 city5)
          (in-city city5-5 city5)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-9 city4)
          (in-city city4-8 city4)
          (in-city city4-7 city4)
          (in-city city4-6 city4)
          (in-city city4-5 city4)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-9 city3)
          (in-city city3-8 city3)
          (in-city city3-7 city3)
          (in-city city3-6 city3)
          (in-city city3-5 city3)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-9 city2)
          (in-city city2-8 city2)
          (in-city city2-7 city2)
          (in-city city2-6 city2)
          (in-city city2-5 city2)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-9 city1)
          (in-city city1-8 city1)
          (in-city city1-7 city1)
          (in-city city1-6 city1)
          (in-city city1-5 city1)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane13 city8-9)
          (at plane12 city4-9)
          (at plane11 city2-9)
          (at plane10 city5-9)
          (at plane9 city2-9)
          (at plane8 city7-9)
          (at plane7 city5-9)
          (at plane6 city3-9)
          (at plane5 city11-9)
          (at plane4 city7-9)
          (at plane3 city6-9)
          (at plane2 city11-9)
          (at plane1 city2-9)
          (at truck40 city14-3)
          (at truck39 city13-7)
          (at truck38 city12-7)
          (at truck37 city11-5)
          (at truck36 city10-1)
          (at truck35 city9-3)
          (at truck34 city8-8)
          (at truck33 city7-1)
          (at truck32 city6-3)
          (at truck31 city5-7)
          (at truck30 city4-4)
          (at truck29 city3-1)
          (at truck28 city2-7)
          (at truck27 city1-5)
          (at truck26 city4-6)
          (at truck25 city9-1)
          (at truck24 city9-7)
          (at truck23 city4-4)
          (at truck22 city3-3)
          (at truck21 city7-8)
          (at truck20 city2-6)
          (at truck19 city13-3)
          (at truck18 city5-5)
          (at truck17 city4-5)
          (at truck16 city7-1)
          (at truck15 city7-8)
          (at truck14 city4-9)
          (at truck13 city2-1)
          (at truck12 city2-8)
          (at truck11 city6-2)
          (at truck10 city8-3)
          (at truck9 city3-1)
          (at truck8 city11-7)
          (at truck7 city8-5)
          (at truck6 city4-7)
          (at truck5 city1-3)
          (at truck4 city1-3)
          (at truck3 city2-6)
          (at truck2 city2-9)
          (at truck1 city12-9)
          (at package11 city3-8)
          (at package10 city3-1)
          (at package9 city2-5)
          (at package8 city6-6)
          (at package7 city9-8)
          (at package6 city1-6)
          (at package5 city1-1)
          (at package4 city8-8)
          (at package3 city5-8)
          (at package2 city10-1)
          (at package1 city12-1))
   (:goal (and (at package11 city9-8)
               (at package10 city12-9)
               (at package9 city2-3)
               (at package8 city10-7)
               (at package7 city2-2)
               (at package6 city12-6)
               (at package5 city14-8)
               (at package4 city13-2)
               (at package3 city2-8)
               (at package2 city6-2)
               (at package1 city11-6))))

(define (problem strips-log-x-22)
   (:domain logistics-strips)
   (:objects package44 package43 package42 package41 package40
             package39 package38 package37 package36 package35 package34
             package33 package32 package31 package30 package29 package28
             package27 package26 package25 package24 package23 package22
             package21 package20 package19 package18 package17 package16
             package15 package14 package13 package12 package11 package10
             package9 package8 package7 package6 package5 package4 package3
             package2 package1 city30 city29 city28 city27 city26 city25
             city24 city23 city22 city21 city20 city19 city18 city17 city16
             city15 city14 city13 city12 city11 city10 city9 city8 city7
             city6 city5 city4 city3 city2 city1 truck74 truck73 truck72
             truck71 truck70 truck69 truck68 truck67 truck66 truck65
             truck64 truck63 truck62 truck61 truck60 truck59 truck58
             truck57 truck56 truck55 truck54 truck53 truck52 truck51
             truck50 truck49 truck48 truck47 truck46 truck45 truck44
             truck43 truck42 truck41 truck40 truck39 truck38 truck37
             truck36 truck35 truck34 truck33 truck32 truck31 truck30
             truck29 truck28 truck27 truck26 truck25 truck24 truck23
             truck22 truck21 truck20 truck19 truck18 truck17 truck16
             truck15 truck14 truck13 truck12 truck11 truck10 truck9 truck8
             truck7 truck6 truck5 truck4 truck3 truck2 truck1 plane6 plane5
             plane4 plane3 plane2 plane1 city30-3 city30-2 city30-1
             city29-3 city29-2 city29-1 city28-3 city28-2 city28-1 city27-3
             city27-2 city27-1 city26-3 city26-2 city26-1 city25-3 city25-2
             city25-1 city24-3 city24-2 city24-1 city23-3 city23-2 city23-1
             city22-3 city22-2 city22-1 city21-3 city21-2 city21-1 city20-3
             city20-2 city20-1 city19-3 city19-2 city19-1 city18-3 city18-2
             city18-1 city17-3 city17-2 city17-1 city16-3 city16-2 city16-1
             city15-3 city15-2 city15-1 city14-3 city14-2 city14-1 city13-3
             city13-2 city13-1 city12-3 city12-2 city12-1 city11-3 city11-2
             city11-1 city10-3 city10-2 city10-1 city9-3 city9-2 city9-1
             city8-3 city8-2 city8-1 city7-3 city7-2 city7-1 city6-3
             city6-2 city6-1 city5-3 city5-2 city5-1 city4-3 city4-2
             city4-1 city3-3 city3-2 city3-1 city2-3 city2-2 city2-1
             city1-3 city1-2 city1-1 city30-4 city29-4 city28-4 city27-4
             city26-4 city25-4 city24-4 city23-4 city22-4 city21-4 city20-4
             city19-4 city18-4 city17-4 city16-4 city15-4 city14-4 city13-4
             city12-4 city11-4 city10-4 city9-4 city8-4 city7-4 city6-4
             city5-4 city4-4 city3-4 city2-4 city1-4)
   (:init (obj package44)
          (obj package43)
          (obj package42)
          (obj package41)
          (obj package40)
          (obj package39)
          (obj package38)
          (obj package37)
          (obj package36)
          (obj package35)
          (obj package34)
          (obj package33)
          (obj package32)
          (obj package31)
          (obj package30)
          (obj package29)
          (obj package28)
          (obj package27)
          (obj package26)
          (obj package25)
          (obj package24)
          (obj package23)
          (obj package22)
          (obj package21)
          (obj package20)
          (obj package19)
          (obj package18)
          (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city30)
          (city city29)
          (city city28)
          (city city27)
          (city city26)
          (city city25)
          (city city24)
          (city city23)
          (city city22)
          (city city21)
          (city city20)
          (city city19)
          (city city18)
          (city city17)
          (city city16)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck74)
          (truck truck73)
          (truck truck72)
          (truck truck71)
          (truck truck70)
          (truck truck69)
          (truck truck68)
          (truck truck67)
          (truck truck66)
          (truck truck65)
          (truck truck64)
          (truck truck63)
          (truck truck62)
          (truck truck61)
          (truck truck60)
          (truck truck59)
          (truck truck58)
          (truck truck57)
          (truck truck56)
          (truck truck55)
          (truck truck54)
          (truck truck53)
          (truck truck52)
          (truck truck51)
          (truck truck50)
          (truck truck49)
          (truck truck48)
          (truck truck47)
          (truck truck46)
          (truck truck45)
          (truck truck44)
          (truck truck43)
          (truck truck42)
          (truck truck41)
          (truck truck40)
          (truck truck39)
          (truck truck38)
          (truck truck37)
          (truck truck36)
          (truck truck35)
          (truck truck34)
          (truck truck33)
          (truck truck32)
          (truck truck31)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city30-3)
          (location city30-2)
          (location city30-1)
          (location city29-3)
          (location city29-2)
          (location city29-1)
          (location city28-3)
          (location city28-2)
          (location city28-1)
          (location city27-3)
          (location city27-2)
          (location city27-1)
          (location city26-3)
          (location city26-2)
          (location city26-1)
          (location city25-3)
          (location city25-2)
          (location city25-1)
          (location city24-3)
          (location city24-2)
          (location city24-1)
          (location city23-3)
          (location city23-2)
          (location city23-1)
          (location city22-3)
          (location city22-2)
          (location city22-1)
          (location city21-3)
          (location city21-2)
          (location city21-1)
          (location city20-3)
          (location city20-2)
          (location city20-1)
          (location city19-3)
          (location city19-2)
          (location city19-1)
          (location city18-3)
          (location city18-2)
          (location city18-1)
          (location city17-3)
          (location city17-2)
          (location city17-1)
          (location city16-3)
          (location city16-2)
          (location city16-1)
          (location city15-3)
          (location city15-2)
          (location city15-1)
          (location city14-3)
          (location city14-2)
          (location city14-1)
          (location city13-3)
          (location city13-2)
          (location city13-1)
          (location city12-3)
          (location city12-2)
          (location city12-1)
          (location city11-3)
          (location city11-2)
          (location city11-1)
          (location city10-3)
          (location city10-2)
          (location city10-1)
          (location city9-3)
          (location city9-2)
          (location city9-1)
          (location city8-3)
          (location city8-2)
          (location city8-1)
          (location city7-3)
          (location city7-2)
          (location city7-1)
          (location city6-3)
          (location city6-2)
          (location city6-1)
          (location city5-3)
          (location city5-2)
          (location city5-1)
          (location city4-3)
          (location city4-2)
          (location city4-1)
          (location city3-3)
          (location city3-2)
          (location city3-1)
          (location city2-3)
          (location city2-2)
          (location city2-1)
          (location city1-3)
          (location city1-2)
          (location city1-1)
          (airport city30-4)
          (location city30-4)
          (airport city29-4)
          (location city29-4)
          (airport city28-4)
          (location city28-4)
          (airport city27-4)
          (location city27-4)
          (airport city26-4)
          (location city26-4)
          (airport city25-4)
          (location city25-4)
          (airport city24-4)
          (location city24-4)
          (airport city23-4)
          (location city23-4)
          (airport city22-4)
          (location city22-4)
          (airport city21-4)
          (location city21-4)
          (airport city20-4)
          (location city20-4)
          (airport city19-4)
          (location city19-4)
          (airport city18-4)
          (location city18-4)
          (airport city17-4)
          (location city17-4)
          (airport city16-4)
          (location city16-4)
          (airport city15-4)
          (location city15-4)
          (airport city14-4)
          (location city14-4)
          (airport city13-4)
          (location city13-4)
          (airport city12-4)
          (location city12-4)
          (airport city11-4)
          (location city11-4)
          (airport city10-4)
          (location city10-4)
          (airport city9-4)
          (location city9-4)
          (airport city8-4)
          (location city8-4)
          (airport city7-4)
          (location city7-4)
          (airport city6-4)
          (location city6-4)
          (airport city5-4)
          (location city5-4)
          (airport city4-4)
          (location city4-4)
          (airport city3-4)
          (location city3-4)
          (airport city2-4)
          (location city2-4)
          (airport city1-4)
          (location city1-4)
          (in-city city30-4 city30)
          (in-city city30-3 city30)
          (in-city city30-2 city30)
          (in-city city30-1 city30)
          (in-city city29-4 city29)
          (in-city city29-3 city29)
          (in-city city29-2 city29)
          (in-city city29-1 city29)
          (in-city city28-4 city28)
          (in-city city28-3 city28)
          (in-city city28-2 city28)
          (in-city city28-1 city28)
          (in-city city27-4 city27)
          (in-city city27-3 city27)
          (in-city city27-2 city27)
          (in-city city27-1 city27)
          (in-city city26-4 city26)
          (in-city city26-3 city26)
          (in-city city26-2 city26)
          (in-city city26-1 city26)
          (in-city city25-4 city25)
          (in-city city25-3 city25)
          (in-city city25-2 city25)
          (in-city city25-1 city25)
          (in-city city24-4 city24)
          (in-city city24-3 city24)
          (in-city city24-2 city24)
          (in-city city24-1 city24)
          (in-city city23-4 city23)
          (in-city city23-3 city23)
          (in-city city23-2 city23)
          (in-city city23-1 city23)
          (in-city city22-4 city22)
          (in-city city22-3 city22)
          (in-city city22-2 city22)
          (in-city city22-1 city22)
          (in-city city21-4 city21)
          (in-city city21-3 city21)
          (in-city city21-2 city21)
          (in-city city21-1 city21)
          (in-city city20-4 city20)
          (in-city city20-3 city20)
          (in-city city20-2 city20)
          (in-city city20-1 city20)
          (in-city city19-4 city19)
          (in-city city19-3 city19)
          (in-city city19-2 city19)
          (in-city city19-1 city19)
          (in-city city18-4 city18)
          (in-city city18-3 city18)
          (in-city city18-2 city18)
          (in-city city18-1 city18)
          (in-city city17-4 city17)
          (in-city city17-3 city17)
          (in-city city17-2 city17)
          (in-city city17-1 city17)
          (in-city city16-4 city16)
          (in-city city16-3 city16)
          (in-city city16-2 city16)
          (in-city city16-1 city16)
          (in-city city15-4 city15)
          (in-city city15-3 city15)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-4 city14)
          (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-4 city13)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-4 city12)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-4 city11)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-4 city10)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-4 city9)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane6 city11-4)
          (at plane5 city24-4)
          (at plane4 city30-4)
          (at plane3 city9-4)
          (at plane2 city20-4)
          (at plane1 city2-4)
          (at truck74 city30-2)
          (at truck73 city29-2)
          (at truck72 city28-2)
          (at truck71 city27-3)
          (at truck70 city26-1)
          (at truck69 city25-2)
          (at truck68 city24-1)
          (at truck67 city23-3)
          (at truck66 city22-2)
          (at truck65 city21-3)
          (at truck64 city20-1)
          (at truck63 city19-2)
          (at truck62 city18-3)
          (at truck61 city17-1)
          (at truck60 city16-1)
          (at truck59 city15-1)
          (at truck58 city14-2)
          (at truck57 city13-3)
          (at truck56 city12-3)
          (at truck55 city11-2)
          (at truck54 city10-3)
          (at truck53 city9-2)
          (at truck52 city8-3)
          (at truck51 city7-2)
          (at truck50 city6-1)
          (at truck49 city5-1)
          (at truck48 city4-3)
          (at truck47 city3-3)
          (at truck46 city2-3)
          (at truck45 city1-2)
          (at truck44 city7-3)
          (at truck43 city1-4)
          (at truck42 city29-3)
          (at truck41 city9-2)
          (at truck40 city26-2)
          (at truck39 city12-1)
          (at truck38 city28-3)
          (at truck37 city6-4)
          (at truck36 city8-3)
          (at truck35 city14-4)
          (at truck34 city29-4)
          (at truck33 city4-4)
          (at truck32 city17-1)
          (at truck31 city29-1)
          (at truck30 city14-2)
          (at truck29 city9-2)
          (at truck28 city28-1)
          (at truck27 city18-2)
          (at truck26 city17-2)
          (at truck25 city15-4)
          (at truck24 city28-2)
          (at truck23 city7-3)
          (at truck22 city6-2)
          (at truck21 city29-3)
          (at truck20 city18-2)
          (at truck19 city28-3)
          (at truck18 city26-2)
          (at truck17 city1-4)
          (at truck16 city5-1)
          (at truck15 city18-1)
          (at truck14 city29-1)
          (at truck13 city12-4)
          (at truck12 city30-3)
          (at truck11 city7-3)
          (at truck10 city29-1)
          (at truck9 city26-4)
          (at truck8 city2-4)
          (at truck7 city13-1)
          (at truck6 city3-4)
          (at truck5 city8-4)
          (at truck4 city20-4)
          (at truck3 city10-1)
          (at truck2 city10-1)
          (at truck1 city21-2)
          (at package44 city13-1)
          (at package43 city20-2)
          (at package42 city30-4)
          (at package41 city14-4)
          (at package40 city10-3)
          (at package39 city3-3)
          (at package38 city27-3)
          (at package37 city30-3)
          (at package36 city22-1)
          (at package35 city10-3)
          (at package34 city2-4)
          (at package33 city22-2)
          (at package32 city1-4)
          (at package31 city6-3)
          (at package30 city7-3)
          (at package29 city5-3)
          (at package28 city23-2)
          (at package27 city21-3)
          (at package26 city9-4)
          (at package25 city11-2)
          (at package24 city12-3)
          (at package23 city30-2)
          (at package22 city22-1)
          (at package21 city18-2)
          (at package20 city22-1)
          (at package19 city4-1)
          (at package18 city19-2)
          (at package17 city6-4)
          (at package16 city9-1)
          (at package15 city1-1)
          (at package14 city3-2)
          (at package13 city28-2)
          (at package12 city9-3)
          (at package11 city26-2)
          (at package10 city30-2)
          (at package9 city20-3)
          (at package8 city27-4)
          (at package7 city2-2)
          (at package6 city18-3)
          (at package5 city20-1)
          (at package4 city10-3)
          (at package3 city20-1)
          (at package2 city8-2)
          (at package1 city22-1))
   (:goal (and (at package44 city29-3)
               (at package43 city28-3)
               (at package42 city30-3)
               (at package41 city29-3)
               (at package40 city4-2)
               (at package39 city15-3)
               (at package38 city6-4)
               (at package37 city10-1)
               (at package36 city28-2)
               (at package35 city20-2)
               (at package34 city10-4)
               (at package33 city21-2)
               (at package32 city26-4)
               (at package31 city17-4)
               (at package30 city13-4)
               (at package29 city30-4)
               (at package28 city12-3)
               (at package27 city10-1)
               (at package26 city29-2)
               (at package25 city22-1)
               (at package24 city30-3)
               (at package23 city20-3)
               (at package22 city28-4)
               (at package21 city22-2)
               (at package20 city16-2)
               (at package19 city5-3)
               (at package18 city16-2)
               (at package17 city22-2)
               (at package16 city14-4)
               (at package15 city18-3)
               (at package14 city13-2)
               (at package13 city2-3)
               (at package12 city28-1)
               (at package11 city22-2)
               (at package10 city5-4)
               (at package9 city12-3))))

(define (problem strips-log-x-23)
   (:domain logistics-strips)
   (:objects package21 package20 package19 package18 package17
             package16 package15 package14 package13 package12 package11
             package10 package9 package8 package7 package6 package5 package4
             package3 package2 package1 city8 city7 city6 city5 city4 city3
             city2 city1 truck28 truck27 truck26 truck25 truck24 truck23
             truck22 truck21 truck20 truck19 truck18 truck17 truck16
             truck15 truck14 truck13 truck12 truck11 truck10 truck9 truck8
             truck7 truck6 truck5 truck4 truck3 truck2 truck1 plane4 plane3
             plane2 plane1 city8-1 city7-1 city6-1 city5-1 city4-1 city3-1
             city2-1 city1-1 city8-2 city7-2 city6-2 city5-2 city4-2
             city3-2 city2-2 city1-2)
   (:init (obj package21)
          (obj package20)
          (obj package19)
          (obj package18)
          (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city8-1)
          (location city7-1)
          (location city6-1)
          (location city5-1)
          (location city4-1)
          (location city3-1)
          (location city2-1)
          (location city1-1)
          (airport city8-2)
          (location city8-2)
          (airport city7-2)
          (location city7-2)
          (airport city6-2)
          (location city6-2)
          (airport city5-2)
          (location city5-2)
          (airport city4-2)
          (location city4-2)
          (airport city3-2)
          (location city3-2)
          (airport city2-2)
          (location city2-2)
          (airport city1-2)
          (location city1-2)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane4 city5-2)
          (at plane3 city7-2)
          (at plane2 city3-2)
          (at plane1 city1-2)
          (at truck28 city8-1)
          (at truck27 city7-1)
          (at truck26 city6-1)
          (at truck25 city5-1)
          (at truck24 city4-1)
          (at truck23 city3-1)
          (at truck22 city2-1)
          (at truck21 city1-1)
          (at truck20 city2-2)
          (at truck19 city1-1)
          (at truck18 city2-1)
          (at truck17 city7-1)
          (at truck16 city2-2)
          (at truck15 city3-1)
          (at truck14 city5-2)
          (at truck13 city5-1)
          (at truck12 city5-2)
          (at truck11 city6-2)
          (at truck10 city2-2)
          (at truck9 city2-2)
          (at truck8 city1-1)
          (at truck7 city1-1)
          (at truck6 city4-1)
          (at truck5 city6-2)
          (at truck4 city4-1)
          (at truck3 city4-1)
          (at truck2 city2-1)
          (at truck1 city5-2)
          (at package21 city3-1)
          (at package20 city3-1)
          (at package19 city8-1)
          (at package18 city5-1)
          (at package17 city1-2)
          (at package16 city6-1)
          (at package15 city7-2)
          (at package14 city4-2)
          (at package13 city1-1)
          (at package12 city1-2)
          (at package11 city1-2)
          (at package10 city1-2)
          (at package9 city1-1)
          (at package8 city6-1)
          (at package7 city1-1)
          (at package6 city7-1)
          (at package5 city3-1)
          (at package4 city3-2)
          (at package3 city3-1)
          (at package2 city1-2)
          (at package1 city1-1))
   (:goal (and (at package21 city5-2)
               (at package20 city2-2)
               (at package19 city2-1)
               (at package18 city2-2)
               (at package17 city6-1)
               (at package16 city1-1)
               (at package15 city3-2)
               (at package14 city3-1)
               (at package13 city6-1)
               (at package12 city8-1)
               (at package11 city1-2)
               (at package10 city4-1)
               (at package9 city7-1)
               (at package8 city2-1)
               (at package7 city3-2)
               (at package6 city2-2)
               (at package5 city8-2)
               (at package4 city8-2)
               (at package3 city1-2)
               (at package2 city6-2)
               (at package1 city8-2))))

(define (problem strips-log-x-24)
   (:domain logistics-strips)
   (:objects package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 city9
             city8 city7 city6 city5 city4 city3 city2 city1 truck54
             truck53 truck52 truck51 truck50 truck49 truck48 truck47
             truck46 truck45 truck44 truck43 truck42 truck41 truck40
             truck39 truck38 truck37 truck36 truck35 truck34 truck33
             truck32 truck31 truck30 truck29 truck28 truck27 truck26
             truck25 truck24 truck23 truck22 truck21 truck20 truck19
             truck18 truck17 truck16 truck15 truck14 truck13 truck12
             truck11 truck10 truck9 truck8 truck7 truck6 truck5 truck4
             truck3 truck2 truck1 plane8 plane7 plane6 plane5 plane4 plane3
             plane2 plane1 city9-11 city9-10 city9-9 city9-8 city9-7
             city9-6 city9-5 city9-4 city9-3 city9-2 city9-1 city8-11
             city8-10 city8-9 city8-8 city8-7 city8-6 city8-5 city8-4
             city8-3 city8-2 city8-1 city7-11 city7-10 city7-9 city7-8
             city7-7 city7-6 city7-5 city7-4 city7-3 city7-2 city7-1
             city6-11 city6-10 city6-9 city6-8 city6-7 city6-6 city6-5
             city6-4 city6-3 city6-2 city6-1 city5-11 city5-10 city5-9
             city5-8 city5-7 city5-6 city5-5 city5-4 city5-3 city5-2
             city5-1 city4-11 city4-10 city4-9 city4-8 city4-7 city4-6
             city4-5 city4-4 city4-3 city4-2 city4-1 city3-11 city3-10
             city3-9 city3-8 city3-7 city3-6 city3-5 city3-4 city3-3
             city3-2 city3-1 city2-11 city2-10 city2-9 city2-8 city2-7
             city2-6 city2-5 city2-4 city2-3 city2-2 city2-1 city1-11
             city1-10 city1-9 city1-8 city1-7 city1-6 city1-5 city1-4
             city1-3 city1-2 city1-1 city9-12 city8-12 city7-12 city6-12
             city5-12 city4-12 city3-12 city2-12 city1-12)
   (:init (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck54)
          (truck truck53)
          (truck truck52)
          (truck truck51)
          (truck truck50)
          (truck truck49)
          (truck truck48)
          (truck truck47)
          (truck truck46)
          (truck truck45)
          (truck truck44)
          (truck truck43)
          (truck truck42)
          (truck truck41)
          (truck truck40)
          (truck truck39)
          (truck truck38)
          (truck truck37)
          (truck truck36)
          (truck truck35)
          (truck truck34)
          (truck truck33)
          (truck truck32)
          (truck truck31)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane8)
          (airplane plane7)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city9-11)
          (location city9-10)
          (location city9-9)
          (location city9-8)
          (location city9-7)
          (location city9-6)
          (location city9-5)
          (location city9-4)
          (location city9-3)
          (location city9-2)
          (location city9-1)
          (location city8-11)
          (location city8-10)
          (location city8-9)
          (location city8-8)
          (location city8-7)
          (location city8-6)
          (location city8-5)
          (location city8-4)
          (location city8-3)
          (location city8-2)
          (location city8-1)
          (location city7-11)
          (location city7-10)
          (location city7-9)
          (location city7-8)
          (location city7-7)
          (location city7-6)
          (location city7-5)
          (location city7-4)
          (location city7-3)
          (location city7-2)
          (location city7-1)
          (location city6-11)
          (location city6-10)
          (location city6-9)
          (location city6-8)
          (location city6-7)
          (location city6-6)
          (location city6-5)
          (location city6-4)
          (location city6-3)
          (location city6-2)
          (location city6-1)
          (location city5-11)
          (location city5-10)
          (location city5-9)
          (location city5-8)
          (location city5-7)
          (location city5-6)
          (location city5-5)
          (location city5-4)
          (location city5-3)
          (location city5-2)
          (location city5-1)
          (location city4-11)
          (location city4-10)
          (location city4-9)
          (location city4-8)
          (location city4-7)
          (location city4-6)
          (location city4-5)
          (location city4-4)
          (location city4-3)
          (location city4-2)
          (location city4-1)
          (location city3-11)
          (location city3-10)
          (location city3-9)
          (location city3-8)
          (location city3-7)
          (location city3-6)
          (location city3-5)
          (location city3-4)
          (location city3-3)
          (location city3-2)
          (location city3-1)
          (location city2-11)
          (location city2-10)
          (location city2-9)
          (location city2-8)
          (location city2-7)
          (location city2-6)
          (location city2-5)
          (location city2-4)
          (location city2-3)
          (location city2-2)
          (location city2-1)
          (location city1-11)
          (location city1-10)
          (location city1-9)
          (location city1-8)
          (location city1-7)
          (location city1-6)
          (location city1-5)
          (location city1-4)
          (location city1-3)
          (location city1-2)
          (location city1-1)
          (airport city9-12)
          (location city9-12)
          (airport city8-12)
          (location city8-12)
          (airport city7-12)
          (location city7-12)
          (airport city6-12)
          (location city6-12)
          (airport city5-12)
          (location city5-12)
          (airport city4-12)
          (location city4-12)
          (airport city3-12)
          (location city3-12)
          (airport city2-12)
          (location city2-12)
          (airport city1-12)
          (location city1-12)
          (in-city city9-12 city9)
          (in-city city9-11 city9)
          (in-city city9-10 city9)
          (in-city city9-9 city9)
          (in-city city9-8 city9)
          (in-city city9-7 city9)
          (in-city city9-6 city9)
          (in-city city9-5 city9)
          (in-city city9-4 city9)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-12 city8)
          (in-city city8-11 city8)
          (in-city city8-10 city8)
          (in-city city8-9 city8)
          (in-city city8-8 city8)
          (in-city city8-7 city8)
          (in-city city8-6 city8)
          (in-city city8-5 city8)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-12 city7)
          (in-city city7-11 city7)
          (in-city city7-10 city7)
          (in-city city7-9 city7)
          (in-city city7-8 city7)
          (in-city city7-7 city7)
          (in-city city7-6 city7)
          (in-city city7-5 city7)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-12 city6)
          (in-city city6-11 city6)
          (in-city city6-10 city6)
          (in-city city6-9 city6)
          (in-city city6-8 city6)
          (in-city city6-7 city6)
          (in-city city6-6 city6)
          (in-city city6-5 city6)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-12 city5)
          (in-city city5-11 city5)
          (in-city city5-10 city5)
          (in-city city5-9 city5)
          (in-city city5-8 city5)
          (in-city city5-7 city5)
          (in-city city5-6 city5)
          (in-city city5-5 city5)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-12 city4)
          (in-city city4-11 city4)
          (in-city city4-10 city4)
          (in-city city4-9 city4)
          (in-city city4-8 city4)
          (in-city city4-7 city4)
          (in-city city4-6 city4)
          (in-city city4-5 city4)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-12 city3)
          (in-city city3-11 city3)
          (in-city city3-10 city3)
          (in-city city3-9 city3)
          (in-city city3-8 city3)
          (in-city city3-7 city3)
          (in-city city3-6 city3)
          (in-city city3-5 city3)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-12 city2)
          (in-city city2-11 city2)
          (in-city city2-10 city2)
          (in-city city2-9 city2)
          (in-city city2-8 city2)
          (in-city city2-7 city2)
          (in-city city2-6 city2)
          (in-city city2-5 city2)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-12 city1)
          (in-city city1-11 city1)
          (in-city city1-10 city1)
          (in-city city1-9 city1)
          (in-city city1-8 city1)
          (in-city city1-7 city1)
          (in-city city1-6 city1)
          (in-city city1-5 city1)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane8 city6-12)
          (at plane7 city6-12)
          (at plane6 city9-12)
          (at plane5 city3-12)
          (at plane4 city9-12)
          (at plane3 city2-12)
          (at plane2 city7-12)
          (at plane1 city6-12)
          (at truck54 city9-4)
          (at truck53 city8-5)
          (at truck52 city7-11)
          (at truck51 city6-1)
          (at truck50 city5-4)
          (at truck49 city4-5)
          (at truck48 city3-2)
          (at truck47 city2-8)
          (at truck46 city1-9)
          (at truck45 city5-4)
          (at truck44 city7-6)
          (at truck43 city8-5)
          (at truck42 city3-2)
          (at truck41 city6-8)
          (at truck40 city2-3)
          (at truck39 city2-10)
          (at truck38 city2-12)
          (at truck37 city2-5)
          (at truck36 city5-7)
          (at truck35 city1-3)
          (at truck34 city1-11)
          (at truck33 city6-10)
          (at truck32 city1-2)
          (at truck31 city3-3)
          (at truck30 city5-12)
          (at truck29 city2-4)
          (at truck28 city3-3)
          (at truck27 city2-3)
          (at truck26 city3-3)
          (at truck25 city4-1)
          (at truck24 city1-12)
          (at truck23 city1-1)
          (at truck22 city7-11)
          (at truck21 city4-5)
          (at truck20 city8-6)
          (at truck19 city1-4)
          (at truck18 city4-7)
          (at truck17 city4-10)
          (at truck16 city1-11)
          (at truck15 city9-7)
          (at truck14 city3-3)
          (at truck13 city1-4)
          (at truck12 city4-8)
          (at truck11 city8-9)
          (at truck10 city6-7)
          (at truck9 city6-10)
          (at truck8 city1-1)
          (at truck7 city4-3)
          (at truck6 city4-5)
          (at truck5 city4-5)
          (at truck4 city9-8)
          (at truck3 city4-8)
          (at truck2 city1-5)
          (at truck1 city9-7)
          (at package11 city5-4)
          (at package10 city2-5)
          (at package9 city6-5)
          (at package8 city1-5)
          (at package7 city3-9)
          (at package6 city6-9)
          (at package5 city4-12)
          (at package4 city7-1)
          (at package3 city6-6)
          (at package2 city2-7)
          (at package1 city8-1))
   (:goal (and (at package11 city8-8)
               (at package10 city3-2)
               (at package9 city1-11)
               (at package8 city3-4))))

(define (problem strips-log-x-25)
   (:domain logistics-strips)
   (:objects package18 package17 package16 package15 package14
             package13 package12 package11 package10 package9 package8
             package7 package6 package5 package4 package3 package2 package1
             city27 city26 city25 city24 city23 city22 city21 city20 city19
             city18 city17 city16 city15 city14 city13 city12 city11 city10
             city9 city8 city7 city6 city5 city4 city3 city2 city1 truck29
             truck28 truck27 truck26 truck25 truck24 truck23 truck22
             truck21 truck20 truck19 truck18 truck17 truck16 truck15
             truck14 truck13 truck12 truck11 truck10 truck9 truck8 truck7
             truck6 truck5 truck4 truck3 truck2 truck1 plane13 plane12
             plane11 plane10 plane9 plane8 plane7 plane6 plane5 plane4
             plane3 plane2 plane1 city27-12 city27-11 city27-10 city27-9
             city27-8 city27-7 city27-6 city27-5 city27-4 city27-3 city27-2
             city27-1 city26-12 city26-11 city26-10 city26-9 city26-8
             city26-7 city26-6 city26-5 city26-4 city26-3 city26-2 city26-1
             city25-12 city25-11 city25-10 city25-9 city25-8 city25-7
             city25-6 city25-5 city25-4 city25-3 city25-2 city25-1
             city24-12 city24-11 city24-10 city24-9 city24-8 city24-7
             city24-6 city24-5 city24-4 city24-3 city24-2 city24-1
             city23-12 city23-11 city23-10 city23-9 city23-8 city23-7
             city23-6 city23-5 city23-4 city23-3 city23-2 city23-1
             city22-12 city22-11 city22-10 city22-9 city22-8 city22-7
             city22-6 city22-5 city22-4 city22-3 city22-2 city22-1
             city21-12 city21-11 city21-10 city21-9 city21-8 city21-7
             city21-6 city21-5 city21-4 city21-3 city21-2 city21-1
             city20-12 city20-11 city20-10 city20-9 city20-8 city20-7
             city20-6 city20-5 city20-4 city20-3 city20-2 city20-1
             city19-12 city19-11 city19-10 city19-9 city19-8 city19-7
             city19-6 city19-5 city19-4 city19-3 city19-2 city19-1
             city18-12 city18-11 city18-10 city18-9 city18-8 city18-7
             city18-6 city18-5 city18-4 city18-3 city18-2 city18-1
             city17-12 city17-11 city17-10 city17-9 city17-8 city17-7
             city17-6 city17-5 city17-4 city17-3 city17-2 city17-1
             city16-12 city16-11 city16-10 city16-9 city16-8 city16-7
             city16-6 city16-5 city16-4 city16-3 city16-2 city16-1
             city15-12 city15-11 city15-10 city15-9 city15-8 city15-7
             city15-6 city15-5 city15-4 city15-3 city15-2 city15-1
             city14-12 city14-11 city14-10 city14-9 city14-8 city14-7
             city14-6 city14-5 city14-4 city14-3 city14-2 city14-1
             city13-12 city13-11 city13-10 city13-9 city13-8 city13-7
             city13-6 city13-5 city13-4 city13-3 city13-2 city13-1
             city12-12 city12-11 city12-10 city12-9 city12-8 city12-7
             city12-6 city12-5 city12-4 city12-3 city12-2 city12-1
             city11-12 city11-11 city11-10 city11-9 city11-8 city11-7
             city11-6 city11-5 city11-4 city11-3 city11-2 city11-1
             city10-12 city10-11 city10-10 city10-9 city10-8 city10-7
             city10-6 city10-5 city10-4 city10-3 city10-2 city10-1 city9-12
             city9-11 city9-10 city9-9 city9-8 city9-7 city9-6 city9-5
             city9-4 city9-3 city9-2 city9-1 city8-12 city8-11 city8-10
             city8-9 city8-8 city8-7 city8-6 city8-5 city8-4 city8-3
             city8-2 city8-1 city7-12 city7-11 city7-10 city7-9 city7-8
             city7-7 city7-6 city7-5 city7-4 city7-3 city7-2 city7-1
             city6-12 city6-11 city6-10 city6-9 city6-8 city6-7 city6-6
             city6-5 city6-4 city6-3 city6-2 city6-1 city5-12 city5-11
             city5-10 city5-9 city5-8 city5-7 city5-6 city5-5 city5-4
             city5-3 city5-2 city5-1 city4-12 city4-11 city4-10 city4-9
             city4-8 city4-7 city4-6 city4-5 city4-4 city4-3 city4-2
             city4-1 city3-12 city3-11 city3-10 city3-9 city3-8 city3-7
             city3-6 city3-5 city3-4 city3-3 city3-2 city3-1 city2-12
             city2-11 city2-10 city2-9 city2-8 city2-7 city2-6 city2-5
             city2-4 city2-3 city2-2 city2-1 city1-12 city1-11 city1-10
             city1-9 city1-8 city1-7 city1-6 city1-5 city1-4 city1-3
             city1-2 city1-1 city27-13 city26-13 city25-13 city24-13
             city23-13 city22-13 city21-13 city20-13 city19-13 city18-13
             city17-13 city16-13 city15-13 city14-13 city13-13 city12-13
             city11-13 city10-13 city9-13 city8-13 city7-13 city6-13
             city5-13 city4-13 city3-13 city2-13 city1-13)
   (:init (obj package18)
          (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city27)
          (city city26)
          (city city25)
          (city city24)
          (city city23)
          (city city22)
          (city city21)
          (city city20)
          (city city19)
          (city city18)
          (city city17)
          (city city16)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane13)
          (airplane plane12)
          (airplane plane11)
          (airplane plane10)
          (airplane plane9)
          (airplane plane8)
          (airplane plane7)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city27-12)
          (location city27-11)
          (location city27-10)
          (location city27-9)
          (location city27-8)
          (location city27-7)
          (location city27-6)
          (location city27-5)
          (location city27-4)
          (location city27-3)
          (location city27-2)
          (location city27-1)
          (location city26-12)
          (location city26-11)
          (location city26-10)
          (location city26-9)
          (location city26-8)
          (location city26-7)
          (location city26-6)
          (location city26-5)
          (location city26-4)
          (location city26-3)
          (location city26-2)
          (location city26-1)
          (location city25-12)
          (location city25-11)
          (location city25-10)
          (location city25-9)
          (location city25-8)
          (location city25-7)
          (location city25-6)
          (location city25-5)
          (location city25-4)
          (location city25-3)
          (location city25-2)
          (location city25-1)
          (location city24-12)
          (location city24-11)
          (location city24-10)
          (location city24-9)
          (location city24-8)
          (location city24-7)
          (location city24-6)
          (location city24-5)
          (location city24-4)
          (location city24-3)
          (location city24-2)
          (location city24-1)
          (location city23-12)
          (location city23-11)
          (location city23-10)
          (location city23-9)
          (location city23-8)
          (location city23-7)
          (location city23-6)
          (location city23-5)
          (location city23-4)
          (location city23-3)
          (location city23-2)
          (location city23-1)
          (location city22-12)
          (location city22-11)
          (location city22-10)
          (location city22-9)
          (location city22-8)
          (location city22-7)
          (location city22-6)
          (location city22-5)
          (location city22-4)
          (location city22-3)
          (location city22-2)
          (location city22-1)
          (location city21-12)
          (location city21-11)
          (location city21-10)
          (location city21-9)
          (location city21-8)
          (location city21-7)
          (location city21-6)
          (location city21-5)
          (location city21-4)
          (location city21-3)
          (location city21-2)
          (location city21-1)
          (location city20-12)
          (location city20-11)
          (location city20-10)
          (location city20-9)
          (location city20-8)
          (location city20-7)
          (location city20-6)
          (location city20-5)
          (location city20-4)
          (location city20-3)
          (location city20-2)
          (location city20-1)
          (location city19-12)
          (location city19-11)
          (location city19-10)
          (location city19-9)
          (location city19-8)
          (location city19-7)
          (location city19-6)
          (location city19-5)
          (location city19-4)
          (location city19-3)
          (location city19-2)
          (location city19-1)
          (location city18-12)
          (location city18-11)
          (location city18-10)
          (location city18-9)
          (location city18-8)
          (location city18-7)
          (location city18-6)
          (location city18-5)
          (location city18-4)
          (location city18-3)
          (location city18-2)
          (location city18-1)
          (location city17-12)
          (location city17-11)
          (location city17-10)
          (location city17-9)
          (location city17-8)
          (location city17-7)
          (location city17-6)
          (location city17-5)
          (location city17-4)
          (location city17-3)
          (location city17-2)
          (location city17-1)
          (location city16-12)
          (location city16-11)
          (location city16-10)
          (location city16-9)
          (location city16-8)
          (location city16-7)
          (location city16-6)
          (location city16-5)
          (location city16-4)
          (location city16-3)
          (location city16-2)
          (location city16-1)
          (location city15-12)
          (location city15-11)
          (location city15-10)
          (location city15-9)
          (location city15-8)
          (location city15-7)
          (location city15-6)
          (location city15-5)
          (location city15-4)
          (location city15-3)
          (location city15-2)
          (location city15-1)
          (location city14-12)
          (location city14-11)
          (location city14-10)
          (location city14-9)
          (location city14-8)
          (location city14-7)
          (location city14-6)
          (location city14-5)
          (location city14-4)
          (location city14-3)
          (location city14-2)
          (location city14-1)
          (location city13-12)
          (location city13-11)
          (location city13-10)
          (location city13-9)
          (location city13-8)
          (location city13-7)
          (location city13-6)
          (location city13-5)
          (location city13-4)
          (location city13-3)
          (location city13-2)
          (location city13-1)
          (location city12-12)
          (location city12-11)
          (location city12-10)
          (location city12-9)
          (location city12-8)
          (location city12-7)
          (location city12-6)
          (location city12-5)
          (location city12-4)
          (location city12-3)
          (location city12-2)
          (location city12-1)
          (location city11-12)
          (location city11-11)
          (location city11-10)
          (location city11-9)
          (location city11-8)
          (location city11-7)
          (location city11-6)
          (location city11-5)
          (location city11-4)
          (location city11-3)
          (location city11-2)
          (location city11-1)
          (location city10-12)
          (location city10-11)
          (location city10-10)
          (location city10-9)
          (location city10-8)
          (location city10-7)
          (location city10-6)
          (location city10-5)
          (location city10-4)
          (location city10-3)
          (location city10-2)
          (location city10-1)
          (location city9-12)
          (location city9-11)
          (location city9-10)
          (location city9-9)
          (location city9-8)
          (location city9-7)
          (location city9-6)
          (location city9-5)
          (location city9-4)
          (location city9-3)
          (location city9-2)
          (location city9-1)
          (location city8-12)
          (location city8-11)
          (location city8-10)
          (location city8-9)
          (location city8-8)
          (location city8-7)
          (location city8-6)
          (location city8-5)
          (location city8-4)
          (location city8-3)
          (location city8-2)
          (location city8-1)
          (location city7-12)
          (location city7-11)
          (location city7-10)
          (location city7-9)
          (location city7-8)
          (location city7-7)
          (location city7-6)
          (location city7-5)
          (location city7-4)
          (location city7-3)
          (location city7-2)
          (location city7-1)
          (location city6-12)
          (location city6-11)
          (location city6-10)
          (location city6-9)
          (location city6-8)
          (location city6-7)
          (location city6-6)
          (location city6-5)
          (location city6-4)
          (location city6-3)
          (location city6-2)
          (location city6-1)
          (location city5-12)
          (location city5-11)
          (location city5-10)
          (location city5-9)
          (location city5-8)
          (location city5-7)
          (location city5-6)
          (location city5-5)
          (location city5-4)
          (location city5-3)
          (location city5-2)
          (location city5-1)
          (location city4-12)
          (location city4-11)
          (location city4-10)
          (location city4-9)
          (location city4-8)
          (location city4-7)
          (location city4-6)
          (location city4-5)
          (location city4-4)
          (location city4-3)
          (location city4-2)
          (location city4-1)
          (location city3-12)
          (location city3-11)
          (location city3-10)
          (location city3-9)
          (location city3-8)
          (location city3-7)
          (location city3-6)
          (location city3-5)
          (location city3-4)
          (location city3-3)
          (location city3-2)
          (location city3-1)
          (location city2-12)
          (location city2-11)
          (location city2-10)
          (location city2-9)
          (location city2-8)
          (location city2-7)
          (location city2-6)
          (location city2-5)
          (location city2-4)
          (location city2-3)
          (location city2-2)
          (location city2-1)
          (location city1-12)
          (location city1-11)
          (location city1-10)
          (location city1-9)
          (location city1-8)
          (location city1-7)
          (location city1-6)
          (location city1-5)
          (location city1-4)
          (location city1-3)
          (location city1-2)
          (location city1-1)
          (airport city27-13)
          (location city27-13)
          (airport city26-13)
          (location city26-13)
          (airport city25-13)
          (location city25-13)
          (airport city24-13)
          (location city24-13)
          (airport city23-13)
          (location city23-13)
          (airport city22-13)
          (location city22-13)
          (airport city21-13)
          (location city21-13)
          (airport city20-13)
          (location city20-13)
          (airport city19-13)
          (location city19-13)
          (airport city18-13)
          (location city18-13)
          (airport city17-13)
          (location city17-13)
          (airport city16-13)
          (location city16-13)
          (airport city15-13)
          (location city15-13)
          (airport city14-13)
          (location city14-13)
          (airport city13-13)
          (location city13-13)
          (airport city12-13)
          (location city12-13)
          (airport city11-13)
          (location city11-13)
          (airport city10-13)
          (location city10-13)
          (airport city9-13)
          (location city9-13)
          (airport city8-13)
          (location city8-13)
          (airport city7-13)
          (location city7-13)
          (airport city6-13)
          (location city6-13)
          (airport city5-13)
          (location city5-13)
          (airport city4-13)
          (location city4-13)
          (airport city3-13)
          (location city3-13)
          (airport city2-13)
          (location city2-13)
          (airport city1-13)
          (location city1-13)
          (in-city city27-13 city27)
          (in-city city27-12 city27)
          (in-city city27-11 city27)
          (in-city city27-10 city27)
          (in-city city27-9 city27)
          (in-city city27-8 city27)
          (in-city city27-7 city27)
          (in-city city27-6 city27)
          (in-city city27-5 city27)
          (in-city city27-4 city27)
          (in-city city27-3 city27)
          (in-city city27-2 city27)
          (in-city city27-1 city27)
          (in-city city26-13 city26)
          (in-city city26-12 city26)
          (in-city city26-11 city26)
          (in-city city26-10 city26)
          (in-city city26-9 city26)
          (in-city city26-8 city26)
          (in-city city26-7 city26)
          (in-city city26-6 city26)
          (in-city city26-5 city26)
          (in-city city26-4 city26)
          (in-city city26-3 city26)
          (in-city city26-2 city26)
          (in-city city26-1 city26)
          (in-city city25-13 city25)
          (in-city city25-12 city25)
          (in-city city25-11 city25)
          (in-city city25-10 city25)
          (in-city city25-9 city25)
          (in-city city25-8 city25)
          (in-city city25-7 city25)
          (in-city city25-6 city25)
          (in-city city25-5 city25)
          (in-city city25-4 city25)
          (in-city city25-3 city25)
          (in-city city25-2 city25)
          (in-city city25-1 city25)
          (in-city city24-13 city24)
          (in-city city24-12 city24)
          (in-city city24-11 city24)
          (in-city city24-10 city24)
          (in-city city24-9 city24)
          (in-city city24-8 city24)
          (in-city city24-7 city24)
          (in-city city24-6 city24)
          (in-city city24-5 city24)
          (in-city city24-4 city24)
          (in-city city24-3 city24)
          (in-city city24-2 city24)
          (in-city city24-1 city24)
          (in-city city23-13 city23)
          (in-city city23-12 city23)
          (in-city city23-11 city23)
          (in-city city23-10 city23)
          (in-city city23-9 city23)
          (in-city city23-8 city23)
          (in-city city23-7 city23)
          (in-city city23-6 city23)
          (in-city city23-5 city23)
          (in-city city23-4 city23)
          (in-city city23-3 city23)
          (in-city city23-2 city23)
          (in-city city23-1 city23)
          (in-city city22-13 city22)
          (in-city city22-12 city22)
          (in-city city22-11 city22)
          (in-city city22-10 city22)
          (in-city city22-9 city22)
          (in-city city22-8 city22)
          (in-city city22-7 city22)
          (in-city city22-6 city22)
          (in-city city22-5 city22)
          (in-city city22-4 city22)
          (in-city city22-3 city22)
          (in-city city22-2 city22)
          (in-city city22-1 city22)
          (in-city city21-13 city21)
          (in-city city21-12 city21)
          (in-city city21-11 city21)
          (in-city city21-10 city21)
          (in-city city21-9 city21)
          (in-city city21-8 city21)
          (in-city city21-7 city21)
          (in-city city21-6 city21)
          (in-city city21-5 city21)
          (in-city city21-4 city21)
          (in-city city21-3 city21)
          (in-city city21-2 city21)
          (in-city city21-1 city21)
          (in-city city20-13 city20)
          (in-city city20-12 city20)
          (in-city city20-11 city20)
          (in-city city20-10 city20)
          (in-city city20-9 city20)
          (in-city city20-8 city20)
          (in-city city20-7 city20)
          (in-city city20-6 city20)
          (in-city city20-5 city20)
          (in-city city20-4 city20)
          (in-city city20-3 city20)
          (in-city city20-2 city20)
          (in-city city20-1 city20)
          (in-city city19-13 city19)
          (in-city city19-12 city19)
          (in-city city19-11 city19)
          (in-city city19-10 city19)
          (in-city city19-9 city19)
          (in-city city19-8 city19)
          (in-city city19-7 city19)
          (in-city city19-6 city19)
          (in-city city19-5 city19)
          (in-city city19-4 city19)
          (in-city city19-3 city19)
          (in-city city19-2 city19)
          (in-city city19-1 city19)
          (in-city city18-13 city18)
          (in-city city18-12 city18)
          (in-city city18-11 city18)
          (in-city city18-10 city18)
          (in-city city18-9 city18)
          (in-city city18-8 city18)
          (in-city city18-7 city18)
          (in-city city18-6 city18)
          (in-city city18-5 city18)
          (in-city city18-4 city18)
          (in-city city18-3 city18)
          (in-city city18-2 city18)
          (in-city city18-1 city18)
          (in-city city17-13 city17)
          (in-city city17-12 city17)
          (in-city city17-11 city17)
          (in-city city17-10 city17)
          (in-city city17-9 city17)
          (in-city city17-8 city17)
          (in-city city17-7 city17)
          (in-city city17-6 city17)
          (in-city city17-5 city17)
          (in-city city17-4 city17)
          (in-city city17-3 city17)
          (in-city city17-2 city17)
          (in-city city17-1 city17)
          (in-city city16-13 city16)
          (in-city city16-12 city16)
          (in-city city16-11 city16)
          (in-city city16-10 city16)
          (in-city city16-9 city16)
          (in-city city16-8 city16)
          (in-city city16-7 city16)
          (in-city city16-6 city16)
          (in-city city16-5 city16)
          (in-city city16-4 city16)
          (in-city city16-3 city16)
          (in-city city16-2 city16)
          (in-city city16-1 city16)
          (in-city city15-13 city15)
          (in-city city15-12 city15)
          (in-city city15-11 city15)
          (in-city city15-10 city15)
          (in-city city15-9 city15)
          (in-city city15-8 city15)
          (in-city city15-7 city15)
          (in-city city15-6 city15)
          (in-city city15-5 city15)
          (in-city city15-4 city15)
          (in-city city15-3 city15)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-13 city14)
          (in-city city14-12 city14)
          (in-city city14-11 city14)
          (in-city city14-10 city14)
          (in-city city14-9 city14)
          (in-city city14-8 city14)
          (in-city city14-7 city14)
          (in-city city14-6 city14)
          (in-city city14-5 city14)
          (in-city city14-4 city14)
          (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-13 city13)
          (in-city city13-12 city13)
          (in-city city13-11 city13)
          (in-city city13-10 city13)
          (in-city city13-9 city13)
          (in-city city13-8 city13)
          (in-city city13-7 city13)
          (in-city city13-6 city13)
          (in-city city13-5 city13)
          (in-city city13-4 city13)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-13 city12)
          (in-city city12-12 city12)
          (in-city city12-11 city12)
          (in-city city12-10 city12)
          (in-city city12-9 city12)
          (in-city city12-8 city12)
          (in-city city12-7 city12)
          (in-city city12-6 city12)
          (in-city city12-5 city12)
          (in-city city12-4 city12)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-13 city11)
          (in-city city11-12 city11)
          (in-city city11-11 city11)
          (in-city city11-10 city11)
          (in-city city11-9 city11)
          (in-city city11-8 city11)
          (in-city city11-7 city11)
          (in-city city11-6 city11)
          (in-city city11-5 city11)
          (in-city city11-4 city11)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-13 city10)
          (in-city city10-12 city10)
          (in-city city10-11 city10)
          (in-city city10-10 city10)
          (in-city city10-9 city10)
          (in-city city10-8 city10)
          (in-city city10-7 city10)
          (in-city city10-6 city10)
          (in-city city10-5 city10)
          (in-city city10-4 city10)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-13 city9)
          (in-city city9-12 city9)
          (in-city city9-11 city9)
          (in-city city9-10 city9)
          (in-city city9-9 city9)
          (in-city city9-8 city9)
          (in-city city9-7 city9)
          (in-city city9-6 city9)
          (in-city city9-5 city9)
          (in-city city9-4 city9)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-13 city8)
          (in-city city8-12 city8)
          (in-city city8-11 city8)
          (in-city city8-10 city8)
          (in-city city8-9 city8)
          (in-city city8-8 city8)
          (in-city city8-7 city8)
          (in-city city8-6 city8)
          (in-city city8-5 city8)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-13 city7)
          (in-city city7-12 city7)
          (in-city city7-11 city7)
          (in-city city7-10 city7)
          (in-city city7-9 city7)
          (in-city city7-8 city7)
          (in-city city7-7 city7)
          (in-city city7-6 city7)
          (in-city city7-5 city7)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-13 city6)
          (in-city city6-12 city6)
          (in-city city6-11 city6)
          (in-city city6-10 city6)
          (in-city city6-9 city6)
          (in-city city6-8 city6)
          (in-city city6-7 city6)
          (in-city city6-6 city6)
          (in-city city6-5 city6)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-13 city5)
          (in-city city5-12 city5)
          (in-city city5-11 city5)
          (in-city city5-10 city5)
          (in-city city5-9 city5)
          (in-city city5-8 city5)
          (in-city city5-7 city5)
          (in-city city5-6 city5)
          (in-city city5-5 city5)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-13 city4)
          (in-city city4-12 city4)
          (in-city city4-11 city4)
          (in-city city4-10 city4)
          (in-city city4-9 city4)
          (in-city city4-8 city4)
          (in-city city4-7 city4)
          (in-city city4-6 city4)
          (in-city city4-5 city4)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-13 city3)
          (in-city city3-12 city3)
          (in-city city3-11 city3)
          (in-city city3-10 city3)
          (in-city city3-9 city3)
          (in-city city3-8 city3)
          (in-city city3-7 city3)
          (in-city city3-6 city3)
          (in-city city3-5 city3)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-13 city2)
          (in-city city2-12 city2)
          (in-city city2-11 city2)
          (in-city city2-10 city2)
          (in-city city2-9 city2)
          (in-city city2-8 city2)
          (in-city city2-7 city2)
          (in-city city2-6 city2)
          (in-city city2-5 city2)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-13 city1)
          (in-city city1-12 city1)
          (in-city city1-11 city1)
          (in-city city1-10 city1)
          (in-city city1-9 city1)
          (in-city city1-8 city1)
          (in-city city1-7 city1)
          (in-city city1-6 city1)
          (in-city city1-5 city1)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane13 city16-13)
          (at plane12 city7-13)
          (at plane11 city3-13)
          (at plane10 city6-13)
          (at plane9 city3-13)
          (at plane8 city8-13)
          (at plane7 city21-13)
          (at plane6 city9-13)
          (at plane5 city26-13)
          (at plane4 city20-13)
          (at plane3 city23-13)
          (at plane2 city22-13)
          (at plane1 city1-13)
          (at truck29 city27-2)
          (at truck28 city26-6)
          (at truck27 city25-6)
          (at truck26 city24-9)
          (at truck25 city23-3)
          (at truck24 city22-5)
          (at truck23 city21-8)
          (at truck22 city20-5)
          (at truck21 city19-9)
          (at truck20 city18-9)
          (at truck19 city17-8)
          (at truck18 city16-9)
          (at truck17 city15-2)
          (at truck16 city14-9)
          (at truck15 city13-8)
          (at truck14 city12-1)
          (at truck13 city11-4)
          (at truck12 city10-5)
          (at truck11 city9-1)
          (at truck10 city8-9)
          (at truck9 city7-3)
          (at truck8 city6-10)
          (at truck7 city5-5)
          (at truck6 city4-10)
          (at truck5 city3-4)
          (at truck4 city2-10)
          (at truck3 city1-7)
          (at truck2 city11-7)
          (at truck1 city14-7)
          (at package18 city27-2)
          (at package17 city5-11)
          (at package16 city7-11)
          (at package15 city6-7)
          (at package14 city9-5)
          (at package13 city1-12)
          (at package12 city8-7)
          (at package11 city21-11)
          (at package10 city24-12)
          (at package9 city2-1)
          (at package8 city6-13)
          (at package7 city20-7)
          (at package6 city5-2)
          (at package5 city13-4)
          (at package4 city15-10)
          (at package3 city15-5)
          (at package2 city5-7)
          (at package1 city20-7))
   (:goal (and (at package18 city11-8)
               (at package17 city21-6)
               (at package16 city26-12)
               (at package15 city16-11)
               (at package14 city10-8)
               (at package13 city7-2)
               (at package12 city24-6)
               (at package11 city23-12)
               (at package10 city14-3)
               (at package9 city22-1)
               (at package8 city3-11)
               (at package7 city11-11)
               (at package6 city9-1)
               (at package5 city6-3)
               (at package4 city9-4)
               (at package3 city19-5)
               (at package2 city16-11)
               (at package1 city26-3))))

(define (problem strips-log-x-26)
   (:domain logistics-strips)
   (:objects package33 package32 package31 package30 package29
             package28 package27 package26 package25 package24 package23
             package22 package21 package20 package19 package18 package17
             package16 package15 package14 package13 package12 package11
             package10 package9 package8 package7 package6 package5 package4
             package3 package2 package1 city47 city46 city45 city44 city43
             city42 city41 city40 city39 city38 city37 city36 city35 city34
             city33 city32 city31 city30 city29 city28 city27 city26 city25
             city24 city23 city22 city21 city20 city19 city18 city17 city16
             city15 city14 city13 city12 city11 city10 city9 city8 city7
             city6 city5 city4 city3 city2 city1 truck106 truck105
             truck104 truck103 truck102 truck101 truck100 truck99 truck98
             truck97 truck96 truck95 truck94 truck93 truck92 truck91
             truck90 truck89 truck88 truck87 truck86 truck85 truck84
             truck83 truck82 truck81 truck80 truck79 truck78 truck77
             truck76 truck75 truck74 truck73 truck72 truck71 truck70
             truck69 truck68 truck67 truck66 truck65 truck64 truck63
             truck62 truck61 truck60 truck59 truck58 truck57 truck56
             truck55 truck54 truck53 truck52 truck51 truck50 truck49
             truck48 truck47 truck46 truck45 truck44 truck43 truck42
             truck41 truck40 truck39 truck38 truck37 truck36 truck35
             truck34 truck33 truck32 truck31 truck30 truck29 truck28
             truck27 truck26 truck25 truck24 truck23 truck22 truck21
             truck20 truck19 truck18 truck17 truck16 truck15 truck14
             truck13 truck12 truck11 truck10 truck9 truck8 truck7 truck6
             truck5 truck4 truck3 truck2 truck1 plane2 plane1 city47-1
             city46-1 city45-1 city44-1 city43-1 city42-1 city41-1 city40-1
             city39-1 city38-1 city37-1 city36-1 city35-1 city34-1 city33-1
             city32-1 city31-1 city30-1 city29-1 city28-1 city27-1 city26-1
             city25-1 city24-1 city23-1 city22-1 city21-1 city20-1 city19-1
             city18-1 city17-1 city16-1 city15-1 city14-1 city13-1 city12-1
             city11-1 city10-1 city9-1 city8-1 city7-1 city6-1 city5-1
             city4-1 city3-1 city2-1 city1-1 city47-2 city46-2 city45-2
             city44-2 city43-2 city42-2 city41-2 city40-2 city39-2 city38-2
             city37-2 city36-2 city35-2 city34-2 city33-2 city32-2 city31-2
             city30-2 city29-2 city28-2 city27-2 city26-2 city25-2 city24-2
             city23-2 city22-2 city21-2 city20-2 city19-2 city18-2 city17-2
             city16-2 city15-2 city14-2 city13-2 city12-2 city11-2 city10-2
             city9-2 city8-2 city7-2 city6-2 city5-2 city4-2 city3-2
             city2-2 city1-2)
   (:init (obj package33)
          (obj package32)
          (obj package31)
          (obj package30)
          (obj package29)
          (obj package28)
          (obj package27)
          (obj package26)
          (obj package25)
          (obj package24)
          (obj package23)
          (obj package22)
          (obj package21)
          (obj package20)
          (obj package19)
          (obj package18)
          (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city47)
          (city city46)
          (city city45)
          (city city44)
          (city city43)
          (city city42)
          (city city41)
          (city city40)
          (city city39)
          (city city38)
          (city city37)
          (city city36)
          (city city35)
          (city city34)
          (city city33)
          (city city32)
          (city city31)
          (city city30)
          (city city29)
          (city city28)
          (city city27)
          (city city26)
          (city city25)
          (city city24)
          (city city23)
          (city city22)
          (city city21)
          (city city20)
          (city city19)
          (city city18)
          (city city17)
          (city city16)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck106)
          (truck truck105)
          (truck truck104)
          (truck truck103)
          (truck truck102)
          (truck truck101)
          (truck truck100)
          (truck truck99)
          (truck truck98)
          (truck truck97)
          (truck truck96)
          (truck truck95)
          (truck truck94)
          (truck truck93)
          (truck truck92)
          (truck truck91)
          (truck truck90)
          (truck truck89)
          (truck truck88)
          (truck truck87)
          (truck truck86)
          (truck truck85)
          (truck truck84)
          (truck truck83)
          (truck truck82)
          (truck truck81)
          (truck truck80)
          (truck truck79)
          (truck truck78)
          (truck truck77)
          (truck truck76)
          (truck truck75)
          (truck truck74)
          (truck truck73)
          (truck truck72)
          (truck truck71)
          (truck truck70)
          (truck truck69)
          (truck truck68)
          (truck truck67)
          (truck truck66)
          (truck truck65)
          (truck truck64)
          (truck truck63)
          (truck truck62)
          (truck truck61)
          (truck truck60)
          (truck truck59)
          (truck truck58)
          (truck truck57)
          (truck truck56)
          (truck truck55)
          (truck truck54)
          (truck truck53)
          (truck truck52)
          (truck truck51)
          (truck truck50)
          (truck truck49)
          (truck truck48)
          (truck truck47)
          (truck truck46)
          (truck truck45)
          (truck truck44)
          (truck truck43)
          (truck truck42)
          (truck truck41)
          (truck truck40)
          (truck truck39)
          (truck truck38)
          (truck truck37)
          (truck truck36)
          (truck truck35)
          (truck truck34)
          (truck truck33)
          (truck truck32)
          (truck truck31)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane2)
          (airplane plane1)
          (location city47-1)
          (location city46-1)
          (location city45-1)
          (location city44-1)
          (location city43-1)
          (location city42-1)
          (location city41-1)
          (location city40-1)
          (location city39-1)
          (location city38-1)
          (location city37-1)
          (location city36-1)
          (location city35-1)
          (location city34-1)
          (location city33-1)
          (location city32-1)
          (location city31-1)
          (location city30-1)
          (location city29-1)
          (location city28-1)
          (location city27-1)
          (location city26-1)
          (location city25-1)
          (location city24-1)
          (location city23-1)
          (location city22-1)
          (location city21-1)
          (location city20-1)
          (location city19-1)
          (location city18-1)
          (location city17-1)
          (location city16-1)
          (location city15-1)
          (location city14-1)
          (location city13-1)
          (location city12-1)
          (location city11-1)
          (location city10-1)
          (location city9-1)
          (location city8-1)
          (location city7-1)
          (location city6-1)
          (location city5-1)
          (location city4-1)
          (location city3-1)
          (location city2-1)
          (location city1-1)
          (airport city47-2)
          (location city47-2)
          (airport city46-2)
          (location city46-2)
          (airport city45-2)
          (location city45-2)
          (airport city44-2)
          (location city44-2)
          (airport city43-2)
          (location city43-2)
          (airport city42-2)
          (location city42-2)
          (airport city41-2)
          (location city41-2)
          (airport city40-2)
          (location city40-2)
          (airport city39-2)
          (location city39-2)
          (airport city38-2)
          (location city38-2)
          (airport city37-2)
          (location city37-2)
          (airport city36-2)
          (location city36-2)
          (airport city35-2)
          (location city35-2)
          (airport city34-2)
          (location city34-2)
          (airport city33-2)
          (location city33-2)
          (airport city32-2)
          (location city32-2)
          (airport city31-2)
          (location city31-2)
          (airport city30-2)
          (location city30-2)
          (airport city29-2)
          (location city29-2)
          (airport city28-2)
          (location city28-2)
          (airport city27-2)
          (location city27-2)
          (airport city26-2)
          (location city26-2)
          (airport city25-2)
          (location city25-2)
          (airport city24-2)
          (location city24-2)
          (airport city23-2)
          (location city23-2)
          (airport city22-2)
          (location city22-2)
          (airport city21-2)
          (location city21-2)
          (airport city20-2)
          (location city20-2)
          (airport city19-2)
          (location city19-2)
          (airport city18-2)
          (location city18-2)
          (airport city17-2)
          (location city17-2)
          (airport city16-2)
          (location city16-2)
          (airport city15-2)
          (location city15-2)
          (airport city14-2)
          (location city14-2)
          (airport city13-2)
          (location city13-2)
          (airport city12-2)
          (location city12-2)
          (airport city11-2)
          (location city11-2)
          (airport city10-2)
          (location city10-2)
          (airport city9-2)
          (location city9-2)
          (airport city8-2)
          (location city8-2)
          (airport city7-2)
          (location city7-2)
          (airport city6-2)
          (location city6-2)
          (airport city5-2)
          (location city5-2)
          (airport city4-2)
          (location city4-2)
          (airport city3-2)
          (location city3-2)
          (airport city2-2)
          (location city2-2)
          (airport city1-2)
          (location city1-2)
          (in-city city47-2 city47)
          (in-city city47-1 city47)
          (in-city city46-2 city46)
          (in-city city46-1 city46)
          (in-city city45-2 city45)
          (in-city city45-1 city45)
          (in-city city44-2 city44)
          (in-city city44-1 city44)
          (in-city city43-2 city43)
          (in-city city43-1 city43)
          (in-city city42-2 city42)
          (in-city city42-1 city42)
          (in-city city41-2 city41)
          (in-city city41-1 city41)
          (in-city city40-2 city40)
          (in-city city40-1 city40)
          (in-city city39-2 city39)
          (in-city city39-1 city39)
          (in-city city38-2 city38)
          (in-city city38-1 city38)
          (in-city city37-2 city37)
          (in-city city37-1 city37)
          (in-city city36-2 city36)
          (in-city city36-1 city36)
          (in-city city35-2 city35)
          (in-city city35-1 city35)
          (in-city city34-2 city34)
          (in-city city34-1 city34)
          (in-city city33-2 city33)
          (in-city city33-1 city33)
          (in-city city32-2 city32)
          (in-city city32-1 city32)
          (in-city city31-2 city31)
          (in-city city31-1 city31)
          (in-city city30-2 city30)
          (in-city city30-1 city30)
          (in-city city29-2 city29)
          (in-city city29-1 city29)
          (in-city city28-2 city28)
          (in-city city28-1 city28)
          (in-city city27-2 city27)
          (in-city city27-1 city27)
          (in-city city26-2 city26)
          (in-city city26-1 city26)
          (in-city city25-2 city25)
          (in-city city25-1 city25)
          (in-city city24-2 city24)
          (in-city city24-1 city24)
          (in-city city23-2 city23)
          (in-city city23-1 city23)
          (in-city city22-2 city22)
          (in-city city22-1 city22)
          (in-city city21-2 city21)
          (in-city city21-1 city21)
          (in-city city20-2 city20)
          (in-city city20-1 city20)
          (in-city city19-2 city19)
          (in-city city19-1 city19)
          (in-city city18-2 city18)
          (in-city city18-1 city18)
          (in-city city17-2 city17)
          (in-city city17-1 city17)
          (in-city city16-2 city16)
          (in-city city16-1 city16)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane2 city37-2)
          (at plane1 city33-2)
          (at truck106 city47-1)
          (at truck105 city46-1)
          (at truck104 city45-1)
          (at truck103 city44-1)
          (at truck102 city43-1)
          (at truck101 city42-1)
          (at truck100 city41-1)
          (at truck99 city40-1)
          (at truck98 city39-1)
          (at truck97 city38-1)
          (at truck96 city37-1)
          (at truck95 city36-1)
          (at truck94 city35-1)
          (at truck93 city34-1)
          (at truck92 city33-1)
          (at truck91 city32-1)
          (at truck90 city31-1)
          (at truck89 city30-1)
          (at truck88 city29-1)
          (at truck87 city28-1)
          (at truck86 city27-1)
          (at truck85 city26-1)
          (at truck84 city25-1)
          (at truck83 city24-1)
          (at truck82 city23-1)
          (at truck81 city22-1)
          (at truck80 city21-1)
          (at truck79 city20-1)
          (at truck78 city19-1)
          (at truck77 city18-1)
          (at truck76 city17-1)
          (at truck75 city16-1)
          (at truck74 city15-1)
          (at truck73 city14-1)
          (at truck72 city13-1)
          (at truck71 city12-1)
          (at truck70 city11-1)
          (at truck69 city10-1)
          (at truck68 city9-1)
          (at truck67 city8-1)
          (at truck66 city7-1)
          (at truck65 city6-1)
          (at truck64 city5-1)
          (at truck63 city4-1)
          (at truck62 city3-1)
          (at truck61 city2-1)
          (at truck60 city1-1)
          (at truck59 city1-2)
          (at truck58 city12-1)
          (at truck57 city15-2)
          (at truck56 city28-2)
          (at truck55 city7-1)
          (at truck54 city36-1)
          (at truck53 city15-1)
          (at truck52 city45-2)
          (at truck51 city3-1)
          (at truck50 city44-2)
          (at truck49 city42-1)
          (at truck48 city42-2)
          (at truck47 city23-1)
          (at truck46 city5-1)
          (at truck45 city11-1)
          (at truck44 city23-2)
          (at truck43 city19-2)
          (at truck42 city17-2)
          (at truck41 city42-1)
          (at truck40 city25-2)
          (at truck39 city14-1)
          (at truck38 city9-1)
          (at truck37 city32-2)
          (at truck36 city3-1)
          (at truck35 city13-2)
          (at truck34 city47-2)
          (at truck33 city1-2)
          (at truck32 city10-2)
          (at truck31 city35-1)
          (at truck30 city44-2)
          (at truck29 city14-2)
          (at truck28 city23-1)
          (at truck27 city24-1)
          (at truck26 city24-2)
          (at truck25 city23-1)
          (at truck24 city5-2)
          (at truck23 city4-1)
          (at truck22 city30-1)
          (at truck21 city6-2)
          (at truck20 city31-2)
          (at truck19 city7-1)
          (at truck18 city35-2)
          (at truck17 city40-1)
          (at truck16 city45-2)
          (at truck15 city35-2)
          (at truck14 city12-2)
          (at truck13 city2-2)
          (at truck12 city29-1)
          (at truck11 city1-1)
          (at truck10 city25-1)
          (at truck9 city1-2)
          (at truck8 city30-1)
          (at truck7 city16-2)
          (at truck6 city25-2)
          (at truck5 city37-1)
          (at truck4 city41-2)
          (at truck3 city36-2)
          (at truck2 city39-2)
          (at truck1 city4-2)
          (at package33 city29-2)
          (at package32 city10-2)
          (at package31 city45-2)
          (at package30 city21-2)
          (at package29 city34-1)
          (at package28 city4-2)
          (at package27 city30-2)
          (at package26 city5-2)
          (at package25 city38-1)
          (at package24 city10-1)
          (at package23 city23-1)
          (at package22 city42-1)
          (at package21 city18-1)
          (at package20 city35-2)
          (at package19 city37-2)
          (at package18 city43-1)
          (at package17 city14-2)
          (at package16 city42-2)
          (at package15 city27-2)
          (at package14 city40-2)
          (at package13 city7-1)
          (at package12 city6-1)
          (at package11 city40-2)
          (at package10 city14-2)
          (at package9 city34-1)
          (at package8 city7-1)
          (at package7 city12-1)
          (at package6 city44-1)
          (at package5 city11-1)
          (at package4 city28-2)
          (at package3 city6-2)
          (at package2 city27-1)
          (at package1 city12-2))
   (:goal (and (at package33 city40-2)
               (at package32 city46-2)
               (at package31 city26-2)
               (at package30 city25-2)
               (at package29 city23-1)
               (at package28 city30-2)
               (at package27 city11-2)
               (at package26 city2-1)
               (at package25 city7-1)
               (at package24 city46-1)
               (at package23 city39-1)
               (at package22 city25-1)
               (at package21 city31-2)
               (at package20 city11-2)
               (at package19 city14-1)
               (at package18 city3-2)
               (at package17 city2-1)
               (at package16 city19-2)
               (at package15 city8-2)
               (at package14 city17-1)
               (at package13 city37-2)
               (at package12 city27-1)
               (at package11 city9-2)
               (at package10 city22-2)
               (at package9 city38-1)
               (at package8 city20-1)
               (at package7 city30-1)
               (at package6 city46-1)
               (at package5 city6-2)
               (at package4 city5-2)
               (at package3 city2-2))))

(define (problem strips-log-x-27)
   (:domain logistics-strips)
   (:objects package57 package56 package55 package54 package53
             package52 package51 package50 package49 package48 package47
             package46 package45 package44 package43 package42 package41
             package40 package39 package38 package37 package36 package35
             package34 package33 package32 package31 package30 package29
             package28 package27 package26 package25 package24 package23
             package22 package21 package20 package19 package18 package17
             package16 package15 package14 package13 package12 package11
             package10 package9 package8 package7 package6 package5 package4
             package3 package2 package1 city15 city14 city13 city12 city11
             city10 city9 city8 city7 city6 city5 city4 city3 city2 city1
             truck28 truck27 truck26 truck25 truck24 truck23 truck22
             truck21 truck20 truck19 truck18 truck17 truck16 truck15
             truck14 truck13 truck12 truck11 truck10 truck9 truck8 truck7
             truck6 truck5 truck4 truck3 truck2 truck1 plane9 plane8 plane7
             plane6 plane5 plane4 plane3 plane2 plane1 city15-13 city15-12
             city15-11 city15-10 city15-9 city15-8 city15-7 city15-6
             city15-5 city15-4 city15-3 city15-2 city15-1 city14-13
             city14-12 city14-11 city14-10 city14-9 city14-8 city14-7
             city14-6 city14-5 city14-4 city14-3 city14-2 city14-1
             city13-13 city13-12 city13-11 city13-10 city13-9 city13-8
             city13-7 city13-6 city13-5 city13-4 city13-3 city13-2 city13-1
             city12-13 city12-12 city12-11 city12-10 city12-9 city12-8
             city12-7 city12-6 city12-5 city12-4 city12-3 city12-2 city12-1
             city11-13 city11-12 city11-11 city11-10 city11-9 city11-8
             city11-7 city11-6 city11-5 city11-4 city11-3 city11-2 city11-1
             city10-13 city10-12 city10-11 city10-10 city10-9 city10-8
             city10-7 city10-6 city10-5 city10-4 city10-3 city10-2 city10-1
             city9-13 city9-12 city9-11 city9-10 city9-9 city9-8 city9-7
             city9-6 city9-5 city9-4 city9-3 city9-2 city9-1 city8-13
             city8-12 city8-11 city8-10 city8-9 city8-8 city8-7 city8-6
             city8-5 city8-4 city8-3 city8-2 city8-1 city7-13 city7-12
             city7-11 city7-10 city7-9 city7-8 city7-7 city7-6 city7-5
             city7-4 city7-3 city7-2 city7-1 city6-13 city6-12 city6-11
             city6-10 city6-9 city6-8 city6-7 city6-6 city6-5 city6-4
             city6-3 city6-2 city6-1 city5-13 city5-12 city5-11 city5-10
             city5-9 city5-8 city5-7 city5-6 city5-5 city5-4 city5-3
             city5-2 city5-1 city4-13 city4-12 city4-11 city4-10 city4-9
             city4-8 city4-7 city4-6 city4-5 city4-4 city4-3 city4-2
             city4-1 city3-13 city3-12 city3-11 city3-10 city3-9 city3-8
             city3-7 city3-6 city3-5 city3-4 city3-3 city3-2 city3-1
             city2-13 city2-12 city2-11 city2-10 city2-9 city2-8 city2-7
             city2-6 city2-5 city2-4 city2-3 city2-2 city2-1 city1-13
             city1-12 city1-11 city1-10 city1-9 city1-8 city1-7 city1-6
             city1-5 city1-4 city1-3 city1-2 city1-1 city15-14 city14-14
             city13-14 city12-14 city11-14 city10-14 city9-14 city8-14
             city7-14 city6-14 city5-14 city4-14 city3-14 city2-14 city1-14)
   (:init (obj package57)
          (obj package56)
          (obj package55)
          (obj package54)
          (obj package53)
          (obj package52)
          (obj package51)
          (obj package50)
          (obj package49)
          (obj package48)
          (obj package47)
          (obj package46)
          (obj package45)
          (obj package44)
          (obj package43)
          (obj package42)
          (obj package41)
          (obj package40)
          (obj package39)
          (obj package38)
          (obj package37)
          (obj package36)
          (obj package35)
          (obj package34)
          (obj package33)
          (obj package32)
          (obj package31)
          (obj package30)
          (obj package29)
          (obj package28)
          (obj package27)
          (obj package26)
          (obj package25)
          (obj package24)
          (obj package23)
          (obj package22)
          (obj package21)
          (obj package20)
          (obj package19)
          (obj package18)
          (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane9)
          (airplane plane8)
          (airplane plane7)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city15-13)
          (location city15-12)
          (location city15-11)
          (location city15-10)
          (location city15-9)
          (location city15-8)
          (location city15-7)
          (location city15-6)
          (location city15-5)
          (location city15-4)
          (location city15-3)
          (location city15-2)
          (location city15-1)
          (location city14-13)
          (location city14-12)
          (location city14-11)
          (location city14-10)
          (location city14-9)
          (location city14-8)
          (location city14-7)
          (location city14-6)
          (location city14-5)
          (location city14-4)
          (location city14-3)
          (location city14-2)
          (location city14-1)
          (location city13-13)
          (location city13-12)
          (location city13-11)
          (location city13-10)
          (location city13-9)
          (location city13-8)
          (location city13-7)
          (location city13-6)
          (location city13-5)
          (location city13-4)
          (location city13-3)
          (location city13-2)
          (location city13-1)
          (location city12-13)
          (location city12-12)
          (location city12-11)
          (location city12-10)
          (location city12-9)
          (location city12-8)
          (location city12-7)
          (location city12-6)
          (location city12-5)
          (location city12-4)
          (location city12-3)
          (location city12-2)
          (location city12-1)
          (location city11-13)
          (location city11-12)
          (location city11-11)
          (location city11-10)
          (location city11-9)
          (location city11-8)
          (location city11-7)
          (location city11-6)
          (location city11-5)
          (location city11-4)
          (location city11-3)
          (location city11-2)
          (location city11-1)
          (location city10-13)
          (location city10-12)
          (location city10-11)
          (location city10-10)
          (location city10-9)
          (location city10-8)
          (location city10-7)
          (location city10-6)
          (location city10-5)
          (location city10-4)
          (location city10-3)
          (location city10-2)
          (location city10-1)
          (location city9-13)
          (location city9-12)
          (location city9-11)
          (location city9-10)
          (location city9-9)
          (location city9-8)
          (location city9-7)
          (location city9-6)
          (location city9-5)
          (location city9-4)
          (location city9-3)
          (location city9-2)
          (location city9-1)
          (location city8-13)
          (location city8-12)
          (location city8-11)
          (location city8-10)
          (location city8-9)
          (location city8-8)
          (location city8-7)
          (location city8-6)
          (location city8-5)
          (location city8-4)
          (location city8-3)
          (location city8-2)
          (location city8-1)
          (location city7-13)
          (location city7-12)
          (location city7-11)
          (location city7-10)
          (location city7-9)
          (location city7-8)
          (location city7-7)
          (location city7-6)
          (location city7-5)
          (location city7-4)
          (location city7-3)
          (location city7-2)
          (location city7-1)
          (location city6-13)
          (location city6-12)
          (location city6-11)
          (location city6-10)
          (location city6-9)
          (location city6-8)
          (location city6-7)
          (location city6-6)
          (location city6-5)
          (location city6-4)
          (location city6-3)
          (location city6-2)
          (location city6-1)
          (location city5-13)
          (location city5-12)
          (location city5-11)
          (location city5-10)
          (location city5-9)
          (location city5-8)
          (location city5-7)
          (location city5-6)
          (location city5-5)
          (location city5-4)
          (location city5-3)
          (location city5-2)
          (location city5-1)
          (location city4-13)
          (location city4-12)
          (location city4-11)
          (location city4-10)
          (location city4-9)
          (location city4-8)
          (location city4-7)
          (location city4-6)
          (location city4-5)
          (location city4-4)
          (location city4-3)
          (location city4-2)
          (location city4-1)
          (location city3-13)
          (location city3-12)
          (location city3-11)
          (location city3-10)
          (location city3-9)
          (location city3-8)
          (location city3-7)
          (location city3-6)
          (location city3-5)
          (location city3-4)
          (location city3-3)
          (location city3-2)
          (location city3-1)
          (location city2-13)
          (location city2-12)
          (location city2-11)
          (location city2-10)
          (location city2-9)
          (location city2-8)
          (location city2-7)
          (location city2-6)
          (location city2-5)
          (location city2-4)
          (location city2-3)
          (location city2-2)
          (location city2-1)
          (location city1-13)
          (location city1-12)
          (location city1-11)
          (location city1-10)
          (location city1-9)
          (location city1-8)
          (location city1-7)
          (location city1-6)
          (location city1-5)
          (location city1-4)
          (location city1-3)
          (location city1-2)
          (location city1-1)
          (airport city15-14)
          (location city15-14)
          (airport city14-14)
          (location city14-14)
          (airport city13-14)
          (location city13-14)
          (airport city12-14)
          (location city12-14)
          (airport city11-14)
          (location city11-14)
          (airport city10-14)
          (location city10-14)
          (airport city9-14)
          (location city9-14)
          (airport city8-14)
          (location city8-14)
          (airport city7-14)
          (location city7-14)
          (airport city6-14)
          (location city6-14)
          (airport city5-14)
          (location city5-14)
          (airport city4-14)
          (location city4-14)
          (airport city3-14)
          (location city3-14)
          (airport city2-14)
          (location city2-14)
          (airport city1-14)
          (location city1-14)
          (in-city city15-14 city15)
          (in-city city15-13 city15)
          (in-city city15-12 city15)
          (in-city city15-11 city15)
          (in-city city15-10 city15)
          (in-city city15-9 city15)
          (in-city city15-8 city15)
          (in-city city15-7 city15)
          (in-city city15-6 city15)
          (in-city city15-5 city15)
          (in-city city15-4 city15)
          (in-city city15-3 city15)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-14 city14)
          (in-city city14-13 city14)
          (in-city city14-12 city14)
          (in-city city14-11 city14)
          (in-city city14-10 city14)
          (in-city city14-9 city14)
          (in-city city14-8 city14)
          (in-city city14-7 city14)
          (in-city city14-6 city14)
          (in-city city14-5 city14)
          (in-city city14-4 city14)
          (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-14 city13)
          (in-city city13-13 city13)
          (in-city city13-12 city13)
          (in-city city13-11 city13)
          (in-city city13-10 city13)
          (in-city city13-9 city13)
          (in-city city13-8 city13)
          (in-city city13-7 city13)
          (in-city city13-6 city13)
          (in-city city13-5 city13)
          (in-city city13-4 city13)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-14 city12)
          (in-city city12-13 city12)
          (in-city city12-12 city12)
          (in-city city12-11 city12)
          (in-city city12-10 city12)
          (in-city city12-9 city12)
          (in-city city12-8 city12)
          (in-city city12-7 city12)
          (in-city city12-6 city12)
          (in-city city12-5 city12)
          (in-city city12-4 city12)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-14 city11)
          (in-city city11-13 city11)
          (in-city city11-12 city11)
          (in-city city11-11 city11)
          (in-city city11-10 city11)
          (in-city city11-9 city11)
          (in-city city11-8 city11)
          (in-city city11-7 city11)
          (in-city city11-6 city11)
          (in-city city11-5 city11)
          (in-city city11-4 city11)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-14 city10)
          (in-city city10-13 city10)
          (in-city city10-12 city10)
          (in-city city10-11 city10)
          (in-city city10-10 city10)
          (in-city city10-9 city10)
          (in-city city10-8 city10)
          (in-city city10-7 city10)
          (in-city city10-6 city10)
          (in-city city10-5 city10)
          (in-city city10-4 city10)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-14 city9)
          (in-city city9-13 city9)
          (in-city city9-12 city9)
          (in-city city9-11 city9)
          (in-city city9-10 city9)
          (in-city city9-9 city9)
          (in-city city9-8 city9)
          (in-city city9-7 city9)
          (in-city city9-6 city9)
          (in-city city9-5 city9)
          (in-city city9-4 city9)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-14 city8)
          (in-city city8-13 city8)
          (in-city city8-12 city8)
          (in-city city8-11 city8)
          (in-city city8-10 city8)
          (in-city city8-9 city8)
          (in-city city8-8 city8)
          (in-city city8-7 city8)
          (in-city city8-6 city8)
          (in-city city8-5 city8)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-14 city7)
          (in-city city7-13 city7)
          (in-city city7-12 city7)
          (in-city city7-11 city7)
          (in-city city7-10 city7)
          (in-city city7-9 city7)
          (in-city city7-8 city7)
          (in-city city7-7 city7)
          (in-city city7-6 city7)
          (in-city city7-5 city7)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-14 city6)
          (in-city city6-13 city6)
          (in-city city6-12 city6)
          (in-city city6-11 city6)
          (in-city city6-10 city6)
          (in-city city6-9 city6)
          (in-city city6-8 city6)
          (in-city city6-7 city6)
          (in-city city6-6 city6)
          (in-city city6-5 city6)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-14 city5)
          (in-city city5-13 city5)
          (in-city city5-12 city5)
          (in-city city5-11 city5)
          (in-city city5-10 city5)
          (in-city city5-9 city5)
          (in-city city5-8 city5)
          (in-city city5-7 city5)
          (in-city city5-6 city5)
          (in-city city5-5 city5)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-14 city4)
          (in-city city4-13 city4)
          (in-city city4-12 city4)
          (in-city city4-11 city4)
          (in-city city4-10 city4)
          (in-city city4-9 city4)
          (in-city city4-8 city4)
          (in-city city4-7 city4)
          (in-city city4-6 city4)
          (in-city city4-5 city4)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-14 city3)
          (in-city city3-13 city3)
          (in-city city3-12 city3)
          (in-city city3-11 city3)
          (in-city city3-10 city3)
          (in-city city3-9 city3)
          (in-city city3-8 city3)
          (in-city city3-7 city3)
          (in-city city3-6 city3)
          (in-city city3-5 city3)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-14 city2)
          (in-city city2-13 city2)
          (in-city city2-12 city2)
          (in-city city2-11 city2)
          (in-city city2-10 city2)
          (in-city city2-9 city2)
          (in-city city2-8 city2)
          (in-city city2-7 city2)
          (in-city city2-6 city2)
          (in-city city2-5 city2)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-14 city1)
          (in-city city1-13 city1)
          (in-city city1-12 city1)
          (in-city city1-11 city1)
          (in-city city1-10 city1)
          (in-city city1-9 city1)
          (in-city city1-8 city1)
          (in-city city1-7 city1)
          (in-city city1-6 city1)
          (in-city city1-5 city1)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane9 city11-14)
          (at plane8 city2-14)
          (at plane7 city6-14)
          (at plane6 city4-14)
          (at plane5 city6-14)
          (at plane4 city13-14)
          (at plane3 city7-14)
          (at plane2 city8-14)
          (at plane1 city9-14)
          (at truck28 city15-5)
          (at truck27 city14-8)
          (at truck26 city13-2)
          (at truck25 city12-8)
          (at truck24 city11-7)
          (at truck23 city10-10)
          (at truck22 city9-8)
          (at truck21 city8-6)
          (at truck20 city7-1)
          (at truck19 city6-13)
          (at truck18 city5-9)
          (at truck17 city4-8)
          (at truck16 city3-6)
          (at truck15 city2-12)
          (at truck14 city1-11)
          (at truck13 city7-9)
          (at truck12 city2-12)
          (at truck11 city9-12)
          (at truck10 city12-9)
          (at truck9 city14-9)
          (at truck8 city14-4)
          (at truck7 city10-6)
          (at truck6 city14-10)
          (at truck5 city10-11)
          (at truck4 city7-10)
          (at truck3 city5-2)
          (at truck2 city3-2)
          (at truck1 city15-1)
          (at package57 city6-7)
          (at package56 city2-4)
          (at package55 city2-8)
          (at package54 city15-7)
          (at package53 city6-14)
          (at package52 city11-4)
          (at package51 city11-14)
          (at package50 city14-13)
          (at package49 city2-7)
          (at package48 city5-14)
          (at package47 city14-13)
          (at package46 city2-2)
          (at package45 city3-5)
          (at package44 city2-1)
          (at package43 city15-12)
          (at package42 city15-1)
          (at package41 city13-14)
          (at package40 city4-14)
          (at package39 city13-6)
          (at package38 city2-12)
          (at package37 city9-7)
          (at package36 city7-10)
          (at package35 city7-3)
          (at package34 city10-4)
          (at package33 city6-14)
          (at package32 city13-6)
          (at package31 city15-13)
          (at package30 city11-5)
          (at package29 city12-12)
          (at package28 city14-1)
          (at package27 city7-8)
          (at package26 city15-7)
          (at package25 city4-6)
          (at package24 city7-8)
          (at package23 city10-14)
          (at package22 city9-11)
          (at package21 city8-14)
          (at package20 city3-8)
          (at package19 city9-4)
          (at package18 city8-2)
          (at package17 city11-9)
          (at package16 city10-14)
          (at package15 city7-8)
          (at package14 city5-13)
          (at package13 city5-12)
          (at package12 city6-12)
          (at package11 city5-12)
          (at package10 city11-1)
          (at package9 city10-12)
          (at package8 city12-3)
          (at package7 city13-4)
          (at package6 city5-8)
          (at package5 city2-1)
          (at package4 city3-9)
          (at package3 city9-2)
          (at package2 city8-7)
          (at package1 city6-12))
   (:goal (and (at package57 city12-11)
               (at package56 city2-8)
               (at package55 city10-4)
               (at package54 city11-12)
               (at package53 city4-6)
               (at package52 city8-4)
               (at package51 city13-4)
               (at package50 city14-7)
               (at package49 city15-10)
               (at package48 city9-12)
               (at package47 city9-7)
               (at package46 city8-2)
               (at package45 city9-4)
               (at package44 city4-13)
               (at package43 city14-7)
               (at package42 city11-3)
               (at package41 city9-9))))

(define (problem strips-log-x-28)
   (:domain logistics-strips)
   (:objects package42 package41 package40 package39 package38
             package37 package36 package35 package34 package33 package32
             package31 package30 package29 package28 package27 package26
             package25 package24 package23 package22 package21 package20
             package19 package18 package17 package16 package15 package14
             package13 package12 package11 package10 package9 package8
             package7 package6 package5 package4 package3 package2 package1
             city20 city19 city18 city17 city16 city15 city14 city13 city12
             city11 city10 city9 city8 city7 city6 city5 city4 city3 city2
             city1 truck83 truck82 truck81 truck80 truck79 truck78
             truck77 truck76 truck75 truck74 truck73 truck72 truck71
             truck70 truck69 truck68 truck67 truck66 truck65 truck64
             truck63 truck62 truck61 truck60 truck59 truck58 truck57
             truck56 truck55 truck54 truck53 truck52 truck51 truck50
             truck49 truck48 truck47 truck46 truck45 truck44 truck43
             truck42 truck41 truck40 truck39 truck38 truck37 truck36
             truck35 truck34 truck33 truck32 truck31 truck30 truck29
             truck28 truck27 truck26 truck25 truck24 truck23 truck22
             truck21 truck20 truck19 truck18 truck17 truck16 truck15
             truck14 truck13 truck12 truck11 truck10 truck9 truck8 truck7
             truck6 truck5 truck4 truck3 truck2 truck1 plane5 plane4 plane3
             plane2 plane1 city20-16 city20-15 city20-14 city20-13
             city20-12 city20-11 city20-10 city20-9 city20-8 city20-7
             city20-6 city20-5 city20-4 city20-3 city20-2 city20-1
             city19-16 city19-15 city19-14 city19-13 city19-12 city19-11
             city19-10 city19-9 city19-8 city19-7 city19-6 city19-5 city19-4
             city19-3 city19-2 city19-1 city18-16 city18-15 city18-14
             city18-13 city18-12 city18-11 city18-10 city18-9 city18-8
             city18-7 city18-6 city18-5 city18-4 city18-3 city18-2 city18-1
             city17-16 city17-15 city17-14 city17-13 city17-12 city17-11
             city17-10 city17-9 city17-8 city17-7 city17-6 city17-5 city17-4
             city17-3 city17-2 city17-1 city16-16 city16-15 city16-14
             city16-13 city16-12 city16-11 city16-10 city16-9 city16-8
             city16-7 city16-6 city16-5 city16-4 city16-3 city16-2 city16-1
             city15-16 city15-15 city15-14 city15-13 city15-12 city15-11
             city15-10 city15-9 city15-8 city15-7 city15-6 city15-5 city15-4
             city15-3 city15-2 city15-1 city14-16 city14-15 city14-14
             city14-13 city14-12 city14-11 city14-10 city14-9 city14-8
             city14-7 city14-6 city14-5 city14-4 city14-3 city14-2 city14-1
             city13-16 city13-15 city13-14 city13-13 city13-12 city13-11
             city13-10 city13-9 city13-8 city13-7 city13-6 city13-5 city13-4
             city13-3 city13-2 city13-1 city12-16 city12-15 city12-14
             city12-13 city12-12 city12-11 city12-10 city12-9 city12-8
             city12-7 city12-6 city12-5 city12-4 city12-3 city12-2 city12-1
             city11-16 city11-15 city11-14 city11-13 city11-12 city11-11
             city11-10 city11-9 city11-8 city11-7 city11-6 city11-5 city11-4
             city11-3 city11-2 city11-1 city10-16 city10-15 city10-14
             city10-13 city10-12 city10-11 city10-10 city10-9 city10-8
             city10-7 city10-6 city10-5 city10-4 city10-3 city10-2 city10-1
             city9-16 city9-15 city9-14 city9-13 city9-12 city9-11 city9-10
             city9-9 city9-8 city9-7 city9-6 city9-5 city9-4 city9-3
             city9-2 city9-1 city8-16 city8-15 city8-14 city8-13 city8-12
             city8-11 city8-10 city8-9 city8-8 city8-7 city8-6 city8-5
             city8-4 city8-3 city8-2 city8-1 city7-16 city7-15 city7-14
             city7-13 city7-12 city7-11 city7-10 city7-9 city7-8 city7-7
             city7-6 city7-5 city7-4 city7-3 city7-2 city7-1 city6-16
             city6-15 city6-14 city6-13 city6-12 city6-11 city6-10 city6-9
             city6-8 city6-7 city6-6 city6-5 city6-4 city6-3 city6-2
             city6-1 city5-16 city5-15 city5-14 city5-13 city5-12 city5-11
             city5-10 city5-9 city5-8 city5-7 city5-6 city5-5 city5-4
             city5-3 city5-2 city5-1 city4-16 city4-15 city4-14 city4-13
             city4-12 city4-11 city4-10 city4-9 city4-8 city4-7 city4-6
             city4-5 city4-4 city4-3 city4-2 city4-1 city3-16 city3-15
             city3-14 city3-13 city3-12 city3-11 city3-10 city3-9 city3-8
             city3-7 city3-6 city3-5 city3-4 city3-3 city3-2 city3-1
             city2-16 city2-15 city2-14 city2-13 city2-12 city2-11 city2-10
             city2-9 city2-8 city2-7 city2-6 city2-5 city2-4 city2-3
             city2-2 city2-1 city1-16 city1-15 city1-14 city1-13 city1-12
             city1-11 city1-10 city1-9 city1-8 city1-7 city1-6 city1-5
             city1-4 city1-3 city1-2 city1-1 city20-17 city19-17 city18-17
             city17-17 city16-17 city15-17 city14-17 city13-17 city12-17
             city11-17 city10-17 city9-17 city8-17 city7-17 city6-17
             city5-17 city4-17 city3-17 city2-17 city1-17)
   (:init (obj package42)
          (obj package41)
          (obj package40)
          (obj package39)
          (obj package38)
          (obj package37)
          (obj package36)
          (obj package35)
          (obj package34)
          (obj package33)
          (obj package32)
          (obj package31)
          (obj package30)
          (obj package29)
          (obj package28)
          (obj package27)
          (obj package26)
          (obj package25)
          (obj package24)
          (obj package23)
          (obj package22)
          (obj package21)
          (obj package20)
          (obj package19)
          (obj package18)
          (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city20)
          (city city19)
          (city city18)
          (city city17)
          (city city16)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck83)
          (truck truck82)
          (truck truck81)
          (truck truck80)
          (truck truck79)
          (truck truck78)
          (truck truck77)
          (truck truck76)
          (truck truck75)
          (truck truck74)
          (truck truck73)
          (truck truck72)
          (truck truck71)
          (truck truck70)
          (truck truck69)
          (truck truck68)
          (truck truck67)
          (truck truck66)
          (truck truck65)
          (truck truck64)
          (truck truck63)
          (truck truck62)
          (truck truck61)
          (truck truck60)
          (truck truck59)
          (truck truck58)
          (truck truck57)
          (truck truck56)
          (truck truck55)
          (truck truck54)
          (truck truck53)
          (truck truck52)
          (truck truck51)
          (truck truck50)
          (truck truck49)
          (truck truck48)
          (truck truck47)
          (truck truck46)
          (truck truck45)
          (truck truck44)
          (truck truck43)
          (truck truck42)
          (truck truck41)
          (truck truck40)
          (truck truck39)
          (truck truck38)
          (truck truck37)
          (truck truck36)
          (truck truck35)
          (truck truck34)
          (truck truck33)
          (truck truck32)
          (truck truck31)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city20-16)
          (location city20-15)
          (location city20-14)
          (location city20-13)
          (location city20-12)
          (location city20-11)
          (location city20-10)
          (location city20-9)
          (location city20-8)
          (location city20-7)
          (location city20-6)
          (location city20-5)
          (location city20-4)
          (location city20-3)
          (location city20-2)
          (location city20-1)
          (location city19-16)
          (location city19-15)
          (location city19-14)
          (location city19-13)
          (location city19-12)
          (location city19-11)
          (location city19-10)
          (location city19-9)
          (location city19-8)
          (location city19-7)
          (location city19-6)
          (location city19-5)
          (location city19-4)
          (location city19-3)
          (location city19-2)
          (location city19-1)
          (location city18-16)
          (location city18-15)
          (location city18-14)
          (location city18-13)
          (location city18-12)
          (location city18-11)
          (location city18-10)
          (location city18-9)
          (location city18-8)
          (location city18-7)
          (location city18-6)
          (location city18-5)
          (location city18-4)
          (location city18-3)
          (location city18-2)
          (location city18-1)
          (location city17-16)
          (location city17-15)
          (location city17-14)
          (location city17-13)
          (location city17-12)
          (location city17-11)
          (location city17-10)
          (location city17-9)
          (location city17-8)
          (location city17-7)
          (location city17-6)
          (location city17-5)
          (location city17-4)
          (location city17-3)
          (location city17-2)
          (location city17-1)
          (location city16-16)
          (location city16-15)
          (location city16-14)
          (location city16-13)
          (location city16-12)
          (location city16-11)
          (location city16-10)
          (location city16-9)
          (location city16-8)
          (location city16-7)
          (location city16-6)
          (location city16-5)
          (location city16-4)
          (location city16-3)
          (location city16-2)
          (location city16-1)
          (location city15-16)
          (location city15-15)
          (location city15-14)
          (location city15-13)
          (location city15-12)
          (location city15-11)
          (location city15-10)
          (location city15-9)
          (location city15-8)
          (location city15-7)
          (location city15-6)
          (location city15-5)
          (location city15-4)
          (location city15-3)
          (location city15-2)
          (location city15-1)
          (location city14-16)
          (location city14-15)
          (location city14-14)
          (location city14-13)
          (location city14-12)
          (location city14-11)
          (location city14-10)
          (location city14-9)
          (location city14-8)
          (location city14-7)
          (location city14-6)
          (location city14-5)
          (location city14-4)
          (location city14-3)
          (location city14-2)
          (location city14-1)
          (location city13-16)
          (location city13-15)
          (location city13-14)
          (location city13-13)
          (location city13-12)
          (location city13-11)
          (location city13-10)
          (location city13-9)
          (location city13-8)
          (location city13-7)
          (location city13-6)
          (location city13-5)
          (location city13-4)
          (location city13-3)
          (location city13-2)
          (location city13-1)
          (location city12-16)
          (location city12-15)
          (location city12-14)
          (location city12-13)
          (location city12-12)
          (location city12-11)
          (location city12-10)
          (location city12-9)
          (location city12-8)
          (location city12-7)
          (location city12-6)
          (location city12-5)
          (location city12-4)
          (location city12-3)
          (location city12-2)
          (location city12-1)
          (location city11-16)
          (location city11-15)
          (location city11-14)
          (location city11-13)
          (location city11-12)
          (location city11-11)
          (location city11-10)
          (location city11-9)
          (location city11-8)
          (location city11-7)
          (location city11-6)
          (location city11-5)
          (location city11-4)
          (location city11-3)
          (location city11-2)
          (location city11-1)
          (location city10-16)
          (location city10-15)
          (location city10-14)
          (location city10-13)
          (location city10-12)
          (location city10-11)
          (location city10-10)
          (location city10-9)
          (location city10-8)
          (location city10-7)
          (location city10-6)
          (location city10-5)
          (location city10-4)
          (location city10-3)
          (location city10-2)
          (location city10-1)
          (location city9-16)
          (location city9-15)
          (location city9-14)
          (location city9-13)
          (location city9-12)
          (location city9-11)
          (location city9-10)
          (location city9-9)
          (location city9-8)
          (location city9-7)
          (location city9-6)
          (location city9-5)
          (location city9-4)
          (location city9-3)
          (location city9-2)
          (location city9-1)
          (location city8-16)
          (location city8-15)
          (location city8-14)
          (location city8-13)
          (location city8-12)
          (location city8-11)
          (location city8-10)
          (location city8-9)
          (location city8-8)
          (location city8-7)
          (location city8-6)
          (location city8-5)
          (location city8-4)
          (location city8-3)
          (location city8-2)
          (location city8-1)
          (location city7-16)
          (location city7-15)
          (location city7-14)
          (location city7-13)
          (location city7-12)
          (location city7-11)
          (location city7-10)
          (location city7-9)
          (location city7-8)
          (location city7-7)
          (location city7-6)
          (location city7-5)
          (location city7-4)
          (location city7-3)
          (location city7-2)
          (location city7-1)
          (location city6-16)
          (location city6-15)
          (location city6-14)
          (location city6-13)
          (location city6-12)
          (location city6-11)
          (location city6-10)
          (location city6-9)
          (location city6-8)
          (location city6-7)
          (location city6-6)
          (location city6-5)
          (location city6-4)
          (location city6-3)
          (location city6-2)
          (location city6-1)
          (location city5-16)
          (location city5-15)
          (location city5-14)
          (location city5-13)
          (location city5-12)
          (location city5-11)
          (location city5-10)
          (location city5-9)
          (location city5-8)
          (location city5-7)
          (location city5-6)
          (location city5-5)
          (location city5-4)
          (location city5-3)
          (location city5-2)
          (location city5-1)
          (location city4-16)
          (location city4-15)
          (location city4-14)
          (location city4-13)
          (location city4-12)
          (location city4-11)
          (location city4-10)
          (location city4-9)
          (location city4-8)
          (location city4-7)
          (location city4-6)
          (location city4-5)
          (location city4-4)
          (location city4-3)
          (location city4-2)
          (location city4-1)
          (location city3-16)
          (location city3-15)
          (location city3-14)
          (location city3-13)
          (location city3-12)
          (location city3-11)
          (location city3-10)
          (location city3-9)
          (location city3-8)
          (location city3-7)
          (location city3-6)
          (location city3-5)
          (location city3-4)
          (location city3-3)
          (location city3-2)
          (location city3-1)
          (location city2-16)
          (location city2-15)
          (location city2-14)
          (location city2-13)
          (location city2-12)
          (location city2-11)
          (location city2-10)
          (location city2-9)
          (location city2-8)
          (location city2-7)
          (location city2-6)
          (location city2-5)
          (location city2-4)
          (location city2-3)
          (location city2-2)
          (location city2-1)
          (location city1-16)
          (location city1-15)
          (location city1-14)
          (location city1-13)
          (location city1-12)
          (location city1-11)
          (location city1-10)
          (location city1-9)
          (location city1-8)
          (location city1-7)
          (location city1-6)
          (location city1-5)
          (location city1-4)
          (location city1-3)
          (location city1-2)
          (location city1-1)
          (airport city20-17)
          (location city20-17)
          (airport city19-17)
          (location city19-17)
          (airport city18-17)
          (location city18-17)
          (airport city17-17)
          (location city17-17)
          (airport city16-17)
          (location city16-17)
          (airport city15-17)
          (location city15-17)
          (airport city14-17)
          (location city14-17)
          (airport city13-17)
          (location city13-17)
          (airport city12-17)
          (location city12-17)
          (airport city11-17)
          (location city11-17)
          (airport city10-17)
          (location city10-17)
          (airport city9-17)
          (location city9-17)
          (airport city8-17)
          (location city8-17)
          (airport city7-17)
          (location city7-17)
          (airport city6-17)
          (location city6-17)
          (airport city5-17)
          (location city5-17)
          (airport city4-17)
          (location city4-17)
          (airport city3-17)
          (location city3-17)
          (airport city2-17)
          (location city2-17)
          (airport city1-17)
          (location city1-17)
          (in-city city20-17 city20)
          (in-city city20-16 city20)
          (in-city city20-15 city20)
          (in-city city20-14 city20)
          (in-city city20-13 city20)
          (in-city city20-12 city20)
          (in-city city20-11 city20)
          (in-city city20-10 city20)
          (in-city city20-9 city20)
          (in-city city20-8 city20)
          (in-city city20-7 city20)
          (in-city city20-6 city20)
          (in-city city20-5 city20)
          (in-city city20-4 city20)
          (in-city city20-3 city20)
          (in-city city20-2 city20)
          (in-city city20-1 city20)
          (in-city city19-17 city19)
          (in-city city19-16 city19)
          (in-city city19-15 city19)
          (in-city city19-14 city19)
          (in-city city19-13 city19)
          (in-city city19-12 city19)
          (in-city city19-11 city19)
          (in-city city19-10 city19)
          (in-city city19-9 city19)
          (in-city city19-8 city19)
          (in-city city19-7 city19)
          (in-city city19-6 city19)
          (in-city city19-5 city19)
          (in-city city19-4 city19)
          (in-city city19-3 city19)
          (in-city city19-2 city19)
          (in-city city19-1 city19)
          (in-city city18-17 city18)
          (in-city city18-16 city18)
          (in-city city18-15 city18)
          (in-city city18-14 city18)
          (in-city city18-13 city18)
          (in-city city18-12 city18)
          (in-city city18-11 city18)
          (in-city city18-10 city18)
          (in-city city18-9 city18)
          (in-city city18-8 city18)
          (in-city city18-7 city18)
          (in-city city18-6 city18)
          (in-city city18-5 city18)
          (in-city city18-4 city18)
          (in-city city18-3 city18)
          (in-city city18-2 city18)
          (in-city city18-1 city18)
          (in-city city17-17 city17)
          (in-city city17-16 city17)
          (in-city city17-15 city17)
          (in-city city17-14 city17)
          (in-city city17-13 city17)
          (in-city city17-12 city17)
          (in-city city17-11 city17)
          (in-city city17-10 city17)
          (in-city city17-9 city17)
          (in-city city17-8 city17)
          (in-city city17-7 city17)
          (in-city city17-6 city17)
          (in-city city17-5 city17)
          (in-city city17-4 city17)
          (in-city city17-3 city17)
          (in-city city17-2 city17)
          (in-city city17-1 city17)
          (in-city city16-17 city16)
          (in-city city16-16 city16)
          (in-city city16-15 city16)
          (in-city city16-14 city16)
          (in-city city16-13 city16)
          (in-city city16-12 city16)
          (in-city city16-11 city16)
          (in-city city16-10 city16)
          (in-city city16-9 city16)
          (in-city city16-8 city16)
          (in-city city16-7 city16)
          (in-city city16-6 city16)
          (in-city city16-5 city16)
          (in-city city16-4 city16)
          (in-city city16-3 city16)
          (in-city city16-2 city16)
          (in-city city16-1 city16)
          (in-city city15-17 city15)
          (in-city city15-16 city15)
          (in-city city15-15 city15)
          (in-city city15-14 city15)
          (in-city city15-13 city15)
          (in-city city15-12 city15)
          (in-city city15-11 city15)
          (in-city city15-10 city15)
          (in-city city15-9 city15)
          (in-city city15-8 city15)
          (in-city city15-7 city15)
          (in-city city15-6 city15)
          (in-city city15-5 city15)
          (in-city city15-4 city15)
          (in-city city15-3 city15)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-17 city14)
          (in-city city14-16 city14)
          (in-city city14-15 city14)
          (in-city city14-14 city14)
          (in-city city14-13 city14)
          (in-city city14-12 city14)
          (in-city city14-11 city14)
          (in-city city14-10 city14)
          (in-city city14-9 city14)
          (in-city city14-8 city14)
          (in-city city14-7 city14)
          (in-city city14-6 city14)
          (in-city city14-5 city14)
          (in-city city14-4 city14)
          (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-17 city13)
          (in-city city13-16 city13)
          (in-city city13-15 city13)
          (in-city city13-14 city13)
          (in-city city13-13 city13)
          (in-city city13-12 city13)
          (in-city city13-11 city13)
          (in-city city13-10 city13)
          (in-city city13-9 city13)
          (in-city city13-8 city13)
          (in-city city13-7 city13)
          (in-city city13-6 city13)
          (in-city city13-5 city13)
          (in-city city13-4 city13)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-17 city12)
          (in-city city12-16 city12)
          (in-city city12-15 city12)
          (in-city city12-14 city12)
          (in-city city12-13 city12)
          (in-city city12-12 city12)
          (in-city city12-11 city12)
          (in-city city12-10 city12)
          (in-city city12-9 city12)
          (in-city city12-8 city12)
          (in-city city12-7 city12)
          (in-city city12-6 city12)
          (in-city city12-5 city12)
          (in-city city12-4 city12)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-17 city11)
          (in-city city11-16 city11)
          (in-city city11-15 city11)
          (in-city city11-14 city11)
          (in-city city11-13 city11)
          (in-city city11-12 city11)
          (in-city city11-11 city11)
          (in-city city11-10 city11)
          (in-city city11-9 city11)
          (in-city city11-8 city11)
          (in-city city11-7 city11)
          (in-city city11-6 city11)
          (in-city city11-5 city11)
          (in-city city11-4 city11)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-17 city10)
          (in-city city10-16 city10)
          (in-city city10-15 city10)
          (in-city city10-14 city10)
          (in-city city10-13 city10)
          (in-city city10-12 city10)
          (in-city city10-11 city10)
          (in-city city10-10 city10)
          (in-city city10-9 city10)
          (in-city city10-8 city10)
          (in-city city10-7 city10)
          (in-city city10-6 city10)
          (in-city city10-5 city10)
          (in-city city10-4 city10)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-17 city9)
          (in-city city9-16 city9)
          (in-city city9-15 city9)
          (in-city city9-14 city9)
          (in-city city9-13 city9)
          (in-city city9-12 city9)
          (in-city city9-11 city9)
          (in-city city9-10 city9)
          (in-city city9-9 city9)
          (in-city city9-8 city9)
          (in-city city9-7 city9)
          (in-city city9-6 city9)
          (in-city city9-5 city9)
          (in-city city9-4 city9)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-17 city8)
          (in-city city8-16 city8)
          (in-city city8-15 city8)
          (in-city city8-14 city8)
          (in-city city8-13 city8)
          (in-city city8-12 city8)
          (in-city city8-11 city8)
          (in-city city8-10 city8)
          (in-city city8-9 city8)
          (in-city city8-8 city8)
          (in-city city8-7 city8)
          (in-city city8-6 city8)
          (in-city city8-5 city8)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-17 city7)
          (in-city city7-16 city7)
          (in-city city7-15 city7)
          (in-city city7-14 city7)
          (in-city city7-13 city7)
          (in-city city7-12 city7)
          (in-city city7-11 city7)
          (in-city city7-10 city7)
          (in-city city7-9 city7)
          (in-city city7-8 city7)
          (in-city city7-7 city7)
          (in-city city7-6 city7)
          (in-city city7-5 city7)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-17 city6)
          (in-city city6-16 city6)
          (in-city city6-15 city6)
          (in-city city6-14 city6)
          (in-city city6-13 city6)
          (in-city city6-12 city6)
          (in-city city6-11 city6)
          (in-city city6-10 city6)
          (in-city city6-9 city6)
          (in-city city6-8 city6)
          (in-city city6-7 city6)
          (in-city city6-6 city6)
          (in-city city6-5 city6)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-17 city5)
          (in-city city5-16 city5)
          (in-city city5-15 city5)
          (in-city city5-14 city5)
          (in-city city5-13 city5)
          (in-city city5-12 city5)
          (in-city city5-11 city5)
          (in-city city5-10 city5)
          (in-city city5-9 city5)
          (in-city city5-8 city5)
          (in-city city5-7 city5)
          (in-city city5-6 city5)
          (in-city city5-5 city5)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-17 city4)
          (in-city city4-16 city4)
          (in-city city4-15 city4)
          (in-city city4-14 city4)
          (in-city city4-13 city4)
          (in-city city4-12 city4)
          (in-city city4-11 city4)
          (in-city city4-10 city4)
          (in-city city4-9 city4)
          (in-city city4-8 city4)
          (in-city city4-7 city4)
          (in-city city4-6 city4)
          (in-city city4-5 city4)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-17 city3)
          (in-city city3-16 city3)
          (in-city city3-15 city3)
          (in-city city3-14 city3)
          (in-city city3-13 city3)
          (in-city city3-12 city3)
          (in-city city3-11 city3)
          (in-city city3-10 city3)
          (in-city city3-9 city3)
          (in-city city3-8 city3)
          (in-city city3-7 city3)
          (in-city city3-6 city3)
          (in-city city3-5 city3)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-17 city2)
          (in-city city2-16 city2)
          (in-city city2-15 city2)
          (in-city city2-14 city2)
          (in-city city2-13 city2)
          (in-city city2-12 city2)
          (in-city city2-11 city2)
          (in-city city2-10 city2)
          (in-city city2-9 city2)
          (in-city city2-8 city2)
          (in-city city2-7 city2)
          (in-city city2-6 city2)
          (in-city city2-5 city2)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-17 city1)
          (in-city city1-16 city1)
          (in-city city1-15 city1)
          (in-city city1-14 city1)
          (in-city city1-13 city1)
          (in-city city1-12 city1)
          (in-city city1-11 city1)
          (in-city city1-10 city1)
          (in-city city1-9 city1)
          (in-city city1-8 city1)
          (in-city city1-7 city1)
          (in-city city1-6 city1)
          (in-city city1-5 city1)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane5 city19-17)
          (at plane4 city9-17)
          (at plane3 city18-17)
          (at plane2 city18-17)
          (at plane1 city14-17)
          (at truck83 city20-7)
          (at truck82 city19-2)
          (at truck81 city18-5)
          (at truck80 city17-14)
          (at truck79 city16-15)
          (at truck78 city15-7)
          (at truck77 city14-14)
          (at truck76 city13-9)
          (at truck75 city12-8)
          (at truck74 city11-1)
          (at truck73 city10-13)
          (at truck72 city9-4)
          (at truck71 city8-3)
          (at truck70 city7-15)
          (at truck69 city6-2)
          (at truck68 city5-8)
          (at truck67 city4-5)
          (at truck66 city3-15)
          (at truck65 city2-7)
          (at truck64 city1-2)
          (at truck63 city1-16)
          (at truck62 city9-15)
          (at truck61 city19-9)
          (at truck60 city12-8)
          (at truck59 city7-10)
          (at truck58 city15-5)
          (at truck57 city7-13)
          (at truck56 city11-1)
          (at truck55 city2-11)
          (at truck54 city13-7)
          (at truck53 city18-13)
          (at truck52 city16-11)
          (at truck51 city19-10)
          (at truck50 city2-8)
          (at truck49 city19-8)
          (at truck48 city19-9)
          (at truck47 city11-2)
          (at truck46 city14-7)
          (at truck45 city2-17)
          (at truck44 city9-17)
          (at truck43 city2-8)
          (at truck42 city19-12)
          (at truck41 city7-15)
          (at truck40 city2-4)
          (at truck39 city18-1)
          (at truck38 city16-6)
          (at truck37 city7-7)
          (at truck36 city12-6)
          (at truck35 city15-17)
          (at truck34 city2-2)
          (at truck33 city13-16)
          (at truck32 city11-2)
          (at truck31 city3-13)
          (at truck30 city8-5)
          (at truck29 city5-7)
          (at truck28 city5-10)
          (at truck27 city4-8)
          (at truck26 city2-5)
          (at truck25 city10-17)
          (at truck24 city13-16)
          (at truck23 city3-13)
          (at truck22 city5-9)
          (at truck21 city11-11)
          (at truck20 city15-13)
          (at truck19 city8-1)
          (at truck18 city5-17)
          (at truck17 city17-15)
          (at truck16 city3-11)
          (at truck15 city10-16)
          (at truck14 city12-4)
          (at truck13 city15-15)
          (at truck12 city13-7)
          (at truck11 city13-2)
          (at truck10 city19-5)
          (at truck9 city6-10)
          (at truck8 city13-6)
          (at truck7 city15-16)
          (at truck6 city8-14)
          (at truck5 city18-3)
          (at truck4 city13-8)
          (at truck3 city17-17)
          (at truck2 city10-6)
          (at truck1 city13-11)
          (at package42 city16-15)
          (at package41 city19-8)
          (at package40 city3-6)
          (at package39 city7-6)
          (at package38 city16-7)
          (at package37 city10-13)
          (at package36 city13-17)
          (at package35 city18-8)
          (at package34 city15-1)
          (at package33 city6-7)
          (at package32 city12-6)
          (at package31 city16-8)
          (at package30 city16-3)
          (at package29 city11-14)
          (at package28 city8-4)
          (at package27 city11-2)
          (at package26 city12-7)
          (at package25 city13-6)
          (at package24 city16-9)
          (at package23 city11-9)
          (at package22 city16-7)
          (at package21 city5-3)
          (at package20 city3-6)
          (at package19 city3-13)
          (at package18 city1-12)
          (at package17 city8-13)
          (at package16 city9-1)
          (at package15 city15-4)
          (at package14 city3-17)
          (at package13 city15-6)
          (at package12 city3-3)
          (at package11 city13-8)
          (at package10 city2-17)
          (at package9 city12-4)
          (at package8 city3-1)
          (at package7 city13-5)
          (at package6 city5-4)
          (at package5 city14-3)
          (at package4 city5-3)
          (at package3 city15-1)
          (at package2 city2-7)
          (at package1 city4-10))
   (:goal (and (at package42 city13-8)
               (at package41 city3-16)
               (at package40 city8-9)
               (at package39 city3-8)
               (at package38 city12-4)
               (at package37 city19-7)
               (at package36 city19-16)
               (at package35 city17-15)
               (at package34 city8-4)
               (at package33 city9-12)
               (at package32 city2-16)
               (at package31 city4-12)
               (at package30 city17-2)
               (at package29 city11-7)
               (at package28 city10-17)
               (at package27 city15-14)
               (at package26 city12-11)
               (at package25 city8-12)
               (at package24 city18-5)
               (at package23 city16-16)
               (at package22 city4-11)
               (at package21 city11-2)
               (at package20 city9-2)
               (at package19 city17-4)
               (at package18 city10-16)
               (at package17 city1-3)
               (at package16 city20-11)
               (at package15 city11-16)
               (at package14 city2-6)
               (at package13 city10-14))))

(define (problem strips-log-x-29)
   (:domain logistics-strips)
   (:objects package53 package52 package51 package50 package49
             package48 package47 package46 package45 package44 package43
             package42 package41 package40 package39 package38 package37
             package36 package35 package34 package33 package32 package31
             package30 package29 package28 package27 package26 package25
             package24 package23 package22 package21 package20 package19
             package18 package17 package16 package15 package14 package13
             package12 package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 city27
             city26 city25 city24 city23 city22 city21 city20 city19 city18
             city17 city16 city15 city14 city13 city12 city11 city10 city9
             city8 city7 city6 city5 city4 city3 city2 city1 truck46
             truck45 truck44 truck43 truck42 truck41 truck40 truck39
             truck38 truck37 truck36 truck35 truck34 truck33 truck32
             truck31 truck30 truck29 truck28 truck27 truck26 truck25
             truck24 truck23 truck22 truck21 truck20 truck19 truck18
             truck17 truck16 truck15 truck14 truck13 truck12 truck11
             truck10 truck9 truck8 truck7 truck6 truck5 truck4 truck3 truck2
             truck1 plane10 plane9 plane8 plane7 plane6 plane5 plane4
             plane3 plane2 plane1 city27-2 city27-1 city26-2 city26-1
             city25-2 city25-1 city24-2 city24-1 city23-2 city23-1 city22-2
             city22-1 city21-2 city21-1 city20-2 city20-1 city19-2 city19-1
             city18-2 city18-1 city17-2 city17-1 city16-2 city16-1 city15-2
             city15-1 city14-2 city14-1 city13-2 city13-1 city12-2 city12-1
             city11-2 city11-1 city10-2 city10-1 city9-2 city9-1 city8-2
             city8-1 city7-2 city7-1 city6-2 city6-1 city5-2 city5-1
             city4-2 city4-1 city3-2 city3-1 city2-2 city2-1 city1-2
             city1-1 city27-3 city26-3 city25-3 city24-3 city23-3 city22-3
             city21-3 city20-3 city19-3 city18-3 city17-3 city16-3 city15-3
             city14-3 city13-3 city12-3 city11-3 city10-3 city9-3 city8-3
             city7-3 city6-3 city5-3 city4-3 city3-3 city2-3 city1-3)
   (:init (obj package53)
          (obj package52)
          (obj package51)
          (obj package50)
          (obj package49)
          (obj package48)
          (obj package47)
          (obj package46)
          (obj package45)
          (obj package44)
          (obj package43)
          (obj package42)
          (obj package41)
          (obj package40)
          (obj package39)
          (obj package38)
          (obj package37)
          (obj package36)
          (obj package35)
          (obj package34)
          (obj package33)
          (obj package32)
          (obj package31)
          (obj package30)
          (obj package29)
          (obj package28)
          (obj package27)
          (obj package26)
          (obj package25)
          (obj package24)
          (obj package23)
          (obj package22)
          (obj package21)
          (obj package20)
          (obj package19)
          (obj package18)
          (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city27)
          (city city26)
          (city city25)
          (city city24)
          (city city23)
          (city city22)
          (city city21)
          (city city20)
          (city city19)
          (city city18)
          (city city17)
          (city city16)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck46)
          (truck truck45)
          (truck truck44)
          (truck truck43)
          (truck truck42)
          (truck truck41)
          (truck truck40)
          (truck truck39)
          (truck truck38)
          (truck truck37)
          (truck truck36)
          (truck truck35)
          (truck truck34)
          (truck truck33)
          (truck truck32)
          (truck truck31)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane10)
          (airplane plane9)
          (airplane plane8)
          (airplane plane7)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city27-2)
          (location city27-1)
          (location city26-2)
          (location city26-1)
          (location city25-2)
          (location city25-1)
          (location city24-2)
          (location city24-1)
          (location city23-2)
          (location city23-1)
          (location city22-2)
          (location city22-1)
          (location city21-2)
          (location city21-1)
          (location city20-2)
          (location city20-1)
          (location city19-2)
          (location city19-1)
          (location city18-2)
          (location city18-1)
          (location city17-2)
          (location city17-1)
          (location city16-2)
          (location city16-1)
          (location city15-2)
          (location city15-1)
          (location city14-2)
          (location city14-1)
          (location city13-2)
          (location city13-1)
          (location city12-2)
          (location city12-1)
          (location city11-2)
          (location city11-1)
          (location city10-2)
          (location city10-1)
          (location city9-2)
          (location city9-1)
          (location city8-2)
          (location city8-1)
          (location city7-2)
          (location city7-1)
          (location city6-2)
          (location city6-1)
          (location city5-2)
          (location city5-1)
          (location city4-2)
          (location city4-1)
          (location city3-2)
          (location city3-1)
          (location city2-2)
          (location city2-1)
          (location city1-2)
          (location city1-1)
          (airport city27-3)
          (location city27-3)
          (airport city26-3)
          (location city26-3)
          (airport city25-3)
          (location city25-3)
          (airport city24-3)
          (location city24-3)
          (airport city23-3)
          (location city23-3)
          (airport city22-3)
          (location city22-3)
          (airport city21-3)
          (location city21-3)
          (airport city20-3)
          (location city20-3)
          (airport city19-3)
          (location city19-3)
          (airport city18-3)
          (location city18-3)
          (airport city17-3)
          (location city17-3)
          (airport city16-3)
          (location city16-3)
          (airport city15-3)
          (location city15-3)
          (airport city14-3)
          (location city14-3)
          (airport city13-3)
          (location city13-3)
          (airport city12-3)
          (location city12-3)
          (airport city11-3)
          (location city11-3)
          (airport city10-3)
          (location city10-3)
          (airport city9-3)
          (location city9-3)
          (airport city8-3)
          (location city8-3)
          (airport city7-3)
          (location city7-3)
          (airport city6-3)
          (location city6-3)
          (airport city5-3)
          (location city5-3)
          (airport city4-3)
          (location city4-3)
          (airport city3-3)
          (location city3-3)
          (airport city2-3)
          (location city2-3)
          (airport city1-3)
          (location city1-3)
          (in-city city27-3 city27)
          (in-city city27-2 city27)
          (in-city city27-1 city27)
          (in-city city26-3 city26)
          (in-city city26-2 city26)
          (in-city city26-1 city26)
          (in-city city25-3 city25)
          (in-city city25-2 city25)
          (in-city city25-1 city25)
          (in-city city24-3 city24)
          (in-city city24-2 city24)
          (in-city city24-1 city24)
          (in-city city23-3 city23)
          (in-city city23-2 city23)
          (in-city city23-1 city23)
          (in-city city22-3 city22)
          (in-city city22-2 city22)
          (in-city city22-1 city22)
          (in-city city21-3 city21)
          (in-city city21-2 city21)
          (in-city city21-1 city21)
          (in-city city20-3 city20)
          (in-city city20-2 city20)
          (in-city city20-1 city20)
          (in-city city19-3 city19)
          (in-city city19-2 city19)
          (in-city city19-1 city19)
          (in-city city18-3 city18)
          (in-city city18-2 city18)
          (in-city city18-1 city18)
          (in-city city17-3 city17)
          (in-city city17-2 city17)
          (in-city city17-1 city17)
          (in-city city16-3 city16)
          (in-city city16-2 city16)
          (in-city city16-1 city16)
          (in-city city15-3 city15)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane10 city9-3)
          (at plane9 city18-3)
          (at plane8 city15-3)
          (at plane7 city6-3)
          (at plane6 city7-3)
          (at plane5 city15-3)
          (at plane4 city13-3)
          (at plane3 city25-3)
          (at plane2 city6-3)
          (at plane1 city4-3)
          (at truck46 city27-2)
          (at truck45 city26-1)
          (at truck44 city25-1)
          (at truck43 city24-1)
          (at truck42 city23-2)
          (at truck41 city22-1)
          (at truck40 city21-1)
          (at truck39 city20-1)
          (at truck38 city19-2)
          (at truck37 city18-2)
          (at truck36 city17-1)
          (at truck35 city16-2)
          (at truck34 city15-1)
          (at truck33 city14-2)
          (at truck32 city13-2)
          (at truck31 city12-1)
          (at truck30 city11-2)
          (at truck29 city10-1)
          (at truck28 city9-1)
          (at truck27 city8-1)
          (at truck26 city7-1)
          (at truck25 city6-1)
          (at truck24 city5-2)
          (at truck23 city4-2)
          (at truck22 city3-2)
          (at truck21 city2-2)
          (at truck20 city1-1)
          (at truck19 city16-3)
          (at truck18 city21-1)
          (at truck17 city1-3)
          (at truck16 city25-3)
          (at truck15 city15-3)
          (at truck14 city25-1)
          (at truck13 city16-2)
          (at truck12 city24-1)
          (at truck11 city7-1)
          (at truck10 city10-3)
          (at truck9 city4-3)
          (at truck8 city25-1)
          (at truck7 city19-3)
          (at truck6 city25-2)
          (at truck5 city4-2)
          (at truck4 city19-2)
          (at truck3 city3-2)
          (at truck2 city27-3)
          (at truck1 city9-1)
          (at package53 city6-3)
          (at package52 city6-3)
          (at package51 city16-2)
          (at package50 city25-1)
          (at package49 city24-1)
          (at package48 city1-2)
          (at package47 city6-2)
          (at package46 city7-3)
          (at package45 city15-1)
          (at package44 city20-2)
          (at package43 city25-3)
          (at package42 city20-2)
          (at package41 city18-1)
          (at package40 city20-2)
          (at package39 city6-1)
          (at package38 city27-3)
          (at package37 city8-2)
          (at package36 city14-3)
          (at package35 city20-2)
          (at package34 city25-1)
          (at package33 city23-3)
          (at package32 city4-1)
          (at package31 city27-1)
          (at package30 city17-3)
          (at package29 city13-2)
          (at package28 city25-3)
          (at package27 city19-1)
          (at package26 city26-3)
          (at package25 city8-2)
          (at package24 city3-1)
          (at package23 city10-2)
          (at package22 city11-2)
          (at package21 city8-2)
          (at package20 city4-2)
          (at package19 city22-2)
          (at package18 city23-1)
          (at package17 city24-1)
          (at package16 city14-1)
          (at package15 city6-2)
          (at package14 city11-1)
          (at package13 city16-1)
          (at package12 city5-3)
          (at package11 city9-2)
          (at package10 city21-2)
          (at package9 city18-2)
          (at package8 city9-1)
          (at package7 city27-1)
          (at package6 city12-3)
          (at package5 city23-1)
          (at package4 city21-3)
          (at package3 city18-3)
          (at package2 city6-3)
          (at package1 city25-1))
   (:goal (and (at package53 city16-2)
               (at package52 city6-3)
               (at package51 city12-2)
               (at package50 city9-2)
               (at package49 city9-3)
               (at package48 city20-1)
               (at package47 city17-2)
               (at package46 city22-3)
               (at package45 city8-3)
               (at package44 city8-1)
               (at package43 city19-3)
               (at package42 city7-1)
               (at package41 city26-3)
               (at package40 city2-2)
               (at package39 city12-1)
               (at package38 city11-2)
               (at package37 city1-3)
               (at package36 city22-3)
               (at package35 city14-2)
               (at package34 city1-3)
               (at package33 city3-3)
               (at package32 city9-3)
               (at package31 city1-2)
               (at package30 city1-2)
               (at package29 city14-1)
               (at package28 city23-3)
               (at package27 city23-3)
               (at package26 city22-1)
               (at package25 city23-2)
               (at package24 city7-3)
               (at package23 city23-3)
               (at package22 city12-1)
               (at package21 city12-2)
               (at package20 city10-3)
               (at package19 city18-1)
               (at package18 city24-2)
               (at package17 city16-3)
               (at package16 city18-3)
               (at package15 city8-2)
               (at package14 city18-3)
               (at package13 city7-1)
               (at package12 city22-1)
               (at package11 city1-1)
               (at package10 city6-3)
               (at package9 city9-1))))

(define (problem strips-log-x-30)
   (:domain logistics-strips)
   (:objects package15 package14 package13 package12 package11
             package10 package9 package8 package7 package6 package5 package4
             package3 package2 package1 city22 city21 city20 city19 city18
             city17 city16 city15 city14 city13 city12 city11 city10 city9
             city8 city7 city6 city5 city4 city3 city2 city1 truck80
             truck79 truck78 truck77 truck76 truck75 truck74 truck73
             truck72 truck71 truck70 truck69 truck68 truck67 truck66
             truck65 truck64 truck63 truck62 truck61 truck60 truck59
             truck58 truck57 truck56 truck55 truck54 truck53 truck52
             truck51 truck50 truck49 truck48 truck47 truck46 truck45
             truck44 truck43 truck42 truck41 truck40 truck39 truck38
             truck37 truck36 truck35 truck34 truck33 truck32 truck31
             truck30 truck29 truck28 truck27 truck26 truck25 truck24
             truck23 truck22 truck21 truck20 truck19 truck18 truck17
             truck16 truck15 truck14 truck13 truck12 truck11 truck10 truck9
             truck8 truck7 truck6 truck5 truck4 truck3 truck2 truck1 plane3
             plane2 plane1 city22-11 city22-10 city22-9 city22-8 city22-7
             city22-6 city22-5 city22-4 city22-3 city22-2 city22-1
             city21-11 city21-10 city21-9 city21-8 city21-7 city21-6
             city21-5 city21-4 city21-3 city21-2 city21-1 city20-11
             city20-10 city20-9 city20-8 city20-7 city20-6 city20-5 city20-4
             city20-3 city20-2 city20-1 city19-11 city19-10 city19-9
             city19-8 city19-7 city19-6 city19-5 city19-4 city19-3 city19-2
             city19-1 city18-11 city18-10 city18-9 city18-8 city18-7
             city18-6 city18-5 city18-4 city18-3 city18-2 city18-1
             city17-11 city17-10 city17-9 city17-8 city17-7 city17-6
             city17-5 city17-4 city17-3 city17-2 city17-1 city16-11
             city16-10 city16-9 city16-8 city16-7 city16-6 city16-5 city16-4
             city16-3 city16-2 city16-1 city15-11 city15-10 city15-9
             city15-8 city15-7 city15-6 city15-5 city15-4 city15-3 city15-2
             city15-1 city14-11 city14-10 city14-9 city14-8 city14-7
             city14-6 city14-5 city14-4 city14-3 city14-2 city14-1
             city13-11 city13-10 city13-9 city13-8 city13-7 city13-6
             city13-5 city13-4 city13-3 city13-2 city13-1 city12-11
             city12-10 city12-9 city12-8 city12-7 city12-6 city12-5 city12-4
             city12-3 city12-2 city12-1 city11-11 city11-10 city11-9
             city11-8 city11-7 city11-6 city11-5 city11-4 city11-3 city11-2
             city11-1 city10-11 city10-10 city10-9 city10-8 city10-7
             city10-6 city10-5 city10-4 city10-3 city10-2 city10-1 city9-11
             city9-10 city9-9 city9-8 city9-7 city9-6 city9-5 city9-4
             city9-3 city9-2 city9-1 city8-11 city8-10 city8-9 city8-8
             city8-7 city8-6 city8-5 city8-4 city8-3 city8-2 city8-1
             city7-11 city7-10 city7-9 city7-8 city7-7 city7-6 city7-5
             city7-4 city7-3 city7-2 city7-1 city6-11 city6-10 city6-9
             city6-8 city6-7 city6-6 city6-5 city6-4 city6-3 city6-2
             city6-1 city5-11 city5-10 city5-9 city5-8 city5-7 city5-6
             city5-5 city5-4 city5-3 city5-2 city5-1 city4-11 city4-10
             city4-9 city4-8 city4-7 city4-6 city4-5 city4-4 city4-3
             city4-2 city4-1 city3-11 city3-10 city3-9 city3-8 city3-7
             city3-6 city3-5 city3-4 city3-3 city3-2 city3-1 city2-11
             city2-10 city2-9 city2-8 city2-7 city2-6 city2-5 city2-4
             city2-3 city2-2 city2-1 city1-11 city1-10 city1-9 city1-8
             city1-7 city1-6 city1-5 city1-4 city1-3 city1-2 city1-1
             city22-12 city21-12 city20-12 city19-12 city18-12 city17-12
             city16-12 city15-12 city14-12 city13-12 city12-12 city11-12
             city10-12 city9-12 city8-12 city7-12 city6-12 city5-12 city4-12
             city3-12 city2-12 city1-12)
   (:init (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city22)
          (city city21)
          (city city20)
          (city city19)
          (city city18)
          (city city17)
          (city city16)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck80)
          (truck truck79)
          (truck truck78)
          (truck truck77)
          (truck truck76)
          (truck truck75)
          (truck truck74)
          (truck truck73)
          (truck truck72)
          (truck truck71)
          (truck truck70)
          (truck truck69)
          (truck truck68)
          (truck truck67)
          (truck truck66)
          (truck truck65)
          (truck truck64)
          (truck truck63)
          (truck truck62)
          (truck truck61)
          (truck truck60)
          (truck truck59)
          (truck truck58)
          (truck truck57)
          (truck truck56)
          (truck truck55)
          (truck truck54)
          (truck truck53)
          (truck truck52)
          (truck truck51)
          (truck truck50)
          (truck truck49)
          (truck truck48)
          (truck truck47)
          (truck truck46)
          (truck truck45)
          (truck truck44)
          (truck truck43)
          (truck truck42)
          (truck truck41)
          (truck truck40)
          (truck truck39)
          (truck truck38)
          (truck truck37)
          (truck truck36)
          (truck truck35)
          (truck truck34)
          (truck truck33)
          (truck truck32)
          (truck truck31)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city22-11)
          (location city22-10)
          (location city22-9)
          (location city22-8)
          (location city22-7)
          (location city22-6)
          (location city22-5)
          (location city22-4)
          (location city22-3)
          (location city22-2)
          (location city22-1)
          (location city21-11)
          (location city21-10)
          (location city21-9)
          (location city21-8)
          (location city21-7)
          (location city21-6)
          (location city21-5)
          (location city21-4)
          (location city21-3)
          (location city21-2)
          (location city21-1)
          (location city20-11)
          (location city20-10)
          (location city20-9)
          (location city20-8)
          (location city20-7)
          (location city20-6)
          (location city20-5)
          (location city20-4)
          (location city20-3)
          (location city20-2)
          (location city20-1)
          (location city19-11)
          (location city19-10)
          (location city19-9)
          (location city19-8)
          (location city19-7)
          (location city19-6)
          (location city19-5)
          (location city19-4)
          (location city19-3)
          (location city19-2)
          (location city19-1)
          (location city18-11)
          (location city18-10)
          (location city18-9)
          (location city18-8)
          (location city18-7)
          (location city18-6)
          (location city18-5)
          (location city18-4)
          (location city18-3)
          (location city18-2)
          (location city18-1)
          (location city17-11)
          (location city17-10)
          (location city17-9)
          (location city17-8)
          (location city17-7)
          (location city17-6)
          (location city17-5)
          (location city17-4)
          (location city17-3)
          (location city17-2)
          (location city17-1)
          (location city16-11)
          (location city16-10)
          (location city16-9)
          (location city16-8)
          (location city16-7)
          (location city16-6)
          (location city16-5)
          (location city16-4)
          (location city16-3)
          (location city16-2)
          (location city16-1)
          (location city15-11)
          (location city15-10)
          (location city15-9)
          (location city15-8)
          (location city15-7)
          (location city15-6)
          (location city15-5)
          (location city15-4)
          (location city15-3)
          (location city15-2)
          (location city15-1)
          (location city14-11)
          (location city14-10)
          (location city14-9)
          (location city14-8)
          (location city14-7)
          (location city14-6)
          (location city14-5)
          (location city14-4)
          (location city14-3)
          (location city14-2)
          (location city14-1)
          (location city13-11)
          (location city13-10)
          (location city13-9)
          (location city13-8)
          (location city13-7)
          (location city13-6)
          (location city13-5)
          (location city13-4)
          (location city13-3)
          (location city13-2)
          (location city13-1)
          (location city12-11)
          (location city12-10)
          (location city12-9)
          (location city12-8)
          (location city12-7)
          (location city12-6)
          (location city12-5)
          (location city12-4)
          (location city12-3)
          (location city12-2)
          (location city12-1)
          (location city11-11)
          (location city11-10)
          (location city11-9)
          (location city11-8)
          (location city11-7)
          (location city11-6)
          (location city11-5)
          (location city11-4)
          (location city11-3)
          (location city11-2)
          (location city11-1)
          (location city10-11)
          (location city10-10)
          (location city10-9)
          (location city10-8)
          (location city10-7)
          (location city10-6)
          (location city10-5)
          (location city10-4)
          (location city10-3)
          (location city10-2)
          (location city10-1)
          (location city9-11)
          (location city9-10)
          (location city9-9)
          (location city9-8)
          (location city9-7)
          (location city9-6)
          (location city9-5)
          (location city9-4)
          (location city9-3)
          (location city9-2)
          (location city9-1)
          (location city8-11)
          (location city8-10)
          (location city8-9)
          (location city8-8)
          (location city8-7)
          (location city8-6)
          (location city8-5)
          (location city8-4)
          (location city8-3)
          (location city8-2)
          (location city8-1)
          (location city7-11)
          (location city7-10)
          (location city7-9)
          (location city7-8)
          (location city7-7)
          (location city7-6)
          (location city7-5)
          (location city7-4)
          (location city7-3)
          (location city7-2)
          (location city7-1)
          (location city6-11)
          (location city6-10)
          (location city6-9)
          (location city6-8)
          (location city6-7)
          (location city6-6)
          (location city6-5)
          (location city6-4)
          (location city6-3)
          (location city6-2)
          (location city6-1)
          (location city5-11)
          (location city5-10)
          (location city5-9)
          (location city5-8)
          (location city5-7)
          (location city5-6)
          (location city5-5)
          (location city5-4)
          (location city5-3)
          (location city5-2)
          (location city5-1)
          (location city4-11)
          (location city4-10)
          (location city4-9)
          (location city4-8)
          (location city4-7)
          (location city4-6)
          (location city4-5)
          (location city4-4)
          (location city4-3)
          (location city4-2)
          (location city4-1)
          (location city3-11)
          (location city3-10)
          (location city3-9)
          (location city3-8)
          (location city3-7)
          (location city3-6)
          (location city3-5)
          (location city3-4)
          (location city3-3)
          (location city3-2)
          (location city3-1)
          (location city2-11)
          (location city2-10)
          (location city2-9)
          (location city2-8)
          (location city2-7)
          (location city2-6)
          (location city2-5)
          (location city2-4)
          (location city2-3)
          (location city2-2)
          (location city2-1)
          (location city1-11)
          (location city1-10)
          (location city1-9)
          (location city1-8)
          (location city1-7)
          (location city1-6)
          (location city1-5)
          (location city1-4)
          (location city1-3)
          (location city1-2)
          (location city1-1)
          (airport city22-12)
          (location city22-12)
          (airport city21-12)
          (location city21-12)
          (airport city20-12)
          (location city20-12)
          (airport city19-12)
          (location city19-12)
          (airport city18-12)
          (location city18-12)
          (airport city17-12)
          (location city17-12)
          (airport city16-12)
          (location city16-12)
          (airport city15-12)
          (location city15-12)
          (airport city14-12)
          (location city14-12)
          (airport city13-12)
          (location city13-12)
          (airport city12-12)
          (location city12-12)
          (airport city11-12)
          (location city11-12)
          (airport city10-12)
          (location city10-12)
          (airport city9-12)
          (location city9-12)
          (airport city8-12)
          (location city8-12)
          (airport city7-12)
          (location city7-12)
          (airport city6-12)
          (location city6-12)
          (airport city5-12)
          (location city5-12)
          (airport city4-12)
          (location city4-12)
          (airport city3-12)
          (location city3-12)
          (airport city2-12)
          (location city2-12)
          (airport city1-12)
          (location city1-12)
          (in-city city22-12 city22)
          (in-city city22-11 city22)
          (in-city city22-10 city22)
          (in-city city22-9 city22)
          (in-city city22-8 city22)
          (in-city city22-7 city22)
          (in-city city22-6 city22)
          (in-city city22-5 city22)
          (in-city city22-4 city22)
          (in-city city22-3 city22)
          (in-city city22-2 city22)
          (in-city city22-1 city22)
          (in-city city21-12 city21)
          (in-city city21-11 city21)
          (in-city city21-10 city21)
          (in-city city21-9 city21)
          (in-city city21-8 city21)
          (in-city city21-7 city21)
          (in-city city21-6 city21)
          (in-city city21-5 city21)
          (in-city city21-4 city21)
          (in-city city21-3 city21)
          (in-city city21-2 city21)
          (in-city city21-1 city21)
          (in-city city20-12 city20)
          (in-city city20-11 city20)
          (in-city city20-10 city20)
          (in-city city20-9 city20)
          (in-city city20-8 city20)
          (in-city city20-7 city20)
          (in-city city20-6 city20)
          (in-city city20-5 city20)
          (in-city city20-4 city20)
          (in-city city20-3 city20)
          (in-city city20-2 city20)
          (in-city city20-1 city20)
          (in-city city19-12 city19)
          (in-city city19-11 city19)
          (in-city city19-10 city19)
          (in-city city19-9 city19)
          (in-city city19-8 city19)
          (in-city city19-7 city19)
          (in-city city19-6 city19)
          (in-city city19-5 city19)
          (in-city city19-4 city19)
          (in-city city19-3 city19)
          (in-city city19-2 city19)
          (in-city city19-1 city19)
          (in-city city18-12 city18)
          (in-city city18-11 city18)
          (in-city city18-10 city18)
          (in-city city18-9 city18)
          (in-city city18-8 city18)
          (in-city city18-7 city18)
          (in-city city18-6 city18)
          (in-city city18-5 city18)
          (in-city city18-4 city18)
          (in-city city18-3 city18)
          (in-city city18-2 city18)
          (in-city city18-1 city18)
          (in-city city17-12 city17)
          (in-city city17-11 city17)
          (in-city city17-10 city17)
          (in-city city17-9 city17)
          (in-city city17-8 city17)
          (in-city city17-7 city17)
          (in-city city17-6 city17)
          (in-city city17-5 city17)
          (in-city city17-4 city17)
          (in-city city17-3 city17)
          (in-city city17-2 city17)
          (in-city city17-1 city17)
          (in-city city16-12 city16)
          (in-city city16-11 city16)
          (in-city city16-10 city16)
          (in-city city16-9 city16)
          (in-city city16-8 city16)
          (in-city city16-7 city16)
          (in-city city16-6 city16)
          (in-city city16-5 city16)
          (in-city city16-4 city16)
          (in-city city16-3 city16)
          (in-city city16-2 city16)
          (in-city city16-1 city16)
          (in-city city15-12 city15)
          (in-city city15-11 city15)
          (in-city city15-10 city15)
          (in-city city15-9 city15)
          (in-city city15-8 city15)
          (in-city city15-7 city15)
          (in-city city15-6 city15)
          (in-city city15-5 city15)
          (in-city city15-4 city15)
          (in-city city15-3 city15)
          (in-city city15-2 city15)
          (in-city city15-1 city15)
          (in-city city14-12 city14)
          (in-city city14-11 city14)
          (in-city city14-10 city14)
          (in-city city14-9 city14)
          (in-city city14-8 city14)
          (in-city city14-7 city14)
          (in-city city14-6 city14)
          (in-city city14-5 city14)
          (in-city city14-4 city14)
          (in-city city14-3 city14)
          (in-city city14-2 city14)
          (in-city city14-1 city14)
          (in-city city13-12 city13)
          (in-city city13-11 city13)
          (in-city city13-10 city13)
          (in-city city13-9 city13)
          (in-city city13-8 city13)
          (in-city city13-7 city13)
          (in-city city13-6 city13)
          (in-city city13-5 city13)
          (in-city city13-4 city13)
          (in-city city13-3 city13)
          (in-city city13-2 city13)
          (in-city city13-1 city13)
          (in-city city12-12 city12)
          (in-city city12-11 city12)
          (in-city city12-10 city12)
          (in-city city12-9 city12)
          (in-city city12-8 city12)
          (in-city city12-7 city12)
          (in-city city12-6 city12)
          (in-city city12-5 city12)
          (in-city city12-4 city12)
          (in-city city12-3 city12)
          (in-city city12-2 city12)
          (in-city city12-1 city12)
          (in-city city11-12 city11)
          (in-city city11-11 city11)
          (in-city city11-10 city11)
          (in-city city11-9 city11)
          (in-city city11-8 city11)
          (in-city city11-7 city11)
          (in-city city11-6 city11)
          (in-city city11-5 city11)
          (in-city city11-4 city11)
          (in-city city11-3 city11)
          (in-city city11-2 city11)
          (in-city city11-1 city11)
          (in-city city10-12 city10)
          (in-city city10-11 city10)
          (in-city city10-10 city10)
          (in-city city10-9 city10)
          (in-city city10-8 city10)
          (in-city city10-7 city10)
          (in-city city10-6 city10)
          (in-city city10-5 city10)
          (in-city city10-4 city10)
          (in-city city10-3 city10)
          (in-city city10-2 city10)
          (in-city city10-1 city10)
          (in-city city9-12 city9)
          (in-city city9-11 city9)
          (in-city city9-10 city9)
          (in-city city9-9 city9)
          (in-city city9-8 city9)
          (in-city city9-7 city9)
          (in-city city9-6 city9)
          (in-city city9-5 city9)
          (in-city city9-4 city9)
          (in-city city9-3 city9)
          (in-city city9-2 city9)
          (in-city city9-1 city9)
          (in-city city8-12 city8)
          (in-city city8-11 city8)
          (in-city city8-10 city8)
          (in-city city8-9 city8)
          (in-city city8-8 city8)
          (in-city city8-7 city8)
          (in-city city8-6 city8)
          (in-city city8-5 city8)
          (in-city city8-4 city8)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-12 city7)
          (in-city city7-11 city7)
          (in-city city7-10 city7)
          (in-city city7-9 city7)
          (in-city city7-8 city7)
          (in-city city7-7 city7)
          (in-city city7-6 city7)
          (in-city city7-5 city7)
          (in-city city7-4 city7)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-12 city6)
          (in-city city6-11 city6)
          (in-city city6-10 city6)
          (in-city city6-9 city6)
          (in-city city6-8 city6)
          (in-city city6-7 city6)
          (in-city city6-6 city6)
          (in-city city6-5 city6)
          (in-city city6-4 city6)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-12 city5)
          (in-city city5-11 city5)
          (in-city city5-10 city5)
          (in-city city5-9 city5)
          (in-city city5-8 city5)
          (in-city city5-7 city5)
          (in-city city5-6 city5)
          (in-city city5-5 city5)
          (in-city city5-4 city5)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-12 city4)
          (in-city city4-11 city4)
          (in-city city4-10 city4)
          (in-city city4-9 city4)
          (in-city city4-8 city4)
          (in-city city4-7 city4)
          (in-city city4-6 city4)
          (in-city city4-5 city4)
          (in-city city4-4 city4)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-12 city3)
          (in-city city3-11 city3)
          (in-city city3-10 city3)
          (in-city city3-9 city3)
          (in-city city3-8 city3)
          (in-city city3-7 city3)
          (in-city city3-6 city3)
          (in-city city3-5 city3)
          (in-city city3-4 city3)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-12 city2)
          (in-city city2-11 city2)
          (in-city city2-10 city2)
          (in-city city2-9 city2)
          (in-city city2-8 city2)
          (in-city city2-7 city2)
          (in-city city2-6 city2)
          (in-city city2-5 city2)
          (in-city city2-4 city2)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-12 city1)
          (in-city city1-11 city1)
          (in-city city1-10 city1)
          (in-city city1-9 city1)
          (in-city city1-8 city1)
          (in-city city1-7 city1)
          (in-city city1-6 city1)
          (in-city city1-5 city1)
          (in-city city1-4 city1)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane3 city20-12)
          (at plane2 city8-12)
          (at plane1 city14-12)
          (at truck80 city22-1)
          (at truck79 city21-7)
          (at truck78 city20-4)
          (at truck77 city19-7)
          (at truck76 city18-4)
          (at truck75 city17-5)
          (at truck74 city16-2)
          (at truck73 city15-9)
          (at truck72 city14-4)
          (at truck71 city13-9)
          (at truck70 city12-5)
          (at truck69 city11-1)
          (at truck68 city10-9)
          (at truck67 city9-8)
          (at truck66 city8-8)
          (at truck65 city7-1)
          (at truck64 city6-2)
          (at truck63 city5-4)
          (at truck62 city4-1)
          (at truck61 city3-7)
          (at truck60 city2-7)
          (at truck59 city1-10)
          (at truck58 city1-5)
          (at truck57 city20-9)
          (at truck56 city5-10)
          (at truck55 city19-5)
          (at truck54 city5-2)
          (at truck53 city11-8)
          (at truck52 city21-9)
          (at truck51 city3-4)
          (at truck50 city11-1)
          (at truck49 city9-6)
          (at truck48 city17-11)
          (at truck47 city6-6)
          (at truck46 city3-7)
          (at truck45 city14-6)
          (at truck44 city8-3)
          (at truck43 city5-2)
          (at truck42 city2-8)
          (at truck41 city15-11)
          (at truck40 city14-5)
          (at truck39 city7-2)
          (at truck38 city10-8)
          (at truck37 city21-6)
          (at truck36 city11-2)
          (at truck35 city21-6)
          (at truck34 city15-12)
          (at truck33 city7-12)
          (at truck32 city8-3)
          (at truck31 city22-9)
          (at truck30 city16-7)
          (at truck29 city8-6)
          (at truck28 city15-7)
          (at truck27 city12-12)
          (at truck26 city14-10)
          (at truck25 city8-7)
          (at truck24 city10-7)
          (at truck23 city10-10)
          (at truck22 city11-3)
          (at truck21 city9-5)
          (at truck20 city6-3)
          (at truck19 city4-4)
          (at truck18 city5-6)
          (at truck17 city5-10)
          (at truck16 city7-3)
          (at truck15 city21-7)
          (at truck14 city16-9)
          (at truck13 city1-10)
          (at truck12 city2-10)
          (at truck11 city4-9)
          (at truck10 city7-11)
          (at truck9 city8-9)
          (at truck8 city12-7)
          (at truck7 city19-5)
          (at truck6 city3-12)
          (at truck5 city13-2)
          (at truck4 city6-12)
          (at truck3 city2-6)
          (at truck2 city11-3)
          (at truck1 city14-1)
          (at package15 city5-7)
          (at package14 city15-7)
          (at package13 city11-12)
          (at package12 city8-3)
          (at package11 city10-7)
          (at package10 city14-11)
          (at package9 city16-1)
          (at package8 city21-12)
          (at package7 city13-4)
          (at package6 city2-3)
          (at package5 city6-10)
          (at package4 city11-2)
          (at package3 city7-7)
          (at package2 city8-6)
          (at package1 city6-12))
   (:goal (and (at package15 city14-12)
               (at package14 city20-9)
               (at package13 city5-8)
               (at package12 city20-4)
               (at package11 city1-4)
               (at package10 city20-7)
               (at package9 city2-5)
               (at package8 city11-10)
               (at package7 city4-12)
               (at package6 city3-11)
               (at package5 city9-3)
               (at package4 city9-6)
               (at package3 city5-12)
               (at package2 city11-8)
               (at package1 city5-5))))

(define (problem strips-log-y-1)
   (:domain logistics-strips)
   (:objects package3 package2 package1 city5 city4 city3 city2
             city1 truck5 truck4 truck3 truck2 truck1 plane2 plane1
             city5-1 city4-1 city3-1 city2-1 city1-1 city5-2 city4-2
             city3-2 city2-2 city1-2)
   (:init (obj package3)
          (obj package2)
          (obj package1)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane2)
          (airplane plane1)
          (location city5-1)
          (location city4-1)
          (location city3-1)
          (location city2-1)
          (location city1-1)
          (airport city5-2)
          (location city5-2)
          (airport city4-2)
          (location city4-2)
          (airport city3-2)
          (location city3-2)
          (airport city2-2)
          (location city2-2)
          (airport city1-2)
          (location city1-2)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane2 city1-2)
          (at plane1 city2-2)
          (at truck5 city5-1)
          (at truck4 city4-1)
          (at truck3 city3-1)
          (at truck2 city2-1)
          (at truck1 city1-1)
          (at package3 city1-1)
          (at package2 city1-2)
          (at package1 city4-1))
   (:goal (and (at package3 city1-2)
               (at package2 city1-1)
               (at package1 city3-2))))

(define (problem strips-log-y-2)
   (:domain logistics-strips)
   (:objects package5 package4 package3 package2 package1 city3
             city2 city1 truck6 truck5 truck4 truck3 truck2 truck1 plane1
             city3-1 city2-1 city1-1 city3-2 city2-2 city1-2)
   (:init (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city3)
          (city city2)
          (city city1)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane1)
          (location city3-1)
          (location city2-1)
          (location city1-1)
          (airport city3-2)
          (location city3-2)
          (airport city2-2)
          (location city2-2)
          (airport city1-2)
          (location city1-2)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane1 city3-2)
          (at truck6 city3-1)
          (at truck5 city2-1)
          (at truck4 city1-1)
          (at truck3 city3-2)
          (at truck2 city1-2)
          (at truck1 city2-2)
          (at package5 city2-1)
          (at package4 city1-2)
          (at package3 city1-1)
          (at package2 city2-2)
          (at package1 city2-1))
   (:goal (and (at package5 city3-2)
               (at package4 city2-1)
               (at package3 city2-1))))

(define (problem strips-log-y-3)
   (:domain logistics-strips)
   (:objects package7 package6 package5 package4 package3 package2
             package1 city3 city2 city1 truck9 truck8 truck7 truck6 truck5
             truck4 truck3 truck2 truck1 plane1 city3-1 city2-1 city1-1
             city3-2 city2-2 city1-2)
   (:init (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city3)
          (city city2)
          (city city1)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane1)
          (location city3-1)
          (location city2-1)
          (location city1-1)
          (airport city3-2)
          (location city3-2)
          (airport city2-2)
          (location city2-2)
          (airport city1-2)
          (location city1-2)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane1 city1-2)
          (at truck9 city3-1)
          (at truck8 city2-1)
          (at truck7 city1-1)
          (at truck6 city1-2)
          (at truck5 city3-1)
          (at truck4 city3-1)
          (at truck3 city1-2)
          (at truck2 city1-2)
          (at truck1 city2-2)
          (at package7 city2-1)
          (at package6 city2-2)
          (at package5 city2-2)
          (at package4 city3-1)
          (at package3 city2-1)
          (at package2 city1-2)
          (at package1 city1-2))
   (:goal (and (at package7 city2-2)
               (at package6 city3-2)
               (at package5 city3-2)
               (at package4 city2-2)
               (at package3 city3-2)
               (at package2 city1-1)
               (at package1 city2-1))))

(define (problem strips-log-y-4)
   (:domain logistics-strips)
   (:objects package6 package5 package4 package3 package2 package1
             city5 city4 city3 city2 city1 truck14 truck13 truck12 truck11
             truck10 truck9 truck8 truck7 truck6 truck5 truck4 truck3 truck2
             truck1 plane2 plane1 city5-2 city5-1 city4-2 city4-1 city3-2
             city3-1 city2-2 city2-1 city1-2 city1-1 city5-3 city4-3
             city3-3 city2-3 city1-3)
   (:init (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane2)
          (airplane plane1)
          (location city5-2)
          (location city5-1)
          (location city4-2)
          (location city4-1)
          (location city3-2)
          (location city3-1)
          (location city2-2)
          (location city2-1)
          (location city1-2)
          (location city1-1)
          (airport city5-3)
          (location city5-3)
          (airport city4-3)
          (location city4-3)
          (airport city3-3)
          (location city3-3)
          (airport city2-3)
          (location city2-3)
          (airport city1-3)
          (location city1-3)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane2 city3-3)
          (at plane1 city5-3)
          (at truck14 city5-1)
          (at truck13 city4-1)
          (at truck12 city3-2)
          (at truck11 city2-2)
          (at truck10 city1-2)
          (at truck9 city3-1)
          (at truck8 city3-1)
          (at truck7 city1-3)
          (at truck6 city5-1)
          (at truck5 city4-1)
          (at truck4 city1-1)
          (at truck3 city1-2)
          (at truck2 city3-1)
          (at truck1 city2-1)
          (at package6 city4-2)
          (at package5 city4-3)
          (at package4 city1-1)
          (at package3 city3-2)
          (at package2 city5-1)
          (at package1 city4-1))
   (:goal (and (at package6 city1-3)
               (at package5 city5-2)
               (at package4 city3-1)
               (at package3 city4-2)
               (at package2 city2-3)
               (at package1 city2-2))))

(define (problem strips-log-y-5)
   (:domain logistics-strips)
   (:objects package5 package4 package3 package2 package1 city8
             city7 city6 city5 city4 city3 city2 city1 truck15 truck14
             truck13 truck12 truck11 truck10 truck9 truck8 truck7 truck6
             truck5 truck4 truck3 truck2 truck1 plane1 city8-2 city8-1
             city7-2 city7-1 city6-2 city6-1 city5-2 city5-1 city4-2
             city4-1 city3-2 city3-1 city2-2 city2-1 city1-2 city1-1
             city8-3 city7-3 city6-3 city5-3 city4-3 city3-3 city2-3
             city1-3)
   (:init (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane1)
          (location city8-2)
          (location city8-1)
          (location city7-2)
          (location city7-1)
          (location city6-2)
          (location city6-1)
          (location city5-2)
          (location city5-1)
          (location city4-2)
          (location city4-1)
          (location city3-2)
          (location city3-1)
          (location city2-2)
          (location city2-1)
          (location city1-2)
          (location city1-1)
          (airport city8-3)
          (location city8-3)
          (airport city7-3)
          (location city7-3)
          (airport city6-3)
          (location city6-3)
          (airport city5-3)
          (location city5-3)
          (airport city4-3)
          (location city4-3)
          (airport city3-3)
          (location city3-3)
          (airport city2-3)
          (location city2-3)
          (airport city1-3)
          (location city1-3)
          (in-city city8-3 city8)
          (in-city city8-2 city8)
          (in-city city8-1 city8)
          (in-city city7-3 city7)
          (in-city city7-2 city7)
          (in-city city7-1 city7)
          (in-city city6-3 city6)
          (in-city city6-2 city6)
          (in-city city6-1 city6)
          (in-city city5-3 city5)
          (in-city city5-2 city5)
          (in-city city5-1 city5)
          (in-city city4-3 city4)
          (in-city city4-2 city4)
          (in-city city4-1 city4)
          (in-city city3-3 city3)
          (in-city city3-2 city3)
          (in-city city3-1 city3)
          (in-city city2-3 city2)
          (in-city city2-2 city2)
          (in-city city2-1 city2)
          (in-city city1-3 city1)
          (in-city city1-2 city1)
          (in-city city1-1 city1)
          (at plane1 city3-3)
          (at truck15 city8-2)
          (at truck14 city7-2)
          (at truck13 city6-1)
          (at truck12 city5-2)
          (at truck11 city4-1)
          (at truck10 city3-2)
          (at truck9 city2-1)
          (at truck8 city1-2)
          (at truck7 city6-1)
          (at truck6 city3-2)
          (at truck5 city1-3)
          (at truck4 city4-3)
          (at truck3 city1-3)
          (at truck2 city7-1)
          (at truck1 city8-1)
          (at package5 city3-2)
          (at package4 city5-1)
          (at package3 city1-1)
          (at package2 city5-2)
          (at package1 city2-1))
   (:goal (and (at package5 city6-3)
               (at package4 city5-3)
               (at package3 city8-3)
               (at package2 city4-3)
               (at package1 city6-3))))

(DEFINE (PROBLEM STRIPS-LOG-Y-1)
        (:DOMAIN LOGISTICS-ADL)
        (:OBJECTS CITY1-2 CITY2-2 CITY3-2 CITY4-2 CITY5-2 - AIRPORT CITY1-2
                  CITY2-2 CITY3-2 CITY4-2 CITY5-2 CITY1-1 CITY2-1 CITY3-1
                  CITY4-1 CITY5-1 - LOCATION PLANE1 PLANE2 - AIRPLANE TRUCK1
                  TRUCK2 TRUCK3 TRUCK4 TRUCK5 - TRUCK CITY1 CITY2 CITY3 CITY4
                  CITY5 - CITY PACKAGE1 PACKAGE2 PACKAGE3 - OBJ)
        (:INIT (IN-CITY CITY5-2 CITY5)
               (IN-CITY CITY5-1 CITY5)
               (IN-CITY CITY4-2 CITY4)
               (IN-CITY CITY4-1 CITY4)
               (IN-CITY CITY3-2 CITY3)
               (IN-CITY CITY3-1 CITY3)
               (IN-CITY CITY2-2 CITY2)
               (IN-CITY CITY2-1 CITY2)
               (IN-CITY CITY1-2 CITY1)
               (IN-CITY CITY1-1 CITY1)
               (AT PLANE2 CITY1-2)
               (AT PLANE1 CITY2-2)
               (AT TRUCK5 CITY5-1)
               (AT TRUCK4 CITY4-1)
               (AT TRUCK3 CITY3-1)
               (AT TRUCK2 CITY2-1)
               (AT TRUCK1 CITY1-1)
               (AT PACKAGE3 CITY1-1)
               (AT PACKAGE2 CITY1-2)
               (AT PACKAGE1 CITY4-1))
        (:GOAL (AND (AT PACKAGE3 CITY1-2)
                    (AT PACKAGE2 CITY1-1)
                    (AT PACKAGE1 CITY3-2))))

(DEFINE (PROBLEM STRIPS-LOG-Y-2)
        (:DOMAIN LOGISTICS-ADL)
        (:OBJECTS CITY1-2 CITY2-2 CITY3-2 - AIRPORT CITY1-2 CITY2-2 CITY3-2
                  CITY1-1 CITY2-1 CITY3-1 - LOCATION PLANE1 - AIRPLANE TRUCK1
                  TRUCK2 TRUCK3 TRUCK4 TRUCK5 TRUCK6 - TRUCK CITY1 CITY2 CITY3 -
                  CITY PACKAGE1 PACKAGE2 PACKAGE3 PACKAGE4 PACKAGE5 - OBJ)
        (:INIT (IN-CITY CITY3-2 CITY3)
               (IN-CITY CITY3-1 CITY3)
               (IN-CITY CITY2-2 CITY2)
               (IN-CITY CITY2-1 CITY2)
               (IN-CITY CITY1-2 CITY1)
               (IN-CITY CITY1-1 CITY1)
               (AT PLANE1 CITY3-2)
               (AT TRUCK6 CITY3-1)
               (AT TRUCK5 CITY2-1)
               (AT TRUCK4 CITY1-1)
               (AT TRUCK3 CITY3-2)
               (AT TRUCK2 CITY1-2)
               (AT TRUCK1 CITY2-2)
               (AT PACKAGE5 CITY2-1)
               (AT PACKAGE4 CITY1-2)
               (AT PACKAGE3 CITY1-1)
               (AT PACKAGE2 CITY2-2)
               (AT PACKAGE1 CITY2-1))
        (:GOAL (AND (AT PACKAGE5 CITY3-2)
                    (AT PACKAGE4 CITY2-1)
                    (AT PACKAGE3 CITY2-1))))

(DEFINE (PROBLEM STRIPS-LOG-Y-3)
        (:DOMAIN LOGISTICS-ADL)
        (:OBJECTS CITY1-2 CITY2-2 CITY3-2 - AIRPORT CITY1-2 CITY2-2 CITY3-2
                  CITY1-1 CITY2-1 CITY3-1 - LOCATION PLANE1 - AIRPLANE TRUCK1
                  TRUCK2 TRUCK3 TRUCK4 TRUCK5 TRUCK6 TRUCK7 TRUCK8 TRUCK9 -
                  TRUCK CITY1 CITY2 CITY3 - CITY PACKAGE1 PACKAGE2 PACKAGE3
                  PACKAGE4 PACKAGE5 PACKAGE6 PACKAGE7 - OBJ)
        (:INIT (IN-CITY CITY3-2 CITY3)
               (IN-CITY CITY3-1 CITY3)
               (IN-CITY CITY2-2 CITY2)
               (IN-CITY CITY2-1 CITY2)
               (IN-CITY CITY1-2 CITY1)
               (IN-CITY CITY1-1 CITY1)
               (AT PLANE1 CITY1-2)
               (AT TRUCK9 CITY3-1)
               (AT TRUCK8 CITY2-1)
               (AT TRUCK7 CITY1-1)
               (AT TRUCK6 CITY1-2)
               (AT TRUCK5 CITY3-1)
               (AT TRUCK4 CITY3-1)
               (AT TRUCK3 CITY1-2)
               (AT TRUCK2 CITY1-2)
               (AT TRUCK1 CITY2-2)
               (AT PACKAGE7 CITY2-1)
               (AT PACKAGE6 CITY2-2)
               (AT PACKAGE5 CITY2-2)
               (AT PACKAGE4 CITY3-1)
               (AT PACKAGE3 CITY2-1)
               (AT PACKAGE2 CITY1-2)
               (AT PACKAGE1 CITY1-2))
        (:GOAL
         (AND (AT PACKAGE7 CITY2-2)
              (AT PACKAGE6 CITY3-2)
              (AT PACKAGE5 CITY3-2)
              (AT PACKAGE4 CITY2-2)
              (AT PACKAGE3 CITY3-2)
              (AT PACKAGE2 CITY1-1)
              (AT PACKAGE1 CITY2-1))))

(DEFINE (PROBLEM STRIPS-LOG-Y-4)
        (:DOMAIN LOGISTICS-ADL)
        (:OBJECTS CITY1-3 CITY2-3 CITY3-3 CITY4-3 CITY5-3 - AIRPORT CITY1-3
                  CITY2-3 CITY3-3 CITY4-3 CITY5-3 CITY1-1 CITY1-2 CITY2-1
                  CITY2-2 CITY3-1 CITY3-2 CITY4-1 CITY4-2 CITY5-1 CITY5-2 -
                  LOCATION PLANE1 PLANE2 - AIRPLANE TRUCK1 TRUCK2 TRUCK3 TRUCK4
                  TRUCK5 TRUCK6 TRUCK7 TRUCK8 TRUCK9 TRUCK10 TRUCK11 TRUCK12
                  TRUCK13 TRUCK14 - TRUCK CITY1 CITY2 CITY3 CITY4 CITY5 - CITY
                  PACKAGE1 PACKAGE2 PACKAGE3 PACKAGE4 PACKAGE5 PACKAGE6 - OBJ)
        (:INIT (IN-CITY CITY5-3 CITY5)
               (IN-CITY CITY5-2 CITY5)
               (IN-CITY CITY5-1 CITY5)
               (IN-CITY CITY4-3 CITY4)
               (IN-CITY CITY4-2 CITY4)
               (IN-CITY CITY4-1 CITY4)
               (IN-CITY CITY3-3 CITY3)
               (IN-CITY CITY3-2 CITY3)
               (IN-CITY CITY3-1 CITY3)
               (IN-CITY CITY2-3 CITY2)
               (IN-CITY CITY2-2 CITY2)
               (IN-CITY CITY2-1 CITY2)
               (IN-CITY CITY1-3 CITY1)
               (IN-CITY CITY1-2 CITY1)
               (IN-CITY CITY1-1 CITY1)
               (AT PLANE2 CITY3-3)
               (AT PLANE1 CITY5-3)
               (AT TRUCK14 CITY5-1)
               (AT TRUCK13 CITY4-1)
               (AT TRUCK12 CITY3-2)
               (AT TRUCK11 CITY2-2)
               (AT TRUCK10 CITY1-2)
               (AT TRUCK9 CITY3-1)
               (AT TRUCK8 CITY3-1)
               (AT TRUCK7 CITY1-3)
               (AT TRUCK6 CITY5-1)
               (AT TRUCK5 CITY4-1)
               (AT TRUCK4 CITY1-1)
               (AT TRUCK3 CITY1-2)
               (AT TRUCK2 CITY3-1)
               (AT TRUCK1 CITY2-1)
               (AT PACKAGE6 CITY4-2)
               (AT PACKAGE5 CITY4-3)
               (AT PACKAGE4 CITY1-1)
               (AT PACKAGE3 CITY3-2)
               (AT PACKAGE2 CITY5-1)
               (AT PACKAGE1 CITY4-1))
        (:GOAL
         (AND (AT PACKAGE6 CITY1-3)
              (AT PACKAGE5 CITY5-2)
              (AT PACKAGE4 CITY3-1)
              (AT PACKAGE3 CITY4-2)
              (AT PACKAGE2 CITY2-3)
              (AT PACKAGE1 CITY2-2))))

(DEFINE (PROBLEM STRIPS-LOG-Y-5)
        (:DOMAIN LOGISTICS-ADL)
        (:OBJECTS CITY1-3 CITY2-3 CITY3-3 CITY4-3 CITY5-3 CITY6-3 CITY7-3
                  CITY8-3 - AIRPORT CITY1-3 CITY2-3 CITY3-3 CITY4-3 CITY5-3
                  CITY6-3 CITY7-3 CITY8-3 CITY1-1 CITY1-2 CITY2-1 CITY2-2
                  CITY3-1 CITY3-2 CITY4-1 CITY4-2 CITY5-1 CITY5-2 CITY6-1
                  CITY6-2 CITY7-1 CITY7-2 CITY8-1 CITY8-2 - LOCATION PLANE1 -
                  AIRPLANE TRUCK1 TRUCK2 TRUCK3 TRUCK4 TRUCK5 TRUCK6 TRUCK7
                  TRUCK8 TRUCK9 TRUCK10 TRUCK11 TRUCK12 TRUCK13 TRUCK14 TRUCK15
                  - TRUCK CITY1 CITY2 CITY3 CITY4 CITY5 CITY6 CITY7 CITY8 - CITY
                  PACKAGE1 PACKAGE2 PACKAGE3 PACKAGE4 PACKAGE5 - OBJ)
        (:INIT (IN-CITY CITY8-3 CITY8)
               (IN-CITY CITY8-2 CITY8)
               (IN-CITY CITY8-1 CITY8)
               (IN-CITY CITY7-3 CITY7)
               (IN-CITY CITY7-2 CITY7)
               (IN-CITY CITY7-1 CITY7)
               (IN-CITY CITY6-3 CITY6)
               (IN-CITY CITY6-2 CITY6)
               (IN-CITY CITY6-1 CITY6)
               (IN-CITY CITY5-3 CITY5)
               (IN-CITY CITY5-2 CITY5)
               (IN-CITY CITY5-1 CITY5)
               (IN-CITY CITY4-3 CITY4)
               (IN-CITY CITY4-2 CITY4)
               (IN-CITY CITY4-1 CITY4)
               (IN-CITY CITY3-3 CITY3)
               (IN-CITY CITY3-2 CITY3)
               (IN-CITY CITY3-1 CITY3)
               (IN-CITY CITY2-3 CITY2)
               (IN-CITY CITY2-2 CITY2)
               (IN-CITY CITY2-1 CITY2)
               (IN-CITY CITY1-3 CITY1)
               (IN-CITY CITY1-2 CITY1)
               (IN-CITY CITY1-1 CITY1)
               (AT PLANE1 CITY3-3)
               (AT TRUCK15 CITY8-2)
               (AT TRUCK14 CITY7-2)
               (AT TRUCK13 CITY6-1)
               (AT TRUCK12 CITY5-2)
               (AT TRUCK11 CITY4-1)
               (AT TRUCK10 CITY3-2)
               (AT TRUCK9 CITY2-1)
               (AT TRUCK8 CITY1-2)
               (AT TRUCK7 CITY6-1)
               (AT TRUCK6 CITY3-2)
               (AT TRUCK5 CITY1-3)
               (AT TRUCK4 CITY4-3)
               (AT TRUCK3 CITY1-3)
               (AT TRUCK2 CITY7-1)
               (AT TRUCK1 CITY8-1)
               (AT PACKAGE5 CITY3-2)
               (AT PACKAGE4 CITY5-1)
               (AT PACKAGE3 CITY1-1)
               (AT PACKAGE2 CITY5-2)
               (AT PACKAGE1 CITY2-1))
        (:GOAL (AND (AT PACKAGE5 CITY6-3)
                    (AT PACKAGE4 CITY5-3)
                    (AT PACKAGE3 CITY8-3)
                    (AT PACKAGE2 CITY4-3)
                    (AT PACKAGE1 CITY6-3))))

