; revised by dvm, 6/3/1998 so that all domains have consistent names.
; the only difference in the logic is the use of conditional effects
; in the adl version, so that an object is at a location before it is
; unloaded.

;;; these domains engineered from the att satplan encodings 
;;; which were derived from the graphplan domains
;;; which i think were derived from veloso's prodigy domains
;;; - dsw 1/97

(define (domain logisticsUstrips)
  (:requirements :strips) 
  (:predicates 	(obj varobj)
	       	(truck vartruck)
               	(location varloc)
		(airplane varairplane)
                (city varcity)
                (airport varairport)
		(at varobj varloc)
		(in varobj1 varobj2)
		(inUcity varobj varcity))
 
  ; (:types )		; default object

(:action loadUtruck
  :parameters
   (varobj
    vartruck
    varloc)
  :precondition
   (and (obj varobj) (truck vartruck) (location varloc)
   (at vartruck varloc) (at varobj varloc))
  :effect
   (and (not (at varobj varloc)) (in varobj vartruck)))

(:action loadUairplane
  :parameters
   (varobj
    varairplane
    varloc)
  :precondition
   (and (obj varobj) (airplane varairplane) (location varloc)
   (at varobj varloc) (at varairplane varloc))
  :effect
   (and (not (at varobj varloc)) (in varobj varairplane)))

(:action unloadUtruck
  :parameters
   (varobj
    vartruck
    varloc)
  :precondition
   (and (obj varobj) (truck vartruck) (location varloc)
        (at vartruck varloc) (in varobj vartruck))
  :effect
   (and (not (in varobj vartruck)) (at varobj varloc)))

(:action unloadUairplane
  :parameters
   (varobj
    varairplane
    varloc)
  :precondition
   (and (obj varobj) (airplane varairplane) (location varloc)
        (in varobj varairplane) (at varairplane varloc))
  :effect
   (and (not (in varobj varairplane)) (at varobj varloc)))

(:action driveUtruck
  :parameters
   (vartruck
    varlocUfrom
    varlocUto
    varcity)
  :precondition
   (and (truck vartruck) (location varlocUfrom) (location varlocUto) (city varcity)
   (at vartruck varlocUfrom)
   (inUcity varlocUfrom varcity)
   (inUcity varlocUto varcity))
  :effect
   (and (not (at vartruck varlocUfrom)) (at vartruck varlocUto)))

(:action flyUairplane
  :parameters
   (varairplane
    varlocUfrom
    varlocUto)
  :precondition
   (and (airplane varairplane) (airport varlocUfrom) (airport varlocUto)
	(at varairplane varlocUfrom))
  :effect
   (and (not (at varairplane varlocUfrom)) (at varairplane varlocUto)))
)

;;; a three step plan works
(define (problem attUlog0) 
  (:domain logisticsUstrips)
  (:objects package1 pghUtruck bosUtruck airplane1
	    bosUpo pghUpo bosUairport pghUairport
	    pgh bos)
  (:init (obj package1)		; statis predicates
	 (truck pghUtruck)
	 (truck bosUtruck)
	 (airplane airplane1)
	 (location bosUpo)
	 (location pghUpo)
	 (location bosUairport)
	 (location pghUairport)
	 (airport bosUairport)
	 (airport pghUairport)
	 (city pgh)
	 (city bos)
	 (inUcity pghUpo pgh)
	 (inUcity pghUairport pgh)
	 (inUcity bosUpo bos)
	 (inUcity bosUairport bos)
	 (at package1 pghUairport);; dynamic predicates
	 (at airplane1 pghUairport)
	 (at bosUtruck bosUpo)
	 (at pghUtruck pghUpo))
  (:goal (and (at package1 bosUairport)))
  )


;;; this one takes six steps
(define (problem attUlog1) (:domain logisticsUstrips)
  (:objects package1 pghUtruck bosUtruck airplane1
	    bosUpo pghUpo bosUairport pghUairport
	    pgh bos)
  (:init (obj package1)			; statis predicates
	 (truck pghUtruck)
	 (truck bosUtruck)
	 (airplane airplane1)
	 (location bosUpo)
	 (location pghUpo)
	 (location bosUairport)
	 (location pghUairport)
	 (airport bosUairport)
	 (airport pghUairport)
	 (city pgh)
	 (city bos)
	 (inUcity pghUpo pgh)
	 (inUcity pghUairport pgh)
	 (inUcity bosUpo bos)
	 (inUcity bosUairport bos)
	 (at package1 pghUpo);; dynamic predicates
	 (at airplane1 pghUairport)
	 (at bosUtruck bosUpo)
	 (at pghUtruck pghUpo))
  (:goal (and (at package1 bosUairport))))

;;; this one takes nine steps
(define (problem attUlog2) (:domain logisticsUstrips)
  (:objects package1 pghUtruck bosUtruck airplane1
	    bosUpo pghUpo bosUairport pghUairport
	    pgh bos)
  (:init (obj package1)		; statis predicates
	 (truck pghUtruck)
	 (truck bosUtruck)
	 (airplane airplane1)
	 (location bosUpo)
	 (location pghUpo)
	 (location bosUairport)
	 (location pghUairport)
	 (airport bosUairport)
	 (airport pghUairport)
	 (city pgh)
	 (city bos)
	 (inUcity pghUpo pgh)
	 (inUcity pghUairport pgh)
	 (inUcity bosUpo bos)
	 (inUcity bosUairport bos)
	 (at package1 pghUpo);; dynamic predicates
	 (at airplane1 pghUairport)
	 (at bosUtruck bosUairport)
	 (at pghUtruck pghUpo))
  (:goal (and (at package1 bosUpo))))

;;; ten steps
(define (problem attUlog3) 
  (:domain logisticsUstrips)
  (:objects package1 package2 package3 package4 
	    package5 package6 package7 package8
	    pghUtruck bosUtruck laUtruck airplane1 airplane2
	    bosUpo pghUpo laUpo bosUairport pghUairport laUairport
	    pgh bos la)
  (:init (obj package1)		; statis predicates
	 (obj package2)
	 (obj package3)
	 (obj package4)
	 (obj package5)
	 (obj package6)
	 (obj package7)
	 (obj package8)
	 (truck pghUtruck)
	 (truck bosUtruck)
	 (truck laUtruck)
	 (airplane airplane1)
	 (airplane airplane2)
	 (location bosUpo)
	 (location laUpo)
	 (location pghUpo)
	 (location bosUairport)
	 (location laUairport)
	 (location pghUairport)
	 (airport bosUairport)
	 (airport pghUairport)
	 (airport laUairport)
	 (city pgh)
	 (city bos)
	 (city la)
	 (inUcity pghUpo pgh)
	 (inUcity pghUairport pgh)
	 (inUcity bosUpo bos)
	 (inUcity bosUairport bos)
	 (inUcity laUpo la)
	 (inUcity laUairport la)
	 (at package1 pghUpo);; dynamic predicates
	 (at package2 pghUpo)
	 (at package3 pghUpo)
	 (at package4 pghUpo)
	 (at package5 bosUpo)
	 (at package6 bosUpo)
	 (at package7 bosUpo)
	 (at package8 laUpo)
	 (at airplane1 pghUairport)
	 (at airplane2 pghUairport)
	 (at bosUtruck bosUpo)
	 (at pghUtruck pghUpo)
	 (at laUtruck laUpo))
  (:goal (and (at package1 bosUpo))))

(define (problem attUlog4) 
  (:domain logisticsUstrips)
  (:objects package1 package2 package3 package4 
	    package5 package6 package7 package8
	    pghUtruck bosUtruck laUtruck airplane1 airplane2
	    bosUpo pghUpo laUpo bosUairport pghUairport laUairport
	    pgh bos la)
  (:init (obj package1)		; statis predicates
	 (obj package2)
	 (obj package3)
	 (obj package4)
	 (obj package5)
	 (obj package6)
	 (obj package7)
	 (obj package8)
	 (truck pghUtruck)
	 (truck bosUtruck)
	 (truck laUtruck)
	 (airplane airplane1)
	 (airplane airplane2)
	 (location bosUpo)
	 (location laUpo)
	 (location pghUpo)
	 (location bosUairport)
	 (location laUairport)
	 (location pghUairport)
	 (airport bosUairport)
	 (airport pghUairport)
	 (airport laUairport)
	 (city pgh)
	 (city bos)
	 (city la)
	 (inUcity pghUpo pgh)
	 (inUcity pghUairport pgh)
	 (inUcity bosUpo bos)
	 (inUcity bosUairport bos)
	 (inUcity laUpo la)
	 (inUcity laUairport la)
	 (at package1 pghUpo);; dynamic predicates
	 (at package2 pghUpo)
	 (at package3 pghUpo)
	 (at package4 pghUpo)
	 (at package5 bosUpo)
	 (at package6 bosUpo)
	 (at package7 bosUpo)
	 (at package8 laUpo)
	 (at airplane1 pghUairport)
	 (at airplane2 pghUairport)
	 (at bosUtruck bosUpo)
	 (at pghUtruck pghUpo)
	 (at laUtruck laUpo))
  (:goal (and (at package1 bosUpo)
	      (at package2 bosUairport))))

(define (problem attUlogUa) 
  (:domain logisticsUstrips)
  (:objects package1 package2 package3 package4 
	    package5 package6 package7 package8
	    pghUtruck bosUtruck laUtruck airplane1 airplane2
	    bosUpo pghUpo laUpo bosUairport pghUairport laUairport
	    pgh bos la)
  (:init (obj package1)		; statis predicates
	 (obj package2)
	 (obj package3)
	 (obj package4)
	 (obj package5)
	 (obj package6)
	 (obj package7)
	 (obj package8)
	 (truck pghUtruck)
	 (truck bosUtruck)
	 (truck laUtruck)
	 (airplane airplane1)
	 (airplane airplane2)
	 (location bosUpo)
	 (location laUpo)
	 (location pghUpo)
	 (location bosUairport)
	 (location laUairport)
	 (location pghUairport)
	 (airport bosUairport)
	 (airport pghUairport)
	 (airport laUairport)
	 (city pgh)
	 (city bos)
	 (city la)
	 (inUcity pghUpo pgh)
	 (inUcity pghUairport pgh)
	 (inUcity bosUpo bos)
	 (inUcity bosUairport bos)
	 (inUcity laUpo la)
	 (inUcity laUairport la)
	 (at package1 pghUpo);; dynamic predicates
	 (at package2 pghUpo)
	 (at package3 pghUpo)
	 (at package4 pghUpo)
	 (at package5 bosUpo)
	 (at package6 bosUpo)
	 (at package7 bosUpo)
	 (at package8 laUpo)
	 (at airplane1 pghUairport)
	 (at airplane2 pghUairport)
	 (at bosUtruck bosUpo)
	 (at pghUtruck pghUpo)
	 (at laUtruck laUpo))
  (:goal (and (at package1 bosUpo)
	      (at package2 bosUairport)
	      (at package3 laUpo)
	      (at package4 laUairport)
	      (at package5 pghUpo)
	      (at package6 pghUairport)
	      (at package7 pghUpo)
	      (at package8 pghUpo)))
  )


;; attUlogistics treats trucks and airplanes
;;fundamentally differently (both loading and unloading).
;;
;; logisticsUtyped does the same, but it is typed.
;; 
;; logisticsUaxiom introduces the axiom that says
;; they are both vehicles, and treats them
;; uniformly.
;; 
;; logisticsUadl treats them uniformly as well. 
;; whereas typed and axiom treat a thing as not at
;; a location until it is unloaded, logistics uses
;; the conditional effect.

(define (domain logisticsUadl)
  (:requirements :adl :domainUaxioms)
  (:types physobj - object
	  obj vehicle - physobj
	  truck airplane - vehicle
	  location city - object
	  airport - location)
  (:predicates (at varx - physobj varl - location)
	       (in varx - obj vart - vehicle)
	       (inUcity varl - location varc - city)
	       (loaded varx - physobj))   ; varx is loaded on a vehicle

  (:action load 
	     :parameters (varobj - obj varveh - vehicle varloc - location) 
	     :precondition (and (at varobj varloc)
				(at varveh varloc)
				(not (loaded varobj)))
	     :effect (and (in varobj varveh)
			  (loaded varobj)))
  (:action unload 
	     :parameters (varobj - obj varveh - vehicle varloc - location) 
	     :precondition (and (in varobj varveh) (at varveh varloc)) 
	     :effect (and (not (in varobj varveh))
			  (not (loaded varobj))))
  (:action driveUtruck 
	   :parameters (vartruck - truck varlocUfrom varlocUto - location
			varcity - city)
	     :precondition (and (at vartruck varlocUfrom) 
				 (inUcity varlocUfrom varcity) 
				 (inUcity varlocUto varcity))
	     :effect  (and (at vartruck varlocUto) 
			    (not (at vartruck varlocUfrom))		  
			    (forall (varx - obj)
				     (when (and (in varx vartruck))
					    (and (not (at varx varlocUfrom)) 
						  (at varx varlocUto))))))
  (:action flyUairplane
   :parameters (varplane - airplane varlocUfrom varlocUto - airport)
   :precondition (and (at varplane varlocUfrom) )
   :effect  (and (at varplane varlocUto) 
		      (not (at varplane varlocUfrom))		  
			      (forall (varx - obj)
				       (when (and (in varx varplane))
					      (and (not (at varx varlocUfrom)) 
						    (at varx varlocUto)))))))

(define (problem logistics1)
  (:domain logisticsUadl)
  (:objects package1 package2 package3 package4 package5 package6 - obj
	    pghUtruck bosUtruck laUtruck - truck
	    airplane1 airplane2 - airplane
	    bosUpo laUpo pghUpo - location
	    bosUairport pghUairport laUairport - airport
	    pgh bos la - city)

  (:init (at package1 pghUpo)
	 (at package2 pghUpo)
	 (at package3 pghUpo)
	 (at package4 pghUpo)
	 (at package5 pghUpo)
	 (at package6 laUpo)
	 (at airplane1 pghUairport)
	 (at airplane2 pghUairport)
	 (at bosUtruck bosUpo)
	 (at pghUtruck pghUpo)
	 (at laUtruck laUpo)
	 (inUcity pghUpo pgh)
	 (inUcity pghUairport pgh)
	 (inUcity bosUpo bos)
	 (inUcity bosUairport bos)
	 (inUcity laUpo la)
	 (inUcity laUairport la))
  (:goal (and (at package1 bosUpo)
	      (at package2 laUpo)
	      (at package3 laUpo)
	      (at package4 laUairport)
	      (at package5 bosUpo)
	      (at package6 pghUpo)
	      )))

(define (problem logistics2)
  (:domain logisticsUadl)
  (:objects package1 package2 package3 package5 package7 - obj
	    pghUtruck bosUtruck laUtruck nyUtruck - truck
	    airplane1 airplane2 - airplane
	    bosUpo laUpo pghUpo nyUpo - location
	    bosUairport pghUairport laUairport nyUairport - airport
	    pgh bos la ny - city)
  (:init (at package1 pghUpo)
	 (at package2 pghUpo)
	 (at package3 pghUpo)
	 (at package5 bosUpo)
	 (at package7 nyUpo)
	 (at airplane1 pghUairport)
	 (at airplane2 pghUairport)
	 (at bosUtruck bosUpo)
	 (at pghUtruck pghUpo)
	 (at laUtruck laUpo)
	 (at nyUtruck nyUpo)
	 (inUcity pghUpo pgh)
	 (inUcity pghUairport pgh)
	 (inUcity bosUpo bos)
	 (inUcity bosUairport bos)
	 (inUcity laUpo la)
	 (inUcity laUairport la)
	 (inUcity nyUpo ny)
	 (inUcity nyUairport ny))
  (:goal (and (at package1 bosUpo)
	      (at package2 nyUpo)
	      (at package3 laUpo)
	      (at package5 pghUpo)
	      (at package7 pghUpo)))
  )

(define (problem logistics3)
  (:domain logisticsUadl)
  (:objects package1 package2 package3 package4 
	    package5 package6 package7 - obj
	    pghUtruck bosUtruck laUtruck nyUtruck - truck
	    airplane1 airplane2 - airplane
	    bosUpo laUpo pghUpo nyUpo - location
	    bosUairport pghUairport laUairport nyUairport - airport
	    pgh bos la ny - city)
  (:init (at package1 pghUpo)
	 (at package2 pghUpo)
	 (at package3 pghUpo)
	 (at package4 nyUpo)
	 (at package5 bosUpo)
	 (at package6 bosUpo)
	 (at package7 nyUpo)
	 (at airplane1 pghUairport)
	 (at airplane2 pghUairport)
	 (at bosUtruck bosUpo)
	 (at pghUtruck pghUpo)
	 (at laUtruck laUpo)
	 (at nyUtruck nyUpo)
	 (inUcity pghUpo pgh)
	 (inUcity pghUairport pgh)
	 (inUcity bosUpo bos)
	 (inUcity bosUairport bos)
	 (inUcity laUpo la)
	 (inUcity laUairport la)
	 (inUcity nyUpo ny)
	 (inUcity nyUairport ny))
  (:goal (and
	  (at package1 bosUpo)
	  (at package2 nyUpo)
	  (at package3 laUpo)
	  (at package4 laUairport)
	  (at package5 pghUpo)
	  (at package6 nyUairport)
	  (at package7 pghUpo)))
    )






;; original name logistics.easy
;; (:length (:parallel 9))
;; optimal
;;

(define (problem log01)
    (:domain logisticsUstrips)
    (:objects
        package1
        package2
        package3

        airplane1
        airplane2

        pgh
        bos
        la

        pghUtruck
        bosUtruck
        laUtruck

        pghUpo
        bosUpo
        laUpo

        pghUcentral
        bosUcentral
        laUcentral

        pghUairport
        bosUairport
        laUairport
    )
    (:init
        (obj package1)
        (obj package2)
        (obj package3)

        (airplane airplane1)
        (airplane airplane2)

        (city pgh)
        (city bos)
        (city la)

        (truck pghUtruck)
        (truck bosUtruck)
        (truck laUtruck)

        (location bosUpo)
        (location laUpo)
        (location pghUpo)

        (location bosUcentral)
        (location laUcentral)
        (location pghUcentral)

        (airport bosUairport)
        (location bosUairport)
        (airport pghUairport)
        (location pghUairport)
        (airport laUairport)
        (location laUairport)

        (inUcity pghUpo pgh)
        (inUcity pghUairport pgh)
        (inUcity pghUcentral pgh)

        (inUcity bosUpo bos)
        (inUcity bosUairport bos)
        (inUcity bosUcentral bos)

        (inUcity laUpo la)
        (inUcity laUairport la)
        (inUcity laUcentral la)

        (at package1 pghUpo)
        (at package2 pghUpo)
        (at package3 pghUpo)

        (at airplane1 pghUairport)
        (at airplane2 pghUairport)

        (at bosUtruck bosUpo)
        (at pghUtruck pghUpo)
        (at laUtruck laUpo)

    )
    (:goal (and
        (at package1 bosUpo)
        (at package2 laUpo)
        (at package3 bosUpo)
    ))
)

;; original name logistics.fact4pp
;; (:length (:parallel 9))
;; optimal
;;

(define (problem log02)
    (:domain logisticsUstrips)
    (:objects
        package1
        package2
        package3
        package4

        airplane1
        airplane2

        pgh
        bos
        la

        pghUtruck
        bosUtruck
        laUtruck

        pghUpo
        bosUpo
        laUpo

        pghUcentral
        bosUcentral
        laUcentral

        pghUairport
        bosUairport
        laUairport
    )
    (:init
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)

        (airplane airplane1)
        (airplane airplane2)

        (city pgh)
        (city bos)
        (city la)

        (truck pghUtruck)
        (truck bosUtruck)
        (truck laUtruck)

        (location bosUpo)
        (location laUpo)
        (location pghUpo)

        (location bosUcentral)
        (location laUcentral)
        (location pghUcentral)

        (airport bosUairport)
        (location bosUairport)
        (airport pghUairport)
        (location pghUairport)
        (airport laUairport)
        (location laUairport)

        (inUcity pghUpo pgh)
        (inUcity pghUairport pgh)
        (inUcity pghUcentral pgh)

        (inUcity bosUpo bos)
        (inUcity bosUairport bos)
        (inUcity bosUcentral bos)

        (inUcity laUpo la)
        (inUcity laUairport la)
        (inUcity laUcentral la)

        (at package1 pghUpo)
        (at package2 pghUpo)
        (at package3 pghUpo)
        (at package4 pghUpo)
       
        (at airplane1 pghUairport)
        (at airplane2 pghUairport)
       
        (at bosUtruck bosUpo)
        (at pghUtruck pghUpo)
        (at laUtruck laUpo)

    )
    (:goal (and
        (at package1 bosUpo)
        (at package2 laUairport)
        (at package3 bosUpo)
        (at package4 laUairport))
    ))
;; original name logistics.a
;; extended version of logistics_facts7h
;; (:length (:parallel 11))
;; optimal
;; #actions 54 #states 10^11
;;
;; note: by going to a nonUtyped representation
;;       of the problems, the instances become (somewhat)
;;       harder to solve.
;;       (larger propositional representation)
;;

(define (problem log03)
    (:domain logisticsUstrips)
    (:objects
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8

        airplane1
        airplane2

        pgh
        bos
        la

        pghUtruck
        bosUtruck
        laUtruck

        pghUpo
        bosUpo
        laUpo

        pghUcentral
        bosUcentral
        laUcentral

        pghUairport
        bosUairport
        laUairport
    )
    (:init
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (obj package7)
        (obj package8)

        (airplane airplane1)
        (airplane airplane2)

        (city pgh)
        (city bos)
        (city la)

        (truck pghUtruck)
        (truck bosUtruck)
        (truck laUtruck)

        (location bosUpo)
        (location laUpo)
        (location pghUpo)

        (location bosUcentral)
        (location laUcentral)
        (location pghUcentral)

        (airport bosUairport)
        (location bosUairport)
        (airport pghUairport)
        (location pghUairport)
        (airport laUairport)
        (location laUairport)

        (inUcity pghUpo pgh)
        (inUcity pghUairport pgh)
        (inUcity pghUcentral pgh)

        (inUcity bosUpo bos)
        (inUcity bosUairport bos)
        (inUcity bosUcentral bos)

        (inUcity laUpo la)
        (inUcity laUairport la)
        (inUcity laUcentral la)

        (at package1 pghUpo)
        (at package2 pghUpo)
        (at package3 pghUpo)
        (at package4 pghUpo)
        (at package5 bosUpo)
        (at package6 bosUpo)
        (at package7 bosUpo)
        (at package8 laUpo)

        (at airplane1 pghUairport)
        (at airplane2 pghUairport)
       
        (at bosUtruck bosUpo)
        (at pghUtruck pghUpo)
        (at laUtruck laUpo)
    )
    (:goal (and
        (at package1 bosUpo)
        (at package2 bosUairport)
        (at package3 laUpo)
        (at package4 laUairport)
        (at package5 pghUpo)
        (at package6 pghUairport)
        (at package7 pghUpo)
        (at package8 pghUpo)
    ))
)
;; original name logistics.b
;; (:length (:parallel 13))
;; optimal
;; #actions 47 #states 10^8
;;

(define (problem log04)
    (:domain logisticsUstrips)
    (:objects
        package1
        package2
        package3
        package4
        package5
        package6
        package7

        airplane1
        airplane2

        pgh
        bos
        la
        ny

        pghUtruck
        bosUtruck
        laUtruck
        nyUtruck

        pghUpo
        bosUpo
        laUpo
        nyUpo

        pghUcentral
        bosUcentral
        laUcentral
        nyUcentral

        pghUairport
        bosUairport
        laUairport
        nyUairport
    )
    (:init
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (obj package7)

        (airplane airplane1)
        (airplane airplane2)

        (city pgh)
        (city bos)
        (city la)
        (city ny)

        (truck pghUtruck)
        (truck bosUtruck)
        (truck laUtruck)
        (truck nyUtruck)

        (location bosUpo)
        (location laUpo)
        (location pghUpo)
        (location nyUpo)

        (location bosUcentral)
        (location laUcentral)
        (location pghUcentral)
        (location nyUcentral)

        (airport bosUairport)
        (location bosUairport)
        (airport pghUairport)
        (location pghUairport)
        (airport laUairport)
        (location laUairport)
        (airport nyUairport)
        (location nyUairport)

        (inUcity pghUpo pgh)
        (inUcity pghUairport pgh)
        (inUcity pghUcentral pgh)

        (inUcity bosUpo bos)
        (inUcity bosUairport bos)
        (inUcity bosUcentral bos)

        (inUcity laUpo la)
        (inUcity laUairport la)
        (inUcity laUcentral la)

        (inUcity nyUpo ny)
        (inUcity nyUairport ny)
        (inUcity nyUcentral ny)

        (at package1 pghUpo)
        (at package2 pghUpo)
        (at package3 pghUpo)
        (at package5 bosUpo)
        (at package7 nyUpo)

        (at airplane1 pghUairport)
        (at airplane2 pghUairport)

        (at bosUtruck bosUpo)
        (at pghUtruck pghUpo)
        (at laUtruck laUpo)
        (at nyUtruck nyUpo)
    )
    (:goal (and
        (at package1 bosUpo)
        (at package2 nyUpo)
        (at package3 laUpo)
        (at package5 pghUpo)
        (at package7 pghUpo)
    ))
)
;; original name logistics.c
;; (:length (:parallel 13))
;; optimal
;; #actions 63 #states 10^10
;;

(define (problem log05)
    (:domain logisticsUstrips)
    (:objects
        package1
        package2
        package3
        package4
        package5
        package6
        package7

        airplane1
        airplane2

        pgh
        bos
        la
        ny

        pghUtruck
        bosUtruck
        laUtruck
        nyUtruck

        pghUpo
        bosUpo
        laUpo
        nyUpo

        pghUcentral
        bosUcentral
        laUcentral
        nyUcentral

        pghUairport
        bosUairport
        laUairport
        nyUairport
    )
    (:init
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (obj package7)

        (airplane airplane1)
        (airplane airplane2)

        (city pgh)
        (city bos)
        (city la)
        (city ny)

        (truck pghUtruck)
        (truck bosUtruck)
        (truck laUtruck)
        (truck nyUtruck)

        (location bosUpo)
        (location laUpo)
        (location pghUpo)
        (location nyUpo)

        (location bosUcentral)
        (location laUcentral)
        (location pghUcentral)
        (location nyUcentral)

        (airport bosUairport)
        (location bosUairport)
        (airport pghUairport)
        (location pghUairport)
        (airport laUairport)
        (location laUairport)
        (airport nyUairport)
        (location nyUairport)

        (inUcity pghUpo pgh)
        (inUcity pghUairport pgh)
        (inUcity pghUcentral pgh)

        (inUcity bosUpo bos)
        (inUcity bosUairport bos)
        (inUcity bosUcentral bos)

        (inUcity laUpo la)
        (inUcity laUairport la)
        (inUcity laUcentral la)

        (inUcity nyUpo ny)
        (inUcity nyUairport ny)
        (inUcity nyUcentral ny)

        (at package1 pghUpo)
        (at package2 pghUpo)
        (at package3 pghUpo)
        (at package4 nyUpo)
        (at package5 bosUpo)
        (at package6 bosUpo)
        (at package7 nyUpo)

        (at airplane1 pghUairport)
        (at airplane2 pghUairport)

        (at bosUtruck bosUpo)
        (at pghUtruck pghUpo)
        (at laUtruck laUpo)
        (at nyUtruck nyUpo)

    )
    (:goal (and
        (at package1 bosUpo)
        (at package2 nyUpo)
        (at package3 laUpo)
        (at package4 laUairport)
        (at package5 pghUpo)
        (at package6 nyUairport)
        (at package7 pghUpo)
    ))
)
;; original name logistics.d
;; (:length (:parallel 14))
;; optimal
;; #actions 74 #states 10^16
;; note small bug sf locations
;;      fixed in "log09" (slightly easier)
;;

(define (problem log06)
    (:domain logisticsUstrips)
    (:objects
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9

        airplane1
        airplane2

        pgh
        bos
        la
        ny
        sf

        pghUtruck
        bosUtruck
        laUtruck
        nyUtruck
        sfUtruck

        pghUpo
        bosUpo
        laUpo
        nyUpo
        sfUpo

        pghUcentral
        bosUcentral
        laUcentral
        nyUcentral
        sfUcentral

        pghUairport
        bosUairport
        laUairport
        nyUairport
        sfUairport
    )
    (:init
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (obj package7)
        (obj package8)
        (obj package9)

        (airplane airplane1)
        (airplane airplane2)

        (city pgh)
        (city bos)
        (city la)
        (city ny)
        (city sf)

        (truck pghUtruck)
        (truck bosUtruck)
        (truck laUtruck)
        (truck nyUtruck)
        (truck sfUtruck)

        (location bosUpo)
        (location laUpo)
        (location pghUpo)
        (location nyUpo)
        (location sfUpo)

        (location bosUcentral)
        (location laUcentral)
        (location pghUcentral)
        (location nyUcentral)
        (location sfUcentral)

        (airport bosUairport)
        (location bosUairport)
        (airport pghUairport)
        (location pghUairport)
        (airport laUairport)
        (location laUairport)
        (airport nyUairport)
        (location nyUairport)
        (airport sfUairport)
        (location sfUairport)

        (inUcity pghUpo pgh)
        (inUcity pghUairport pgh)
        (inUcity pghUcentral pgh)

        (inUcity bosUpo bos)
        (inUcity bosUairport bos)
        (inUcity bosUcentral bos)

        (inUcity laUpo la)
        (inUcity laUairport la)
        (inUcity laUcentral la)

        (inUcity nyUpo ny)
        (inUcity nyUairport ny)
        (inUcity nyUcentral ny)

        (inUcity sfUpo ny)
        (inUcity sfUairport ny)
        (inUcity sfUcentral ny)

        (at package1 pghUpo)
        (at package2 pghUcentral)
        (at package3 pghUcentral)
        (at package4 nyUpo)
        (at package5 bosUpo)
        (at package6 bosUpo)
        (at package7 nyUpo)
        (at package8 sfUairport)
        (at package9 sfUcentral)

        (at airplane1 pghUairport)
        (at airplane2 pghUairport)

        (at bosUtruck bosUpo)
        (at pghUtruck pghUairport)
        (at laUtruck laUpo)
        (at nyUtruck nyUcentral)
        (at sfUtruck sfUairport)
    )
    (:goal (and
       (at package1 bosUpo)
       (at package2 nyUpo)
       (at package3 laUcentral)
       (at package4 laUairport)
       (at package5 pghUpo)
       (at package6 nyUcentral)
       (at package7 pghUpo)
       (at package8 nyUcentral)
       (at package9 sfUpo)
    ))
)

;; original name logistics.d1a
;; (:length (:parallel 13))
;; optimal
;;

(define (problem log07)
    (:domain logisticsUstrips)
    (:objects
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9

        airplane1
        airplane2
        airplane3

        pgh
        bos
        la
        ny
        sf

        pghUtruck
        bosUtruck
        laUtruck
        nyUtruck
        sfUtruck

        pghUpo
        bosUpo
        laUpo
        nyUpo
        sfUpo

        pghUcentral
        bosUcentral
        laUcentral
        nyUcentral
        sfUcentral

        pghUairport
        bosUairport
        laUairport
        nyUairport
        sfUairport
    )
    (:init
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (obj package7)
        (obj package8)
        (obj package9)

        (airplane airplane1)
        (airplane airplane2)
        (airplane airplane3)

        (city pgh)
        (city bos)
        (city la)
        (city ny)
        (city sf)

        (truck pghUtruck)
        (truck bosUtruck)
        (truck laUtruck)
        (truck nyUtruck)
        (truck sfUtruck)

        (location bosUpo)
        (location laUpo)
        (location pghUpo)
        (location nyUpo)
        (location sfUpo)

        (location bosUcentral)
        (location laUcentral)
        (location pghUcentral)
        (location nyUcentral)
        (location sfUcentral)

        (airport bosUairport)
        (location bosUairport)
        (airport pghUairport)
        (location pghUairport)
        (airport laUairport)
        (location laUairport)
        (airport nyUairport)
        (location nyUairport)
        (airport sfUairport)
        (location sfUairport)

        (inUcity pghUpo pgh)
        (inUcity pghUairport pgh)
        (inUcity pghUcentral pgh)

        (inUcity bosUpo bos)
        (inUcity bosUairport bos)
        (inUcity bosUcentral bos)

        (inUcity laUpo la)
        (inUcity laUairport la)
        (inUcity laUcentral la)

        (inUcity nyUpo ny)
        (inUcity nyUairport ny)
        (inUcity nyUcentral ny)

        (inUcity sfUpo sf)
        (inUcity sfUairport sf)
        (inUcity sfUcentral sf)

        (at package1 pghUpo)
        (at package2 pghUcentral)
        (at package3 pghUcentral)
        (at package4 nyUpo)
        (at package5 bosUpo)
        (at package6 bosUpo)
        (at package7 nyUpo)
        (at package8 sfUairport)
        (at package9 sfUcentral)
       
        (at airplane1 pghUairport)
        (at airplane2 pghUairport)
        (at airplane3 pghUairport)
       
        (at bosUtruck bosUpo)
        (at pghUtruck pghUairport)
        (at laUtruck laUpo)
        (at nyUtruck nyUcentral)
        (at sfUtruck sfUairport)
    )
    (:goal (and
        (at package1 bosUpo)
        (at package2 nyUpo)
        (at package3 laUcentral)
        (at package4 laUairport)
        (at package5 pghUpo)
        (at package6 nyUcentral)
        (at package7 pghUpo)
        (at package8 nyUcentral)
        (at package9 sfUpo)
    ))
)
;; original name logistics.d1b
;; (:length (:parallel 17))
;; optimal
;;

(define (problem log08)
    (:domain logisticsUstrips)
    (:objects
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9

        airplane1

        pgh
        bos
        la
        ny
        sf

        pghUtruck
        bosUtruck
        laUtruck
        nyUtruck
        sfUtruck

        pghUpo
        bosUpo
        laUpo
        nyUpo
        sfUpo

        pghUcentral
        bosUcentral
        laUcentral
        nyUcentral
        sfUcentral

        pghUairport
        bosUairport
        laUairport
        nyUairport
        sfUairport
    )
    (:init
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (obj package7)
        (obj package8)
        (obj package9)

        (airplane airplane1)

        (city pgh)
        (city bos)
        (city la)
        (city ny)
        (city sf)

        (truck pghUtruck)
        (truck bosUtruck)
        (truck laUtruck)
        (truck nyUtruck)
        (truck sfUtruck)

        (location bosUpo)
        (location laUpo)
        (location pghUpo)
        (location nyUpo)
        (location sfUpo)

        (location bosUcentral)
        (location laUcentral)
        (location pghUcentral)
        (location nyUcentral)
        (location sfUcentral)

        (airport bosUairport)
        (location bosUairport)
        (airport pghUairport)
        (location pghUairport)
        (airport laUairport)
        (location laUairport)
        (airport nyUairport)
        (location nyUairport)
        (airport sfUairport)
        (location sfUairport)

        (inUcity pghUpo pgh)
        (inUcity pghUairport pgh)
        (inUcity pghUcentral pgh)

        (inUcity bosUpo bos)
        (inUcity bosUairport bos)
        (inUcity bosUcentral bos)

        (inUcity laUpo la)
        (inUcity laUairport la)
        (inUcity laUcentral la)

        (inUcity nyUpo ny)
        (inUcity nyUairport ny)
        (inUcity nyUcentral ny)

        (inUcity sfUpo sf)
        (inUcity sfUairport sf)
        (inUcity sfUcentral sf)

        (at package1 pghUpo)
        (at package2 pghUcentral)
        (at package3 pghUcentral)
        (at package4 nyUpo)
        (at package5 bosUpo)
        (at package6 bosUpo)
        (at package7 nyUpo)
        (at package8 sfUairport)
        (at package9 sfUcentral)

        (at airplane1 pghUairport)

        (at bosUtruck bosUpo)
        (at pghUtruck pghUairport)
        (at laUtruck laUpo)
        (at nyUtruck nyUcentral)
        (at sfUtruck sfUairport)
    )
    (:goal (and
        (at package1 bosUpo)
        (at package2 nyUpo)
        (at package3 laUcentral)
        (at package4 laUairport)
        (at package5 pghUpo)
        (at package6 nyUcentral)
        (at package7 pghUpo)
        (at package8 nyUcentral)
        (at package9 sfUpo)
    ))
)
;; original name logistics.d1
;; (:length (:parallel 14))
;; optimal
;;

(define (problem log09)
    (:domain logisticsUstrips)
    (:objects
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9

        airplane1
        airplane2

        pgh
        bos
        la
        ny
        sf

        pghUtruck
        bosUtruck
        laUtruck
        nyUtruck
        sfUtruck

        pghUpo
        bosUpo
        laUpo
        nyUpo
        sfUpo

        pghUcentral
        bosUcentral
        laUcentral
        nyUcentral
        sfUcentral

        pghUairport
        bosUairport
        laUairport
        nyUairport
        sfUairport
    )
    (:init
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (obj package7)
        (obj package8)
        (obj package9)

        (airplane airplane1)
        (airplane airplane2)

        (city pgh)
        (city bos)
        (city la)
        (city ny)
        (city sf)

        (truck pghUtruck)
        (truck bosUtruck)
        (truck laUtruck)
        (truck nyUtruck)
        (truck sfUtruck)

        (location bosUpo)
        (location laUpo)
        (location pghUpo)
        (location nyUpo)
        (location sfUpo)

        (location bosUcentral)
        (location laUcentral)
        (location pghUcentral)
        (location nyUcentral)
        (location sfUcentral)

        (airport bosUairport)
        (location bosUairport)
        (airport pghUairport)
        (location pghUairport)
        (airport laUairport)
        (location laUairport)
        (airport nyUairport)
        (location nyUairport)
        (airport sfUairport)
        (location sfUairport)

        (inUcity pghUpo pgh)
        (inUcity pghUairport pgh)
        (inUcity pghUcentral pgh)

        (inUcity bosUpo bos)
        (inUcity bosUairport bos)
        (inUcity bosUcentral bos)

        (inUcity laUpo la)
        (inUcity laUairport la)
        (inUcity laUcentral la)

        (inUcity nyUpo ny)
        (inUcity nyUairport ny)
        (inUcity nyUcentral ny)

        (inUcity sfUpo sf)
        (inUcity sfUairport sf)
        (inUcity sfUcentral sf)

        (at package1 pghUpo)
        (at package2 pghUcentral)
        (at package3 pghUcentral)
        (at package4 nyUpo)
        (at package5 bosUpo)
        (at package6 bosUpo)
        (at package7 nyUpo)
        (at package8 sfUairport)
        (at package9 sfUcentral)

        (at airplane1 pghUairport)
        (at airplane2 pghUairport)

        (at bosUtruck bosUpo)
        (at pghUtruck pghUairport)
        (at laUtruck laUpo)
        (at nyUtruck nyUcentral)
        (at sfUtruck sfUairport)
    )
    (:goal (and
       (at package1 bosUpo)
       (at package2 nyUpo)
       (at package3 laUcentral)
       (at package4 laUairport)
       (at package5 pghUpo)
       (at package6 nyUcentral)
       (at package7 pghUpo)
       (at package8 nyUcentral)
       (at package9 sfUpo)
    ))
)
;; a logistics problem instance
;; name: log07
;; #packages: 10        #cities: 6  #planes: 2
;; #locs_per_city: 2   #trucks_per_city: 1
;; #goals: 10           seed: 76525784

(define (problem log10)
    (:domain logisticsUstrips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        package10
        plane1
        plane2
        truck1U1
        loc1U1
        loc1U2
        city1
        truck2U1
        loc2U1
        loc2U2
        city2
        truck3U1
        loc3U1
        loc3U2
        city3
        truck4U1
        loc4U1
        loc4U2
        city4
        truck5U1
        loc5U1
        loc5U2
        city5
        truck6U1
        loc6U1
        loc6U2
        city6
    )
    (:init 
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (obj package7)
        (obj package8)
        (obj package9)
        (obj package10)
        (airplane plane1)
        (airplane plane2)
        (truck truck1U1)
        (location loc1U1)
        (location loc1U2)
        (city city1)
        (airport loc1U1)
        (truck truck2U1)
        (location loc2U1)
        (location loc2U2)
        (city city2)
        (airport loc2U1)
        (truck truck3U1)
        (location loc3U1)
        (location loc3U2)
        (city city3)
        (airport loc3U1)
        (truck truck4U1)
        (location loc4U1)
        (location loc4U2)
        (city city4)
        (airport loc4U1)
        (truck truck5U1)
        (location loc5U1)
        (location loc5U2)
        (city city5)
        (airport loc5U1)
        (truck truck6U1)
        (location loc6U1)
        (location loc6U2)
        (city city6)
        (airport loc6U1)
        (inUcity loc1U1 city1)
        (inUcity loc1U2 city1)
        (inUcity loc2U1 city2)
        (inUcity loc2U2 city2)
        (inUcity loc3U1 city3)
        (inUcity loc3U2 city3)
        (inUcity loc4U1 city4)
        (inUcity loc4U2 city4)
        (inUcity loc5U1 city5)
        (inUcity loc5U2 city5)
        (inUcity loc6U1 city6)
        (inUcity loc6U2 city6)
        (at plane1 loc4U1)
        (at plane2 loc4U1)
        (at truck1U1 loc1U1)
        (at truck2U1 loc2U2)
        (at truck3U1 loc3U1)
        (at truck4U1 loc4U2)
        (at truck5U1 loc5U2)
        (at truck6U1 loc6U1)
        (at package1 loc5U1)
        (at package2 loc4U1)
        (at package3 loc6U2)
        (at package4 loc4U1)
        (at package5 loc4U2)
        (at package6 loc3U1)
        (at package7 loc2U2)
        (at package8 loc4U1)
        (at package9 loc3U2)
        (at package10 loc6U1)
    )
    (:goal (and
        (at package1 loc2U1)
        (at package2 loc5U1)
        (at package3 loc4U1)
        (at package4 loc2U1)
        (at package5 loc4U2)
        (at package6 loc3U2)
        (at package7 loc4U1)
        (at package8 loc5U2)
        (at package9 loc6U2)
        (at package10 loc6U1)
    ))
)
;; a logistics problem instance
;; name: log08
;; #packages: 9        #cities: 5  #planes: 2
;; #locs_per_city: 2   #trucks_per_city: 1
;; #goals: 9           seed: 82752309

(define (problem log11)
    (:domain logisticsUstrips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        plane1
        plane2
        truck1U1
        loc1U1
        loc1U2
        city1
        truck2U1
        loc2U1
        loc2U2
        city2
        truck3U1
        loc3U1
        loc3U2
        city3
        truck4U1
        loc4U1
        loc4U2
        city4
        truck5U1
        loc5U1
        loc5U2
        city5
    )
    (:init 
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (obj package7)
        (obj package8)
        (obj package9)
        (airplane plane1)
        (airplane plane2)
        (truck truck1U1)
        (location loc1U1)
        (location loc1U2)
        (city city1)
        (airport loc1U1)
        (truck truck2U1)
        (location loc2U1)
        (location loc2U2)
        (city city2)
        (airport loc2U1)
        (truck truck3U1)
        (location loc3U1)
        (location loc3U2)
        (city city3)
        (airport loc3U1)
        (truck truck4U1)
        (location loc4U1)
        (location loc4U2)
        (city city4)
        (airport loc4U1)
        (truck truck5U1)
        (location loc5U1)
        (location loc5U2)
        (city city5)
        (airport loc5U1)
        (inUcity loc1U1 city1)
        (inUcity loc1U2 city1)
        (inUcity loc2U1 city2)
        (inUcity loc2U2 city2)
        (inUcity loc3U1 city3)
        (inUcity loc3U2 city3)
        (inUcity loc4U1 city4)
        (inUcity loc4U2 city4)
        (inUcity loc5U1 city5)
        (inUcity loc5U2 city5)
        (at plane1 loc4U1)
        (at plane2 loc5U1)
        (at truck1U1 loc1U2)
        (at truck2U1 loc2U1)
        (at truck3U1 loc3U2)
        (at truck4U1 loc4U2)
        (at truck5U1 loc5U1)
        (at package1 loc1U2)
        (at package2 loc1U2)
        (at package3 loc5U2)
        (at package4 loc3U2)
        (at package5 loc1U2)
        (at package6 loc3U1)
        (at package7 loc5U1)
        (at package8 loc1U1)
        (at package9 loc5U2)
    )
    (:goal (and
        (at package1 loc1U2)
        (at package2 loc5U1)
        (at package3 loc1U1)
        (at package4 loc5U2)
        (at package5 loc2U1)
        (at package6 loc2U2)
        (at package7 loc3U1)
        (at package8 loc3U1)
        (at package9 loc3U2)
    ))
)
;; a logistics problem instance
;; name: log09
;; #packages: 9        #cities: 4  #planes: 3
;; #locs_per_city: 2   #trucks_per_city: 1
;; #goals: 9           seed: 21736079

(define (problem log12)
    (:domain logisticsUstrips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        plane1
        plane2
        plane3
        truck1U1
        loc1U1
        loc1U2
        city1
        truck2U1
        loc2U1
        loc2U2
        city2
        truck3U1
        loc3U1
        loc3U2
        city3
        truck4U1
        loc4U1
        loc4U2
        city4
    )
    (:init 
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (obj package7)
        (obj package8)
        (obj package9)
        (airplane plane1)
        (airplane plane2)
        (airplane plane3)
        (truck truck1U1)
        (location loc1U1)
        (location loc1U2)
        (city city1)
        (airport loc1U1)
        (truck truck2U1)
        (location loc2U1)
        (location loc2U2)
        (city city2)
        (airport loc2U1)
        (truck truck3U1)
        (location loc3U1)
        (location loc3U2)
        (city city3)
        (airport loc3U1)
        (truck truck4U1)
        (location loc4U1)
        (location loc4U2)
        (city city4)
        (airport loc4U1)
        (inUcity loc1U1 city1)
        (inUcity loc1U2 city1)
        (inUcity loc2U1 city2)
        (inUcity loc2U2 city2)
        (inUcity loc3U1 city3)
        (inUcity loc3U2 city3)
        (inUcity loc4U1 city4)
        (inUcity loc4U2 city4)
        (at plane1 loc1U1)
        (at plane2 loc1U1)
        (at plane3 loc1U1)
        (at truck1U1 loc1U1)
        (at truck2U1 loc2U2)
        (at truck3U1 loc3U1)
        (at truck4U1 loc4U1)
        (at package1 loc2U1)
        (at package2 loc4U1)
        (at package3 loc3U1)
        (at package4 loc3U1)
        (at package5 loc2U1)
        (at package6 loc2U2)
        (at package7 loc2U2)
        (at package8 loc2U1)
        (at package9 loc1U2)
    )
    (:goal (and
        (at package1 loc2U1)
        (at package2 loc1U1)
        (at package3 loc2U2)
        (at package4 loc1U2)
        (at package5 loc1U2)
        (at package6 loc4U1)
        (at package7 loc2U1)
        (at package8 loc3U1)
        (at package9 loc1U1)
    ))
)
;; a logistics problem instance
;; name: log10
;; #packages: 9        #cities: 6  #planes: 3
;; #locs_per_city: 2   #trucks_per_city: 1
;; #goals: 9           seed: 82947632

(define (problem log13)
    (:domain logisticsUstrips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        plane1
        plane2
        plane3
        truck1U1
        loc1U1
        loc1U2
        city1
        truck2U1
        loc2U1
        loc2U2
        city2
        truck3U1
        loc3U1
        loc3U2
        city3
        truck4U1
        loc4U1
        loc4U2
        city4
        truck5U1
        loc5U1
        loc5U2
        city5
        truck6U1
        loc6U1
        loc6U2
        city6
    )
    (:init 
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (obj package7)
        (obj package8)
        (obj package9)
        (airplane plane1)
        (airplane plane2)
        (airplane plane3)
        (truck truck1U1)
        (location loc1U1)
        (location loc1U2)
        (city city1)
        (airport loc1U1)
        (truck truck2U1)
        (location loc2U1)
        (location loc2U2)
        (city city2)
        (airport loc2U1)
        (truck truck3U1)
        (location loc3U1)
        (location loc3U2)
        (city city3)
        (airport loc3U1)
        (truck truck4U1)
        (location loc4U1)
        (location loc4U2)
        (city city4)
        (airport loc4U1)
        (truck truck5U1)
        (location loc5U1)
        (location loc5U2)
        (city city5)
        (airport loc5U1)
        (truck truck6U1)
        (location loc6U1)
        (location loc6U2)
        (city city6)
        (airport loc6U1)
        (inUcity loc1U1 city1)
        (inUcity loc1U2 city1)
        (inUcity loc2U1 city2)
        (inUcity loc2U2 city2)
        (inUcity loc3U1 city3)
        (inUcity loc3U2 city3)
        (inUcity loc4U1 city4)
        (inUcity loc4U2 city4)
        (inUcity loc5U1 city5)
        (inUcity loc5U2 city5)
        (inUcity loc6U1 city6)
        (inUcity loc6U2 city6)
        (at plane1 loc6U1)
        (at plane2 loc6U1)
        (at plane3 loc3U1)
        (at truck1U1 loc1U2)
        (at truck2U1 loc2U1)
        (at truck3U1 loc3U2)
        (at truck4U1 loc4U2)
        (at truck5U1 loc5U1)
        (at truck6U1 loc6U1)
        (at package1 loc3U2)
        (at package2 loc3U2)
        (at package3 loc4U2)
        (at package4 loc5U2)
        (at package5 loc2U1)
        (at package6 loc5U2)
        (at package7 loc4U2)
        (at package8 loc1U1)
        (at package9 loc2U2)
    )
    (:goal (and
        (at package1 loc5U2)
        (at package2 loc1U1)
        (at package3 loc5U2)
        (at package4 loc1U2)
        (at package5 loc3U2)
        (at package6 loc6U1)
        (at package7 loc6U2)
        (at package8 loc3U1)
        (at package9 loc6U2)
    ))
)
;; a logistics problem instance
;; name: log11
;; #packages: 11        #cities: 6  #planes: 3
;; #locs_per_city: 2   #trucks_per_city: 1
;; #goals: 11           seed: 121386628

(define (problem log14)
    (:domain logisticsUstrips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        package10
        package11
        plane1
        plane2
        plane3
        truck1U1
        loc1U1
        loc1U2
        city1
        truck2U1
        loc2U1
        loc2U2
        city2
        truck3U1
        loc3U1
        loc3U2
        city3
        truck4U1
        loc4U1
        loc4U2
        city4
        truck5U1
        loc5U1
        loc5U2
        city5
        truck6U1
        loc6U1
        loc6U2
        city6
    )
    (:init 
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (obj package7)
        (obj package8)
        (obj package9)
        (obj package10)
        (obj package11)
        (airplane plane1)
        (airplane plane2)
        (airplane plane3)
        (truck truck1U1)
        (location loc1U1)
        (location loc1U2)
        (city city1)
        (airport loc1U1)
        (truck truck2U1)
        (location loc2U1)
        (location loc2U2)
        (city city2)
        (airport loc2U1)
        (truck truck3U1)
        (location loc3U1)
        (location loc3U2)
        (city city3)
        (airport loc3U1)
        (truck truck4U1)
        (location loc4U1)
        (location loc4U2)
        (city city4)
        (airport loc4U1)
        (truck truck5U1)
        (location loc5U1)
        (location loc5U2)
        (city city5)
        (airport loc5U1)
        (truck truck6U1)
        (location loc6U1)
        (location loc6U2)
        (city city6)
        (airport loc6U1)
        (inUcity loc1U1 city1)
        (inUcity loc1U2 city1)
        (inUcity loc2U1 city2)
        (inUcity loc2U2 city2)
        (inUcity loc3U1 city3)
        (inUcity loc3U2 city3)
        (inUcity loc4U1 city4)
        (inUcity loc4U2 city4)
        (inUcity loc5U1 city5)
        (inUcity loc5U2 city5)
        (inUcity loc6U1 city6)
        (inUcity loc6U2 city6)
        (at plane1 loc4U1)
        (at plane2 loc2U1)
        (at plane3 loc5U1)
        (at truck1U1 loc1U2)
        (at truck2U1 loc2U1)
        (at truck3U1 loc3U2)
        (at truck4U1 loc4U2)
        (at truck5U1 loc5U1)
        (at truck6U1 loc6U1)
        (at package1 loc5U2)
        (at package2 loc5U2)
        (at package3 loc2U2)
        (at package4 loc3U2)
        (at package5 loc6U1)
        (at package6 loc3U2)
        (at package7 loc2U2)
        (at package8 loc3U1)
        (at package9 loc2U2)
        (at package10 loc3U2)
        (at package11 loc1U1)
    )
    (:goal (and
        (at package1 loc3U2)
        (at package2 loc3U2)
        (at package3 loc3U2)
        (at package4 loc6U1)
        (at package5 loc4U2)
        (at package6 loc1U1)
        (at package7 loc4U2)
        (at package8 loc2U2)
        (at package9 loc3U2)
        (at package10 loc3U1)
        (at package11 loc1U2)
    ))
)
;; a logistics problem instance
;; name: log12
;; #packages: 11        #cities: 6  #planes: 2
;; #locs_per_city: 2   #trucks_per_city: 1
;; #goals: 11           seed: 69437334

(define (problem log15)
    (:domain logisticsUstrips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        package10
        package11
        plane1
        plane2
        truck1U1
        loc1U1
        loc1U2
        city1
        truck2U1
        loc2U1
        loc2U2
        city2
        truck3U1
        loc3U1
        loc3U2
        city3
        truck4U1
        loc4U1
        loc4U2
        city4
        truck5U1
        loc5U1
        loc5U2
        city5
        truck6U1
        loc6U1
        loc6U2
        city6
    )
    (:init 
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (obj package7)
        (obj package8)
        (obj package9)
        (obj package10)
        (obj package11)
        (airplane plane1)
        (airplane plane2)
        (truck truck1U1)
        (location loc1U1)
        (location loc1U2)
        (city city1)
        (airport loc1U1)
        (truck truck2U1)
        (location loc2U1)
        (location loc2U2)
        (city city2)
        (airport loc2U1)
        (truck truck3U1)
        (location loc3U1)
        (location loc3U2)
        (city city3)
        (airport loc3U1)
        (truck truck4U1)
        (location loc4U1)
        (location loc4U2)
        (city city4)
        (airport loc4U1)
        (truck truck5U1)
        (location loc5U1)
        (location loc5U2)
        (city city5)
        (airport loc5U1)
        (truck truck6U1)
        (location loc6U1)
        (location loc6U2)
        (city city6)
        (airport loc6U1)
        (inUcity loc1U1 city1)
        (inUcity loc1U2 city1)
        (inUcity loc2U1 city2)
        (inUcity loc2U2 city2)
        (inUcity loc3U1 city3)
        (inUcity loc3U2 city3)
        (inUcity loc4U1 city4)
        (inUcity loc4U2 city4)
        (inUcity loc5U1 city5)
        (inUcity loc5U2 city5)
        (inUcity loc6U1 city6)
        (inUcity loc6U2 city6)
        (at plane1 loc3U1)
        (at plane2 loc4U1)
        (at truck1U1 loc1U2)
        (at truck2U1 loc2U2)
        (at truck3U1 loc3U1)
        (at truck4U1 loc4U1)
        (at truck5U1 loc5U2)
        (at truck6U1 loc6U1)
        (at package1 loc4U2)
        (at package2 loc1U2)
        (at package3 loc3U2)
        (at package4 loc3U1)
        (at package5 loc5U1)
        (at package6 loc2U2)
        (at package7 loc1U2)
        (at package8 loc6U1)
        (at package9 loc5U2)
        (at package10 loc3U2)
        (at package11 loc4U1)
    )
    (:goal (and
        (at package1 loc6U2)
        (at package2 loc4U1)
        (at package3 loc5U1)
        (at package4 loc5U1)
        (at package5 loc5U2)
        (at package6 loc6U2)
        (at package7 loc4U1)
        (at package8 loc3U2)
        (at package9 loc3U1)
        (at package10 loc1U1)
        (at package11 loc2U1)
    ))
)
;; a logistics problem instance
;; name: log13
;; #packages: 6        #cities: 6  #planes: 1
;; #locs_per_city: 2   #trucks_per_city: 1
;; #goals: 6           seed: 68345397

(define (problem log16)
    (:domain logisticsUstrips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        plane1
        truck1U1
        loc1U1
        loc1U2
        city1
        truck2U1
        loc2U1
        loc2U2
        city2
        truck3U1
        loc3U1
        loc3U2
        city3
        truck4U1
        loc4U1
        loc4U2
        city4
        truck5U1
        loc5U1
        loc5U2
        city5
        truck6U1
        loc6U1
        loc6U2
        city6
    )
    (:init 
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (airplane plane1)
        (truck truck1U1)
        (location loc1U1)
        (location loc1U2)
        (city city1)
        (airport loc1U1)
        (truck truck2U1)
        (location loc2U1)
        (location loc2U2)
        (city city2)
        (airport loc2U1)
        (truck truck3U1)
        (location loc3U1)
        (location loc3U2)
        (city city3)
        (airport loc3U1)
        (truck truck4U1)
        (location loc4U1)
        (location loc4U2)
        (city city4)
        (airport loc4U1)
        (truck truck5U1)
        (location loc5U1)
        (location loc5U2)
        (city city5)
        (airport loc5U1)
        (truck truck6U1)
        (location loc6U1)
        (location loc6U2)
        (city city6)
        (airport loc6U1)
        (inUcity loc1U1 city1)
        (inUcity loc1U2 city1)
        (inUcity loc2U1 city2)
        (inUcity loc2U2 city2)
        (inUcity loc3U1 city3)
        (inUcity loc3U2 city3)
        (inUcity loc4U1 city4)
        (inUcity loc4U2 city4)
        (inUcity loc5U1 city5)
        (inUcity loc5U2 city5)
        (inUcity loc6U1 city6)
        (inUcity loc6U2 city6)
        (at plane1 loc2U1)
        (at truck1U1 loc1U1)
        (at truck2U1 loc2U2)
        (at truck3U1 loc3U1)
        (at truck4U1 loc4U2)
        (at truck5U1 loc5U2)
        (at truck6U1 loc6U1)
        (at package1 loc2U2)
        (at package2 loc3U2)
        (at package3 loc4U2)
        (at package4 loc5U2)
        (at package5 loc6U2)
        (at package6 loc5U1)
    )
    (:goal (and
        (at package1 loc1U1)
        (at package2 loc4U1)
        (at package3 loc5U2)
        (at package4 loc4U2)
        (at package5 loc6U1)
        (at package6 loc6U1)
    ))
)
;; a logistics problem instance
;; name: log14
;; #packages: 6        #cities: 6  #planes: 1
;; #locs_per_city: 2   #trucks_per_city: 1
;; #goals: 6           seed: 68345397
;; modified by hand from log13.
;; placed packages in circle & one destination

(define (problem log17)
    (:domain logisticsUstrips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        plane1
        truck1U1
        loc1U1
        loc1U2
        city1
        truck2U1
        loc2U1
        loc2U2
        city2
        truck3U1
        loc3U1
        loc3U2
        city3
        truck4U1
        loc4U1
        loc4U2
        city4
        truck5U1
        loc5U1
        loc5U2
        city5
        truck6U1
        loc6U1
        loc6U2
        city6
    )
    (:init 
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (airplane plane1)
        (truck truck1U1)
        (location loc1U1)
        (location loc1U2)
        (city city1)
        (airport loc1U1)
        (truck truck2U1)
        (location loc2U1)
        (location loc2U2)
        (city city2)
        (airport loc2U1)
        (truck truck3U1)
        (location loc3U1)
        (location loc3U2)
        (city city3)
        (airport loc3U1)
        (truck truck4U1)
        (location loc4U1)
        (location loc4U2)
        (city city4)
        (airport loc4U1)
        (truck truck5U1)
        (location loc5U1)
        (location loc5U2)
        (city city5)
        (airport loc5U1)
        (truck truck6U1)
        (location loc6U1)
        (location loc6U2)
        (city city6)
        (airport loc6U1)
        (inUcity loc1U1 city1)
        (inUcity loc1U2 city1)
        (inUcity loc2U1 city2)
        (inUcity loc2U2 city2)
        (inUcity loc3U1 city3)
        (inUcity loc3U2 city3)
        (inUcity loc4U1 city4)
        (inUcity loc4U2 city4)
        (inUcity loc5U1 city5)
        (inUcity loc5U2 city5)
        (inUcity loc6U1 city6)
        (inUcity loc6U2 city6)
        (at plane1 loc2U1)
        (at truck1U1 loc1U1)
        (at truck2U1 loc2U2)
        (at truck3U1 loc3U1)
        (at truck4U1 loc4U2)
        (at truck5U1 loc5U2)
        (at truck6U1 loc6U1)
        (at package1 loc1U2)
        (at package2 loc2U2)
        (at package3 loc3U2)
        (at package4 loc4U2)
        (at package5 loc5U2)
        (at package6 loc6U2)
    )
    (:goal (and
        (at package1 loc6U2)
        (at package2 loc6U2)
        (at package3 loc6U2)
        (at package4 loc6U2)
        (at package5 loc6U2)
        (at package6 loc6U2)
    ))
)
;; a logistics problem instance
;; name: log15
;; #packages: 8        #cities: 6  #planes: 2
;; #locs_per_city: 3   #trucks_per_city: 2
;; #goals: 8           seed: 112000697

(define (problem log18)
    (:domain logisticsUstrips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        plane1
        plane2
        truck1U1
        truck1U2
        loc1U1
        loc1U2
        loc1U3
        city1
        truck2U1
        truck2U2
        loc2U1
        loc2U2
        loc2U3
        city2
        truck3U1
        truck3U2
        loc3U1
        loc3U2
        loc3U3
        city3
        truck4U1
        truck4U2
        loc4U1
        loc4U2
        loc4U3
        city4
        truck5U1
        truck5U2
        loc5U1
        loc5U2
        loc5U3
        city5
        truck6U1
        truck6U2
        loc6U1
        loc6U2
        loc6U3
        city6
    )
    (:init 
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (obj package7)
        (obj package8)
        (airplane plane1)
        (airplane plane2)
        (truck truck1U1)
        (truck truck1U2)
        (location loc1U1)
        (location loc1U2)
        (location loc1U3)
        (city city1)
        (airport loc1U1)
        (truck truck2U1)
        (truck truck2U2)
        (location loc2U1)
        (location loc2U2)
        (location loc2U3)
        (city city2)
        (airport loc2U1)
        (truck truck3U1)
        (truck truck3U2)
        (location loc3U1)
        (location loc3U2)
        (location loc3U3)
        (city city3)
        (airport loc3U1)
        (truck truck4U1)
        (truck truck4U2)
        (location loc4U1)
        (location loc4U2)
        (location loc4U3)
        (city city4)
        (airport loc4U1)
        (truck truck5U1)
        (truck truck5U2)
        (location loc5U1)
        (location loc5U2)
        (location loc5U3)
        (city city5)
        (airport loc5U1)
        (truck truck6U1)
        (truck truck6U2)
        (location loc6U1)
        (location loc6U2)
        (location loc6U3)
        (city city6)
        (airport loc6U1)
        (inUcity loc1U1 city1)
        (inUcity loc1U2 city1)
        (inUcity loc1U3 city1)
        (inUcity loc2U1 city2)
        (inUcity loc2U2 city2)
        (inUcity loc2U3 city2)
        (inUcity loc3U1 city3)
        (inUcity loc3U2 city3)
        (inUcity loc3U3 city3)
        (inUcity loc4U1 city4)
        (inUcity loc4U2 city4)
        (inUcity loc4U3 city4)
        (inUcity loc5U1 city5)
        (inUcity loc5U2 city5)
        (inUcity loc5U3 city5)
        (inUcity loc6U1 city6)
        (inUcity loc6U2 city6)
        (inUcity loc6U3 city6)
        (at plane1 loc2U1)
        (at plane2 loc3U1)
        (at truck1U1 loc1U1)
        (at truck1U2 loc1U1)
        (at truck2U1 loc2U1)
        (at truck2U2 loc2U1)
        (at truck3U1 loc3U3)
        (at truck3U2 loc3U2)
        (at truck4U1 loc4U2)
        (at truck4U2 loc4U3)
        (at truck5U1 loc5U2)
        (at truck5U2 loc5U1)
        (at truck6U1 loc6U3)
        (at truck6U2 loc6U2)
        (at package1 loc2U3)
        (at package2 loc4U2)
        (at package3 loc5U3)
        (at package4 loc1U2)
        (at package5 loc5U1)
        (at package6 loc4U2)
        (at package7 loc2U1)
        (at package8 loc1U2)
    )
    (:goal (and
        (at package1 loc5U3)
        (at package2 loc4U3)
        (at package3 loc5U3)
        (at package4 loc4U1)
        (at package5 loc1U2)
        (at package6 loc1U3)
        (at package7 loc2U3)
        (at package8 loc2U3)
    ))
)
;; a logistics problem instance
;; name: log16
;; #packages: 9        #cities: 6  #planes: 2
;; #locs_per_city: 2   #trucks_per_city: 1
;; #goals: 9           seed: 70842326

(define (problem log19)
    (:domain logisticsUstrips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        plane1
        plane2
        truck1U1
        loc1U1
        loc1U2
        city1
        truck2U1
        loc2U1
        loc2U2
        city2
        truck3U1
        loc3U1
        loc3U2
        city3
        truck4U1
        loc4U1
        loc4U2
        city4
        truck5U1
        loc5U1
        loc5U2
        city5
        truck6U1
        loc6U1
        loc6U2
        city6
    )
    (:init 
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (obj package7)
        (obj package8)
        (obj package9)
        (airplane plane1)
        (airplane plane2)
        (truck truck1U1)
        (location loc1U1)
        (location loc1U2)
        (city city1)
        (airport loc1U1)
        (truck truck2U1)
        (location loc2U1)
        (location loc2U2)
        (city city2)
        (airport loc2U1)
        (truck truck3U1)
        (location loc3U1)
        (location loc3U2)
        (city city3)
        (airport loc3U1)
        (truck truck4U1)
        (location loc4U1)
        (location loc4U2)
        (city city4)
        (airport loc4U1)
        (truck truck5U1)
        (location loc5U1)
        (location loc5U2)
        (city city5)
        (airport loc5U1)
        (truck truck6U1)
        (location loc6U1)
        (location loc6U2)
        (city city6)
        (airport loc6U1)
        (inUcity loc1U1 city1)
        (inUcity loc1U2 city1)
        (inUcity loc2U1 city2)
        (inUcity loc2U2 city2)
        (inUcity loc3U1 city3)
        (inUcity loc3U2 city3)
        (inUcity loc4U1 city4)
        (inUcity loc4U2 city4)
        (inUcity loc5U1 city5)
        (inUcity loc5U2 city5)
        (inUcity loc6U1 city6)
        (inUcity loc6U2 city6)
        (at plane1 loc5U1)
        (at plane2 loc4U1)
        (at truck1U1 loc1U2)
        (at truck2U1 loc2U2)
        (at truck3U1 loc3U1)
        (at truck4U1 loc4U1)
        (at truck5U1 loc5U2)
        (at truck6U1 loc6U1)
        (at package1 loc6U2)
        (at package2 loc5U2)
        (at package3 loc3U2)
        (at package4 loc3U1)
        (at package5 loc1U1)
        (at package6 loc6U2)
        (at package7 loc1U2)
        (at package8 loc4U1)
        (at package9 loc5U2)
    )
    (:goal (and
        (at package1 loc5U2)
        (at package2 loc4U1)
        (at package3 loc6U2)
        (at package4 loc2U1)
        (at package5 loc1U1)
        (at package6 loc5U1)
        (at package7 loc1U2)
        (at package8 loc2U2)
        (at package9 loc6U1)
    ))
)
;; a logistics problem instance
;; name: log17
;; #packages: 10        #cities: 7  #planes: 2
;; #locs_per_city: 2   #trucks_per_city: 1
;; #goals: 10           seed: 62880555
;; modified by hand to increase regularity
;;    force more sharing in solution; harder to solve

(define (problem log20)
    (:domain logisticsUstrips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        package10
        plane1
        plane2
        truck1U1
        loc1U1
        loc1U2
        city1
        truck2U1
        loc2U1
        loc2U2
        city2
        truck3U1
        loc3U1
        loc3U2
        city3
        truck4U1
        loc4U1
        loc4U2
        city4
        truck5U1
        loc5U1
        loc5U2
        city5
        truck6U1
        loc6U1
        loc6U2
        city6
        truck7U1
        loc7U1
        loc7U2
        city7
    )
    (:init 
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (obj package7)
        (obj package8)
        (obj package9)
        (obj package10)
        (airplane plane1)
        (airplane plane2)
        (truck truck1U1)
        (location loc1U1)
        (location loc1U2)
        (city city1)
        (airport loc1U1)
        (truck truck2U1)
        (location loc2U1)
        (location loc2U2)
        (city city2)
        (airport loc2U1)
        (truck truck3U1)
        (location loc3U1)
        (location loc3U2)
        (city city3)
        (airport loc3U1)
        (truck truck4U1)
        (location loc4U1)
        (location loc4U2)
        (city city4)
        (airport loc4U1)
        (truck truck5U1)
        (location loc5U1)
        (location loc5U2)
        (city city5)
        (airport loc5U1)
        (truck truck6U1)
        (location loc6U1)
        (location loc6U2)
        (city city6)
        (airport loc6U1)
        (truck truck7U1)
        (location loc7U1)
        (location loc7U2)
        (city city7)
        (airport loc7U1)
        (inUcity loc1U1 city1)
        (inUcity loc1U2 city1)
        (inUcity loc2U1 city2)
        (inUcity loc2U2 city2)
        (inUcity loc3U1 city3)
        (inUcity loc3U2 city3)
        (inUcity loc4U1 city4)
        (inUcity loc4U2 city4)
        (inUcity loc5U1 city5)
        (inUcity loc5U2 city5)
        (inUcity loc6U1 city6)
        (inUcity loc6U2 city6)
        (inUcity loc7U1 city7)
        (inUcity loc7U2 city7)
        (at plane1 loc1U1)
        (at plane2 loc1U1)
        (at truck1U1 loc1U1)
        (at truck2U1 loc2U1)
        (at truck3U1 loc3U2)
        (at truck4U1 loc4U1)
        (at truck5U1 loc5U1)
        (at truck6U1 loc6U2)
        (at truck7U1 loc7U1)

        (at package1 loc1U2)
        (at package2 loc2U2)
        (at package3 loc3U2)
        (at package4 loc4U2)
        (at package5 loc5U2)
        (at package6 loc6U2)
        (at package7 loc7U2)
        (at package8 loc1U2)
        (at package9 loc2U2)
        (at package10 loc3U2)
    )
    (:goal (and
        (at package1 loc3U2)
        (at package2 loc4U2)
        (at package3 loc5U2)
        (at package4 loc6U2)
        (at package5 loc6U2)
        (at package6 loc5U2)
        (at package7 loc4U2)
        (at package8 loc5U2)
        (at package9 loc6U2)
        (at package10 loc7U2)
    ))
)

;; a logistics problem instance
;; name: log06
;; #packages: 10        #cities: 6  #planes: 3
;; #locs_per_city: 2   #trucks_per_city: 1
;; #goals: 10           seed: 12268313

(define (problem log21)
    (:domain logisticsUstrips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        package10
        plane1
        plane2
        plane3
        truck1U1
        loc1U1
        loc1U2
        city1
        truck2U1
        loc2U1
        loc2U2
        city2
        truck3U1
        loc3U1
        loc3U2
        city3
        truck4U1
        loc4U1
        loc4U2
        city4
        truck5U1
        loc5U1
        loc5U2
        city5
        truck6U1
        loc6U1
        loc6U2
        city6
    )
    (:init 
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (obj package7)
        (obj package8)
        (obj package9)
        (obj package10)
        (airplane plane1)
        (airplane plane2)
        (airplane plane3)
        (truck truck1U1)
        (location loc1U1)
        (location loc1U2)
        (city city1)
        (airport loc1U1)
        (truck truck2U1)
        (location loc2U1)
        (location loc2U2)
        (city city2)
        (airport loc2U1)
        (truck truck3U1)
        (location loc3U1)
        (location loc3U2)
        (city city3)
        (airport loc3U1)
        (truck truck4U1)
        (location loc4U1)
        (location loc4U2)
        (city city4)
        (airport loc4U1)
        (truck truck5U1)
        (location loc5U1)
        (location loc5U2)
        (city city5)
        (airport loc5U1)
        (truck truck6U1)
        (location loc6U1)
        (location loc6U2)
        (city city6)
        (airport loc6U1)
        (inUcity loc1U1 city1)
        (inUcity loc1U2 city1)
        (inUcity loc2U1 city2)
        (inUcity loc2U2 city2)
        (inUcity loc3U1 city3)
        (inUcity loc3U2 city3)
        (inUcity loc4U1 city4)
        (inUcity loc4U2 city4)
        (inUcity loc5U1 city5)
        (inUcity loc5U2 city5)
        (inUcity loc6U1 city6)
        (inUcity loc6U2 city6)
        (at plane1 loc6U1)
        (at plane2 loc5U1)
        (at plane3 loc4U1)
        (at truck1U1 loc1U1)
        (at truck2U1 loc2U2)
        (at truck3U1 loc3U2)
        (at truck4U1 loc4U1)
        (at truck5U1 loc5U2)
        (at truck6U1 loc6U2)
        (at package1 loc1U2)
        (at package2 loc6U2)
        (at package3 loc5U2)
        (at package4 loc6U2)
        (at package5 loc1U1)
        (at package6 loc5U1)
        (at package7 loc2U1)
        (at package8 loc1U2)
        (at package9 loc4U2)
        (at package10 loc4U1)
    )
    (:goal (and
        (at package1 loc6U1)
        (at package2 loc4U2)
        (at package3 loc3U1)
        (at package4 loc2U2)
        (at package5 loc3U1)
        (at package6 loc1U1)
        (at package7 loc4U2)
        (at package8 loc4U2)
        (at package9 loc3U2)
        (at package10 loc4U1)
    ))
)
;; a logistics problem instance
;; name: log19
;; #packages: 9        #cities: 5  #planes: 2
;; #locs_per_city: 3   #trucks_per_city: 1
;; #goals: 9           seed: 74368277

(define (problem log22)
    (:domain logisticsUstrips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        plane1
        plane2
        truck1U1
        loc1U1
        loc1U2
        loc1U3
        city1
        truck2U1
        loc2U1
        loc2U2
        loc2U3
        city2
        truck3U1
        loc3U1
        loc3U2
        loc3U3
        city3
        truck4U1
        loc4U1
        loc4U2
        loc4U3
        city4
        truck5U1
        loc5U1
        loc5U2
        loc5U3
        city5
    )
    (:init 
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (obj package7)
        (obj package8)
        (obj package9)
        (airplane plane1)
        (airplane plane2)
        (truck truck1U1)
        (location loc1U1)
        (location loc1U2)
        (location loc1U3)
        (city city1)
        (airport loc1U1)
        (truck truck2U1)
        (location loc2U1)
        (location loc2U2)
        (location loc2U3)
        (city city2)
        (airport loc2U1)
        (truck truck3U1)
        (location loc3U1)
        (location loc3U2)
        (location loc3U3)
        (city city3)
        (airport loc3U1)
        (truck truck4U1)
        (location loc4U1)
        (location loc4U2)
        (location loc4U3)
        (city city4)
        (airport loc4U1)
        (truck truck5U1)
        (location loc5U1)
        (location loc5U2)
        (location loc5U3)
        (city city5)
        (airport loc5U1)
        (inUcity loc1U1 city1)
        (inUcity loc1U2 city1)
        (inUcity loc1U3 city1)
        (inUcity loc2U1 city2)
        (inUcity loc2U2 city2)
        (inUcity loc2U3 city2)
        (inUcity loc3U1 city3)
        (inUcity loc3U2 city3)
        (inUcity loc3U3 city3)
        (inUcity loc4U1 city4)
        (inUcity loc4U2 city4)
        (inUcity loc4U3 city4)
        (inUcity loc5U1 city5)
        (inUcity loc5U2 city5)
        (inUcity loc5U3 city5)
        (at plane1 loc1U1)
        (at plane2 loc1U1)
        (at truck1U1 loc1U3)
        (at truck2U1 loc2U3)
        (at truck3U1 loc3U3)
        (at truck4U1 loc4U1)
        (at truck5U1 loc5U2)
        (at package1 loc5U3)
        (at package2 loc2U3)
        (at package3 loc4U1)
        (at package4 loc3U3)
        (at package5 loc4U3)
        (at package6 loc2U2)
        (at package7 loc1U2)
        (at package8 loc5U1)
        (at package9 loc5U1)
    )
    (:goal (and
        (at package1 loc4U3)
        (at package2 loc4U2)
        (at package3 loc2U3)
        (at package4 loc5U2)
        (at package5 loc1U2)
        (at package6 loc5U3)
        (at package7 loc3U3)
        (at package8 loc2U2)
        (at package9 loc1U1)
    ))
)
;; a logistics problem instance
;; name: log20
;; #packages: 9        #cities: 5  #planes: 2
;; #locs_per_city: 3   #trucks_per_city: 1
;; #goals: 9           seed: 79224903

(define (problem log23)
    (:domain logisticsUstrips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        plane1
        plane2
        truck1U1
        loc1U1
        loc1U2
        loc1U3
        city1
        truck2U1
        loc2U1
        loc2U2
        loc2U3
        city2
        truck3U1
        loc3U1
        loc3U2
        loc3U3
        city3
        truck4U1
        loc4U1
        loc4U2
        loc4U3
        city4
        truck5U1
        loc5U1
        loc5U2
        loc5U3
        city5
    )
    (:init 
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (obj package7)
        (obj package8)
        (obj package9)
        (airplane plane1)
        (airplane plane2)
        (truck truck1U1)
        (location loc1U1)
        (location loc1U2)
        (location loc1U3)
        (city city1)
        (airport loc1U1)
        (truck truck2U1)
        (location loc2U1)
        (location loc2U2)
        (location loc2U3)
        (city city2)
        (airport loc2U1)
        (truck truck3U1)
        (location loc3U1)
        (location loc3U2)
        (location loc3U3)
        (city city3)
        (airport loc3U1)
        (truck truck4U1)
        (location loc4U1)
        (location loc4U2)
        (location loc4U3)
        (city city4)
        (airport loc4U1)
        (truck truck5U1)
        (location loc5U1)
        (location loc5U2)
        (location loc5U3)
        (city city5)
        (airport loc5U1)
        (inUcity loc1U1 city1)
        (inUcity loc1U2 city1)
        (inUcity loc1U3 city1)
        (inUcity loc2U1 city2)
        (inUcity loc2U2 city2)
        (inUcity loc2U3 city2)
        (inUcity loc3U1 city3)
        (inUcity loc3U2 city3)
        (inUcity loc3U3 city3)
        (inUcity loc4U1 city4)
        (inUcity loc4U2 city4)
        (inUcity loc4U3 city4)
        (inUcity loc5U1 city5)
        (inUcity loc5U2 city5)
        (inUcity loc5U3 city5)
        (at plane1 loc3U1)
        (at plane2 loc1U1)
        (at truck1U1 loc1U1)
        (at truck2U1 loc2U1)
        (at truck3U1 loc3U3)
        (at truck4U1 loc4U3)
        (at truck5U1 loc5U3)
        (at package1 loc5U1)
        (at package2 loc2U3)
        (at package3 loc2U3)
        (at package4 loc4U2)
        (at package5 loc5U2)
        (at package6 loc5U3)
        (at package7 loc5U3)
        (at package8 loc2U1)
        (at package9 loc5U1)
    )
    (:goal (and
        (at package1 loc5U1)
        (at package2 loc1U2)
        (at package3 loc2U1)
        (at package4 loc5U1)
        (at package5 loc4U3)
        (at package6 loc2U2)
        (at package7 loc1U3)
        (at package8 loc4U2)
        (at package9 loc3U2)
    ))
)
;; a logistics problem instance
;; name: log21
;; #packages: 9        #cities: 5  #planes: 2
;; #locs_per_city: 3   #trucks_per_city: 1
;; #goals: 9           seed: 70675221

(define (problem log24)
    (:domain logisticsUstrips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        plane1
        plane2
        truck1U1
        loc1U1
        loc1U2
        loc1U3
        city1
        truck2U1
        loc2U1
        loc2U2
        loc2U3
        city2
        truck3U1
        loc3U1
        loc3U2
        loc3U3
        city3
        truck4U1
        loc4U1
        loc4U2
        loc4U3
        city4
        truck5U1
        loc5U1
        loc5U2
        loc5U3
        city5
    )
    (:init 
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (obj package7)
        (obj package8)
        (obj package9)
        (airplane plane1)
        (airplane plane2)
        (truck truck1U1)
        (location loc1U1)
        (location loc1U2)
        (location loc1U3)
        (city city1)
        (airport loc1U1)
        (truck truck2U1)
        (location loc2U1)
        (location loc2U2)
        (location loc2U3)
        (city city2)
        (airport loc2U1)
        (truck truck3U1)
        (location loc3U1)
        (location loc3U2)
        (location loc3U3)
        (city city3)
        (airport loc3U1)
        (truck truck4U1)
        (location loc4U1)
        (location loc4U2)
        (location loc4U3)
        (city city4)
        (airport loc4U1)
        (truck truck5U1)
        (location loc5U1)
        (location loc5U2)
        (location loc5U3)
        (city city5)
        (airport loc5U1)
        (inUcity loc1U1 city1)
        (inUcity loc1U2 city1)
        (inUcity loc1U3 city1)
        (inUcity loc2U1 city2)
        (inUcity loc2U2 city2)
        (inUcity loc2U3 city2)
        (inUcity loc3U1 city3)
        (inUcity loc3U2 city3)
        (inUcity loc3U3 city3)
        (inUcity loc4U1 city4)
        (inUcity loc4U2 city4)
        (inUcity loc4U3 city4)
        (inUcity loc5U1 city5)
        (inUcity loc5U2 city5)
        (inUcity loc5U3 city5)
        (at plane1 loc4U1)
        (at plane2 loc5U1)
        (at truck1U1 loc1U1)
        (at truck2U1 loc2U3)
        (at truck3U1 loc3U2)
        (at truck4U1 loc4U1)
        (at truck5U1 loc5U2)
        (at package1 loc4U1)
        (at package2 loc4U3)
        (at package3 loc3U2)
        (at package4 loc2U2)
        (at package5 loc5U3)
        (at package6 loc4U3)
        (at package7 loc3U2)
        (at package8 loc2U3)
        (at package9 loc3U1)
    )
    (:goal (and
        (at package1 loc3U2)
        (at package2 loc5U3)
        (at package3 loc5U2)
        (at package4 loc2U3)
        (at package5 loc4U1)
        (at package6 loc1U2)
        (at package7 loc4U2)
        (at package8 loc5U1)
        (at package9 loc1U2)
    ))
)
;; a logistics problem instance
;; name: log22
;; #packages: 9        #cities: 5  #planes: 2
;; #locs_per_city: 3   #trucks_per_city: 1
;; #goals: 9           seed: 76638317

(define (problem log25)
    (:domain logisticsUstrips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        plane1
        plane2
        truck1U1
        loc1U1
        loc1U2
        loc1U3
        city1
        truck2U1
        loc2U1
        loc2U2
        loc2U3
        city2
        truck3U1
        loc3U1
        loc3U2
        loc3U3
        city3
        truck4U1
        loc4U1
        loc4U2
        loc4U3
        city4
        truck5U1
        loc5U1
        loc5U2
        loc5U3
        city5
    )
    (:init 
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (obj package7)
        (obj package8)
        (obj package9)
        (airplane plane1)
        (airplane plane2)
        (truck truck1U1)
        (location loc1U1)
        (location loc1U2)
        (location loc1U3)
        (city city1)
        (airport loc1U1)
        (truck truck2U1)
        (location loc2U1)
        (location loc2U2)
        (location loc2U3)
        (city city2)
        (airport loc2U1)
        (truck truck3U1)
        (location loc3U1)
        (location loc3U2)
        (location loc3U3)
        (city city3)
        (airport loc3U1)
        (truck truck4U1)
        (location loc4U1)
        (location loc4U2)
        (location loc4U3)
        (city city4)
        (airport loc4U1)
        (truck truck5U1)
        (location loc5U1)
        (location loc5U2)
        (location loc5U3)
        (city city5)
        (airport loc5U1)
        (inUcity loc1U1 city1)
        (inUcity loc1U2 city1)
        (inUcity loc1U3 city1)
        (inUcity loc2U1 city2)
        (inUcity loc2U2 city2)
        (inUcity loc2U3 city2)
        (inUcity loc3U1 city3)
        (inUcity loc3U2 city3)
        (inUcity loc3U3 city3)
        (inUcity loc4U1 city4)
        (inUcity loc4U2 city4)
        (inUcity loc4U3 city4)
        (inUcity loc5U1 city5)
        (inUcity loc5U2 city5)
        (inUcity loc5U3 city5)
        (at plane1 loc4U1)
        (at plane2 loc5U1)
        (at truck1U1 loc1U1)
        (at truck2U1 loc2U2)
        (at truck3U1 loc3U1)
        (at truck4U1 loc4U1)
        (at truck5U1 loc5U2)
        (at package1 loc5U1)
        (at package2 loc5U3)
        (at package3 loc1U3)
        (at package4 loc1U1)
        (at package5 loc5U3)
        (at package6 loc5U3)
        (at package7 loc5U2)
        (at package8 loc5U2)
        (at package9 loc2U3)
    )
    (:goal (and
        (at package1 loc2U3)
        (at package2 loc3U3)
        (at package3 loc3U1)
        (at package4 loc2U3)
        (at package5 loc2U1)
        (at package6 loc4U3)
        (at package7 loc5U1)
        (at package8 loc5U2)
        (at package9 loc4U2)
    ))
)
;; a logistics problem instance
;; name: log23
;; #packages: 9        #cities: 5  #planes: 2
;; #locs_per_city: 3   #trucks_per_city: 1
;; #goals: 9           seed: 84823437

(define (problem log26)
    (:domain logisticsUstrips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        plane1
        plane2
        truck1U1
        loc1U1
        loc1U2
        loc1U3
        city1
        truck2U1
        loc2U1
        loc2U2
        loc2U3
        city2
        truck3U1
        loc3U1
        loc3U2
        loc3U3
        city3
        truck4U1
        loc4U1
        loc4U2
        loc4U3
        city4
        truck5U1
        loc5U1
        loc5U2
        loc5U3
        city5
    )
    (:init 
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (obj package7)
        (obj package8)
        (obj package9)
        (airplane plane1)
        (airplane plane2)
        (truck truck1U1)
        (location loc1U1)
        (location loc1U2)
        (location loc1U3)
        (city city1)
        (airport loc1U1)
        (truck truck2U1)
        (location loc2U1)
        (location loc2U2)
        (location loc2U3)
        (city city2)
        (airport loc2U1)
        (truck truck3U1)
        (location loc3U1)
        (location loc3U2)
        (location loc3U3)
        (city city3)
        (airport loc3U1)
        (truck truck4U1)
        (location loc4U1)
        (location loc4U2)
        (location loc4U3)
        (city city4)
        (airport loc4U1)
        (truck truck5U1)
        (location loc5U1)
        (location loc5U2)
        (location loc5U3)
        (city city5)
        (airport loc5U1)
        (inUcity loc1U1 city1)
        (inUcity loc1U2 city1)
        (inUcity loc1U3 city1)
        (inUcity loc2U1 city2)
        (inUcity loc2U2 city2)
        (inUcity loc2U3 city2)
        (inUcity loc3U1 city3)
        (inUcity loc3U2 city3)
        (inUcity loc3U3 city3)
        (inUcity loc4U1 city4)
        (inUcity loc4U2 city4)
        (inUcity loc4U3 city4)
        (inUcity loc5U1 city5)
        (inUcity loc5U2 city5)
        (inUcity loc5U3 city5)
        (at plane1 loc2U1)
        (at plane2 loc1U1)
        (at truck1U1 loc1U1)
        (at truck2U1 loc2U2)
        (at truck3U1 loc3U3)
        (at truck4U1 loc4U1)
        (at truck5U1 loc5U1)
        (at package1 loc5U2)
        (at package2 loc3U1)
        (at package3 loc4U3)
        (at package4 loc2U3)
        (at package5 loc3U1)
        (at package6 loc1U1)
        (at package7 loc4U3)
        (at package8 loc4U3)
        (at package9 loc4U3)
    )
    (:goal (and
        (at package1 loc3U2)
        (at package2 loc5U2)
        (at package3 loc4U3)
        (at package4 loc3U2)
        (at package5 loc3U1)
        (at package6 loc3U3)
        (at package7 loc3U2)
        (at package8 loc2U3)
        (at package9 loc4U3)
    ))
)
;; a logistics problem instance
;; name: log24
;; #packages: 9        #cities: 5  #planes: 2
;; #locs_per_city: 3   #trucks_per_city: 1
;; #goals: 9           seed: 93568004

(define (problem log27)
    (:domain logisticsUstrips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        plane1
        plane2
        truck1U1
        loc1U1
        loc1U2
        loc1U3
        city1
        truck2U1
        loc2U1
        loc2U2
        loc2U3
        city2
        truck3U1
        loc3U1
        loc3U2
        loc3U3
        city3
        truck4U1
        loc4U1
        loc4U2
        loc4U3
        city4
        truck5U1
        loc5U1
        loc5U2
        loc5U3
        city5
    )
    (:init 
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (obj package7)
        (obj package8)
        (obj package9)
        (airplane plane1)
        (airplane plane2)
        (truck truck1U1)
        (location loc1U1)
        (location loc1U2)
        (location loc1U3)
        (city city1)
        (airport loc1U1)
        (truck truck2U1)
        (location loc2U1)
        (location loc2U2)
        (location loc2U3)
        (city city2)
        (airport loc2U1)
        (truck truck3U1)
        (location loc3U1)
        (location loc3U2)
        (location loc3U3)
        (city city3)
        (airport loc3U1)
        (truck truck4U1)
        (location loc4U1)
        (location loc4U2)
        (location loc4U3)
        (city city4)
        (airport loc4U1)
        (truck truck5U1)
        (location loc5U1)
        (location loc5U2)
        (location loc5U3)
        (city city5)
        (airport loc5U1)
        (inUcity loc1U1 city1)
        (inUcity loc1U2 city1)
        (inUcity loc1U3 city1)
        (inUcity loc2U1 city2)
        (inUcity loc2U2 city2)
        (inUcity loc2U3 city2)
        (inUcity loc3U1 city3)
        (inUcity loc3U2 city3)
        (inUcity loc3U3 city3)
        (inUcity loc4U1 city4)
        (inUcity loc4U2 city4)
        (inUcity loc4U3 city4)
        (inUcity loc5U1 city5)
        (inUcity loc5U2 city5)
        (inUcity loc5U3 city5)
        (at plane1 loc2U1)
        (at plane2 loc2U1)
        (at truck1U1 loc1U1)
        (at truck2U1 loc2U3)
        (at truck3U1 loc3U3)
        (at truck4U1 loc4U3)
        (at truck5U1 loc5U3)
        (at package1 loc5U3)
        (at package2 loc2U1)
        (at package3 loc1U2)
        (at package4 loc3U3)
        (at package5 loc3U2)
        (at package6 loc4U1)
        (at package7 loc1U1)
        (at package8 loc5U2)
        (at package9 loc2U3)
    )
    (:goal (and
        (at package1 loc3U2)
        (at package2 loc5U3)
        (at package3 loc3U3)
        (at package4 loc2U2)
        (at package5 loc5U3)
        (at package6 loc2U3)
        (at package7 loc4U1)
        (at package8 loc3U2)
        (at package9 loc1U3)
    ))
)
;; a logistics problem instance
;; name: log25
;; #packages: 10        #cities: 6  #planes: 3
;; #locs_per_city: 3   #trucks_per_city: 1
;; #goals: 10           seed: 15940243

(define (problem log28)
    (:domain logisticsUstrips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        package10
        plane1
        plane2
        plane3
        truck1U1
        loc1U1
        loc1U2
        loc1U3
        city1
        truck2U1
        loc2U1
        loc2U2
        loc2U3
        city2
        truck3U1
        loc3U1
        loc3U2
        loc3U3
        city3
        truck4U1
        loc4U1
        loc4U2
        loc4U3
        city4
        truck5U1
        loc5U1
        loc5U2
        loc5U3
        city5
        truck6U1
        loc6U1
        loc6U2
        loc6U3
        city6
    )
    (:init 
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (obj package7)
        (obj package8)
        (obj package9)
        (obj package10)
        (airplane plane1)
        (airplane plane2)
        (airplane plane3)
        (truck truck1U1)
        (location loc1U1)
        (location loc1U2)
        (location loc1U3)
        (city city1)
        (airport loc1U1)
        (truck truck2U1)
        (location loc2U1)
        (location loc2U2)
        (location loc2U3)
        (city city2)
        (airport loc2U1)
        (truck truck3U1)
        (location loc3U1)
        (location loc3U2)
        (location loc3U3)
        (city city3)
        (airport loc3U1)
        (truck truck4U1)
        (location loc4U1)
        (location loc4U2)
        (location loc4U3)
        (city city4)
        (airport loc4U1)
        (truck truck5U1)
        (location loc5U1)
        (location loc5U2)
        (location loc5U3)
        (city city5)
        (airport loc5U1)
        (truck truck6U1)
        (location loc6U1)
        (location loc6U2)
        (location loc6U3)
        (city city6)
        (airport loc6U1)
        (inUcity loc1U1 city1)
        (inUcity loc1U2 city1)
        (inUcity loc1U3 city1)
        (inUcity loc2U1 city2)
        (inUcity loc2U2 city2)
        (inUcity loc2U3 city2)
        (inUcity loc3U1 city3)
        (inUcity loc3U2 city3)
        (inUcity loc3U3 city3)
        (inUcity loc4U1 city4)
        (inUcity loc4U2 city4)
        (inUcity loc4U3 city4)
        (inUcity loc5U1 city5)
        (inUcity loc5U2 city5)
        (inUcity loc5U3 city5)
        (inUcity loc6U1 city6)
        (inUcity loc6U2 city6)
        (inUcity loc6U3 city6)
        (at plane1 loc1U1)
        (at plane2 loc1U1)
        (at plane3 loc3U1)
        (at truck1U1 loc1U2)
        (at truck2U1 loc2U1)
        (at truck3U1 loc3U3)
        (at truck4U1 loc4U1)
        (at truck5U1 loc5U3)
        (at truck6U1 loc6U3)
        (at package1 loc4U3)
        (at package2 loc1U2)
        (at package3 loc3U1)
        (at package4 loc4U1)
        (at package5 loc4U1)
        (at package6 loc4U3)
        (at package7 loc2U3)
        (at package8 loc5U3)
        (at package9 loc6U2)
        (at package10 loc5U2)
    )
    (:goal (and
        (at package1 loc2U2)
        (at package2 loc5U2)
        (at package3 loc3U1)
        (at package4 loc4U2)
        (at package5 loc2U1)
        (at package6 loc5U2)
        (at package7 loc3U3)
        (at package8 loc1U2)
        (at package9 loc3U2)
        (at package10 loc4U3)
    ))
)
;; a logistics problem instance
;; name: log26
;; #packages: 10        #cities: 6  #planes: 3
;; #locs_per_city: 3   #trucks_per_city: 1
;; #goals: 10           seed: 3967928

(define (problem log29)
    (:domain logisticsUstrips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        package10
        plane1
        plane2
        plane3
        truck1U1
        loc1U1
        loc1U2
        loc1U3
        city1
        truck2U1
        loc2U1
        loc2U2
        loc2U3
        city2
        truck3U1
        loc3U1
        loc3U2
        loc3U3
        city3
        truck4U1
        loc4U1
        loc4U2
        loc4U3
        city4
        truck5U1
        loc5U1
        loc5U2
        loc5U3
        city5
        truck6U1
        loc6U1
        loc6U2
        loc6U3
        city6
    )
    (:init 
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (obj package7)
        (obj package8)
        (obj package9)
        (obj package10)
        (airplane plane1)
        (airplane plane2)
        (airplane plane3)
        (truck truck1U1)
        (location loc1U1)
        (location loc1U2)
        (location loc1U3)
        (city city1)
        (airport loc1U1)
        (truck truck2U1)
        (location loc2U1)
        (location loc2U2)
        (location loc2U3)
        (city city2)
        (airport loc2U1)
        (truck truck3U1)
        (location loc3U1)
        (location loc3U2)
        (location loc3U3)
        (city city3)
        (airport loc3U1)
        (truck truck4U1)
        (location loc4U1)
        (location loc4U2)
        (location loc4U3)
        (city city4)
        (airport loc4U1)
        (truck truck5U1)
        (location loc5U1)
        (location loc5U2)
        (location loc5U3)
        (city city5)
        (airport loc5U1)
        (truck truck6U1)
        (location loc6U1)
        (location loc6U2)
        (location loc6U3)
        (city city6)
        (airport loc6U1)
        (inUcity loc1U1 city1)
        (inUcity loc1U2 city1)
        (inUcity loc1U3 city1)
        (inUcity loc2U1 city2)
        (inUcity loc2U2 city2)
        (inUcity loc2U3 city2)
        (inUcity loc3U1 city3)
        (inUcity loc3U2 city3)
        (inUcity loc3U3 city3)
        (inUcity loc4U1 city4)
        (inUcity loc4U2 city4)
        (inUcity loc4U3 city4)
        (inUcity loc5U1 city5)
        (inUcity loc5U2 city5)
        (inUcity loc5U3 city5)
        (inUcity loc6U1 city6)
        (inUcity loc6U2 city6)
        (inUcity loc6U3 city6)
        (at plane1 loc4U1)
        (at plane2 loc4U1)
        (at plane3 loc5U1)
        (at truck1U1 loc1U1)
        (at truck2U1 loc2U3)
        (at truck3U1 loc3U3)
        (at truck4U1 loc4U1)
        (at truck5U1 loc5U1)
        (at truck6U1 loc6U3)
        (at package1 loc3U3)
        (at package2 loc1U3)
        (at package3 loc6U1)
        (at package4 loc3U2)
        (at package5 loc6U1)
        (at package6 loc3U2)
        (at package7 loc6U1)
        (at package8 loc1U1)
        (at package9 loc4U1)
        (at package10 loc3U1)
    )
    (:goal (and
        (at package1 loc3U3)
        (at package2 loc1U3)
        (at package3 loc5U2)
        (at package4 loc1U1)
        (at package5 loc6U2)
        (at package6 loc4U3)
        (at package7 loc5U2)
        (at package8 loc6U1)
        (at package9 loc2U3)
        (at package10 loc3U3)
    ))
)
;; a logistics problem instance
;; name: log27
;; #packages: 9        #cities: 5  #planes: 2
;; #locs_per_city: 3   #trucks_per_city: 1
;; #goals: 9           seed: 85419287

(define (problem log30)
    (:domain logisticsUstrips)
    (:objects 
        package1
        package2
        package3
        package4
        package5
        package6
        package7
        package8
        package9
        plane1
        plane2
        truck1U1
        loc1U1
        loc1U2
        loc1U3
        city1
        truck2U1
        loc2U1
        loc2U2
        loc2U3
        city2
        truck3U1
        loc3U1
        loc3U2
        loc3U3
        city3
        truck4U1
        loc4U1
        loc4U2
        loc4U3
        city4
        truck5U1
        loc5U1
        loc5U2
        loc5U3
        city5
    )
    (:init 
        (obj package1)
        (obj package2)
        (obj package3)
        (obj package4)
        (obj package5)
        (obj package6)
        (obj package7)
        (obj package8)
        (obj package9)
        (airplane plane1)
        (airplane plane2)
        (truck truck1U1)
        (location loc1U1)
        (location loc1U2)
        (location loc1U3)
        (city city1)
        (airport loc1U1)
        (truck truck2U1)
        (location loc2U1)
        (location loc2U2)
        (location loc2U3)
        (city city2)
        (airport loc2U1)
        (truck truck3U1)
        (location loc3U1)
        (location loc3U2)
        (location loc3U3)
        (city city3)
        (airport loc3U1)
        (truck truck4U1)
        (location loc4U1)
        (location loc4U2)
        (location loc4U3)
        (city city4)
        (airport loc4U1)
        (truck truck5U1)
        (location loc5U1)
        (location loc5U2)
        (location loc5U3)
        (city city5)
        (airport loc5U1)
        (inUcity loc1U1 city1)
        (inUcity loc1U2 city1)
        (inUcity loc1U3 city1)
        (inUcity loc2U1 city2)
        (inUcity loc2U2 city2)
        (inUcity loc2U3 city2)
        (inUcity loc3U1 city3)
        (inUcity loc3U2 city3)
        (inUcity loc3U3 city3)
        (inUcity loc4U1 city4)
        (inUcity loc4U2 city4)
        (inUcity loc4U3 city4)
        (inUcity loc5U1 city5)
        (inUcity loc5U2 city5)
        (inUcity loc5U3 city5)
        (at plane1 loc1U1)
        (at plane2 loc3U1)
        (at truck1U1 loc1U1)
        (at truck2U1 loc2U1)
        (at truck3U1 loc3U1)
        (at truck4U1 loc4U1)
        (at truck5U1 loc5U1)
        (at package1 loc4U2)
        (at package2 loc5U3)
        (at package3 loc5U1)
        (at package4 loc5U2)
        (at package5 loc5U2)
        (at package6 loc4U3)
        (at package7 loc3U3)
        (at package8 loc2U3)
        (at package9 loc3U1)
    )
    (:goal (and
        (at package1 loc5U2)
        (at package2 loc2U2)
        (at package3 loc1U3)
        (at package4 loc1U2)
        (at package5 loc5U2)
        (at package6 loc4U1)
        (at package7 loc5U2)
        (at package8 loc2U3)
        (at package9 loc3U1)
    ))
)

; the remaining problems are from the aipsU98 competition
; x problems are round 1, y problems are round 2.

(define (problem logUxU1)
   (:domain logisticsUadl)
   (:objects package6 package5 package4 package3 package2 package1
             - obj
             city6 city5 city4 city3 city2 city1 - city
             truck6 truck5 truck4 truck3 truck2 truck1 - truck
             plane2 plane1 - airplane
             city6U1 city5U1 city4U1 city3U1 city2U1 city1U1 - location
             city6U2 city5U2 city4U2 city3U2 city2U2 city1U2 - airport)
   (:init (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane2 city4U2)
          (at plane1 city4U2)
          (at truck6 city6U1)
          (at truck5 city5U1)
          (at truck4 city4U1)
          (at truck3 city3U1)
          (at truck2 city2U1)
          (at truck1 city1U1)
          (at package6 city3U1)
          (at package5 city4U2)
          (at package4 city1U1)
          (at package3 city1U1)
          (at package2 city1U2)
          (at package1 city2U1))
   (:goal (and (at package6 city1U2)
               (at package5 city6U2)
               (at package4 city3U2)
               (at package3 city6U1)
               (at package2 city6U2)
               (at package1 city2U1))))

(define (problem logUxU2)
   (:domain logisticsUadl)
   (:objects package5 package4 package3 package2 package1 - obj
             city10 city9 city8 city7 city6 city5 city4 city3 city2 city1
             - city
             truck10 truck9 truck8 truck7 truck6 truck5 truck4 truck3 truck2
             truck1 - truck
             plane4 plane3 plane2 plane1 - airplane
             city10U1 city9U1 city8U1 city7U1 city6U1 city5U1 city4U1
             city3U1 city2U1 city1U1 - location
             city10U2 city9U2 city8U2 city7U2 city6U2 city5U2 city4U2
             city3U2 city2U2 city1U2 - airport)
   (:init (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane4 city3U2)
          (at plane3 city7U2)
          (at plane2 city3U2)
          (at plane1 city6U2)
          (at truck10 city10U1)
          (at truck9 city9U1)
          (at truck8 city8U1)
          (at truck7 city7U1)
          (at truck6 city6U1)
          (at truck5 city5U1)
          (at truck4 city4U1)
          (at truck3 city3U1)
          (at truck2 city2U1)
          (at truck1 city1U1)
          (at package5 city1U2)
          (at package4 city7U2)
          (at package3 city3U2)
          (at package2 city10U1)
          (at package1 city2U2))
   (:goal (and (at package5 city4U2)
               (at package4 city6U1)
               (at package3 city1U1)
               (at package2 city9U2)
               (at package1 city3U1))))

(define (problem logUxU3)
   (:domain logisticsUadl)
   (:objects package9 package8 package7 package6 package5 package4
             package3 package2 package1 - obj
             city14 city13 city12 city11 city10 city9 city8 city7 city6
             city5 city4 city3 city2 city1 - city
             truck14 truck13 truck12 truck11 truck10 truck9 truck8 truck7
             truck6 truck5 truck4 truck3 truck2 truck1 - truck
             plane4 plane3 plane2 plane1 - airplane
             city14U2 city14U1 city13U2 city13U1 city12U2 city12U1 city11U2
             city11U1 city10U2 city10U1 city9U2 city9U1 city8U2 city8U1
             city7U2 city7U1 city6U2 city6U1 city5U2 city5U1 city4U2
             city4U1 city3U2 city3U1 city2U2 city2U1 city1U2 city1U1
             - location
             city14U3 city13U3 city12U3 city11U3 city10U3 city9U3 city8U3
             city7U3 city6U3 city5U3 city4U3 city3U3 city2U3 city1U3
             - airport)
   (:init (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane4 city10U3)
          (at plane3 city1U3)
          (at plane2 city11U3)
          (at plane1 city11U3)
          (at truck14 city14U1)
          (at truck13 city13U1)
          (at truck12 city12U1)
          (at truck11 city11U1)
          (at truck10 city10U1)
          (at truck9 city9U2)
          (at truck8 city8U2)
          (at truck7 city7U1)
          (at truck6 city6U2)
          (at truck5 city5U1)
          (at truck4 city4U2)
          (at truck3 city3U2)
          (at truck2 city2U1)
          (at truck1 city1U1)
          (at package9 city4U2)
          (at package8 city9U1)
          (at package7 city1U2)
          (at package6 city9U1)
          (at package5 city12U2)
          (at package4 city8U1)
          (at package3 city12U3)
          (at package2 city12U2)
          (at package1 city8U3))
   (:goal (and (at package9 city11U2)
               (at package8 city5U3)
               (at package7 city10U3)
               (at package6 city9U3)
               (at package5 city10U1)
               (at package4 city13U1)
               (at package3 city1U3))))

(define (problem logUxU4)
   (:domain logisticsUadl)
   (:objects package7 package6 package5 package4 package3 package2
             package1 - obj
             city13 city12 city11 city10 city9 city8 city7 city6 city5 city4
             city3 city2 city1 - city
             truck23 truck22 truck21 truck20 truck19 truck18 truck17
             truck16 truck15 truck14 truck13 truck12 truck11 truck10 truck9
             truck8 truck7 truck6 truck5 truck4 truck3 truck2 truck1
             - truck
             plane5 plane4 plane3 plane2 plane1 - airplane
             city13U3 city13U2 city13U1 city12U3 city12U2 city12U1 city11U3
             city11U2 city11U1 city10U3 city10U2 city10U1 city9U3 city9U2
             city9U1 city8U3 city8U2 city8U1 city7U3 city7U2 city7U1
             city6U3 city6U2 city6U1 city5U3 city5U2 city5U1 city4U3
             city4U2 city4U1 city3U3 city3U2 city3U1 city2U3 city2U2
             city2U1 city1U3 city1U2 city1U1 - location
             city13U4 city12U4 city11U4 city10U4 city9U4 city8U4 city7U4
             city6U4 city5U4 city4U4 city3U4 city2U4 city1U4 - airport)
   (:init (inUcity city13U4 city13)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U4 city12)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U4 city11)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U4 city10)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U4 city9)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane5 city12U4)
          (at plane4 city8U4)
          (at plane3 city6U4)
          (at plane2 city13U4)
          (at plane1 city2U4)
          (at truck23 city13U2)
          (at truck22 city12U3)
          (at truck21 city11U3)
          (at truck20 city10U1)
          (at truck19 city9U1)
          (at truck18 city8U2)
          (at truck17 city7U3)
          (at truck16 city6U3)
          (at truck15 city5U2)
          (at truck14 city4U1)
          (at truck13 city3U3)
          (at truck12 city2U1)
          (at truck11 city1U1)
          (at truck10 city10U3)
          (at truck9 city8U1)
          (at truck8 city2U2)
          (at truck7 city9U4)
          (at truck6 city9U2)
          (at truck5 city8U2)
          (at truck4 city7U3)
          (at truck3 city7U1)
          (at truck2 city8U1)
          (at truck1 city5U4)
          (at package7 city1U4)
          (at package6 city2U3)
          (at package5 city10U1)
          (at package4 city5U4)
          (at package3 city11U1)
          (at package2 city11U3)
          (at package1 city4U2))
   (:goal (and (at package7 city12U3)
               (at package6 city9U3)
               (at package5 city12U3)
               (at package4 city8U4)
               (at package3 city13U4)
               (at package2 city7U1)
               (at package1 city13U1))))

(define (problem logUxU5)
   (:domain logisticsUadl)
   (:objects package4 package3 package2 package1 - obj
             city9 city8 city7 city6 city5 city4 city3 city2 city1 - city
             truck11 truck10 truck9 truck8 truck7 truck6 truck5 truck4
             truck3 truck2 truck1 - truck
             plane1 - airplane
             city9U1 city8U1 city7U1 city6U1 city5U1 city4U1 city3U1
             city2U1 city1U1 - location
             city9U2 city8U2 city7U2 city6U2 city5U2 city4U2 city3U2
             city2U2 city1U2 - airport)
   (:init (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane1 city8U2)
          (at truck11 city9U1)
          (at truck10 city8U1)
          (at truck9 city7U1)
          (at truck8 city6U1)
          (at truck7 city5U1)
          (at truck6 city4U1)
          (at truck5 city3U1)
          (at truck4 city2U1)
          (at truck3 city1U1)
          (at truck2 city8U1)
          (at truck1 city3U2)
          (at package4 city8U1)
          (at package3 city9U1)
          (at package2 city8U2)
          (at package1 city6U2))
   (:goal (and (at package4 city2U2)
               (at package3 city7U2)
               (at package2 city3U1)
               (at package1 city9U2))))

(define (problem logUxU6)
   (:domain logisticsUadl)
   (:objects package16 package15 package14 package13 package12
             package11 package10 package9 package8 package7 package6
             package5 package4 package3 package2 package1 - obj
             city18 city17 city16 city15 city14 city13 city12 city11 city10
             city9 city8 city7 city6 city5 city4 city3 city2 city1 - city
             truck26 truck25 truck24 truck23 truck22 truck21 truck20
             truck19 truck18 truck17 truck16 truck15 truck14 truck13
             truck12 truck11 truck10 truck9 truck8 truck7 truck6 truck5
             truck4 truck3 truck2 truck1 - truck
             plane2 plane1 - airplane
             city18U3 city18U2 city18U1 city17U3 city17U2 city17U1 city16U3
             city16U2 city16U1 city15U3 city15U2 city15U1 city14U3 city14U2
             city14U1 city13U3 city13U2 city13U1 city12U3 city12U2 city12U1
             city11U3 city11U2 city11U1 city10U3 city10U2 city10U1 city9U3
             city9U2 city9U1 city8U3 city8U2 city8U1 city7U3 city7U2
             city7U1 city6U3 city6U2 city6U1 city5U3 city5U2 city5U1
             city4U3 city4U2 city4U1 city3U3 city3U2 city3U1 city2U3
             city2U2 city2U1 city1U3 city1U2 city1U1 - location
             city18U4 city17U4 city16U4 city15U4 city14U4 city13U4 city12U4
             city11U4 city10U4 city9U4 city8U4 city7U4 city6U4 city5U4
             city4U4 city3U4 city2U4 city1U4 - airport)
   (:init (inUcity city18U4 city18)
          (inUcity city18U3 city18)
          (inUcity city18U2 city18)
          (inUcity city18U1 city18)
          (inUcity city17U4 city17)
          (inUcity city17U3 city17)
          (inUcity city17U2 city17)
          (inUcity city17U1 city17)
          (inUcity city16U4 city16)
          (inUcity city16U3 city16)
          (inUcity city16U2 city16)
          (inUcity city16U1 city16)
          (inUcity city15U4 city15)
          (inUcity city15U3 city15)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U4 city14)
          (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U4 city13)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U4 city12)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U4 city11)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U4 city10)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U4 city9)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane2 city10U4)
          (at plane1 city18U4)
          (at truck26 city18U2)
          (at truck25 city17U1)
          (at truck24 city16U1)
          (at truck23 city15U2)
          (at truck22 city14U2)
          (at truck21 city13U1)
          (at truck20 city12U3)
          (at truck19 city11U1)
          (at truck18 city10U1)
          (at truck17 city9U1)
          (at truck16 city8U2)
          (at truck15 city7U1)
          (at truck14 city6U1)
          (at truck13 city5U1)
          (at truck12 city4U2)
          (at truck11 city3U2)
          (at truck10 city2U2)
          (at truck9 city1U2)
          (at truck8 city14U1)
          (at truck7 city3U4)
          (at truck6 city1U1)
          (at truck5 city14U1)
          (at truck4 city8U1)
          (at truck3 city10U3)
          (at truck2 city4U3)
          (at truck1 city14U3)
          (at package16 city16U2)
          (at package15 city14U3)
          (at package14 city14U1)
          (at package13 city14U4)
          (at package12 city6U1)
          (at package11 city3U1)
          (at package10 city9U4)
          (at package9 city17U3)
          (at package8 city15U2)
          (at package7 city8U4)
          (at package6 city6U1)
          (at package5 city10U3)
          (at package4 city15U2)
          (at package3 city16U3)
          (at package2 city11U2)
          (at package1 city7U3))
   (:goal (and (at package16 city14U3)
               (at package15 city14U2)
               (at package14 city8U4)
               (at package13 city4U3)
               (at package12 city13U4)
               (at package11 city12U2)
               (at package10 city16U2)
               (at package9 city17U4)
               (at package8 city8U1)
               (at package7 city8U2))))

(define (problem logUxU7)
   (:domain logisticsUadl)
   (:objects package10 package9 package8 package7 package6
             package5 package4 package3 package2 package1 - obj
             city11 city10 city9 city8 city7 city6 city5 city4 city3 city2
             city1 - city
             truck11 truck10 truck9 truck8 truck7 truck6 truck5 truck4
             truck3 truck2 truck1 - truck
             plane6 plane5 plane4 plane3 plane2 plane1 - airplane
             city11U1 city10U1 city9U1 city8U1 city7U1 city6U1 city5U1
             city4U1 city3U1 city2U1 city1U1 - location
             city11U2 city10U2 city9U2 city8U2 city7U2 city6U2 city5U2
             city4U2 city3U2 city2U2 city1U2 - airport)
   (:init (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane6 city2U2)
          (at plane5 city5U2)
          (at plane4 city6U2)
          (at plane3 city9U2)
          (at plane2 city8U2)
          (at plane1 city1U2)
          (at truck11 city11U1)
          (at truck10 city10U1)
          (at truck9 city9U1)
          (at truck8 city8U1)
          (at truck7 city7U1)
          (at truck6 city6U1)
          (at truck5 city5U1)
          (at truck4 city4U1)
          (at truck3 city3U1)
          (at truck2 city2U1)
          (at truck1 city1U1)
          (at package10 city6U2)
          (at package9 city5U2)
          (at package8 city10U2)
          (at package7 city6U2)
          (at package6 city1U2)
          (at package5 city4U1)
          (at package4 city4U2)
          (at package3 city1U2)
          (at package2 city10U2)
          (at package1 city8U1))
   (:goal (and (at package10 city9U1)
               (at package9 city9U2)
               (at package8 city1U2)
               (at package7 city5U1)
               (at package6 city10U2)
               (at package5 city7U1))))

(define (problem logUxU8)
   (:domain logisticsUadl)
   (:objects package24 package23 package22 package21 package20
             package19 package18 package17 package16 package15 package14
             package13 package12 package11 package10 package9 package8
             package7 package6 package5 package4 package3 package2 package1
             - obj
             city20 city19 city18 city17 city16 city15 city14 city13 city12
             city11 city10 city9 city8 city7 city6 city5 city4 city3 city2
             city1 - city
             truck33 truck32 truck31 truck30 truck29 truck28 truck27
             truck26 truck25 truck24 truck23 truck22 truck21 truck20
             truck19 truck18 truck17 truck16 truck15 truck14 truck13
             truck12 truck11 truck10 truck9 truck8 truck7 truck6 truck5
             truck4 truck3 truck2 truck1 - truck
             plane4 plane3 plane2 plane1 - airplane
             city20U2 city20U1 city19U2 city19U1 city18U2 city18U1 city17U2
             city17U1 city16U2 city16U1 city15U2 city15U1 city14U2 city14U1
             city13U2 city13U1 city12U2 city12U1 city11U2 city11U1 city10U2
             city10U1 city9U2 city9U1 city8U2 city8U1 city7U2 city7U1
             city6U2 city6U1 city5U2 city5U1 city4U2 city4U1 city3U2
             city3U1 city2U2 city2U1 city1U2 city1U1 - location
             city20U3 city19U3 city18U3 city17U3 city16U3 city15U3 city14U3
             city13U3 city12U3 city11U3 city10U3 city9U3 city8U3 city7U3
             city6U3 city5U3 city4U3 city3U3 city2U3 city1U3 - airport)
   (:init (inUcity city20U3 city20)
          (inUcity city20U2 city20)
          (inUcity city20U1 city20)
          (inUcity city19U3 city19)
          (inUcity city19U2 city19)
          (inUcity city19U1 city19)
          (inUcity city18U3 city18)
          (inUcity city18U2 city18)
          (inUcity city18U1 city18)
          (inUcity city17U3 city17)
          (inUcity city17U2 city17)
          (inUcity city17U1 city17)
          (inUcity city16U3 city16)
          (inUcity city16U2 city16)
          (inUcity city16U1 city16)
          (inUcity city15U3 city15)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane4 city7U3)
          (at plane3 city2U3)
          (at plane2 city16U3)
          (at plane1 city5U3)
          (at truck33 city20U1)
          (at truck32 city19U1)
          (at truck31 city18U2)
          (at truck30 city17U2)
          (at truck29 city16U2)
          (at truck28 city15U2)
          (at truck27 city14U1)
          (at truck26 city13U1)
          (at truck25 city12U2)
          (at truck24 city11U2)
          (at truck23 city10U2)
          (at truck22 city9U1)
          (at truck21 city8U1)
          (at truck20 city7U2)
          (at truck19 city6U2)
          (at truck18 city5U1)
          (at truck17 city4U1)
          (at truck16 city3U2)
          (at truck15 city2U2)
          (at truck14 city1U1)
          (at truck13 city1U3)
          (at truck12 city12U1)
          (at truck11 city5U3)
          (at truck10 city20U3)
          (at truck9 city4U1)
          (at truck8 city10U3)
          (at truck7 city4U2)
          (at truck6 city1U1)
          (at truck5 city5U3)
          (at truck4 city17U2)
          (at truck3 city8U2)
          (at truck2 city2U1)
          (at truck1 city17U2)
          (at package24 city13U1)
          (at package23 city13U3)
          (at package22 city15U3)
          (at package21 city20U3)
          (at package20 city20U2)
          (at package19 city3U3)
          (at package18 city16U1)
          (at package17 city5U2)
          (at package16 city13U1)
          (at package15 city18U2)
          (at package14 city13U1)
          (at package13 city14U1)
          (at package12 city7U2)
          (at package11 city18U3)
          (at package10 city7U1)
          (at package9 city11U3)
          (at package8 city11U3)
          (at package7 city3U3)
          (at package6 city4U2)
          (at package5 city7U3)
          (at package4 city5U2)
          (at package3 city1U1)
          (at package2 city20U3)
          (at package1 city13U1))
   (:goal (and (at package24 city7U1)
               (at package23 city2U1)
               (at package22 city1U3)
               (at package21 city6U3)
               (at package20 city7U1)
               (at package19 city1U2))))

(define (problem logUxU9)
   (:domain logisticsUadl)
   (:objects package12 package11 package10 package9 package8
             package7 package6 package5 package4 package3 package2 package1
             - obj
             city11 city10 city9 city8 city7 city6 city5 city4 city3 city2
             city1 - city
             truck28 truck27 truck26 truck25 truck24 truck23 truck22
             truck21 truck20 truck19 truck18 truck17 truck16 truck15
             truck14 truck13 truck12 truck11 truck10 truck9 truck8 truck7
             truck6 truck5 truck4 truck3 truck2 truck1 - truck
             plane4 plane3 plane2 plane1 - airplane
             city11U5 city11U4 city11U3 city11U2 city11U1 city10U5 city10U4
             city10U3 city10U2 city10U1 city9U5 city9U4 city9U3 city9U2
             city9U1 city8U5 city8U4 city8U3 city8U2 city8U1 city7U5
             city7U4 city7U3 city7U2 city7U1 city6U5 city6U4 city6U3
             city6U2 city6U1 city5U5 city5U4 city5U3 city5U2 city5U1
             city4U5 city4U4 city4U3 city4U2 city4U1 city3U5 city3U4
             city3U3 city3U2 city3U1 city2U5 city2U4 city2U3 city2U2
             city2U1 city1U5 city1U4 city1U3 city1U2 city1U1 - location
             city11U6 city10U6 city9U6 city8U6 city7U6 city6U6 city5U6
             city4U6 city3U6 city2U6 city1U6 - airport)
   (:init (inUcity city11U6 city11)
          (inUcity city11U5 city11)
          (inUcity city11U4 city11)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U6 city10)
          (inUcity city10U5 city10)
          (inUcity city10U4 city10)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U6 city9)
          (inUcity city9U5 city9)
          (inUcity city9U4 city9)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U6 city8)
          (inUcity city8U5 city8)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U6 city7)
          (inUcity city7U5 city7)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U6 city6)
          (inUcity city6U5 city6)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U6 city5)
          (inUcity city5U5 city5)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U6 city4)
          (inUcity city4U5 city4)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U6 city3)
          (inUcity city3U5 city3)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U6 city2)
          (inUcity city2U5 city2)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U6 city1)
          (inUcity city1U5 city1)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane4 city5U6)
          (at plane3 city6U6)
          (at plane2 city7U6)
          (at plane1 city10U6)
          (at truck28 city11U2)
          (at truck27 city10U2)
          (at truck26 city9U1)
          (at truck25 city8U2)
          (at truck24 city7U5)
          (at truck23 city6U1)
          (at truck22 city5U2)
          (at truck21 city4U2)
          (at truck20 city3U3)
          (at truck19 city2U1)
          (at truck18 city1U1)
          (at truck17 city7U3)
          (at truck16 city6U3)
          (at truck15 city8U5)
          (at truck14 city11U6)
          (at truck13 city9U6)
          (at truck12 city7U1)
          (at truck11 city8U6)
          (at truck10 city1U1)
          (at truck9 city4U1)
          (at truck8 city2U5)
          (at truck7 city9U1)
          (at truck6 city2U6)
          (at truck5 city8U6)
          (at truck4 city4U1)
          (at truck3 city4U1)
          (at truck2 city8U2)
          (at truck1 city1U5)
          (at package12 city1U2)
          (at package11 city9U1)
          (at package10 city4U6)
          (at package9 city8U4)
          (at package8 city11U5)
          (at package7 city2U4)
          (at package6 city4U1)
          (at package5 city2U6)
          (at package4 city4U4)
          (at package3 city4U5)
          (at package2 city2U6)
          (at package1 city6U6))
   (:goal (and (at package12 city5U4)
               (at package11 city4U1)
               (at package10 city6U2)
               (at package9 city8U4)
               (at package8 city2U3)
               (at package7 city9U6)
               (at package6 city2U4)
               (at package5 city10U3)
               (at package4 city4U4)
               (at package3 city8U1)
               (at package2 city9U2)
               (at package1 city5U1))))

(define (problem logUxU10)
   (:domain logisticsUadl)
   (:objects package17 package16 package15 package14 package13
             package12 package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 - obj
             city23 city22 city21 city20 city19 city18 city17 city16 city15
             city14 city13 city12 city11 city10 city9 city8 city7 city6
             city5 city4 city3 city2 city1 - city
             truck23 truck22 truck21 truck20 truck19 truck18 truck17
             truck16 truck15 truck14 truck13 truck12 truck11 truck10 truck9
             truck8 truck7 truck6 truck5 truck4 truck3 truck2 truck1
             - truck
             plane4 plane3 plane2 plane1 - airplane
             city23U1 city22U1 city21U1 city20U1 city19U1 city18U1 city17U1
             city16U1 city15U1 city14U1 city13U1 city12U1 city11U1 city10U1
             city9U1 city8U1 city7U1 city6U1 city5U1 city4U1 city3U1
             city2U1 city1U1 - location
             city23U2 city22U2 city21U2 city20U2 city19U2 city18U2 city17U2
             city16U2 city15U2 city14U2 city13U2 city12U2 city11U2 city10U2
             city9U2 city8U2 city7U2 city6U2 city5U2 city4U2 city3U2
             city2U2 city1U2 - airport)
   (:init (inUcity city23U2 city23)
          (inUcity city23U1 city23)
          (inUcity city22U2 city22)
          (inUcity city22U1 city22)
          (inUcity city21U2 city21)
          (inUcity city21U1 city21)
          (inUcity city20U2 city20)
          (inUcity city20U1 city20)
          (inUcity city19U2 city19)
          (inUcity city19U1 city19)
          (inUcity city18U2 city18)
          (inUcity city18U1 city18)
          (inUcity city17U2 city17)
          (inUcity city17U1 city17)
          (inUcity city16U2 city16)
          (inUcity city16U1 city16)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane4 city11U2)
          (at plane3 city13U2)
          (at plane2 city18U2)
          (at plane1 city16U2)
          (at truck23 city23U1)
          (at truck22 city22U1)
          (at truck21 city21U1)
          (at truck20 city20U1)
          (at truck19 city19U1)
          (at truck18 city18U1)
          (at truck17 city17U1)
          (at truck16 city16U1)
          (at truck15 city15U1)
          (at truck14 city14U1)
          (at truck13 city13U1)
          (at truck12 city12U1)
          (at truck11 city11U1)
          (at truck10 city10U1)
          (at truck9 city9U1)
          (at truck8 city8U1)
          (at truck7 city7U1)
          (at truck6 city6U1)
          (at truck5 city5U1)
          (at truck4 city4U1)
          (at truck3 city3U1)
          (at truck2 city2U1)
          (at truck1 city1U1)
          (at package17 city8U2)
          (at package16 city13U2)
          (at package15 city15U2)
          (at package14 city3U2)
          (at package13 city14U2)
          (at package12 city5U1)
          (at package11 city16U1)
          (at package10 city3U2)
          (at package9 city21U1)
          (at package8 city8U1)
          (at package7 city11U1)
          (at package6 city15U2)
          (at package5 city6U1)
          (at package4 city7U1)
          (at package3 city19U1)
          (at package2 city22U1)
          (at package1 city13U1))
   (:goal (and (at package17 city3U1)
               (at package16 city4U2)
               (at package15 city19U1)
               (at package14 city9U1)
               (at package13 city3U2)
               (at package12 city21U1)
               (at package11 city21U2)
               (at package10 city9U2)
               (at package9 city20U2)
               (at package8 city13U2)
               (at package7 city3U1)
               (at package6 city15U2)
               (at package5 city8U1)
               (at package4 city1U1)
               (at package3 city9U2)
               (at package2 city2U1)
               (at package1 city13U1))))

(define (problem logUxU11)
   (:domain logisticsUadl)
   (:objects package8 package7 package6 package5 package4 package3
             package2 package1 - obj
             city3 city2 city1 - city
             truck22 truck21 truck20 truck19 truck18 truck17 truck16
             truck15 truck14 truck13 truck12 truck11 truck10 truck9 truck8
             truck7 truck6 truck5 truck4 truck3 truck2 truck1 - truck
             plane6 plane5 plane4 plane3 plane2 plane1 - airplane
             city3U2 city3U1 city2U2 city2U1 city1U2 city1U1 - location
             city3U3 city2U3 city1U3 - airport)
   (:init (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane6 city2U3)
          (at plane5 city1U3)
          (at plane4 city3U3)
          (at plane3 city2U3)
          (at plane2 city2U3)
          (at plane1 city1U3)
          (at truck22 city3U2)
          (at truck21 city2U1)
          (at truck20 city1U2)
          (at truck19 city2U3)
          (at truck18 city1U2)
          (at truck17 city2U2)
          (at truck16 city2U1)
          (at truck15 city2U3)
          (at truck14 city2U2)
          (at truck13 city1U2)
          (at truck12 city2U2)
          (at truck11 city3U3)
          (at truck10 city3U1)
          (at truck9 city2U3)
          (at truck8 city3U3)
          (at truck7 city2U3)
          (at truck6 city2U3)
          (at truck5 city2U3)
          (at truck4 city3U2)
          (at truck3 city2U2)
          (at truck2 city1U1)
          (at truck1 city2U3)
          (at package8 city1U2)
          (at package7 city2U1)
          (at package6 city3U2)
          (at package5 city1U3)
          (at package4 city3U3)
          (at package3 city2U2)
          (at package2 city3U2)
          (at package1 city1U3))
   (:goal (and (at package8 city3U3)
               (at package7 city3U3)
               (at package6 city3U2)
               (at package5 city1U3)
               (at package4 city3U3)
               (at package3 city1U2)
               (at package2 city2U3)
               (at package1 city1U1))))

(define (problem logUxU12)
   (:domain logisticsUadl)
   (:objects package5 package4 package3 package2 package1 - obj
             city27 city26 city25 city24 city23 city22 city21 city20 city19
             city18 city17 city16 city15 city14 city13 city12 city11 city10
             city9 city8 city7 city6 city5 city4 city3 city2 city1 - city
             truck55 truck54 truck53 truck52 truck51 truck50 truck49
             truck48 truck47 truck46 truck45 truck44 truck43 truck42
             truck41 truck40 truck39 truck38 truck37 truck36 truck35
             truck34 truck33 truck32 truck31 truck30 truck29 truck28
             truck27 truck26 truck25 truck24 truck23 truck22 truck21
             truck20 truck19 truck18 truck17 truck16 truck15 truck14
             truck13 truck12 truck11 truck10 truck9 truck8 truck7 truck6
             truck5 truck4 truck3 truck2 truck1 - truck
             plane9 plane8 plane7 plane6 plane5 plane4 plane3 plane2 plane1
             - airplane
             city27U3 city27U2 city27U1 city26U3 city26U2 city26U1 city25U3
             city25U2 city25U1 city24U3 city24U2 city24U1 city23U3 city23U2
             city23U1 city22U3 city22U2 city22U1 city21U3 city21U2 city21U1
             city20U3 city20U2 city20U1 city19U3 city19U2 city19U1 city18U3
             city18U2 city18U1 city17U3 city17U2 city17U1 city16U3 city16U2
             city16U1 city15U3 city15U2 city15U1 city14U3 city14U2 city14U1
             city13U3 city13U2 city13U1 city12U3 city12U2 city12U1 city11U3
             city11U2 city11U1 city10U3 city10U2 city10U1 city9U3 city9U2
             city9U1 city8U3 city8U2 city8U1 city7U3 city7U2 city7U1
             city6U3 city6U2 city6U1 city5U3 city5U2 city5U1 city4U3
             city4U2 city4U1 city3U3 city3U2 city3U1 city2U3 city2U2
             city2U1 city1U3 city1U2 city1U1 - location
             city27U4 city26U4 city25U4 city24U4 city23U4 city22U4 city21U4
             city20U4 city19U4 city18U4 city17U4 city16U4 city15U4 city14U4
             city13U4 city12U4 city11U4 city10U4 city9U4 city8U4 city7U4
             city6U4 city5U4 city4U4 city3U4 city2U4 city1U4 - airport)
   (:init (inUcity city27U4 city27)
          (inUcity city27U3 city27)
          (inUcity city27U2 city27)
          (inUcity city27U1 city27)
          (inUcity city26U4 city26)
          (inUcity city26U3 city26)
          (inUcity city26U2 city26)
          (inUcity city26U1 city26)
          (inUcity city25U4 city25)
          (inUcity city25U3 city25)
          (inUcity city25U2 city25)
          (inUcity city25U1 city25)
          (inUcity city24U4 city24)
          (inUcity city24U3 city24)
          (inUcity city24U2 city24)
          (inUcity city24U1 city24)
          (inUcity city23U4 city23)
          (inUcity city23U3 city23)
          (inUcity city23U2 city23)
          (inUcity city23U1 city23)
          (inUcity city22U4 city22)
          (inUcity city22U3 city22)
          (inUcity city22U2 city22)
          (inUcity city22U1 city22)
          (inUcity city21U4 city21)
          (inUcity city21U3 city21)
          (inUcity city21U2 city21)
          (inUcity city21U1 city21)
          (inUcity city20U4 city20)
          (inUcity city20U3 city20)
          (inUcity city20U2 city20)
          (inUcity city20U1 city20)
          (inUcity city19U4 city19)
          (inUcity city19U3 city19)
          (inUcity city19U2 city19)
          (inUcity city19U1 city19)
          (inUcity city18U4 city18)
          (inUcity city18U3 city18)
          (inUcity city18U2 city18)
          (inUcity city18U1 city18)
          (inUcity city17U4 city17)
          (inUcity city17U3 city17)
          (inUcity city17U2 city17)
          (inUcity city17U1 city17)
          (inUcity city16U4 city16)
          (inUcity city16U3 city16)
          (inUcity city16U2 city16)
          (inUcity city16U1 city16)
          (inUcity city15U4 city15)
          (inUcity city15U3 city15)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U4 city14)
          (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U4 city13)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U4 city12)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U4 city11)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U4 city10)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U4 city9)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane9 city7U4)
          (at plane8 city2U4)
          (at plane7 city14U4)
          (at plane6 city25U4)
          (at plane5 city23U4)
          (at plane4 city2U4)
          (at plane3 city13U4)
          (at plane2 city1U4)
          (at plane1 city23U4)
          (at truck55 city27U2)
          (at truck54 city26U3)
          (at truck53 city25U2)
          (at truck52 city24U3)
          (at truck51 city23U1)
          (at truck50 city22U2)
          (at truck49 city21U1)
          (at truck48 city20U2)
          (at truck47 city19U1)
          (at truck46 city18U3)
          (at truck45 city17U1)
          (at truck44 city16U3)
          (at truck43 city15U1)
          (at truck42 city14U3)
          (at truck41 city13U1)
          (at truck40 city12U3)
          (at truck39 city11U2)
          (at truck38 city10U1)
          (at truck37 city9U2)
          (at truck36 city8U1)
          (at truck35 city7U2)
          (at truck34 city6U1)
          (at truck33 city5U1)
          (at truck32 city4U1)
          (at truck31 city3U3)
          (at truck30 city2U2)
          (at truck29 city1U2)
          (at truck28 city10U4)
          (at truck27 city7U3)
          (at truck26 city12U4)
          (at truck25 city7U1)
          (at truck24 city11U3)
          (at truck23 city15U3)
          (at truck22 city8U4)
          (at truck21 city8U3)
          (at truck20 city10U1)
          (at truck19 city22U4)
          (at truck18 city25U2)
          (at truck17 city14U2)
          (at truck16 city15U3)
          (at truck15 city25U3)
          (at truck14 city2U3)
          (at truck13 city12U3)
          (at truck12 city19U4)
          (at truck11 city14U2)
          (at truck10 city11U3)
          (at truck9 city24U2)
          (at truck8 city3U3)
          (at truck7 city22U2)
          (at truck6 city25U2)
          (at truck5 city23U3)
          (at truck4 city8U4)
          (at truck3 city3U4)
          (at truck2 city3U3)
          (at truck1 city15U4)
          (at package5 city12U1)
          (at package4 city7U2)
          (at package3 city8U1)
          (at package2 city23U3)
          (at package1 city1U4))
   (:goal (and (at package5 city18U4)
               (at package4 city10U3)
               (at package3 city1U4)
               (at package2 city14U3)
               (at package1 city9U2))))

(define (problem logUxU13)
   (:domain logisticsUadl)
   (:objects package23 package22 package21 package20 package19
             package18 package17 package16 package15 package14 package13
             package12 package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 - obj
             city29 city28 city27 city26 city25 city24 city23 city22 city21
             city20 city19 city18 city17 city16 city15 city14 city13 city12
             city11 city10 city9 city8 city7 city6 city5 city4 city3 city2
             city1 - city
             truck29 truck28 truck27 truck26 truck25 truck24 truck23
             truck22 truck21 truck20 truck19 truck18 truck17 truck16
             truck15 truck14 truck13 truck12 truck11 truck10 truck9 truck8
             truck7 truck6 truck5 truck4 truck3 truck2 truck1 - truck
             plane9 plane8 plane7 plane6 plane5 plane4 plane3 plane2 plane1
             - airplane
             city29U3 city29U2 city29U1 city28U3 city28U2 city28U1 city27U3
             city27U2 city27U1 city26U3 city26U2 city26U1 city25U3 city25U2
             city25U1 city24U3 city24U2 city24U1 city23U3 city23U2 city23U1
             city22U3 city22U2 city22U1 city21U3 city21U2 city21U1 city20U3
             city20U2 city20U1 city19U3 city19U2 city19U1 city18U3 city18U2
             city18U1 city17U3 city17U2 city17U1 city16U3 city16U2 city16U1
             city15U3 city15U2 city15U1 city14U3 city14U2 city14U1 city13U3
             city13U2 city13U1 city12U3 city12U2 city12U1 city11U3 city11U2
             city11U1 city10U3 city10U2 city10U1 city9U3 city9U2 city9U1
             city8U3 city8U2 city8U1 city7U3 city7U2 city7U1 city6U3
             city6U2 city6U1 city5U3 city5U2 city5U1 city4U3 city4U2
             city4U1 city3U3 city3U2 city3U1 city2U3 city2U2 city2U1
             city1U3 city1U2 city1U1 - location
             city29U4 city28U4 city27U4 city26U4 city25U4 city24U4 city23U4
             city22U4 city21U4 city20U4 city19U4 city18U4 city17U4 city16U4
             city15U4 city14U4 city13U4 city12U4 city11U4 city10U4 city9U4
             city8U4 city7U4 city6U4 city5U4 city4U4 city3U4 city2U4
             city1U4 - airport)
   (:init (inUcity city29U4 city29)
          (inUcity city29U3 city29)
          (inUcity city29U2 city29)
          (inUcity city29U1 city29)
          (inUcity city28U4 city28)
          (inUcity city28U3 city28)
          (inUcity city28U2 city28)
          (inUcity city28U1 city28)
          (inUcity city27U4 city27)
          (inUcity city27U3 city27)
          (inUcity city27U2 city27)
          (inUcity city27U1 city27)
          (inUcity city26U4 city26)
          (inUcity city26U3 city26)
          (inUcity city26U2 city26)
          (inUcity city26U1 city26)
          (inUcity city25U4 city25)
          (inUcity city25U3 city25)
          (inUcity city25U2 city25)
          (inUcity city25U1 city25)
          (inUcity city24U4 city24)
          (inUcity city24U3 city24)
          (inUcity city24U2 city24)
          (inUcity city24U1 city24)
          (inUcity city23U4 city23)
          (inUcity city23U3 city23)
          (inUcity city23U2 city23)
          (inUcity city23U1 city23)
          (inUcity city22U4 city22)
          (inUcity city22U3 city22)
          (inUcity city22U2 city22)
          (inUcity city22U1 city22)
          (inUcity city21U4 city21)
          (inUcity city21U3 city21)
          (inUcity city21U2 city21)
          (inUcity city21U1 city21)
          (inUcity city20U4 city20)
          (inUcity city20U3 city20)
          (inUcity city20U2 city20)
          (inUcity city20U1 city20)
          (inUcity city19U4 city19)
          (inUcity city19U3 city19)
          (inUcity city19U2 city19)
          (inUcity city19U1 city19)
          (inUcity city18U4 city18)
          (inUcity city18U3 city18)
          (inUcity city18U2 city18)
          (inUcity city18U1 city18)
          (inUcity city17U4 city17)
          (inUcity city17U3 city17)
          (inUcity city17U2 city17)
          (inUcity city17U1 city17)
          (inUcity city16U4 city16)
          (inUcity city16U3 city16)
          (inUcity city16U2 city16)
          (inUcity city16U1 city16)
          (inUcity city15U4 city15)
          (inUcity city15U3 city15)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U4 city14)
          (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U4 city13)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U4 city12)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U4 city11)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U4 city10)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U4 city9)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane9 city28U4)
          (at plane8 city23U4)
          (at plane7 city27U4)
          (at plane6 city29U4)
          (at plane5 city13U4)
          (at plane4 city4U4)
          (at plane3 city14U4)
          (at plane2 city14U4)
          (at plane1 city13U4)
          (at truck29 city29U1)
          (at truck28 city28U2)
          (at truck27 city27U3)
          (at truck26 city26U1)
          (at truck25 city25U2)
          (at truck24 city24U3)
          (at truck23 city23U3)
          (at truck22 city22U3)
          (at truck21 city21U1)
          (at truck20 city20U1)
          (at truck19 city19U3)
          (at truck18 city18U2)
          (at truck17 city17U3)
          (at truck16 city16U2)
          (at truck15 city15U3)
          (at truck14 city14U3)
          (at truck13 city13U2)
          (at truck12 city12U3)
          (at truck11 city11U1)
          (at truck10 city10U2)
          (at truck9 city9U3)
          (at truck8 city8U2)
          (at truck7 city7U3)
          (at truck6 city6U3)
          (at truck5 city5U3)
          (at truck4 city4U2)
          (at truck3 city3U2)
          (at truck2 city2U3)
          (at truck1 city1U1)
          (at package23 city26U2)
          (at package22 city1U1)
          (at package21 city3U1)
          (at package20 city18U2)
          (at package19 city17U2)
          (at package18 city21U1)
          (at package17 city1U4)
          (at package16 city29U4)
          (at package15 city1U2)
          (at package14 city4U4)
          (at package13 city10U1)
          (at package12 city13U1)
          (at package11 city24U3)
          (at package10 city5U4)
          (at package9 city9U4)
          (at package8 city3U4)
          (at package7 city13U1)
          (at package6 city7U3)
          (at package5 city16U1)
          (at package4 city3U2)
          (at package3 city17U1)
          (at package2 city11U1)
          (at package1 city21U4))
   (:goal (and (at package23 city7U4)
               (at package22 city11U3)
               (at package21 city16U4)
               (at package20 city4U4)
               (at package19 city21U2)
               (at package18 city22U1)
               (at package17 city18U3)
               (at package16 city14U3))))

(define (problem logUxU14)
   (:domain logisticsUadl)
   (:objects package29 package28 package27 package26 package25
             package24 package23 package22 package21 package20 package19
             package18 package17 package16 package15 package14 package13
             package12 package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 - obj
             city11 city10 city9 city8 city7 city6 city5 city4 city3 city2
             city1 - city
             truck47 truck46 truck45 truck44 truck43 truck42 truck41
             truck40 truck39 truck38 truck37 truck36 truck35 truck34
             truck33 truck32 truck31 truck30 truck29 truck28 truck27
             truck26 truck25 truck24 truck23 truck22 truck21 truck20
             truck19 truck18 truck17 truck16 truck15 truck14 truck13
             truck12 truck11 truck10 truck9 truck8 truck7 truck6 truck5
             truck4 truck3 truck2 truck1 - truck
             plane8 plane7 plane6 plane5 plane4 plane3 plane2 plane1
             - airplane
             city11U1 city10U1 city9U1 city8U1 city7U1 city6U1 city5U1
             city4U1 city3U1 city2U1 city1U1 - location
             city11U2 city10U2 city9U2 city8U2 city7U2 city6U2 city5U2
             city4U2 city3U2 city2U2 city1U2 - airport)
   (:init (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane8 city9U2)
          (at plane7 city4U2)
          (at plane6 city1U2)
          (at plane5 city2U2)
          (at plane4 city4U2)
          (at plane3 city11U2)
          (at plane2 city2U2)
          (at plane1 city6U2)
          (at truck47 city11U1)
          (at truck46 city10U1)
          (at truck45 city9U1)
          (at truck44 city8U1)
          (at truck43 city7U1)
          (at truck42 city6U1)
          (at truck41 city5U1)
          (at truck40 city4U1)
          (at truck39 city3U1)
          (at truck38 city2U1)
          (at truck37 city1U1)
          (at truck36 city1U1)
          (at truck35 city4U1)
          (at truck34 city7U1)
          (at truck33 city7U1)
          (at truck32 city10U2)
          (at truck31 city3U2)
          (at truck30 city6U2)
          (at truck29 city6U2)
          (at truck28 city10U1)
          (at truck27 city10U1)
          (at truck26 city8U1)
          (at truck25 city10U1)
          (at truck24 city6U1)
          (at truck23 city5U2)
          (at truck22 city9U2)
          (at truck21 city4U2)
          (at truck20 city2U2)
          (at truck19 city8U1)
          (at truck18 city4U2)
          (at truck17 city3U1)
          (at truck16 city2U1)
          (at truck15 city2U2)
          (at truck14 city6U2)
          (at truck13 city10U2)
          (at truck12 city10U2)
          (at truck11 city7U2)
          (at truck10 city2U1)
          (at truck9 city3U2)
          (at truck8 city1U2)
          (at truck7 city3U1)
          (at truck6 city8U2)
          (at truck5 city7U1)
          (at truck4 city8U2)
          (at truck3 city1U2)
          (at truck2 city1U1)
          (at truck1 city2U1)
          (at package29 city10U1)
          (at package28 city4U2)
          (at package27 city10U2)
          (at package26 city6U1)
          (at package25 city6U2)
          (at package24 city8U2)
          (at package23 city1U1)
          (at package22 city9U1)
          (at package21 city9U2)
          (at package20 city6U2)
          (at package19 city9U1)
          (at package18 city2U2)
          (at package17 city4U2)
          (at package16 city2U2)
          (at package15 city1U2)
          (at package14 city9U1)
          (at package13 city7U1)
          (at package12 city9U2)
          (at package11 city6U2)
          (at package10 city8U2)
          (at package9 city1U2)
          (at package8 city8U1)
          (at package7 city8U2)
          (at package6 city1U2)
          (at package5 city2U2)
          (at package4 city10U2)
          (at package3 city11U1)
          (at package2 city11U1)
          (at package1 city11U2))
   (:goal (and (at package29 city5U2)
               (at package28 city11U2)
               (at package27 city10U1)
               (at package26 city9U1)
               (at package25 city4U1)
               (at package24 city8U2)
               (at package23 city10U2)
               (at package22 city1U2)
               (at package21 city1U1)
               (at package20 city4U1)
               (at package19 city6U1)
               (at package18 city9U1)
               (at package17 city4U1)
               (at package16 city11U1)
               (at package15 city2U2)
               (at package14 city8U2)
               (at package13 city10U2)
               (at package12 city11U2)
               (at package11 city2U2))))

(define (problem logUxU15)
   (:domain logisticsUadl)
   (:objects package23 package22 package21 package20 package19
             package18 package17 package16 package15 package14 package13
             package12 package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 - obj
             city3 city2 city1 - city
             truck5 truck4 truck3 truck2 truck1 - truck
             plane7 plane6 plane5 plane4 plane3 plane2 plane1 - airplane
             city3U5 city3U4 city3U3 city3U2 city3U1 city2U5 city2U4
             city2U3 city2U2 city2U1 city1U5 city1U4 city1U3 city1U2
             city1U1 - location
             city3U6 city2U6 city1U6 - airport)
   (:init (inUcity city3U6 city3)
          (inUcity city3U5 city3)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U6 city2)
          (inUcity city2U5 city2)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U6 city1)
          (inUcity city1U5 city1)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane7 city1U6)
          (at plane6 city2U6)
          (at plane5 city1U6)
          (at plane4 city1U6)
          (at plane3 city3U6)
          (at plane2 city1U6)
          (at plane1 city2U6)
          (at truck5 city3U4)
          (at truck4 city2U3)
          (at truck3 city1U5)
          (at truck2 city1U3)
          (at truck1 city1U6)
          (at package23 city1U5)
          (at package22 city1U5)
          (at package21 city2U4)
          (at package20 city2U3)
          (at package19 city1U2)
          (at package18 city3U3)
          (at package17 city2U3)
          (at package16 city3U5)
          (at package15 city2U2)
          (at package14 city2U1)
          (at package13 city3U4)
          (at package12 city1U6)
          (at package11 city1U4)
          (at package10 city3U3)
          (at package9 city3U3)
          (at package8 city1U2)
          (at package7 city1U4)
          (at package6 city1U4)
          (at package5 city3U1)
          (at package4 city2U1)
          (at package3 city1U5)
          (at package2 city3U3)
          (at package1 city1U2))
   (:goal (and (at package23 city2U3)
               (at package22 city1U5)
               (at package21 city1U6)
               (at package20 city1U1)
               (at package19 city1U3)
               (at package18 city1U3)
               (at package17 city1U5)
               (at package16 city1U1)
               (at package15 city3U3)
               (at package14 city1U5)
               (at package13 city2U5)
               (at package12 city3U2)
               (at package11 city2U6)
               (at package10 city1U6))))

(define (problem logUxU16)
   (:domain logisticsUadl)
   (:objects package7 package6 package5 package4 package3 package2
             package1 - obj
             city11 city10 city9 city8 city7 city6 city5 city4 city3 city2
             city1 - city
             truck52 truck51 truck50 truck49 truck48 truck47 truck46
             truck45 truck44 truck43 truck42 truck41 truck40 truck39
             truck38 truck37 truck36 truck35 truck34 truck33 truck32
             truck31 truck30 truck29 truck28 truck27 truck26 truck25
             truck24 truck23 truck22 truck21 truck20 truck19 truck18
             truck17 truck16 truck15 truck14 truck13 truck12 truck11
             truck10 truck9 truck8 truck7 truck6 truck5 truck4 truck3 truck2
             truck1 - truck
             plane13 plane12 plane11 plane10 plane9 plane8 plane7 plane6
             plane5 plane4 plane3 plane2 plane1 - airplane
             city11U2 city11U1 city10U2 city10U1 city9U2 city9U1 city8U2
             city8U1 city7U2 city7U1 city6U2 city6U1 city5U2 city5U1
             city4U2 city4U1 city3U2 city3U1 city2U2 city2U1 city1U2
             city1U1 - location
             city11U3 city10U3 city9U3 city8U3 city7U3 city6U3 city5U3
             city4U3 city3U3 city2U3 city1U3 - airport)
   (:init (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane13 city10U3)
          (at plane12 city5U3)
          (at plane11 city11U3)
          (at plane10 city1U3)
          (at plane9 city9U3)
          (at plane8 city7U3)
          (at plane7 city1U3)
          (at plane6 city8U3)
          (at plane5 city7U3)
          (at plane4 city9U3)
          (at plane3 city1U3)
          (at plane2 city11U3)
          (at plane1 city6U3)
          (at truck52 city11U2)
          (at truck51 city10U1)
          (at truck50 city9U2)
          (at truck49 city8U1)
          (at truck48 city7U1)
          (at truck47 city6U1)
          (at truck46 city5U2)
          (at truck45 city4U1)
          (at truck44 city3U2)
          (at truck43 city2U2)
          (at truck42 city1U2)
          (at truck41 city7U2)
          (at truck40 city6U1)
          (at truck39 city2U3)
          (at truck38 city3U1)
          (at truck37 city2U3)
          (at truck36 city7U1)
          (at truck35 city8U2)
          (at truck34 city8U2)
          (at truck33 city7U2)
          (at truck32 city6U3)
          (at truck31 city2U2)
          (at truck30 city11U3)
          (at truck29 city1U2)
          (at truck28 city3U1)
          (at truck27 city9U2)
          (at truck26 city7U2)
          (at truck25 city1U3)
          (at truck24 city4U1)
          (at truck23 city9U2)
          (at truck22 city3U1)
          (at truck21 city1U1)
          (at truck20 city7U3)
          (at truck19 city4U3)
          (at truck18 city1U1)
          (at truck17 city4U3)
          (at truck16 city11U3)
          (at truck15 city6U2)
          (at truck14 city5U3)
          (at truck13 city5U1)
          (at truck12 city8U1)
          (at truck11 city8U1)
          (at truck10 city5U2)
          (at truck9 city8U3)
          (at truck8 city1U1)
          (at truck7 city8U2)
          (at truck6 city9U3)
          (at truck5 city10U2)
          (at truck4 city6U3)
          (at truck3 city11U1)
          (at truck2 city5U3)
          (at truck1 city5U2)
          (at package7 city4U2)
          (at package6 city4U1)
          (at package5 city11U2)
          (at package4 city2U2)
          (at package3 city7U2)
          (at package2 city7U2)
          (at package1 city7U2))
   (:goal (and (at package7 city5U1)
               (at package6 city5U2)
               (at package5 city2U1)
               (at package4 city5U3)
               (at package3 city5U1)
               (at package2 city5U2)
               (at package1 city4U1))))

(define (problem logUxU17)
   (:domain logisticsUadl)
   (:objects package15 package14 package13 package12 package11
             package10 package9 package8 package7 package6 package5 package4
             package3 package2 package1 - obj
             city4 city3 city2 city1 - city
             truck45 truck44 truck43 truck42 truck41 truck40 truck39
             truck38 truck37 truck36 truck35 truck34 truck33 truck32
             truck31 truck30 truck29 truck28 truck27 truck26 truck25
             truck24 truck23 truck22 truck21 truck20 truck19 truck18
             truck17 truck16 truck15 truck14 truck13 truck12 truck11
             truck10 truck9 truck8 truck7 truck6 truck5 truck4 truck3 truck2
             truck1 - truck
             plane5 plane4 plane3 plane2 plane1 - airplane
             city4U2 city4U1 city3U2 city3U1 city2U2 city2U1 city1U2
             city1U1 - location
             city4U3 city3U3 city2U3 city1U3 - airport)
   (:init (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane5 city1U3)
          (at plane4 city4U3)
          (at plane3 city4U3)
          (at plane2 city3U3)
          (at plane1 city4U3)
          (at truck45 city4U2)
          (at truck44 city3U2)
          (at truck43 city2U2)
          (at truck42 city1U1)
          (at truck41 city1U3)
          (at truck40 city3U2)
          (at truck39 city2U1)
          (at truck38 city2U3)
          (at truck37 city4U2)
          (at truck36 city3U2)
          (at truck35 city1U1)
          (at truck34 city3U3)
          (at truck33 city3U3)
          (at truck32 city2U1)
          (at truck31 city3U1)
          (at truck30 city3U2)
          (at truck29 city2U2)
          (at truck28 city1U3)
          (at truck27 city4U1)
          (at truck26 city3U2)
          (at truck25 city4U3)
          (at truck24 city2U1)
          (at truck23 city4U1)
          (at truck22 city1U1)
          (at truck21 city3U2)
          (at truck20 city4U3)
          (at truck19 city3U3)
          (at truck18 city1U2)
          (at truck17 city4U2)
          (at truck16 city3U1)
          (at truck15 city3U2)
          (at truck14 city4U3)
          (at truck13 city2U2)
          (at truck12 city2U1)
          (at truck11 city1U1)
          (at truck10 city1U2)
          (at truck9 city1U2)
          (at truck8 city1U1)
          (at truck7 city1U2)
          (at truck6 city2U2)
          (at truck5 city3U1)
          (at truck4 city4U1)
          (at truck3 city1U3)
          (at truck2 city1U3)
          (at truck1 city4U2)
          (at package15 city1U2)
          (at package14 city3U1)
          (at package13 city1U1)
          (at package12 city1U1)
          (at package11 city3U3)
          (at package10 city4U2)
          (at package9 city3U2)
          (at package8 city4U2)
          (at package7 city4U3)
          (at package6 city3U2)
          (at package5 city2U2)
          (at package4 city2U3)
          (at package3 city1U3)
          (at package2 city4U2)
          (at package1 city2U1))
   (:goal (and (at package15 city4U2)
               (at package14 city4U2)
               (at package13 city4U3)
               (at package12 city2U2)
               (at package11 city2U1)
               (at package10 city4U2)
               (at package9 city4U2)
               (at package8 city4U2))))

(define (problem logUxU18)
   (:domain logisticsUadl)
   (:objects package20 package19 package18 package17 package16
             package15 package14 package13 package12 package11 package10
             package9 package8 package7 package6 package5 package4 package3
             package2 package1 - obj
             city30 city29 city28 city27 city26 city25 city24 city23 city22
             city21 city20 city19 city18 city17 city16 city15 city14 city13
             city12 city11 city10 city9 city8 city7 city6 city5 city4 city3
             city2 city1 - city
             truck30 truck29 truck28 truck27 truck26 truck25 truck24
             truck23 truck22 truck21 truck20 truck19 truck18 truck17
             truck16 truck15 truck14 truck13 truck12 truck11 truck10 truck9
             truck8 truck7 truck6 truck5 truck4 truck3 truck2 truck1
             - truck
             plane10 plane9 plane8 plane7 plane6 plane5 plane4 plane3 plane2
             plane1 - airplane
             city30U2 city30U1 city29U2 city29U1 city28U2 city28U1 city27U2
             city27U1 city26U2 city26U1 city25U2 city25U1 city24U2 city24U1
             city23U2 city23U1 city22U2 city22U1 city21U2 city21U1 city20U2
             city20U1 city19U2 city19U1 city18U2 city18U1 city17U2 city17U1
             city16U2 city16U1 city15U2 city15U1 city14U2 city14U1 city13U2
             city13U1 city12U2 city12U1 city11U2 city11U1 city10U2 city10U1
             city9U2 city9U1 city8U2 city8U1 city7U2 city7U1 city6U2
             city6U1 city5U2 city5U1 city4U2 city4U1 city3U2 city3U1
             city2U2 city2U1 city1U2 city1U1 - location
             city30U3 city29U3 city28U3 city27U3 city26U3 city25U3 city24U3
             city23U3 city22U3 city21U3 city20U3 city19U3 city18U3 city17U3
             city16U3 city15U3 city14U3 city13U3 city12U3 city11U3 city10U3
             city9U3 city8U3 city7U3 city6U3 city5U3 city4U3 city3U3
             city2U3 city1U3 - airport)
   (:init (inUcity city30U3 city30)
          (inUcity city30U2 city30)
          (inUcity city30U1 city30)
          (inUcity city29U3 city29)
          (inUcity city29U2 city29)
          (inUcity city29U1 city29)
          (inUcity city28U3 city28)
          (inUcity city28U2 city28)
          (inUcity city28U1 city28)
          (inUcity city27U3 city27)
          (inUcity city27U2 city27)
          (inUcity city27U1 city27)
          (inUcity city26U3 city26)
          (inUcity city26U2 city26)
          (inUcity city26U1 city26)
          (inUcity city25U3 city25)
          (inUcity city25U2 city25)
          (inUcity city25U1 city25)
          (inUcity city24U3 city24)
          (inUcity city24U2 city24)
          (inUcity city24U1 city24)
          (inUcity city23U3 city23)
          (inUcity city23U2 city23)
          (inUcity city23U1 city23)
          (inUcity city22U3 city22)
          (inUcity city22U2 city22)
          (inUcity city22U1 city22)
          (inUcity city21U3 city21)
          (inUcity city21U2 city21)
          (inUcity city21U1 city21)
          (inUcity city20U3 city20)
          (inUcity city20U2 city20)
          (inUcity city20U1 city20)
          (inUcity city19U3 city19)
          (inUcity city19U2 city19)
          (inUcity city19U1 city19)
          (inUcity city18U3 city18)
          (inUcity city18U2 city18)
          (inUcity city18U1 city18)
          (inUcity city17U3 city17)
          (inUcity city17U2 city17)
          (inUcity city17U1 city17)
          (inUcity city16U3 city16)
          (inUcity city16U2 city16)
          (inUcity city16U1 city16)
          (inUcity city15U3 city15)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane10 city6U3)
          (at plane9 city10U3)
          (at plane8 city9U3)
          (at plane7 city23U3)
          (at plane6 city15U3)
          (at plane5 city6U3)
          (at plane4 city8U3)
          (at plane3 city28U3)
          (at plane2 city12U3)
          (at plane1 city19U3)
          (at truck30 city30U1)
          (at truck29 city29U2)
          (at truck28 city28U2)
          (at truck27 city27U2)
          (at truck26 city26U2)
          (at truck25 city25U1)
          (at truck24 city24U2)
          (at truck23 city23U2)
          (at truck22 city22U2)
          (at truck21 city21U1)
          (at truck20 city20U1)
          (at truck19 city19U2)
          (at truck18 city18U1)
          (at truck17 city17U1)
          (at truck16 city16U1)
          (at truck15 city15U2)
          (at truck14 city14U1)
          (at truck13 city13U2)
          (at truck12 city12U2)
          (at truck11 city11U1)
          (at truck10 city10U1)
          (at truck9 city9U2)
          (at truck8 city8U2)
          (at truck7 city7U1)
          (at truck6 city6U1)
          (at truck5 city5U2)
          (at truck4 city4U2)
          (at truck3 city3U2)
          (at truck2 city2U1)
          (at truck1 city1U1)
          (at package20 city28U1)
          (at package19 city19U2)
          (at package18 city10U2)
          (at package17 city20U1)
          (at package16 city20U1)
          (at package15 city13U1)
          (at package14 city8U1)
          (at package13 city17U1)
          (at package12 city9U1)
          (at package11 city7U3)
          (at package10 city4U2)
          (at package9 city7U1)
          (at package8 city15U1)
          (at package7 city23U1)
          (at package6 city22U1)
          (at package5 city12U2)
          (at package4 city28U3)
          (at package3 city6U3)
          (at package2 city28U3)
          (at package1 city16U1))
   (:goal (and (at package20 city6U2)
               (at package19 city12U2)
               (at package18 city2U1)
               (at package17 city25U1)
               (at package16 city22U2)
               (at package15 city4U1)
               (at package14 city6U3)
               (at package13 city1U3)
               (at package12 city29U1)
               (at package11 city6U1)
               (at package10 city30U3)
               (at package9 city17U3)
               (at package8 city10U1)
               (at package7 city14U1)
               (at package6 city28U1)
               (at package5 city25U2)
               (at package4 city10U1)
               (at package3 city10U3)
               (at package2 city9U2)
               (at package1 city29U3))))

(define (problem logUxU19)
   (:domain logisticsUadl)
   (:objects package19 package18 package17 package16 package15
             package14 package13 package12 package11 package10 package9
             package8 package7 package6 package5 package4 package3 package2
             package1 - obj
             city8 city7 city6 city5 city4 city3 city2 city1 - city
             truck30 truck29 truck28 truck27 truck26 truck25 truck24
             truck23 truck22 truck21 truck20 truck19 truck18 truck17
             truck16 truck15 truck14 truck13 truck12 truck11 truck10 truck9
             truck8 truck7 truck6 truck5 truck4 truck3 truck2 truck1
             - truck
             plane11 plane10 plane9 plane8 plane7 plane6 plane5 plane4
             plane3 plane2 plane1 - airplane
             city8U7 city8U6 city8U5 city8U4 city8U3 city8U2 city8U1
             city7U7 city7U6 city7U5 city7U4 city7U3 city7U2 city7U1
             city6U7 city6U6 city6U5 city6U4 city6U3 city6U2 city6U1
             city5U7 city5U6 city5U5 city5U4 city5U3 city5U2 city5U1
             city4U7 city4U6 city4U5 city4U4 city4U3 city4U2 city4U1
             city3U7 city3U6 city3U5 city3U4 city3U3 city3U2 city3U1
             city2U7 city2U6 city2U5 city2U4 city2U3 city2U2 city2U1
             city1U7 city1U6 city1U5 city1U4 city1U3 city1U2 city1U1
             - location
             city8U8 city7U8 city6U8 city5U8 city4U8 city3U8 city2U8
             city1U8 - airport)
   (:init (inUcity city8U8 city8)
          (inUcity city8U7 city8)
          (inUcity city8U6 city8)
          (inUcity city8U5 city8)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U8 city7)
          (inUcity city7U7 city7)
          (inUcity city7U6 city7)
          (inUcity city7U5 city7)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U8 city6)
          (inUcity city6U7 city6)
          (inUcity city6U6 city6)
          (inUcity city6U5 city6)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U8 city5)
          (inUcity city5U7 city5)
          (inUcity city5U6 city5)
          (inUcity city5U5 city5)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U8 city4)
          (inUcity city4U7 city4)
          (inUcity city4U6 city4)
          (inUcity city4U5 city4)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U8 city3)
          (inUcity city3U7 city3)
          (inUcity city3U6 city3)
          (inUcity city3U5 city3)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U8 city2)
          (inUcity city2U7 city2)
          (inUcity city2U6 city2)
          (inUcity city2U5 city2)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U8 city1)
          (inUcity city1U7 city1)
          (inUcity city1U6 city1)
          (inUcity city1U5 city1)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane11 city3U8)
          (at plane10 city7U8)
          (at plane9 city3U8)
          (at plane8 city4U8)
          (at plane7 city2U8)
          (at plane6 city1U8)
          (at plane5 city1U8)
          (at plane4 city2U8)
          (at plane3 city3U8)
          (at plane2 city2U8)
          (at plane1 city7U8)
          (at truck30 city8U5)
          (at truck29 city7U3)
          (at truck28 city6U2)
          (at truck27 city5U6)
          (at truck26 city4U3)
          (at truck25 city3U5)
          (at truck24 city2U1)
          (at truck23 city1U7)
          (at truck22 city2U4)
          (at truck21 city3U8)
          (at truck20 city4U7)
          (at truck19 city6U7)
          (at truck18 city7U6)
          (at truck17 city6U6)
          (at truck16 city7U3)
          (at truck15 city1U8)
          (at truck14 city8U8)
          (at truck13 city1U8)
          (at truck12 city5U7)
          (at truck11 city2U6)
          (at truck10 city1U5)
          (at truck9 city2U7)
          (at truck8 city8U5)
          (at truck7 city4U1)
          (at truck6 city3U5)
          (at truck5 city3U8)
          (at truck4 city2U1)
          (at truck3 city3U1)
          (at truck2 city1U8)
          (at truck1 city5U6)
          (at package19 city7U7)
          (at package18 city4U5)
          (at package17 city3U6)
          (at package16 city1U5)
          (at package15 city8U2)
          (at package14 city8U3)
          (at package13 city6U8)
          (at package12 city8U1)
          (at package11 city2U6)
          (at package10 city6U5)
          (at package9 city7U2)
          (at package8 city6U1)
          (at package7 city4U8)
          (at package6 city6U3)
          (at package5 city4U3)
          (at package4 city1U5)
          (at package3 city2U2)
          (at package2 city4U5)
          (at package1 city7U3))
   (:goal (and (at package19 city6U1)
               (at package18 city2U2)
               (at package17 city1U8)
               (at package16 city2U5)
               (at package15 city3U6)
               (at package14 city7U6)
               (at package13 city8U2)
               (at package12 city7U4)
               (at package11 city8U5)
               (at package10 city1U7)
               (at package9 city1U7)
               (at package8 city6U4)
               (at package7 city4U5)
               (at package6 city2U7)
               (at package5 city3U8)
               (at package4 city7U5)
               (at package3 city2U1)
               (at package2 city7U4)
               (at package1 city5U2))))

(define (problem logUxU20)
   (:domain logisticsUadl)
   (:objects package16 package15 package14 package13 package12
             package11 package10 package9 package8 package7 package6
             package5 package4 package3 package2 package1 - obj
             city15 city14 city13 city12 city11 city10 city9 city8 city7
             city6 city5 city4 city3 city2 city1 - city
             truck19 truck18 truck17 truck16 truck15 truck14 truck13
             truck12 truck11 truck10 truck9 truck8 truck7 truck6 truck5
             truck4 truck3 truck2 truck1 - truck
             plane15 plane14 plane13 plane12 plane11 plane10 plane9 plane8
             plane7 plane6 plane5 plane4 plane3 plane2 plane1 - airplane
             city15U11 city15U10 city15U9 city15U8 city15U7 city15U6
             city15U5 city15U4 city15U3 city15U2 city15U1 city14U11
             city14U10 city14U9 city14U8 city14U7 city14U6 city14U5 city14U4
             city14U3 city14U2 city14U1 city13U11 city13U10 city13U9
             city13U8 city13U7 city13U6 city13U5 city13U4 city13U3 city13U2
             city13U1 city12U11 city12U10 city12U9 city12U8 city12U7
             city12U6 city12U5 city12U4 city12U3 city12U2 city12U1
             city11U11 city11U10 city11U9 city11U8 city11U7 city11U6
             city11U5 city11U4 city11U3 city11U2 city11U1 city10U11
             city10U10 city10U9 city10U8 city10U7 city10U6 city10U5 city10U4
             city10U3 city10U2 city10U1 city9U11 city9U10 city9U9 city9U8
             city9U7 city9U6 city9U5 city9U4 city9U3 city9U2 city9U1
             city8U11 city8U10 city8U9 city8U8 city8U7 city8U6 city8U5
             city8U4 city8U3 city8U2 city8U1 city7U11 city7U10 city7U9
             city7U8 city7U7 city7U6 city7U5 city7U4 city7U3 city7U2
             city7U1 city6U11 city6U10 city6U9 city6U8 city6U7 city6U6
             city6U5 city6U4 city6U3 city6U2 city6U1 city5U11 city5U10
             city5U9 city5U8 city5U7 city5U6 city5U5 city5U4 city5U3
             city5U2 city5U1 city4U11 city4U10 city4U9 city4U8 city4U7
             city4U6 city4U5 city4U4 city4U3 city4U2 city4U1 city3U11
             city3U10 city3U9 city3U8 city3U7 city3U6 city3U5 city3U4
             city3U3 city3U2 city3U1 city2U11 city2U10 city2U9 city2U8
             city2U7 city2U6 city2U5 city2U4 city2U3 city2U2 city2U1
             city1U11 city1U10 city1U9 city1U8 city1U7 city1U6 city1U5
             city1U4 city1U3 city1U2 city1U1 - location
             city15U12 city14U12 city13U12 city12U12 city11U12 city10U12
             city9U12 city8U12 city7U12 city6U12 city5U12 city4U12 city3U12
             city2U12 city1U12 - airport)
   (:init (inUcity city15U12 city15)
          (inUcity city15U11 city15)
          (inUcity city15U10 city15)
          (inUcity city15U9 city15)
          (inUcity city15U8 city15)
          (inUcity city15U7 city15)
          (inUcity city15U6 city15)
          (inUcity city15U5 city15)
          (inUcity city15U4 city15)
          (inUcity city15U3 city15)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U12 city14)
          (inUcity city14U11 city14)
          (inUcity city14U10 city14)
          (inUcity city14U9 city14)
          (inUcity city14U8 city14)
          (inUcity city14U7 city14)
          (inUcity city14U6 city14)
          (inUcity city14U5 city14)
          (inUcity city14U4 city14)
          (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U12 city13)
          (inUcity city13U11 city13)
          (inUcity city13U10 city13)
          (inUcity city13U9 city13)
          (inUcity city13U8 city13)
          (inUcity city13U7 city13)
          (inUcity city13U6 city13)
          (inUcity city13U5 city13)
          (inUcity city13U4 city13)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U12 city12)
          (inUcity city12U11 city12)
          (inUcity city12U10 city12)
          (inUcity city12U9 city12)
          (inUcity city12U8 city12)
          (inUcity city12U7 city12)
          (inUcity city12U6 city12)
          (inUcity city12U5 city12)
          (inUcity city12U4 city12)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U12 city11)
          (inUcity city11U11 city11)
          (inUcity city11U10 city11)
          (inUcity city11U9 city11)
          (inUcity city11U8 city11)
          (inUcity city11U7 city11)
          (inUcity city11U6 city11)
          (inUcity city11U5 city11)
          (inUcity city11U4 city11)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U12 city10)
          (inUcity city10U11 city10)
          (inUcity city10U10 city10)
          (inUcity city10U9 city10)
          (inUcity city10U8 city10)
          (inUcity city10U7 city10)
          (inUcity city10U6 city10)
          (inUcity city10U5 city10)
          (inUcity city10U4 city10)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U12 city9)
          (inUcity city9U11 city9)
          (inUcity city9U10 city9)
          (inUcity city9U9 city9)
          (inUcity city9U8 city9)
          (inUcity city9U7 city9)
          (inUcity city9U6 city9)
          (inUcity city9U5 city9)
          (inUcity city9U4 city9)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U12 city8)
          (inUcity city8U11 city8)
          (inUcity city8U10 city8)
          (inUcity city8U9 city8)
          (inUcity city8U8 city8)
          (inUcity city8U7 city8)
          (inUcity city8U6 city8)
          (inUcity city8U5 city8)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U12 city7)
          (inUcity city7U11 city7)
          (inUcity city7U10 city7)
          (inUcity city7U9 city7)
          (inUcity city7U8 city7)
          (inUcity city7U7 city7)
          (inUcity city7U6 city7)
          (inUcity city7U5 city7)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U12 city6)
          (inUcity city6U11 city6)
          (inUcity city6U10 city6)
          (inUcity city6U9 city6)
          (inUcity city6U8 city6)
          (inUcity city6U7 city6)
          (inUcity city6U6 city6)
          (inUcity city6U5 city6)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U12 city5)
          (inUcity city5U11 city5)
          (inUcity city5U10 city5)
          (inUcity city5U9 city5)
          (inUcity city5U8 city5)
          (inUcity city5U7 city5)
          (inUcity city5U6 city5)
          (inUcity city5U5 city5)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U12 city4)
          (inUcity city4U11 city4)
          (inUcity city4U10 city4)
          (inUcity city4U9 city4)
          (inUcity city4U8 city4)
          (inUcity city4U7 city4)
          (inUcity city4U6 city4)
          (inUcity city4U5 city4)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U12 city3)
          (inUcity city3U11 city3)
          (inUcity city3U10 city3)
          (inUcity city3U9 city3)
          (inUcity city3U8 city3)
          (inUcity city3U7 city3)
          (inUcity city3U6 city3)
          (inUcity city3U5 city3)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U12 city2)
          (inUcity city2U11 city2)
          (inUcity city2U10 city2)
          (inUcity city2U9 city2)
          (inUcity city2U8 city2)
          (inUcity city2U7 city2)
          (inUcity city2U6 city2)
          (inUcity city2U5 city2)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U12 city1)
          (inUcity city1U11 city1)
          (inUcity city1U10 city1)
          (inUcity city1U9 city1)
          (inUcity city1U8 city1)
          (inUcity city1U7 city1)
          (inUcity city1U6 city1)
          (inUcity city1U5 city1)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane15 city5U12)
          (at plane14 city6U12)
          (at plane13 city4U12)
          (at plane12 city7U12)
          (at plane11 city10U12)
          (at plane10 city3U12)
          (at plane9 city9U12)
          (at plane8 city9U12)
          (at plane7 city14U12)
          (at plane6 city8U12)
          (at plane5 city7U12)
          (at plane4 city11U12)
          (at plane3 city11U12)
          (at plane2 city14U12)
          (at plane1 city13U12)
          (at truck19 city15U6)
          (at truck18 city14U5)
          (at truck17 city13U6)
          (at truck16 city12U10)
          (at truck15 city11U5)
          (at truck14 city10U11)
          (at truck13 city9U3)
          (at truck12 city8U7)
          (at truck11 city7U4)
          (at truck10 city6U9)
          (at truck9 city5U11)
          (at truck8 city4U9)
          (at truck7 city3U8)
          (at truck6 city2U11)
          (at truck5 city1U11)
          (at truck4 city4U9)
          (at truck3 city2U9)
          (at truck2 city10U5)
          (at truck1 city6U6)
          (at package16 city1U12)
          (at package15 city3U10)
          (at package14 city9U8)
          (at package13 city5U2)
          (at package12 city15U5)
          (at package11 city13U3)
          (at package10 city2U3)
          (at package9 city10U1)
          (at package8 city4U9)
          (at package7 city3U4)
          (at package6 city9U2)
          (at package5 city8U1)
          (at package4 city7U5)
          (at package3 city12U5)
          (at package2 city9U7)
          (at package1 city12U11))
   (:goal (and (at package16 city9U10)
               (at package15 city5U12)
               (at package14 city10U4)
               (at package13 city3U4)
               (at package12 city10U10)
               (at package11 city7U4)
               (at package10 city8U5)
               (at package9 city4U2)
               (at package8 city15U6)
               (at package7 city4U9)
               (at package6 city5U10)
               (at package5 city8U10)
               (at package4 city3U11)
               (at package3 city3U7)
               (at package2 city9U12)
               (at package1 city10U10))))

(define (problem logUxU21)
   (:domain logisticsUadl)
   (:objects package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 - obj
             city14 city13 city12 city11 city10 city9 city8 city7 city6
             city5 city4 city3 city2 city1 - city
             truck40 truck39 truck38 truck37 truck36 truck35 truck34
             truck33 truck32 truck31 truck30 truck29 truck28 truck27
             truck26 truck25 truck24 truck23 truck22 truck21 truck20
             truck19 truck18 truck17 truck16 truck15 truck14 truck13
             truck12 truck11 truck10 truck9 truck8 truck7 truck6 truck5
             truck4 truck3 truck2 truck1 - truck
             plane13 plane12 plane11 plane10 plane9 plane8 plane7 plane6
             plane5 plane4 plane3 plane2 plane1 - airplane
             city14U8 city14U7 city14U6 city14U5 city14U4 city14U3 city14U2
             city14U1 city13U8 city13U7 city13U6 city13U5 city13U4 city13U3
             city13U2 city13U1 city12U8 city12U7 city12U6 city12U5 city12U4
             city12U3 city12U2 city12U1 city11U8 city11U7 city11U6 city11U5
             city11U4 city11U3 city11U2 city11U1 city10U8 city10U7 city10U6
             city10U5 city10U4 city10U3 city10U2 city10U1 city9U8 city9U7
             city9U6 city9U5 city9U4 city9U3 city9U2 city9U1 city8U8
             city8U7 city8U6 city8U5 city8U4 city8U3 city8U2 city8U1
             city7U8 city7U7 city7U6 city7U5 city7U4 city7U3 city7U2
             city7U1 city6U8 city6U7 city6U6 city6U5 city6U4 city6U3
             city6U2 city6U1 city5U8 city5U7 city5U6 city5U5 city5U4
             city5U3 city5U2 city5U1 city4U8 city4U7 city4U6 city4U5
             city4U4 city4U3 city4U2 city4U1 city3U8 city3U7 city3U6
             city3U5 city3U4 city3U3 city3U2 city3U1 city2U8 city2U7
             city2U6 city2U5 city2U4 city2U3 city2U2 city2U1 city1U8
             city1U7 city1U6 city1U5 city1U4 city1U3 city1U2 city1U1
             - location
             city14U9 city13U9 city12U9 city11U9 city10U9 city9U9 city8U9
             city7U9 city6U9 city5U9 city4U9 city3U9 city2U9 city1U9
             - airport)
   (:init (inUcity city14U9 city14)
          (inUcity city14U8 city14)
          (inUcity city14U7 city14)
          (inUcity city14U6 city14)
          (inUcity city14U5 city14)
          (inUcity city14U4 city14)
          (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U9 city13)
          (inUcity city13U8 city13)
          (inUcity city13U7 city13)
          (inUcity city13U6 city13)
          (inUcity city13U5 city13)
          (inUcity city13U4 city13)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U9 city12)
          (inUcity city12U8 city12)
          (inUcity city12U7 city12)
          (inUcity city12U6 city12)
          (inUcity city12U5 city12)
          (inUcity city12U4 city12)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U9 city11)
          (inUcity city11U8 city11)
          (inUcity city11U7 city11)
          (inUcity city11U6 city11)
          (inUcity city11U5 city11)
          (inUcity city11U4 city11)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U9 city10)
          (inUcity city10U8 city10)
          (inUcity city10U7 city10)
          (inUcity city10U6 city10)
          (inUcity city10U5 city10)
          (inUcity city10U4 city10)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U9 city9)
          (inUcity city9U8 city9)
          (inUcity city9U7 city9)
          (inUcity city9U6 city9)
          (inUcity city9U5 city9)
          (inUcity city9U4 city9)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U9 city8)
          (inUcity city8U8 city8)
          (inUcity city8U7 city8)
          (inUcity city8U6 city8)
          (inUcity city8U5 city8)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U9 city7)
          (inUcity city7U8 city7)
          (inUcity city7U7 city7)
          (inUcity city7U6 city7)
          (inUcity city7U5 city7)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U9 city6)
          (inUcity city6U8 city6)
          (inUcity city6U7 city6)
          (inUcity city6U6 city6)
          (inUcity city6U5 city6)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U9 city5)
          (inUcity city5U8 city5)
          (inUcity city5U7 city5)
          (inUcity city5U6 city5)
          (inUcity city5U5 city5)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U9 city4)
          (inUcity city4U8 city4)
          (inUcity city4U7 city4)
          (inUcity city4U6 city4)
          (inUcity city4U5 city4)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U9 city3)
          (inUcity city3U8 city3)
          (inUcity city3U7 city3)
          (inUcity city3U6 city3)
          (inUcity city3U5 city3)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U9 city2)
          (inUcity city2U8 city2)
          (inUcity city2U7 city2)
          (inUcity city2U6 city2)
          (inUcity city2U5 city2)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U9 city1)
          (inUcity city1U8 city1)
          (inUcity city1U7 city1)
          (inUcity city1U6 city1)
          (inUcity city1U5 city1)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane13 city8U9)
          (at plane12 city4U9)
          (at plane11 city2U9)
          (at plane10 city5U9)
          (at plane9 city2U9)
          (at plane8 city7U9)
          (at plane7 city5U9)
          (at plane6 city3U9)
          (at plane5 city11U9)
          (at plane4 city7U9)
          (at plane3 city6U9)
          (at plane2 city11U9)
          (at plane1 city2U9)
          (at truck40 city14U3)
          (at truck39 city13U7)
          (at truck38 city12U7)
          (at truck37 city11U5)
          (at truck36 city10U1)
          (at truck35 city9U3)
          (at truck34 city8U8)
          (at truck33 city7U1)
          (at truck32 city6U3)
          (at truck31 city5U7)
          (at truck30 city4U4)
          (at truck29 city3U1)
          (at truck28 city2U7)
          (at truck27 city1U5)
          (at truck26 city4U6)
          (at truck25 city9U1)
          (at truck24 city9U7)
          (at truck23 city4U4)
          (at truck22 city3U3)
          (at truck21 city7U8)
          (at truck20 city2U6)
          (at truck19 city13U3)
          (at truck18 city5U5)
          (at truck17 city4U5)
          (at truck16 city7U1)
          (at truck15 city7U8)
          (at truck14 city4U9)
          (at truck13 city2U1)
          (at truck12 city2U8)
          (at truck11 city6U2)
          (at truck10 city8U3)
          (at truck9 city3U1)
          (at truck8 city11U7)
          (at truck7 city8U5)
          (at truck6 city4U7)
          (at truck5 city1U3)
          (at truck4 city1U3)
          (at truck3 city2U6)
          (at truck2 city2U9)
          (at truck1 city12U9)
          (at package11 city3U8)
          (at package10 city3U1)
          (at package9 city2U5)
          (at package8 city6U6)
          (at package7 city9U8)
          (at package6 city1U6)
          (at package5 city1U1)
          (at package4 city8U8)
          (at package3 city5U8)
          (at package2 city10U1)
          (at package1 city12U1))
   (:goal (and (at package11 city9U8)
               (at package10 city12U9)
               (at package9 city2U3)
               (at package8 city10U7)
               (at package7 city2U2)
               (at package6 city12U6)
               (at package5 city14U8)
               (at package4 city13U2)
               (at package3 city2U8)
               (at package2 city6U2)
               (at package1 city11U6))))

(define (problem logUxU22)
   (:domain logisticsUadl)
   (:objects package44 package43 package42 package41 package40
             package39 package38 package37 package36 package35 package34
             package33 package32 package31 package30 package29 package28
             package27 package26 package25 package24 package23 package22
             package21 package20 package19 package18 package17 package16
             package15 package14 package13 package12 package11 package10
             package9 package8 package7 package6 package5 package4 package3
             package2 package1 - obj
             city30 city29 city28 city27 city26 city25 city24 city23 city22
             city21 city20 city19 city18 city17 city16 city15 city14 city13
             city12 city11 city10 city9 city8 city7 city6 city5 city4 city3
             city2 city1 - city
             truck74 truck73 truck72 truck71 truck70 truck69 truck68
             truck67 truck66 truck65 truck64 truck63 truck62 truck61
             truck60 truck59 truck58 truck57 truck56 truck55 truck54
             truck53 truck52 truck51 truck50 truck49 truck48 truck47
             truck46 truck45 truck44 truck43 truck42 truck41 truck40
             truck39 truck38 truck37 truck36 truck35 truck34 truck33
             truck32 truck31 truck30 truck29 truck28 truck27 truck26
             truck25 truck24 truck23 truck22 truck21 truck20 truck19
             truck18 truck17 truck16 truck15 truck14 truck13 truck12
             truck11 truck10 truck9 truck8 truck7 truck6 truck5 truck4
             truck3 truck2 truck1 - truck
             plane6 plane5 plane4 plane3 plane2 plane1 - airplane
             city30U3 city30U2 city30U1 city29U3 city29U2 city29U1 city28U3
             city28U2 city28U1 city27U3 city27U2 city27U1 city26U3 city26U2
             city26U1 city25U3 city25U2 city25U1 city24U3 city24U2 city24U1
             city23U3 city23U2 city23U1 city22U3 city22U2 city22U1 city21U3
             city21U2 city21U1 city20U3 city20U2 city20U1 city19U3 city19U2
             city19U1 city18U3 city18U2 city18U1 city17U3 city17U2 city17U1
             city16U3 city16U2 city16U1 city15U3 city15U2 city15U1 city14U3
             city14U2 city14U1 city13U3 city13U2 city13U1 city12U3 city12U2
             city12U1 city11U3 city11U2 city11U1 city10U3 city10U2 city10U1
             city9U3 city9U2 city9U1 city8U3 city8U2 city8U1 city7U3
             city7U2 city7U1 city6U3 city6U2 city6U1 city5U3 city5U2
             city5U1 city4U3 city4U2 city4U1 city3U3 city3U2 city3U1
             city2U3 city2U2 city2U1 city1U3 city1U2 city1U1 - location
             city30U4 city29U4 city28U4 city27U4 city26U4 city25U4 city24U4
             city23U4 city22U4 city21U4 city20U4 city19U4 city18U4 city17U4
             city16U4 city15U4 city14U4 city13U4 city12U4 city11U4 city10U4
             city9U4 city8U4 city7U4 city6U4 city5U4 city4U4 city3U4
             city2U4 city1U4 - airport)
   (:init (inUcity city30U4 city30)
          (inUcity city30U3 city30)
          (inUcity city30U2 city30)
          (inUcity city30U1 city30)
          (inUcity city29U4 city29)
          (inUcity city29U3 city29)
          (inUcity city29U2 city29)
          (inUcity city29U1 city29)
          (inUcity city28U4 city28)
          (inUcity city28U3 city28)
          (inUcity city28U2 city28)
          (inUcity city28U1 city28)
          (inUcity city27U4 city27)
          (inUcity city27U3 city27)
          (inUcity city27U2 city27)
          (inUcity city27U1 city27)
          (inUcity city26U4 city26)
          (inUcity city26U3 city26)
          (inUcity city26U2 city26)
          (inUcity city26U1 city26)
          (inUcity city25U4 city25)
          (inUcity city25U3 city25)
          (inUcity city25U2 city25)
          (inUcity city25U1 city25)
          (inUcity city24U4 city24)
          (inUcity city24U3 city24)
          (inUcity city24U2 city24)
          (inUcity city24U1 city24)
          (inUcity city23U4 city23)
          (inUcity city23U3 city23)
          (inUcity city23U2 city23)
          (inUcity city23U1 city23)
          (inUcity city22U4 city22)
          (inUcity city22U3 city22)
          (inUcity city22U2 city22)
          (inUcity city22U1 city22)
          (inUcity city21U4 city21)
          (inUcity city21U3 city21)
          (inUcity city21U2 city21)
          (inUcity city21U1 city21)
          (inUcity city20U4 city20)
          (inUcity city20U3 city20)
          (inUcity city20U2 city20)
          (inUcity city20U1 city20)
          (inUcity city19U4 city19)
          (inUcity city19U3 city19)
          (inUcity city19U2 city19)
          (inUcity city19U1 city19)
          (inUcity city18U4 city18)
          (inUcity city18U3 city18)
          (inUcity city18U2 city18)
          (inUcity city18U1 city18)
          (inUcity city17U4 city17)
          (inUcity city17U3 city17)
          (inUcity city17U2 city17)
          (inUcity city17U1 city17)
          (inUcity city16U4 city16)
          (inUcity city16U3 city16)
          (inUcity city16U2 city16)
          (inUcity city16U1 city16)
          (inUcity city15U4 city15)
          (inUcity city15U3 city15)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U4 city14)
          (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U4 city13)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U4 city12)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U4 city11)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U4 city10)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U4 city9)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane6 city11U4)
          (at plane5 city24U4)
          (at plane4 city30U4)
          (at plane3 city9U4)
          (at plane2 city20U4)
          (at plane1 city2U4)
          (at truck74 city30U2)
          (at truck73 city29U2)
          (at truck72 city28U2)
          (at truck71 city27U3)
          (at truck70 city26U1)
          (at truck69 city25U2)
          (at truck68 city24U1)
          (at truck67 city23U3)
          (at truck66 city22U2)
          (at truck65 city21U3)
          (at truck64 city20U1)
          (at truck63 city19U2)
          (at truck62 city18U3)
          (at truck61 city17U1)
          (at truck60 city16U1)
          (at truck59 city15U1)
          (at truck58 city14U2)
          (at truck57 city13U3)
          (at truck56 city12U3)
          (at truck55 city11U2)
          (at truck54 city10U3)
          (at truck53 city9U2)
          (at truck52 city8U3)
          (at truck51 city7U2)
          (at truck50 city6U1)
          (at truck49 city5U1)
          (at truck48 city4U3)
          (at truck47 city3U3)
          (at truck46 city2U3)
          (at truck45 city1U2)
          (at truck44 city7U3)
          (at truck43 city1U4)
          (at truck42 city29U3)
          (at truck41 city9U2)
          (at truck40 city26U2)
          (at truck39 city12U1)
          (at truck38 city28U3)
          (at truck37 city6U4)
          (at truck36 city8U3)
          (at truck35 city14U4)
          (at truck34 city29U4)
          (at truck33 city4U4)
          (at truck32 city17U1)
          (at truck31 city29U1)
          (at truck30 city14U2)
          (at truck29 city9U2)
          (at truck28 city28U1)
          (at truck27 city18U2)
          (at truck26 city17U2)
          (at truck25 city15U4)
          (at truck24 city28U2)
          (at truck23 city7U3)
          (at truck22 city6U2)
          (at truck21 city29U3)
          (at truck20 city18U2)
          (at truck19 city28U3)
          (at truck18 city26U2)
          (at truck17 city1U4)
          (at truck16 city5U1)
          (at truck15 city18U1)
          (at truck14 city29U1)
          (at truck13 city12U4)
          (at truck12 city30U3)
          (at truck11 city7U3)
          (at truck10 city29U1)
          (at truck9 city26U4)
          (at truck8 city2U4)
          (at truck7 city13U1)
          (at truck6 city3U4)
          (at truck5 city8U4)
          (at truck4 city20U4)
          (at truck3 city10U1)
          (at truck2 city10U1)
          (at truck1 city21U2)
          (at package44 city13U1)
          (at package43 city20U2)
          (at package42 city30U4)
          (at package41 city14U4)
          (at package40 city10U3)
          (at package39 city3U3)
          (at package38 city27U3)
          (at package37 city30U3)
          (at package36 city22U1)
          (at package35 city10U3)
          (at package34 city2U4)
          (at package33 city22U2)
          (at package32 city1U4)
          (at package31 city6U3)
          (at package30 city7U3)
          (at package29 city5U3)
          (at package28 city23U2)
          (at package27 city21U3)
          (at package26 city9U4)
          (at package25 city11U2)
          (at package24 city12U3)
          (at package23 city30U2)
          (at package22 city22U1)
          (at package21 city18U2)
          (at package20 city22U1)
          (at package19 city4U1)
          (at package18 city19U2)
          (at package17 city6U4)
          (at package16 city9U1)
          (at package15 city1U1)
          (at package14 city3U2)
          (at package13 city28U2)
          (at package12 city9U3)
          (at package11 city26U2)
          (at package10 city30U2)
          (at package9 city20U3)
          (at package8 city27U4)
          (at package7 city2U2)
          (at package6 city18U3)
          (at package5 city20U1)
          (at package4 city10U3)
          (at package3 city20U1)
          (at package2 city8U2)
          (at package1 city22U1))
   (:goal (and (at package44 city29U3)
               (at package43 city28U3)
               (at package42 city30U3)
               (at package41 city29U3)
               (at package40 city4U2)
               (at package39 city15U3)
               (at package38 city6U4)
               (at package37 city10U1)
               (at package36 city28U2)
               (at package35 city20U2)
               (at package34 city10U4)
               (at package33 city21U2)
               (at package32 city26U4)
               (at package31 city17U4)
               (at package30 city13U4)
               (at package29 city30U4)
               (at package28 city12U3)
               (at package27 city10U1)
               (at package26 city29U2)
               (at package25 city22U1)
               (at package24 city30U3)
               (at package23 city20U3)
               (at package22 city28U4)
               (at package21 city22U2)
               (at package20 city16U2)
               (at package19 city5U3)
               (at package18 city16U2)
               (at package17 city22U2)
               (at package16 city14U4)
               (at package15 city18U3)
               (at package14 city13U2)
               (at package13 city2U3)
               (at package12 city28U1)
               (at package11 city22U2)
               (at package10 city5U4)
               (at package9 city12U3))))

(define (problem logUxU23)
   (:domain logisticsUadl)
   (:objects package21 package20 package19 package18 package17
             package16 package15 package14 package13 package12 package11
             package10 package9 package8 package7 package6 package5 package4
             package3 package2 package1 - obj
             city8 city7 city6 city5 city4 city3 city2 city1 - city
             truck28 truck27 truck26 truck25 truck24 truck23 truck22
             truck21 truck20 truck19 truck18 truck17 truck16 truck15
             truck14 truck13 truck12 truck11 truck10 truck9 truck8 truck7
             truck6 truck5 truck4 truck3 truck2 truck1 - truck
             plane4 plane3 plane2 plane1 - airplane
             city8U1 city7U1 city6U1 city5U1 city4U1 city3U1 city2U1
             city1U1 - location
             city8U2 city7U2 city6U2 city5U2 city4U2 city3U2 city2U2
             city1U2 - airport)
   (:init (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane4 city5U2)
          (at plane3 city7U2)
          (at plane2 city3U2)
          (at plane1 city1U2)
          (at truck28 city8U1)
          (at truck27 city7U1)
          (at truck26 city6U1)
          (at truck25 city5U1)
          (at truck24 city4U1)
          (at truck23 city3U1)
          (at truck22 city2U1)
          (at truck21 city1U1)
          (at truck20 city2U2)
          (at truck19 city1U1)
          (at truck18 city2U1)
          (at truck17 city7U1)
          (at truck16 city2U2)
          (at truck15 city3U1)
          (at truck14 city5U2)
          (at truck13 city5U1)
          (at truck12 city5U2)
          (at truck11 city6U2)
          (at truck10 city2U2)
          (at truck9 city2U2)
          (at truck8 city1U1)
          (at truck7 city1U1)
          (at truck6 city4U1)
          (at truck5 city6U2)
          (at truck4 city4U1)
          (at truck3 city4U1)
          (at truck2 city2U1)
          (at truck1 city5U2)
          (at package21 city3U1)
          (at package20 city3U1)
          (at package19 city8U1)
          (at package18 city5U1)
          (at package17 city1U2)
          (at package16 city6U1)
          (at package15 city7U2)
          (at package14 city4U2)
          (at package13 city1U1)
          (at package12 city1U2)
          (at package11 city1U2)
          (at package10 city1U2)
          (at package9 city1U1)
          (at package8 city6U1)
          (at package7 city1U1)
          (at package6 city7U1)
          (at package5 city3U1)
          (at package4 city3U2)
          (at package3 city3U1)
          (at package2 city1U2)
          (at package1 city1U1))
   (:goal (and (at package21 city5U2)
               (at package20 city2U2)
               (at package19 city2U1)
               (at package18 city2U2)
               (at package17 city6U1)
               (at package16 city1U1)
               (at package15 city3U2)
               (at package14 city3U1)
               (at package13 city6U1)
               (at package12 city8U1)
               (at package11 city1U2)
               (at package10 city4U1)
               (at package9 city7U1)
               (at package8 city2U1)
               (at package7 city3U2)
               (at package6 city2U2)
               (at package5 city8U2)
               (at package4 city8U2)
               (at package3 city1U2)
               (at package2 city6U2)
               (at package1 city8U2))))

(define (problem logUxU24)
   (:domain logisticsUadl)
   (:objects package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 - obj
             city9 city8 city7 city6 city5 city4 city3 city2 city1 - city
             truck54 truck53 truck52 truck51 truck50 truck49 truck48
             truck47 truck46 truck45 truck44 truck43 truck42 truck41
             truck40 truck39 truck38 truck37 truck36 truck35 truck34
             truck33 truck32 truck31 truck30 truck29 truck28 truck27
             truck26 truck25 truck24 truck23 truck22 truck21 truck20
             truck19 truck18 truck17 truck16 truck15 truck14 truck13
             truck12 truck11 truck10 truck9 truck8 truck7 truck6 truck5
             truck4 truck3 truck2 truck1 - truck
             plane8 plane7 plane6 plane5 plane4 plane3 plane2 plane1
             - airplane
             city9U11 city9U10 city9U9 city9U8 city9U7 city9U6 city9U5
             city9U4 city9U3 city9U2 city9U1 city8U11 city8U10 city8U9
             city8U8 city8U7 city8U6 city8U5 city8U4 city8U3 city8U2
             city8U1 city7U11 city7U10 city7U9 city7U8 city7U7 city7U6
             city7U5 city7U4 city7U3 city7U2 city7U1 city6U11 city6U10
             city6U9 city6U8 city6U7 city6U6 city6U5 city6U4 city6U3
             city6U2 city6U1 city5U11 city5U10 city5U9 city5U8 city5U7
             city5U6 city5U5 city5U4 city5U3 city5U2 city5U1 city4U11
             city4U10 city4U9 city4U8 city4U7 city4U6 city4U5 city4U4
             city4U3 city4U2 city4U1 city3U11 city3U10 city3U9 city3U8
             city3U7 city3U6 city3U5 city3U4 city3U3 city3U2 city3U1
             city2U11 city2U10 city2U9 city2U8 city2U7 city2U6 city2U5
             city2U4 city2U3 city2U2 city2U1 city1U11 city1U10 city1U9
             city1U8 city1U7 city1U6 city1U5 city1U4 city1U3 city1U2
             city1U1 - location
             city9U12 city8U12 city7U12 city6U12 city5U12 city4U12 city3U12
             city2U12 city1U12 - airport)
   (:init (inUcity city9U12 city9)
          (inUcity city9U11 city9)
          (inUcity city9U10 city9)
          (inUcity city9U9 city9)
          (inUcity city9U8 city9)
          (inUcity city9U7 city9)
          (inUcity city9U6 city9)
          (inUcity city9U5 city9)
          (inUcity city9U4 city9)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U12 city8)
          (inUcity city8U11 city8)
          (inUcity city8U10 city8)
          (inUcity city8U9 city8)
          (inUcity city8U8 city8)
          (inUcity city8U7 city8)
          (inUcity city8U6 city8)
          (inUcity city8U5 city8)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U12 city7)
          (inUcity city7U11 city7)
          (inUcity city7U10 city7)
          (inUcity city7U9 city7)
          (inUcity city7U8 city7)
          (inUcity city7U7 city7)
          (inUcity city7U6 city7)
          (inUcity city7U5 city7)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U12 city6)
          (inUcity city6U11 city6)
          (inUcity city6U10 city6)
          (inUcity city6U9 city6)
          (inUcity city6U8 city6)
          (inUcity city6U7 city6)
          (inUcity city6U6 city6)
          (inUcity city6U5 city6)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U12 city5)
          (inUcity city5U11 city5)
          (inUcity city5U10 city5)
          (inUcity city5U9 city5)
          (inUcity city5U8 city5)
          (inUcity city5U7 city5)
          (inUcity city5U6 city5)
          (inUcity city5U5 city5)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U12 city4)
          (inUcity city4U11 city4)
          (inUcity city4U10 city4)
          (inUcity city4U9 city4)
          (inUcity city4U8 city4)
          (inUcity city4U7 city4)
          (inUcity city4U6 city4)
          (inUcity city4U5 city4)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U12 city3)
          (inUcity city3U11 city3)
          (inUcity city3U10 city3)
          (inUcity city3U9 city3)
          (inUcity city3U8 city3)
          (inUcity city3U7 city3)
          (inUcity city3U6 city3)
          (inUcity city3U5 city3)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U12 city2)
          (inUcity city2U11 city2)
          (inUcity city2U10 city2)
          (inUcity city2U9 city2)
          (inUcity city2U8 city2)
          (inUcity city2U7 city2)
          (inUcity city2U6 city2)
          (inUcity city2U5 city2)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U12 city1)
          (inUcity city1U11 city1)
          (inUcity city1U10 city1)
          (inUcity city1U9 city1)
          (inUcity city1U8 city1)
          (inUcity city1U7 city1)
          (inUcity city1U6 city1)
          (inUcity city1U5 city1)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane8 city6U12)
          (at plane7 city6U12)
          (at plane6 city9U12)
          (at plane5 city3U12)
          (at plane4 city9U12)
          (at plane3 city2U12)
          (at plane2 city7U12)
          (at plane1 city6U12)
          (at truck54 city9U4)
          (at truck53 city8U5)
          (at truck52 city7U11)
          (at truck51 city6U1)
          (at truck50 city5U4)
          (at truck49 city4U5)
          (at truck48 city3U2)
          (at truck47 city2U8)
          (at truck46 city1U9)
          (at truck45 city5U4)
          (at truck44 city7U6)
          (at truck43 city8U5)
          (at truck42 city3U2)
          (at truck41 city6U8)
          (at truck40 city2U3)
          (at truck39 city2U10)
          (at truck38 city2U12)
          (at truck37 city2U5)
          (at truck36 city5U7)
          (at truck35 city1U3)
          (at truck34 city1U11)
          (at truck33 city6U10)
          (at truck32 city1U2)
          (at truck31 city3U3)
          (at truck30 city5U12)
          (at truck29 city2U4)
          (at truck28 city3U3)
          (at truck27 city2U3)
          (at truck26 city3U3)
          (at truck25 city4U1)
          (at truck24 city1U12)
          (at truck23 city1U1)
          (at truck22 city7U11)
          (at truck21 city4U5)
          (at truck20 city8U6)
          (at truck19 city1U4)
          (at truck18 city4U7)
          (at truck17 city4U10)
          (at truck16 city1U11)
          (at truck15 city9U7)
          (at truck14 city3U3)
          (at truck13 city1U4)
          (at truck12 city4U8)
          (at truck11 city8U9)
          (at truck10 city6U7)
          (at truck9 city6U10)
          (at truck8 city1U1)
          (at truck7 city4U3)
          (at truck6 city4U5)
          (at truck5 city4U5)
          (at truck4 city9U8)
          (at truck3 city4U8)
          (at truck2 city1U5)
          (at truck1 city9U7)
          (at package11 city5U4)
          (at package10 city2U5)
          (at package9 city6U5)
          (at package8 city1U5)
          (at package7 city3U9)
          (at package6 city6U9)
          (at package5 city4U12)
          (at package4 city7U1)
          (at package3 city6U6)
          (at package2 city2U7)
          (at package1 city8U1))
   (:goal (and (at package11 city8U8)
               (at package10 city3U2)
               (at package9 city1U11)
               (at package8 city3U4))))

(define (problem logUxU25)
   (:domain logisticsUadl)
   (:objects package18 package17 package16 package15 package14
             package13 package12 package11 package10 package9 package8
             package7 package6 package5 package4 package3 package2 package1
             - obj
             city27 city26 city25 city24 city23 city22 city21 city20 city19
             city18 city17 city16 city15 city14 city13 city12 city11 city10
             city9 city8 city7 city6 city5 city4 city3 city2 city1 - city
             truck29 truck28 truck27 truck26 truck25 truck24 truck23
             truck22 truck21 truck20 truck19 truck18 truck17 truck16
             truck15 truck14 truck13 truck12 truck11 truck10 truck9 truck8
             truck7 truck6 truck5 truck4 truck3 truck2 truck1 - truck
             plane13 plane12 plane11 plane10 plane9 plane8 plane7 plane6
             plane5 plane4 plane3 plane2 plane1 - airplane
             city27U12 city27U11 city27U10 city27U9 city27U8 city27U7
             city27U6 city27U5 city27U4 city27U3 city27U2 city27U1
             city26U12 city26U11 city26U10 city26U9 city26U8 city26U7
             city26U6 city26U5 city26U4 city26U3 city26U2 city26U1
             city25U12 city25U11 city25U10 city25U9 city25U8 city25U7
             city25U6 city25U5 city25U4 city25U3 city25U2 city25U1
             city24U12 city24U11 city24U10 city24U9 city24U8 city24U7
             city24U6 city24U5 city24U4 city24U3 city24U2 city24U1
             city23U12 city23U11 city23U10 city23U9 city23U8 city23U7
             city23U6 city23U5 city23U4 city23U3 city23U2 city23U1
             city22U12 city22U11 city22U10 city22U9 city22U8 city22U7
             city22U6 city22U5 city22U4 city22U3 city22U2 city22U1
             city21U12 city21U11 city21U10 city21U9 city21U8 city21U7
             city21U6 city21U5 city21U4 city21U3 city21U2 city21U1
             city20U12 city20U11 city20U10 city20U9 city20U8 city20U7
             city20U6 city20U5 city20U4 city20U3 city20U2 city20U1
             city19U12 city19U11 city19U10 city19U9 city19U8 city19U7
             city19U6 city19U5 city19U4 city19U3 city19U2 city19U1
             city18U12 city18U11 city18U10 city18U9 city18U8 city18U7
             city18U6 city18U5 city18U4 city18U3 city18U2 city18U1
             city17U12 city17U11 city17U10 city17U9 city17U8 city17U7
             city17U6 city17U5 city17U4 city17U3 city17U2 city17U1
             city16U12 city16U11 city16U10 city16U9 city16U8 city16U7
             city16U6 city16U5 city16U4 city16U3 city16U2 city16U1
             city15U12 city15U11 city15U10 city15U9 city15U8 city15U7
             city15U6 city15U5 city15U4 city15U3 city15U2 city15U1
             city14U12 city14U11 city14U10 city14U9 city14U8 city14U7
             city14U6 city14U5 city14U4 city14U3 city14U2 city14U1
             city13U12 city13U11 city13U10 city13U9 city13U8 city13U7
             city13U6 city13U5 city13U4 city13U3 city13U2 city13U1
             city12U12 city12U11 city12U10 city12U9 city12U8 city12U7
             city12U6 city12U5 city12U4 city12U3 city12U2 city12U1
             city11U12 city11U11 city11U10 city11U9 city11U8 city11U7
             city11U6 city11U5 city11U4 city11U3 city11U2 city11U1
             city10U12 city10U11 city10U10 city10U9 city10U8 city10U7
             city10U6 city10U5 city10U4 city10U3 city10U2 city10U1 city9U12
             city9U11 city9U10 city9U9 city9U8 city9U7 city9U6 city9U5
             city9U4 city9U3 city9U2 city9U1 city8U12 city8U11 city8U10
             city8U9 city8U8 city8U7 city8U6 city8U5 city8U4 city8U3
             city8U2 city8U1 city7U12 city7U11 city7U10 city7U9 city7U8
             city7U7 city7U6 city7U5 city7U4 city7U3 city7U2 city7U1
             city6U12 city6U11 city6U10 city6U9 city6U8 city6U7 city6U6
             city6U5 city6U4 city6U3 city6U2 city6U1 city5U12 city5U11
             city5U10 city5U9 city5U8 city5U7 city5U6 city5U5 city5U4
             city5U3 city5U2 city5U1 city4U12 city4U11 city4U10 city4U9
             city4U8 city4U7 city4U6 city4U5 city4U4 city4U3 city4U2
             city4U1 city3U12 city3U11 city3U10 city3U9 city3U8 city3U7
             city3U6 city3U5 city3U4 city3U3 city3U2 city3U1 city2U12
             city2U11 city2U10 city2U9 city2U8 city2U7 city2U6 city2U5
             city2U4 city2U3 city2U2 city2U1 city1U12 city1U11 city1U10
             city1U9 city1U8 city1U7 city1U6 city1U5 city1U4 city1U3
             city1U2 city1U1 - location
             city27U13 city26U13 city25U13 city24U13 city23U13 city22U13
             city21U13 city20U13 city19U13 city18U13 city17U13 city16U13
             city15U13 city14U13 city13U13 city12U13 city11U13 city10U13
             city9U13 city8U13 city7U13 city6U13 city5U13 city4U13 city3U13
             city2U13 city1U13 - airport)
   (:init (inUcity city27U13 city27)
          (inUcity city27U12 city27)
          (inUcity city27U11 city27)
          (inUcity city27U10 city27)
          (inUcity city27U9 city27)
          (inUcity city27U8 city27)
          (inUcity city27U7 city27)
          (inUcity city27U6 city27)
          (inUcity city27U5 city27)
          (inUcity city27U4 city27)
          (inUcity city27U3 city27)
          (inUcity city27U2 city27)
          (inUcity city27U1 city27)
          (inUcity city26U13 city26)
          (inUcity city26U12 city26)
          (inUcity city26U11 city26)
          (inUcity city26U10 city26)
          (inUcity city26U9 city26)
          (inUcity city26U8 city26)
          (inUcity city26U7 city26)
          (inUcity city26U6 city26)
          (inUcity city26U5 city26)
          (inUcity city26U4 city26)
          (inUcity city26U3 city26)
          (inUcity city26U2 city26)
          (inUcity city26U1 city26)
          (inUcity city25U13 city25)
          (inUcity city25U12 city25)
          (inUcity city25U11 city25)
          (inUcity city25U10 city25)
          (inUcity city25U9 city25)
          (inUcity city25U8 city25)
          (inUcity city25U7 city25)
          (inUcity city25U6 city25)
          (inUcity city25U5 city25)
          (inUcity city25U4 city25)
          (inUcity city25U3 city25)
          (inUcity city25U2 city25)
          (inUcity city25U1 city25)
          (inUcity city24U13 city24)
          (inUcity city24U12 city24)
          (inUcity city24U11 city24)
          (inUcity city24U10 city24)
          (inUcity city24U9 city24)
          (inUcity city24U8 city24)
          (inUcity city24U7 city24)
          (inUcity city24U6 city24)
          (inUcity city24U5 city24)
          (inUcity city24U4 city24)
          (inUcity city24U3 city24)
          (inUcity city24U2 city24)
          (inUcity city24U1 city24)
          (inUcity city23U13 city23)
          (inUcity city23U12 city23)
          (inUcity city23U11 city23)
          (inUcity city23U10 city23)
          (inUcity city23U9 city23)
          (inUcity city23U8 city23)
          (inUcity city23U7 city23)
          (inUcity city23U6 city23)
          (inUcity city23U5 city23)
          (inUcity city23U4 city23)
          (inUcity city23U3 city23)
          (inUcity city23U2 city23)
          (inUcity city23U1 city23)
          (inUcity city22U13 city22)
          (inUcity city22U12 city22)
          (inUcity city22U11 city22)
          (inUcity city22U10 city22)
          (inUcity city22U9 city22)
          (inUcity city22U8 city22)
          (inUcity city22U7 city22)
          (inUcity city22U6 city22)
          (inUcity city22U5 city22)
          (inUcity city22U4 city22)
          (inUcity city22U3 city22)
          (inUcity city22U2 city22)
          (inUcity city22U1 city22)
          (inUcity city21U13 city21)
          (inUcity city21U12 city21)
          (inUcity city21U11 city21)
          (inUcity city21U10 city21)
          (inUcity city21U9 city21)
          (inUcity city21U8 city21)
          (inUcity city21U7 city21)
          (inUcity city21U6 city21)
          (inUcity city21U5 city21)
          (inUcity city21U4 city21)
          (inUcity city21U3 city21)
          (inUcity city21U2 city21)
          (inUcity city21U1 city21)
          (inUcity city20U13 city20)
          (inUcity city20U12 city20)
          (inUcity city20U11 city20)
          (inUcity city20U10 city20)
          (inUcity city20U9 city20)
          (inUcity city20U8 city20)
          (inUcity city20U7 city20)
          (inUcity city20U6 city20)
          (inUcity city20U5 city20)
          (inUcity city20U4 city20)
          (inUcity city20U3 city20)
          (inUcity city20U2 city20)
          (inUcity city20U1 city20)
          (inUcity city19U13 city19)
          (inUcity city19U12 city19)
          (inUcity city19U11 city19)
          (inUcity city19U10 city19)
          (inUcity city19U9 city19)
          (inUcity city19U8 city19)
          (inUcity city19U7 city19)
          (inUcity city19U6 city19)
          (inUcity city19U5 city19)
          (inUcity city19U4 city19)
          (inUcity city19U3 city19)
          (inUcity city19U2 city19)
          (inUcity city19U1 city19)
          (inUcity city18U13 city18)
          (inUcity city18U12 city18)
          (inUcity city18U11 city18)
          (inUcity city18U10 city18)
          (inUcity city18U9 city18)
          (inUcity city18U8 city18)
          (inUcity city18U7 city18)
          (inUcity city18U6 city18)
          (inUcity city18U5 city18)
          (inUcity city18U4 city18)
          (inUcity city18U3 city18)
          (inUcity city18U2 city18)
          (inUcity city18U1 city18)
          (inUcity city17U13 city17)
          (inUcity city17U12 city17)
          (inUcity city17U11 city17)
          (inUcity city17U10 city17)
          (inUcity city17U9 city17)
          (inUcity city17U8 city17)
          (inUcity city17U7 city17)
          (inUcity city17U6 city17)
          (inUcity city17U5 city17)
          (inUcity city17U4 city17)
          (inUcity city17U3 city17)
          (inUcity city17U2 city17)
          (inUcity city17U1 city17)
          (inUcity city16U13 city16)
          (inUcity city16U12 city16)
          (inUcity city16U11 city16)
          (inUcity city16U10 city16)
          (inUcity city16U9 city16)
          (inUcity city16U8 city16)
          (inUcity city16U7 city16)
          (inUcity city16U6 city16)
          (inUcity city16U5 city16)
          (inUcity city16U4 city16)
          (inUcity city16U3 city16)
          (inUcity city16U2 city16)
          (inUcity city16U1 city16)
          (inUcity city15U13 city15)
          (inUcity city15U12 city15)
          (inUcity city15U11 city15)
          (inUcity city15U10 city15)
          (inUcity city15U9 city15)
          (inUcity city15U8 city15)
          (inUcity city15U7 city15)
          (inUcity city15U6 city15)
          (inUcity city15U5 city15)
          (inUcity city15U4 city15)
          (inUcity city15U3 city15)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U13 city14)
          (inUcity city14U12 city14)
          (inUcity city14U11 city14)
          (inUcity city14U10 city14)
          (inUcity city14U9 city14)
          (inUcity city14U8 city14)
          (inUcity city14U7 city14)
          (inUcity city14U6 city14)
          (inUcity city14U5 city14)
          (inUcity city14U4 city14)
          (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U13 city13)
          (inUcity city13U12 city13)
          (inUcity city13U11 city13)
          (inUcity city13U10 city13)
          (inUcity city13U9 city13)
          (inUcity city13U8 city13)
          (inUcity city13U7 city13)
          (inUcity city13U6 city13)
          (inUcity city13U5 city13)
          (inUcity city13U4 city13)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U13 city12)
          (inUcity city12U12 city12)
          (inUcity city12U11 city12)
          (inUcity city12U10 city12)
          (inUcity city12U9 city12)
          (inUcity city12U8 city12)
          (inUcity city12U7 city12)
          (inUcity city12U6 city12)
          (inUcity city12U5 city12)
          (inUcity city12U4 city12)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U13 city11)
          (inUcity city11U12 city11)
          (inUcity city11U11 city11)
          (inUcity city11U10 city11)
          (inUcity city11U9 city11)
          (inUcity city11U8 city11)
          (inUcity city11U7 city11)
          (inUcity city11U6 city11)
          (inUcity city11U5 city11)
          (inUcity city11U4 city11)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U13 city10)
          (inUcity city10U12 city10)
          (inUcity city10U11 city10)
          (inUcity city10U10 city10)
          (inUcity city10U9 city10)
          (inUcity city10U8 city10)
          (inUcity city10U7 city10)
          (inUcity city10U6 city10)
          (inUcity city10U5 city10)
          (inUcity city10U4 city10)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U13 city9)
          (inUcity city9U12 city9)
          (inUcity city9U11 city9)
          (inUcity city9U10 city9)
          (inUcity city9U9 city9)
          (inUcity city9U8 city9)
          (inUcity city9U7 city9)
          (inUcity city9U6 city9)
          (inUcity city9U5 city9)
          (inUcity city9U4 city9)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U13 city8)
          (inUcity city8U12 city8)
          (inUcity city8U11 city8)
          (inUcity city8U10 city8)
          (inUcity city8U9 city8)
          (inUcity city8U8 city8)
          (inUcity city8U7 city8)
          (inUcity city8U6 city8)
          (inUcity city8U5 city8)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U13 city7)
          (inUcity city7U12 city7)
          (inUcity city7U11 city7)
          (inUcity city7U10 city7)
          (inUcity city7U9 city7)
          (inUcity city7U8 city7)
          (inUcity city7U7 city7)
          (inUcity city7U6 city7)
          (inUcity city7U5 city7)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U13 city6)
          (inUcity city6U12 city6)
          (inUcity city6U11 city6)
          (inUcity city6U10 city6)
          (inUcity city6U9 city6)
          (inUcity city6U8 city6)
          (inUcity city6U7 city6)
          (inUcity city6U6 city6)
          (inUcity city6U5 city6)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U13 city5)
          (inUcity city5U12 city5)
          (inUcity city5U11 city5)
          (inUcity city5U10 city5)
          (inUcity city5U9 city5)
          (inUcity city5U8 city5)
          (inUcity city5U7 city5)
          (inUcity city5U6 city5)
          (inUcity city5U5 city5)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U13 city4)
          (inUcity city4U12 city4)
          (inUcity city4U11 city4)
          (inUcity city4U10 city4)
          (inUcity city4U9 city4)
          (inUcity city4U8 city4)
          (inUcity city4U7 city4)
          (inUcity city4U6 city4)
          (inUcity city4U5 city4)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U13 city3)
          (inUcity city3U12 city3)
          (inUcity city3U11 city3)
          (inUcity city3U10 city3)
          (inUcity city3U9 city3)
          (inUcity city3U8 city3)
          (inUcity city3U7 city3)
          (inUcity city3U6 city3)
          (inUcity city3U5 city3)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U13 city2)
          (inUcity city2U12 city2)
          (inUcity city2U11 city2)
          (inUcity city2U10 city2)
          (inUcity city2U9 city2)
          (inUcity city2U8 city2)
          (inUcity city2U7 city2)
          (inUcity city2U6 city2)
          (inUcity city2U5 city2)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U13 city1)
          (inUcity city1U12 city1)
          (inUcity city1U11 city1)
          (inUcity city1U10 city1)
          (inUcity city1U9 city1)
          (inUcity city1U8 city1)
          (inUcity city1U7 city1)
          (inUcity city1U6 city1)
          (inUcity city1U5 city1)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane13 city16U13)
          (at plane12 city7U13)
          (at plane11 city3U13)
          (at plane10 city6U13)
          (at plane9 city3U13)
          (at plane8 city8U13)
          (at plane7 city21U13)
          (at plane6 city9U13)
          (at plane5 city26U13)
          (at plane4 city20U13)
          (at plane3 city23U13)
          (at plane2 city22U13)
          (at plane1 city1U13)
          (at truck29 city27U2)
          (at truck28 city26U6)
          (at truck27 city25U6)
          (at truck26 city24U9)
          (at truck25 city23U3)
          (at truck24 city22U5)
          (at truck23 city21U8)
          (at truck22 city20U5)
          (at truck21 city19U9)
          (at truck20 city18U9)
          (at truck19 city17U8)
          (at truck18 city16U9)
          (at truck17 city15U2)
          (at truck16 city14U9)
          (at truck15 city13U8)
          (at truck14 city12U1)
          (at truck13 city11U4)
          (at truck12 city10U5)
          (at truck11 city9U1)
          (at truck10 city8U9)
          (at truck9 city7U3)
          (at truck8 city6U10)
          (at truck7 city5U5)
          (at truck6 city4U10)
          (at truck5 city3U4)
          (at truck4 city2U10)
          (at truck3 city1U7)
          (at truck2 city11U7)
          (at truck1 city14U7)
          (at package18 city27U2)
          (at package17 city5U11)
          (at package16 city7U11)
          (at package15 city6U7)
          (at package14 city9U5)
          (at package13 city1U12)
          (at package12 city8U7)
          (at package11 city21U11)
          (at package10 city24U12)
          (at package9 city2U1)
          (at package8 city6U13)
          (at package7 city20U7)
          (at package6 city5U2)
          (at package5 city13U4)
          (at package4 city15U10)
          (at package3 city15U5)
          (at package2 city5U7)
          (at package1 city20U7))
   (:goal (and (at package18 city11U8)
               (at package17 city21U6)
               (at package16 city26U12)
               (at package15 city16U11)
               (at package14 city10U8)
               (at package13 city7U2)
               (at package12 city24U6)
               (at package11 city23U12)
               (at package10 city14U3)
               (at package9 city22U1)
               (at package8 city3U11)
               (at package7 city11U11)
               (at package6 city9U1)
               (at package5 city6U3)
               (at package4 city9U4)
               (at package3 city19U5)
               (at package2 city16U11)
               (at package1 city26U3))))

(define (problem logUxU26)
   (:domain logisticsUadl)
   (:objects package33 package32 package31 package30 package29
             package28 package27 package26 package25 package24 package23
             package22 package21 package20 package19 package18 package17
             package16 package15 package14 package13 package12 package11
             package10 package9 package8 package7 package6 package5 package4
             package3 package2 package1 - obj
             city47 city46 city45 city44 city43 city42 city41 city40 city39
             city38 city37 city36 city35 city34 city33 city32 city31 city30
             city29 city28 city27 city26 city25 city24 city23 city22 city21
             city20 city19 city18 city17 city16 city15 city14 city13 city12
             city11 city10 city9 city8 city7 city6 city5 city4 city3 city2
             city1 - city
             truck106 truck105 truck104 truck103 truck102 truck101 truck100
             truck99 truck98 truck97 truck96 truck95 truck94 truck93
             truck92 truck91 truck90 truck89 truck88 truck87 truck86
             truck85 truck84 truck83 truck82 truck81 truck80 truck79
             truck78 truck77 truck76 truck75 truck74 truck73 truck72
             truck71 truck70 truck69 truck68 truck67 truck66 truck65
             truck64 truck63 truck62 truck61 truck60 truck59 truck58
             truck57 truck56 truck55 truck54 truck53 truck52 truck51
             truck50 truck49 truck48 truck47 truck46 truck45 truck44
             truck43 truck42 truck41 truck40 truck39 truck38 truck37
             truck36 truck35 truck34 truck33 truck32 truck31 truck30
             truck29 truck28 truck27 truck26 truck25 truck24 truck23
             truck22 truck21 truck20 truck19 truck18 truck17 truck16
             truck15 truck14 truck13 truck12 truck11 truck10 truck9 truck8
             truck7 truck6 truck5 truck4 truck3 truck2 truck1 - truck
             plane2 plane1 - airplane
             city47U1 city46U1 city45U1 city44U1 city43U1 city42U1 city41U1
             city40U1 city39U1 city38U1 city37U1 city36U1 city35U1 city34U1
             city33U1 city32U1 city31U1 city30U1 city29U1 city28U1 city27U1
             city26U1 city25U1 city24U1 city23U1 city22U1 city21U1 city20U1
             city19U1 city18U1 city17U1 city16U1 city15U1 city14U1 city13U1
             city12U1 city11U1 city10U1 city9U1 city8U1 city7U1 city6U1
             city5U1 city4U1 city3U1 city2U1 city1U1 - location
             city47U2 city46U2 city45U2 city44U2 city43U2 city42U2 city41U2
             city40U2 city39U2 city38U2 city37U2 city36U2 city35U2 city34U2
             city33U2 city32U2 city31U2 city30U2 city29U2 city28U2 city27U2
             city26U2 city25U2 city24U2 city23U2 city22U2 city21U2 city20U2
             city19U2 city18U2 city17U2 city16U2 city15U2 city14U2 city13U2
             city12U2 city11U2 city10U2 city9U2 city8U2 city7U2 city6U2
             city5U2 city4U2 city3U2 city2U2 city1U2 - airport)
   (:init (inUcity city47U2 city47)
          (inUcity city47U1 city47)
          (inUcity city46U2 city46)
          (inUcity city46U1 city46)
          (inUcity city45U2 city45)
          (inUcity city45U1 city45)
          (inUcity city44U2 city44)
          (inUcity city44U1 city44)
          (inUcity city43U2 city43)
          (inUcity city43U1 city43)
          (inUcity city42U2 city42)
          (inUcity city42U1 city42)
          (inUcity city41U2 city41)
          (inUcity city41U1 city41)
          (inUcity city40U2 city40)
          (inUcity city40U1 city40)
          (inUcity city39U2 city39)
          (inUcity city39U1 city39)
          (inUcity city38U2 city38)
          (inUcity city38U1 city38)
          (inUcity city37U2 city37)
          (inUcity city37U1 city37)
          (inUcity city36U2 city36)
          (inUcity city36U1 city36)
          (inUcity city35U2 city35)
          (inUcity city35U1 city35)
          (inUcity city34U2 city34)
          (inUcity city34U1 city34)
          (inUcity city33U2 city33)
          (inUcity city33U1 city33)
          (inUcity city32U2 city32)
          (inUcity city32U1 city32)
          (inUcity city31U2 city31)
          (inUcity city31U1 city31)
          (inUcity city30U2 city30)
          (inUcity city30U1 city30)
          (inUcity city29U2 city29)
          (inUcity city29U1 city29)
          (inUcity city28U2 city28)
          (inUcity city28U1 city28)
          (inUcity city27U2 city27)
          (inUcity city27U1 city27)
          (inUcity city26U2 city26)
          (inUcity city26U1 city26)
          (inUcity city25U2 city25)
          (inUcity city25U1 city25)
          (inUcity city24U2 city24)
          (inUcity city24U1 city24)
          (inUcity city23U2 city23)
          (inUcity city23U1 city23)
          (inUcity city22U2 city22)
          (inUcity city22U1 city22)
          (inUcity city21U2 city21)
          (inUcity city21U1 city21)
          (inUcity city20U2 city20)
          (inUcity city20U1 city20)
          (inUcity city19U2 city19)
          (inUcity city19U1 city19)
          (inUcity city18U2 city18)
          (inUcity city18U1 city18)
          (inUcity city17U2 city17)
          (inUcity city17U1 city17)
          (inUcity city16U2 city16)
          (inUcity city16U1 city16)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane2 city37U2)
          (at plane1 city33U2)
          (at truck106 city47U1)
          (at truck105 city46U1)
          (at truck104 city45U1)
          (at truck103 city44U1)
          (at truck102 city43U1)
          (at truck101 city42U1)
          (at truck100 city41U1)
          (at truck99 city40U1)
          (at truck98 city39U1)
          (at truck97 city38U1)
          (at truck96 city37U1)
          (at truck95 city36U1)
          (at truck94 city35U1)
          (at truck93 city34U1)
          (at truck92 city33U1)
          (at truck91 city32U1)
          (at truck90 city31U1)
          (at truck89 city30U1)
          (at truck88 city29U1)
          (at truck87 city28U1)
          (at truck86 city27U1)
          (at truck85 city26U1)
          (at truck84 city25U1)
          (at truck83 city24U1)
          (at truck82 city23U1)
          (at truck81 city22U1)
          (at truck80 city21U1)
          (at truck79 city20U1)
          (at truck78 city19U1)
          (at truck77 city18U1)
          (at truck76 city17U1)
          (at truck75 city16U1)
          (at truck74 city15U1)
          (at truck73 city14U1)
          (at truck72 city13U1)
          (at truck71 city12U1)
          (at truck70 city11U1)
          (at truck69 city10U1)
          (at truck68 city9U1)
          (at truck67 city8U1)
          (at truck66 city7U1)
          (at truck65 city6U1)
          (at truck64 city5U1)
          (at truck63 city4U1)
          (at truck62 city3U1)
          (at truck61 city2U1)
          (at truck60 city1U1)
          (at truck59 city1U2)
          (at truck58 city12U1)
          (at truck57 city15U2)
          (at truck56 city28U2)
          (at truck55 city7U1)
          (at truck54 city36U1)
          (at truck53 city15U1)
          (at truck52 city45U2)
          (at truck51 city3U1)
          (at truck50 city44U2)
          (at truck49 city42U1)
          (at truck48 city42U2)
          (at truck47 city23U1)
          (at truck46 city5U1)
          (at truck45 city11U1)
          (at truck44 city23U2)
          (at truck43 city19U2)
          (at truck42 city17U2)
          (at truck41 city42U1)
          (at truck40 city25U2)
          (at truck39 city14U1)
          (at truck38 city9U1)
          (at truck37 city32U2)
          (at truck36 city3U1)
          (at truck35 city13U2)
          (at truck34 city47U2)
          (at truck33 city1U2)
          (at truck32 city10U2)
          (at truck31 city35U1)
          (at truck30 city44U2)
          (at truck29 city14U2)
          (at truck28 city23U1)
          (at truck27 city24U1)
          (at truck26 city24U2)
          (at truck25 city23U1)
          (at truck24 city5U2)
          (at truck23 city4U1)
          (at truck22 city30U1)
          (at truck21 city6U2)
          (at truck20 city31U2)
          (at truck19 city7U1)
          (at truck18 city35U2)
          (at truck17 city40U1)
          (at truck16 city45U2)
          (at truck15 city35U2)
          (at truck14 city12U2)
          (at truck13 city2U2)
          (at truck12 city29U1)
          (at truck11 city1U1)
          (at truck10 city25U1)
          (at truck9 city1U2)
          (at truck8 city30U1)
          (at truck7 city16U2)
          (at truck6 city25U2)
          (at truck5 city37U1)
          (at truck4 city41U2)
          (at truck3 city36U2)
          (at truck2 city39U2)
          (at truck1 city4U2)
          (at package33 city29U2)
          (at package32 city10U2)
          (at package31 city45U2)
          (at package30 city21U2)
          (at package29 city34U1)
          (at package28 city4U2)
          (at package27 city30U2)
          (at package26 city5U2)
          (at package25 city38U1)
          (at package24 city10U1)
          (at package23 city23U1)
          (at package22 city42U1)
          (at package21 city18U1)
          (at package20 city35U2)
          (at package19 city37U2)
          (at package18 city43U1)
          (at package17 city14U2)
          (at package16 city42U2)
          (at package15 city27U2)
          (at package14 city40U2)
          (at package13 city7U1)
          (at package12 city6U1)
          (at package11 city40U2)
          (at package10 city14U2)
          (at package9 city34U1)
          (at package8 city7U1)
          (at package7 city12U1)
          (at package6 city44U1)
          (at package5 city11U1)
          (at package4 city28U2)
          (at package3 city6U2)
          (at package2 city27U1)
          (at package1 city12U2))
   (:goal (and (at package33 city40U2)
               (at package32 city46U2)
               (at package31 city26U2)
               (at package30 city25U2)
               (at package29 city23U1)
               (at package28 city30U2)
               (at package27 city11U2)
               (at package26 city2U1)
               (at package25 city7U1)
               (at package24 city46U1)
               (at package23 city39U1)
               (at package22 city25U1)
               (at package21 city31U2)
               (at package20 city11U2)
               (at package19 city14U1)
               (at package18 city3U2)
               (at package17 city2U1)
               (at package16 city19U2)
               (at package15 city8U2)
               (at package14 city17U1)
               (at package13 city37U2)
               (at package12 city27U1)
               (at package11 city9U2)
               (at package10 city22U2)
               (at package9 city38U1)
               (at package8 city20U1)
               (at package7 city30U1)
               (at package6 city46U1)
               (at package5 city6U2)
               (at package4 city5U2)
               (at package3 city2U2))))

(define (problem logUxU27)
   (:domain logisticsUadl)
   (:objects package57 package56 package55 package54 package53
             package52 package51 package50 package49 package48 package47
             package46 package45 package44 package43 package42 package41
             package40 package39 package38 package37 package36 package35
             package34 package33 package32 package31 package30 package29
             package28 package27 package26 package25 package24 package23
             package22 package21 package20 package19 package18 package17
             package16 package15 package14 package13 package12 package11
             package10 package9 package8 package7 package6 package5 package4
             package3 package2 package1 - obj
             city15 city14 city13 city12 city11 city10 city9 city8 city7
             city6 city5 city4 city3 city2 city1 - city
             truck28 truck27 truck26 truck25 truck24 truck23 truck22
             truck21 truck20 truck19 truck18 truck17 truck16 truck15
             truck14 truck13 truck12 truck11 truck10 truck9 truck8 truck7
             truck6 truck5 truck4 truck3 truck2 truck1 - truck
             plane9 plane8 plane7 plane6 plane5 plane4 plane3 plane2 plane1
             - airplane
             city15U13 city15U12 city15U11 city15U10 city15U9 city15U8
             city15U7 city15U6 city15U5 city15U4 city15U3 city15U2 city15U1
             city14U13 city14U12 city14U11 city14U10 city14U9 city14U8
             city14U7 city14U6 city14U5 city14U4 city14U3 city14U2 city14U1
             city13U13 city13U12 city13U11 city13U10 city13U9 city13U8
             city13U7 city13U6 city13U5 city13U4 city13U3 city13U2 city13U1
             city12U13 city12U12 city12U11 city12U10 city12U9 city12U8
             city12U7 city12U6 city12U5 city12U4 city12U3 city12U2 city12U1
             city11U13 city11U12 city11U11 city11U10 city11U9 city11U8
             city11U7 city11U6 city11U5 city11U4 city11U3 city11U2 city11U1
             city10U13 city10U12 city10U11 city10U10 city10U9 city10U8
             city10U7 city10U6 city10U5 city10U4 city10U3 city10U2 city10U1
             city9U13 city9U12 city9U11 city9U10 city9U9 city9U8 city9U7
             city9U6 city9U5 city9U4 city9U3 city9U2 city9U1 city8U13
             city8U12 city8U11 city8U10 city8U9 city8U8 city8U7 city8U6
             city8U5 city8U4 city8U3 city8U2 city8U1 city7U13 city7U12
             city7U11 city7U10 city7U9 city7U8 city7U7 city7U6 city7U5
             city7U4 city7U3 city7U2 city7U1 city6U13 city6U12 city6U11
             city6U10 city6U9 city6U8 city6U7 city6U6 city6U5 city6U4
             city6U3 city6U2 city6U1 city5U13 city5U12 city5U11 city5U10
             city5U9 city5U8 city5U7 city5U6 city5U5 city5U4 city5U3
             city5U2 city5U1 city4U13 city4U12 city4U11 city4U10 city4U9
             city4U8 city4U7 city4U6 city4U5 city4U4 city4U3 city4U2
             city4U1 city3U13 city3U12 city3U11 city3U10 city3U9 city3U8
             city3U7 city3U6 city3U5 city3U4 city3U3 city3U2 city3U1
             city2U13 city2U12 city2U11 city2U10 city2U9 city2U8 city2U7
             city2U6 city2U5 city2U4 city2U3 city2U2 city2U1 city1U13
             city1U12 city1U11 city1U10 city1U9 city1U8 city1U7 city1U6
             city1U5 city1U4 city1U3 city1U2 city1U1 - location
             city15U14 city14U14 city13U14 city12U14 city11U14 city10U14
             city9U14 city8U14 city7U14 city6U14 city5U14 city4U14 city3U14
             city2U14 city1U14 - airport)
   (:init (inUcity city15U14 city15)
          (inUcity city15U13 city15)
          (inUcity city15U12 city15)
          (inUcity city15U11 city15)
          (inUcity city15U10 city15)
          (inUcity city15U9 city15)
          (inUcity city15U8 city15)
          (inUcity city15U7 city15)
          (inUcity city15U6 city15)
          (inUcity city15U5 city15)
          (inUcity city15U4 city15)
          (inUcity city15U3 city15)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U14 city14)
          (inUcity city14U13 city14)
          (inUcity city14U12 city14)
          (inUcity city14U11 city14)
          (inUcity city14U10 city14)
          (inUcity city14U9 city14)
          (inUcity city14U8 city14)
          (inUcity city14U7 city14)
          (inUcity city14U6 city14)
          (inUcity city14U5 city14)
          (inUcity city14U4 city14)
          (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U14 city13)
          (inUcity city13U13 city13)
          (inUcity city13U12 city13)
          (inUcity city13U11 city13)
          (inUcity city13U10 city13)
          (inUcity city13U9 city13)
          (inUcity city13U8 city13)
          (inUcity city13U7 city13)
          (inUcity city13U6 city13)
          (inUcity city13U5 city13)
          (inUcity city13U4 city13)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U14 city12)
          (inUcity city12U13 city12)
          (inUcity city12U12 city12)
          (inUcity city12U11 city12)
          (inUcity city12U10 city12)
          (inUcity city12U9 city12)
          (inUcity city12U8 city12)
          (inUcity city12U7 city12)
          (inUcity city12U6 city12)
          (inUcity city12U5 city12)
          (inUcity city12U4 city12)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U14 city11)
          (inUcity city11U13 city11)
          (inUcity city11U12 city11)
          (inUcity city11U11 city11)
          (inUcity city11U10 city11)
          (inUcity city11U9 city11)
          (inUcity city11U8 city11)
          (inUcity city11U7 city11)
          (inUcity city11U6 city11)
          (inUcity city11U5 city11)
          (inUcity city11U4 city11)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U14 city10)
          (inUcity city10U13 city10)
          (inUcity city10U12 city10)
          (inUcity city10U11 city10)
          (inUcity city10U10 city10)
          (inUcity city10U9 city10)
          (inUcity city10U8 city10)
          (inUcity city10U7 city10)
          (inUcity city10U6 city10)
          (inUcity city10U5 city10)
          (inUcity city10U4 city10)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U14 city9)
          (inUcity city9U13 city9)
          (inUcity city9U12 city9)
          (inUcity city9U11 city9)
          (inUcity city9U10 city9)
          (inUcity city9U9 city9)
          (inUcity city9U8 city9)
          (inUcity city9U7 city9)
          (inUcity city9U6 city9)
          (inUcity city9U5 city9)
          (inUcity city9U4 city9)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U14 city8)
          (inUcity city8U13 city8)
          (inUcity city8U12 city8)
          (inUcity city8U11 city8)
          (inUcity city8U10 city8)
          (inUcity city8U9 city8)
          (inUcity city8U8 city8)
          (inUcity city8U7 city8)
          (inUcity city8U6 city8)
          (inUcity city8U5 city8)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U14 city7)
          (inUcity city7U13 city7)
          (inUcity city7U12 city7)
          (inUcity city7U11 city7)
          (inUcity city7U10 city7)
          (inUcity city7U9 city7)
          (inUcity city7U8 city7)
          (inUcity city7U7 city7)
          (inUcity city7U6 city7)
          (inUcity city7U5 city7)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U14 city6)
          (inUcity city6U13 city6)
          (inUcity city6U12 city6)
          (inUcity city6U11 city6)
          (inUcity city6U10 city6)
          (inUcity city6U9 city6)
          (inUcity city6U8 city6)
          (inUcity city6U7 city6)
          (inUcity city6U6 city6)
          (inUcity city6U5 city6)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U14 city5)
          (inUcity city5U13 city5)
          (inUcity city5U12 city5)
          (inUcity city5U11 city5)
          (inUcity city5U10 city5)
          (inUcity city5U9 city5)
          (inUcity city5U8 city5)
          (inUcity city5U7 city5)
          (inUcity city5U6 city5)
          (inUcity city5U5 city5)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U14 city4)
          (inUcity city4U13 city4)
          (inUcity city4U12 city4)
          (inUcity city4U11 city4)
          (inUcity city4U10 city4)
          (inUcity city4U9 city4)
          (inUcity city4U8 city4)
          (inUcity city4U7 city4)
          (inUcity city4U6 city4)
          (inUcity city4U5 city4)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U14 city3)
          (inUcity city3U13 city3)
          (inUcity city3U12 city3)
          (inUcity city3U11 city3)
          (inUcity city3U10 city3)
          (inUcity city3U9 city3)
          (inUcity city3U8 city3)
          (inUcity city3U7 city3)
          (inUcity city3U6 city3)
          (inUcity city3U5 city3)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U14 city2)
          (inUcity city2U13 city2)
          (inUcity city2U12 city2)
          (inUcity city2U11 city2)
          (inUcity city2U10 city2)
          (inUcity city2U9 city2)
          (inUcity city2U8 city2)
          (inUcity city2U7 city2)
          (inUcity city2U6 city2)
          (inUcity city2U5 city2)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U14 city1)
          (inUcity city1U13 city1)
          (inUcity city1U12 city1)
          (inUcity city1U11 city1)
          (inUcity city1U10 city1)
          (inUcity city1U9 city1)
          (inUcity city1U8 city1)
          (inUcity city1U7 city1)
          (inUcity city1U6 city1)
          (inUcity city1U5 city1)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane9 city11U14)
          (at plane8 city2U14)
          (at plane7 city6U14)
          (at plane6 city4U14)
          (at plane5 city6U14)
          (at plane4 city13U14)
          (at plane3 city7U14)
          (at plane2 city8U14)
          (at plane1 city9U14)
          (at truck28 city15U5)
          (at truck27 city14U8)
          (at truck26 city13U2)
          (at truck25 city12U8)
          (at truck24 city11U7)
          (at truck23 city10U10)
          (at truck22 city9U8)
          (at truck21 city8U6)
          (at truck20 city7U1)
          (at truck19 city6U13)
          (at truck18 city5U9)
          (at truck17 city4U8)
          (at truck16 city3U6)
          (at truck15 city2U12)
          (at truck14 city1U11)
          (at truck13 city7U9)
          (at truck12 city2U12)
          (at truck11 city9U12)
          (at truck10 city12U9)
          (at truck9 city14U9)
          (at truck8 city14U4)
          (at truck7 city10U6)
          (at truck6 city14U10)
          (at truck5 city10U11)
          (at truck4 city7U10)
          (at truck3 city5U2)
          (at truck2 city3U2)
          (at truck1 city15U1)
          (at package57 city6U7)
          (at package56 city2U4)
          (at package55 city2U8)
          (at package54 city15U7)
          (at package53 city6U14)
          (at package52 city11U4)
          (at package51 city11U14)
          (at package50 city14U13)
          (at package49 city2U7)
          (at package48 city5U14)
          (at package47 city14U13)
          (at package46 city2U2)
          (at package45 city3U5)
          (at package44 city2U1)
          (at package43 city15U12)
          (at package42 city15U1)
          (at package41 city13U14)
          (at package40 city4U14)
          (at package39 city13U6)
          (at package38 city2U12)
          (at package37 city9U7)
          (at package36 city7U10)
          (at package35 city7U3)
          (at package34 city10U4)
          (at package33 city6U14)
          (at package32 city13U6)
          (at package31 city15U13)
          (at package30 city11U5)
          (at package29 city12U12)
          (at package28 city14U1)
          (at package27 city7U8)
          (at package26 city15U7)
          (at package25 city4U6)
          (at package24 city7U8)
          (at package23 city10U14)
          (at package22 city9U11)
          (at package21 city8U14)
          (at package20 city3U8)
          (at package19 city9U4)
          (at package18 city8U2)
          (at package17 city11U9)
          (at package16 city10U14)
          (at package15 city7U8)
          (at package14 city5U13)
          (at package13 city5U12)
          (at package12 city6U12)
          (at package11 city5U12)
          (at package10 city11U1)
          (at package9 city10U12)
          (at package8 city12U3)
          (at package7 city13U4)
          (at package6 city5U8)
          (at package5 city2U1)
          (at package4 city3U9)
          (at package3 city9U2)
          (at package2 city8U7)
          (at package1 city6U12))
   (:goal (and (at package57 city12U11)
               (at package56 city2U8)
               (at package55 city10U4)
               (at package54 city11U12)
               (at package53 city4U6)
               (at package52 city8U4)
               (at package51 city13U4)
               (at package50 city14U7)
               (at package49 city15U10)
               (at package48 city9U12)
               (at package47 city9U7)
               (at package46 city8U2)
               (at package45 city9U4)
               (at package44 city4U13)
               (at package43 city14U7)
               (at package42 city11U3)
               (at package41 city9U9))))

(define (problem logUxU28)
   (:domain logisticsUadl)
   (:objects package42 package41 package40 package39 package38
             package37 package36 package35 package34 package33 package32
             package31 package30 package29 package28 package27 package26
             package25 package24 package23 package22 package21 package20
             package19 package18 package17 package16 package15 package14
             package13 package12 package11 package10 package9 package8
             package7 package6 package5 package4 package3 package2 package1
             - obj
             city20 city19 city18 city17 city16 city15 city14 city13 city12
             city11 city10 city9 city8 city7 city6 city5 city4 city3 city2
             city1 - city
             truck83 truck82 truck81 truck80 truck79 truck78 truck77
             truck76 truck75 truck74 truck73 truck72 truck71 truck70
             truck69 truck68 truck67 truck66 truck65 truck64 truck63
             truck62 truck61 truck60 truck59 truck58 truck57 truck56
             truck55 truck54 truck53 truck52 truck51 truck50 truck49
             truck48 truck47 truck46 truck45 truck44 truck43 truck42
             truck41 truck40 truck39 truck38 truck37 truck36 truck35
             truck34 truck33 truck32 truck31 truck30 truck29 truck28
             truck27 truck26 truck25 truck24 truck23 truck22 truck21
             truck20 truck19 truck18 truck17 truck16 truck15 truck14
             truck13 truck12 truck11 truck10 truck9 truck8 truck7 truck6
             truck5 truck4 truck3 truck2 truck1 - truck
             plane5 plane4 plane3 plane2 plane1 - airplane
             city20U16 city20U15 city20U14 city20U13 city20U12 city20U11
             city20U10 city20U9 city20U8 city20U7 city20U6 city20U5 city20U4
             city20U3 city20U2 city20U1 city19U16 city19U15 city19U14
             city19U13 city19U12 city19U11 city19U10 city19U9 city19U8
             city19U7 city19U6 city19U5 city19U4 city19U3 city19U2 city19U1
             city18U16 city18U15 city18U14 city18U13 city18U12 city18U11
             city18U10 city18U9 city18U8 city18U7 city18U6 city18U5 city18U4
             city18U3 city18U2 city18U1 city17U16 city17U15 city17U14
             city17U13 city17U12 city17U11 city17U10 city17U9 city17U8
             city17U7 city17U6 city17U5 city17U4 city17U3 city17U2 city17U1
             city16U16 city16U15 city16U14 city16U13 city16U12 city16U11
             city16U10 city16U9 city16U8 city16U7 city16U6 city16U5 city16U4
             city16U3 city16U2 city16U1 city15U16 city15U15 city15U14
             city15U13 city15U12 city15U11 city15U10 city15U9 city15U8
             city15U7 city15U6 city15U5 city15U4 city15U3 city15U2 city15U1
             city14U16 city14U15 city14U14 city14U13 city14U12 city14U11
             city14U10 city14U9 city14U8 city14U7 city14U6 city14U5 city14U4
             city14U3 city14U2 city14U1 city13U16 city13U15 city13U14
             city13U13 city13U12 city13U11 city13U10 city13U9 city13U8
             city13U7 city13U6 city13U5 city13U4 city13U3 city13U2 city13U1
             city12U16 city12U15 city12U14 city12U13 city12U12 city12U11
             city12U10 city12U9 city12U8 city12U7 city12U6 city12U5 city12U4
             city12U3 city12U2 city12U1 city11U16 city11U15 city11U14
             city11U13 city11U12 city11U11 city11U10 city11U9 city11U8
             city11U7 city11U6 city11U5 city11U4 city11U3 city11U2 city11U1
             city10U16 city10U15 city10U14 city10U13 city10U12 city10U11
             city10U10 city10U9 city10U8 city10U7 city10U6 city10U5 city10U4
             city10U3 city10U2 city10U1 city9U16 city9U15 city9U14 city9U13
             city9U12 city9U11 city9U10 city9U9 city9U8 city9U7 city9U6
             city9U5 city9U4 city9U3 city9U2 city9U1 city8U16 city8U15
             city8U14 city8U13 city8U12 city8U11 city8U10 city8U9 city8U8
             city8U7 city8U6 city8U5 city8U4 city8U3 city8U2 city8U1
             city7U16 city7U15 city7U14 city7U13 city7U12 city7U11 city7U10
             city7U9 city7U8 city7U7 city7U6 city7U5 city7U4 city7U3
             city7U2 city7U1 city6U16 city6U15 city6U14 city6U13 city6U12
             city6U11 city6U10 city6U9 city6U8 city6U7 city6U6 city6U5
             city6U4 city6U3 city6U2 city6U1 city5U16 city5U15 city5U14
             city5U13 city5U12 city5U11 city5U10 city5U9 city5U8 city5U7
             city5U6 city5U5 city5U4 city5U3 city5U2 city5U1 city4U16
             city4U15 city4U14 city4U13 city4U12 city4U11 city4U10 city4U9
             city4U8 city4U7 city4U6 city4U5 city4U4 city4U3 city4U2
             city4U1 city3U16 city3U15 city3U14 city3U13 city3U12 city3U11
             city3U10 city3U9 city3U8 city3U7 city3U6 city3U5 city3U4
             city3U3 city3U2 city3U1 city2U16 city2U15 city2U14 city2U13
             city2U12 city2U11 city2U10 city2U9 city2U8 city2U7 city2U6
             city2U5 city2U4 city2U3 city2U2 city2U1 city1U16 city1U15
             city1U14 city1U13 city1U12 city1U11 city1U10 city1U9 city1U8
             city1U7 city1U6 city1U5 city1U4 city1U3 city1U2 city1U1
             - location
             city20U17 city19U17 city18U17 city17U17 city16U17 city15U17
             city14U17 city13U17 city12U17 city11U17 city10U17 city9U17
             city8U17 city7U17 city6U17 city5U17 city4U17 city3U17 city2U17
             city1U17 - airport)
   (:init (inUcity city20U17 city20)
          (inUcity city20U16 city20)
          (inUcity city20U15 city20)
          (inUcity city20U14 city20)
          (inUcity city20U13 city20)
          (inUcity city20U12 city20)
          (inUcity city20U11 city20)
          (inUcity city20U10 city20)
          (inUcity city20U9 city20)
          (inUcity city20U8 city20)
          (inUcity city20U7 city20)
          (inUcity city20U6 city20)
          (inUcity city20U5 city20)
          (inUcity city20U4 city20)
          (inUcity city20U3 city20)
          (inUcity city20U2 city20)
          (inUcity city20U1 city20)
          (inUcity city19U17 city19)
          (inUcity city19U16 city19)
          (inUcity city19U15 city19)
          (inUcity city19U14 city19)
          (inUcity city19U13 city19)
          (inUcity city19U12 city19)
          (inUcity city19U11 city19)
          (inUcity city19U10 city19)
          (inUcity city19U9 city19)
          (inUcity city19U8 city19)
          (inUcity city19U7 city19)
          (inUcity city19U6 city19)
          (inUcity city19U5 city19)
          (inUcity city19U4 city19)
          (inUcity city19U3 city19)
          (inUcity city19U2 city19)
          (inUcity city19U1 city19)
          (inUcity city18U17 city18)
          (inUcity city18U16 city18)
          (inUcity city18U15 city18)
          (inUcity city18U14 city18)
          (inUcity city18U13 city18)
          (inUcity city18U12 city18)
          (inUcity city18U11 city18)
          (inUcity city18U10 city18)
          (inUcity city18U9 city18)
          (inUcity city18U8 city18)
          (inUcity city18U7 city18)
          (inUcity city18U6 city18)
          (inUcity city18U5 city18)
          (inUcity city18U4 city18)
          (inUcity city18U3 city18)
          (inUcity city18U2 city18)
          (inUcity city18U1 city18)
          (inUcity city17U17 city17)
          (inUcity city17U16 city17)
          (inUcity city17U15 city17)
          (inUcity city17U14 city17)
          (inUcity city17U13 city17)
          (inUcity city17U12 city17)
          (inUcity city17U11 city17)
          (inUcity city17U10 city17)
          (inUcity city17U9 city17)
          (inUcity city17U8 city17)
          (inUcity city17U7 city17)
          (inUcity city17U6 city17)
          (inUcity city17U5 city17)
          (inUcity city17U4 city17)
          (inUcity city17U3 city17)
          (inUcity city17U2 city17)
          (inUcity city17U1 city17)
          (inUcity city16U17 city16)
          (inUcity city16U16 city16)
          (inUcity city16U15 city16)
          (inUcity city16U14 city16)
          (inUcity city16U13 city16)
          (inUcity city16U12 city16)
          (inUcity city16U11 city16)
          (inUcity city16U10 city16)
          (inUcity city16U9 city16)
          (inUcity city16U8 city16)
          (inUcity city16U7 city16)
          (inUcity city16U6 city16)
          (inUcity city16U5 city16)
          (inUcity city16U4 city16)
          (inUcity city16U3 city16)
          (inUcity city16U2 city16)
          (inUcity city16U1 city16)
          (inUcity city15U17 city15)
          (inUcity city15U16 city15)
          (inUcity city15U15 city15)
          (inUcity city15U14 city15)
          (inUcity city15U13 city15)
          (inUcity city15U12 city15)
          (inUcity city15U11 city15)
          (inUcity city15U10 city15)
          (inUcity city15U9 city15)
          (inUcity city15U8 city15)
          (inUcity city15U7 city15)
          (inUcity city15U6 city15)
          (inUcity city15U5 city15)
          (inUcity city15U4 city15)
          (inUcity city15U3 city15)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U17 city14)
          (inUcity city14U16 city14)
          (inUcity city14U15 city14)
          (inUcity city14U14 city14)
          (inUcity city14U13 city14)
          (inUcity city14U12 city14)
          (inUcity city14U11 city14)
          (inUcity city14U10 city14)
          (inUcity city14U9 city14)
          (inUcity city14U8 city14)
          (inUcity city14U7 city14)
          (inUcity city14U6 city14)
          (inUcity city14U5 city14)
          (inUcity city14U4 city14)
          (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U17 city13)
          (inUcity city13U16 city13)
          (inUcity city13U15 city13)
          (inUcity city13U14 city13)
          (inUcity city13U13 city13)
          (inUcity city13U12 city13)
          (inUcity city13U11 city13)
          (inUcity city13U10 city13)
          (inUcity city13U9 city13)
          (inUcity city13U8 city13)
          (inUcity city13U7 city13)
          (inUcity city13U6 city13)
          (inUcity city13U5 city13)
          (inUcity city13U4 city13)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U17 city12)
          (inUcity city12U16 city12)
          (inUcity city12U15 city12)
          (inUcity city12U14 city12)
          (inUcity city12U13 city12)
          (inUcity city12U12 city12)
          (inUcity city12U11 city12)
          (inUcity city12U10 city12)
          (inUcity city12U9 city12)
          (inUcity city12U8 city12)
          (inUcity city12U7 city12)
          (inUcity city12U6 city12)
          (inUcity city12U5 city12)
          (inUcity city12U4 city12)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U17 city11)
          (inUcity city11U16 city11)
          (inUcity city11U15 city11)
          (inUcity city11U14 city11)
          (inUcity city11U13 city11)
          (inUcity city11U12 city11)
          (inUcity city11U11 city11)
          (inUcity city11U10 city11)
          (inUcity city11U9 city11)
          (inUcity city11U8 city11)
          (inUcity city11U7 city11)
          (inUcity city11U6 city11)
          (inUcity city11U5 city11)
          (inUcity city11U4 city11)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U17 city10)
          (inUcity city10U16 city10)
          (inUcity city10U15 city10)
          (inUcity city10U14 city10)
          (inUcity city10U13 city10)
          (inUcity city10U12 city10)
          (inUcity city10U11 city10)
          (inUcity city10U10 city10)
          (inUcity city10U9 city10)
          (inUcity city10U8 city10)
          (inUcity city10U7 city10)
          (inUcity city10U6 city10)
          (inUcity city10U5 city10)
          (inUcity city10U4 city10)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U17 city9)
          (inUcity city9U16 city9)
          (inUcity city9U15 city9)
          (inUcity city9U14 city9)
          (inUcity city9U13 city9)
          (inUcity city9U12 city9)
          (inUcity city9U11 city9)
          (inUcity city9U10 city9)
          (inUcity city9U9 city9)
          (inUcity city9U8 city9)
          (inUcity city9U7 city9)
          (inUcity city9U6 city9)
          (inUcity city9U5 city9)
          (inUcity city9U4 city9)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U17 city8)
          (inUcity city8U16 city8)
          (inUcity city8U15 city8)
          (inUcity city8U14 city8)
          (inUcity city8U13 city8)
          (inUcity city8U12 city8)
          (inUcity city8U11 city8)
          (inUcity city8U10 city8)
          (inUcity city8U9 city8)
          (inUcity city8U8 city8)
          (inUcity city8U7 city8)
          (inUcity city8U6 city8)
          (inUcity city8U5 city8)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U17 city7)
          (inUcity city7U16 city7)
          (inUcity city7U15 city7)
          (inUcity city7U14 city7)
          (inUcity city7U13 city7)
          (inUcity city7U12 city7)
          (inUcity city7U11 city7)
          (inUcity city7U10 city7)
          (inUcity city7U9 city7)
          (inUcity city7U8 city7)
          (inUcity city7U7 city7)
          (inUcity city7U6 city7)
          (inUcity city7U5 city7)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U17 city6)
          (inUcity city6U16 city6)
          (inUcity city6U15 city6)
          (inUcity city6U14 city6)
          (inUcity city6U13 city6)
          (inUcity city6U12 city6)
          (inUcity city6U11 city6)
          (inUcity city6U10 city6)
          (inUcity city6U9 city6)
          (inUcity city6U8 city6)
          (inUcity city6U7 city6)
          (inUcity city6U6 city6)
          (inUcity city6U5 city6)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U17 city5)
          (inUcity city5U16 city5)
          (inUcity city5U15 city5)
          (inUcity city5U14 city5)
          (inUcity city5U13 city5)
          (inUcity city5U12 city5)
          (inUcity city5U11 city5)
          (inUcity city5U10 city5)
          (inUcity city5U9 city5)
          (inUcity city5U8 city5)
          (inUcity city5U7 city5)
          (inUcity city5U6 city5)
          (inUcity city5U5 city5)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U17 city4)
          (inUcity city4U16 city4)
          (inUcity city4U15 city4)
          (inUcity city4U14 city4)
          (inUcity city4U13 city4)
          (inUcity city4U12 city4)
          (inUcity city4U11 city4)
          (inUcity city4U10 city4)
          (inUcity city4U9 city4)
          (inUcity city4U8 city4)
          (inUcity city4U7 city4)
          (inUcity city4U6 city4)
          (inUcity city4U5 city4)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U17 city3)
          (inUcity city3U16 city3)
          (inUcity city3U15 city3)
          (inUcity city3U14 city3)
          (inUcity city3U13 city3)
          (inUcity city3U12 city3)
          (inUcity city3U11 city3)
          (inUcity city3U10 city3)
          (inUcity city3U9 city3)
          (inUcity city3U8 city3)
          (inUcity city3U7 city3)
          (inUcity city3U6 city3)
          (inUcity city3U5 city3)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U17 city2)
          (inUcity city2U16 city2)
          (inUcity city2U15 city2)
          (inUcity city2U14 city2)
          (inUcity city2U13 city2)
          (inUcity city2U12 city2)
          (inUcity city2U11 city2)
          (inUcity city2U10 city2)
          (inUcity city2U9 city2)
          (inUcity city2U8 city2)
          (inUcity city2U7 city2)
          (inUcity city2U6 city2)
          (inUcity city2U5 city2)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U17 city1)
          (inUcity city1U16 city1)
          (inUcity city1U15 city1)
          (inUcity city1U14 city1)
          (inUcity city1U13 city1)
          (inUcity city1U12 city1)
          (inUcity city1U11 city1)
          (inUcity city1U10 city1)
          (inUcity city1U9 city1)
          (inUcity city1U8 city1)
          (inUcity city1U7 city1)
          (inUcity city1U6 city1)
          (inUcity city1U5 city1)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane5 city19U17)
          (at plane4 city9U17)
          (at plane3 city18U17)
          (at plane2 city18U17)
          (at plane1 city14U17)
          (at truck83 city20U7)
          (at truck82 city19U2)
          (at truck81 city18U5)
          (at truck80 city17U14)
          (at truck79 city16U15)
          (at truck78 city15U7)
          (at truck77 city14U14)
          (at truck76 city13U9)
          (at truck75 city12U8)
          (at truck74 city11U1)
          (at truck73 city10U13)
          (at truck72 city9U4)
          (at truck71 city8U3)
          (at truck70 city7U15)
          (at truck69 city6U2)
          (at truck68 city5U8)
          (at truck67 city4U5)
          (at truck66 city3U15)
          (at truck65 city2U7)
          (at truck64 city1U2)
          (at truck63 city1U16)
          (at truck62 city9U15)
          (at truck61 city19U9)
          (at truck60 city12U8)
          (at truck59 city7U10)
          (at truck58 city15U5)
          (at truck57 city7U13)
          (at truck56 city11U1)
          (at truck55 city2U11)
          (at truck54 city13U7)
          (at truck53 city18U13)
          (at truck52 city16U11)
          (at truck51 city19U10)
          (at truck50 city2U8)
          (at truck49 city19U8)
          (at truck48 city19U9)
          (at truck47 city11U2)
          (at truck46 city14U7)
          (at truck45 city2U17)
          (at truck44 city9U17)
          (at truck43 city2U8)
          (at truck42 city19U12)
          (at truck41 city7U15)
          (at truck40 city2U4)
          (at truck39 city18U1)
          (at truck38 city16U6)
          (at truck37 city7U7)
          (at truck36 city12U6)
          (at truck35 city15U17)
          (at truck34 city2U2)
          (at truck33 city13U16)
          (at truck32 city11U2)
          (at truck31 city3U13)
          (at truck30 city8U5)
          (at truck29 city5U7)
          (at truck28 city5U10)
          (at truck27 city4U8)
          (at truck26 city2U5)
          (at truck25 city10U17)
          (at truck24 city13U16)
          (at truck23 city3U13)
          (at truck22 city5U9)
          (at truck21 city11U11)
          (at truck20 city15U13)
          (at truck19 city8U1)
          (at truck18 city5U17)
          (at truck17 city17U15)
          (at truck16 city3U11)
          (at truck15 city10U16)
          (at truck14 city12U4)
          (at truck13 city15U15)
          (at truck12 city13U7)
          (at truck11 city13U2)
          (at truck10 city19U5)
          (at truck9 city6U10)
          (at truck8 city13U6)
          (at truck7 city15U16)
          (at truck6 city8U14)
          (at truck5 city18U3)
          (at truck4 city13U8)
          (at truck3 city17U17)
          (at truck2 city10U6)
          (at truck1 city13U11)
          (at package42 city16U15)
          (at package41 city19U8)
          (at package40 city3U6)
          (at package39 city7U6)
          (at package38 city16U7)
          (at package37 city10U13)
          (at package36 city13U17)
          (at package35 city18U8)
          (at package34 city15U1)
          (at package33 city6U7)
          (at package32 city12U6)
          (at package31 city16U8)
          (at package30 city16U3)
          (at package29 city11U14)
          (at package28 city8U4)
          (at package27 city11U2)
          (at package26 city12U7)
          (at package25 city13U6)
          (at package24 city16U9)
          (at package23 city11U9)
          (at package22 city16U7)
          (at package21 city5U3)
          (at package20 city3U6)
          (at package19 city3U13)
          (at package18 city1U12)
          (at package17 city8U13)
          (at package16 city9U1)
          (at package15 city15U4)
          (at package14 city3U17)
          (at package13 city15U6)
          (at package12 city3U3)
          (at package11 city13U8)
          (at package10 city2U17)
          (at package9 city12U4)
          (at package8 city3U1)
          (at package7 city13U5)
          (at package6 city5U4)
          (at package5 city14U3)
          (at package4 city5U3)
          (at package3 city15U1)
          (at package2 city2U7)
          (at package1 city4U10))
   (:goal (and (at package42 city13U8)
               (at package41 city3U16)
               (at package40 city8U9)
               (at package39 city3U8)
               (at package38 city12U4)
               (at package37 city19U7)
               (at package36 city19U16)
               (at package35 city17U15)
               (at package34 city8U4)
               (at package33 city9U12)
               (at package32 city2U16)
               (at package31 city4U12)
               (at package30 city17U2)
               (at package29 city11U7)
               (at package28 city10U17)
               (at package27 city15U14)
               (at package26 city12U11)
               (at package25 city8U12)
               (at package24 city18U5)
               (at package23 city16U16)
               (at package22 city4U11)
               (at package21 city11U2)
               (at package20 city9U2)
               (at package19 city17U4)
               (at package18 city10U16)
               (at package17 city1U3)
               (at package16 city20U11)
               (at package15 city11U16)
               (at package14 city2U6)
               (at package13 city10U14))))

(define (problem logUxU29)
   (:domain logisticsUadl)
   (:objects package53 package52 package51 package50 package49
             package48 package47 package46 package45 package44 package43
             package42 package41 package40 package39 package38 package37
             package36 package35 package34 package33 package32 package31
             package30 package29 package28 package27 package26 package25
             package24 package23 package22 package21 package20 package19
             package18 package17 package16 package15 package14 package13
             package12 package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 - obj
             city27 city26 city25 city24 city23 city22 city21 city20 city19
             city18 city17 city16 city15 city14 city13 city12 city11 city10
             city9 city8 city7 city6 city5 city4 city3 city2 city1 - city
             truck46 truck45 truck44 truck43 truck42 truck41 truck40
             truck39 truck38 truck37 truck36 truck35 truck34 truck33
             truck32 truck31 truck30 truck29 truck28 truck27 truck26
             truck25 truck24 truck23 truck22 truck21 truck20 truck19
             truck18 truck17 truck16 truck15 truck14 truck13 truck12
             truck11 truck10 truck9 truck8 truck7 truck6 truck5 truck4
             truck3 truck2 truck1 - truck
             plane10 plane9 plane8 plane7 plane6 plane5 plane4 plane3 plane2
             plane1 - airplane
             city27U2 city27U1 city26U2 city26U1 city25U2 city25U1 city24U2
             city24U1 city23U2 city23U1 city22U2 city22U1 city21U2 city21U1
             city20U2 city20U1 city19U2 city19U1 city18U2 city18U1 city17U2
             city17U1 city16U2 city16U1 city15U2 city15U1 city14U2 city14U1
             city13U2 city13U1 city12U2 city12U1 city11U2 city11U1 city10U2
             city10U1 city9U2 city9U1 city8U2 city8U1 city7U2 city7U1
             city6U2 city6U1 city5U2 city5U1 city4U2 city4U1 city3U2
             city3U1 city2U2 city2U1 city1U2 city1U1 - location
             city27U3 city26U3 city25U3 city24U3 city23U3 city22U3 city21U3
             city20U3 city19U3 city18U3 city17U3 city16U3 city15U3 city14U3
             city13U3 city12U3 city11U3 city10U3 city9U3 city8U3 city7U3
             city6U3 city5U3 city4U3 city3U3 city2U3 city1U3 - airport)
   (:init (inUcity city27U3 city27)
          (inUcity city27U2 city27)
          (inUcity city27U1 city27)
          (inUcity city26U3 city26)
          (inUcity city26U2 city26)
          (inUcity city26U1 city26)
          (inUcity city25U3 city25)
          (inUcity city25U2 city25)
          (inUcity city25U1 city25)
          (inUcity city24U3 city24)
          (inUcity city24U2 city24)
          (inUcity city24U1 city24)
          (inUcity city23U3 city23)
          (inUcity city23U2 city23)
          (inUcity city23U1 city23)
          (inUcity city22U3 city22)
          (inUcity city22U2 city22)
          (inUcity city22U1 city22)
          (inUcity city21U3 city21)
          (inUcity city21U2 city21)
          (inUcity city21U1 city21)
          (inUcity city20U3 city20)
          (inUcity city20U2 city20)
          (inUcity city20U1 city20)
          (inUcity city19U3 city19)
          (inUcity city19U2 city19)
          (inUcity city19U1 city19)
          (inUcity city18U3 city18)
          (inUcity city18U2 city18)
          (inUcity city18U1 city18)
          (inUcity city17U3 city17)
          (inUcity city17U2 city17)
          (inUcity city17U1 city17)
          (inUcity city16U3 city16)
          (inUcity city16U2 city16)
          (inUcity city16U1 city16)
          (inUcity city15U3 city15)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane10 city9U3)
          (at plane9 city18U3)
          (at plane8 city15U3)
          (at plane7 city6U3)
          (at plane6 city7U3)
          (at plane5 city15U3)
          (at plane4 city13U3)
          (at plane3 city25U3)
          (at plane2 city6U3)
          (at plane1 city4U3)
          (at truck46 city27U2)
          (at truck45 city26U1)
          (at truck44 city25U1)
          (at truck43 city24U1)
          (at truck42 city23U2)
          (at truck41 city22U1)
          (at truck40 city21U1)
          (at truck39 city20U1)
          (at truck38 city19U2)
          (at truck37 city18U2)
          (at truck36 city17U1)
          (at truck35 city16U2)
          (at truck34 city15U1)
          (at truck33 city14U2)
          (at truck32 city13U2)
          (at truck31 city12U1)
          (at truck30 city11U2)
          (at truck29 city10U1)
          (at truck28 city9U1)
          (at truck27 city8U1)
          (at truck26 city7U1)
          (at truck25 city6U1)
          (at truck24 city5U2)
          (at truck23 city4U2)
          (at truck22 city3U2)
          (at truck21 city2U2)
          (at truck20 city1U1)
          (at truck19 city16U3)
          (at truck18 city21U1)
          (at truck17 city1U3)
          (at truck16 city25U3)
          (at truck15 city15U3)
          (at truck14 city25U1)
          (at truck13 city16U2)
          (at truck12 city24U1)
          (at truck11 city7U1)
          (at truck10 city10U3)
          (at truck9 city4U3)
          (at truck8 city25U1)
          (at truck7 city19U3)
          (at truck6 city25U2)
          (at truck5 city4U2)
          (at truck4 city19U2)
          (at truck3 city3U2)
          (at truck2 city27U3)
          (at truck1 city9U1)
          (at package53 city6U3)
          (at package52 city6U3)
          (at package51 city16U2)
          (at package50 city25U1)
          (at package49 city24U1)
          (at package48 city1U2)
          (at package47 city6U2)
          (at package46 city7U3)
          (at package45 city15U1)
          (at package44 city20U2)
          (at package43 city25U3)
          (at package42 city20U2)
          (at package41 city18U1)
          (at package40 city20U2)
          (at package39 city6U1)
          (at package38 city27U3)
          (at package37 city8U2)
          (at package36 city14U3)
          (at package35 city20U2)
          (at package34 city25U1)
          (at package33 city23U3)
          (at package32 city4U1)
          (at package31 city27U1)
          (at package30 city17U3)
          (at package29 city13U2)
          (at package28 city25U3)
          (at package27 city19U1)
          (at package26 city26U3)
          (at package25 city8U2)
          (at package24 city3U1)
          (at package23 city10U2)
          (at package22 city11U2)
          (at package21 city8U2)
          (at package20 city4U2)
          (at package19 city22U2)
          (at package18 city23U1)
          (at package17 city24U1)
          (at package16 city14U1)
          (at package15 city6U2)
          (at package14 city11U1)
          (at package13 city16U1)
          (at package12 city5U3)
          (at package11 city9U2)
          (at package10 city21U2)
          (at package9 city18U2)
          (at package8 city9U1)
          (at package7 city27U1)
          (at package6 city12U3)
          (at package5 city23U1)
          (at package4 city21U3)
          (at package3 city18U3)
          (at package2 city6U3)
          (at package1 city25U1))
   (:goal (and (at package53 city16U2)
               (at package52 city6U3)
               (at package51 city12U2)
               (at package50 city9U2)
               (at package49 city9U3)
               (at package48 city20U1)
               (at package47 city17U2)
               (at package46 city22U3)
               (at package45 city8U3)
               (at package44 city8U1)
               (at package43 city19U3)
               (at package42 city7U1)
               (at package41 city26U3)
               (at package40 city2U2)
               (at package39 city12U1)
               (at package38 city11U2)
               (at package37 city1U3)
               (at package36 city22U3)
               (at package35 city14U2)
               (at package34 city1U3)
               (at package33 city3U3)
               (at package32 city9U3)
               (at package31 city1U2)
               (at package30 city1U2)
               (at package29 city14U1)
               (at package28 city23U3)
               (at package27 city23U3)
               (at package26 city22U1)
               (at package25 city23U2)
               (at package24 city7U3)
               (at package23 city23U3)
               (at package22 city12U1)
               (at package21 city12U2)
               (at package20 city10U3)
               (at package19 city18U1)
               (at package18 city24U2)
               (at package17 city16U3)
               (at package16 city18U3)
               (at package15 city8U2)
               (at package14 city18U3)
               (at package13 city7U1)
               (at package12 city22U1)
               (at package11 city1U1)
               (at package10 city6U3)
               (at package9 city9U1))))

(define (problem logUxU30)
   (:domain logisticsUadl)
   (:objects package15 package14 package13 package12 package11
             package10 package9 package8 package7 package6 package5 package4
             package3 package2 package1 - obj
             city22 city21 city20 city19 city18 city17 city16 city15 city14
             city13 city12 city11 city10 city9 city8 city7 city6 city5 city4
             city3 city2 city1 - city
             truck80 truck79 truck78 truck77 truck76 truck75 truck74
             truck73 truck72 truck71 truck70 truck69 truck68 truck67
             truck66 truck65 truck64 truck63 truck62 truck61 truck60
             truck59 truck58 truck57 truck56 truck55 truck54 truck53
             truck52 truck51 truck50 truck49 truck48 truck47 truck46
             truck45 truck44 truck43 truck42 truck41 truck40 truck39
             truck38 truck37 truck36 truck35 truck34 truck33 truck32
             truck31 truck30 truck29 truck28 truck27 truck26 truck25
             truck24 truck23 truck22 truck21 truck20 truck19 truck18
             truck17 truck16 truck15 truck14 truck13 truck12 truck11
             truck10 truck9 truck8 truck7 truck6 truck5 truck4 truck3 truck2
             truck1 - truck
             plane3 plane2 plane1 - airplane
             city22U11 city22U10 city22U9 city22U8 city22U7 city22U6
             city22U5 city22U4 city22U3 city22U2 city22U1 city21U11
             city21U10 city21U9 city21U8 city21U7 city21U6 city21U5 city21U4
             city21U3 city21U2 city21U1 city20U11 city20U10 city20U9
             city20U8 city20U7 city20U6 city20U5 city20U4 city20U3 city20U2
             city20U1 city19U11 city19U10 city19U9 city19U8 city19U7
             city19U6 city19U5 city19U4 city19U3 city19U2 city19U1
             city18U11 city18U10 city18U9 city18U8 city18U7 city18U6
             city18U5 city18U4 city18U3 city18U2 city18U1 city17U11
             city17U10 city17U9 city17U8 city17U7 city17U6 city17U5 city17U4
             city17U3 city17U2 city17U1 city16U11 city16U10 city16U9
             city16U8 city16U7 city16U6 city16U5 city16U4 city16U3 city16U2
             city16U1 city15U11 city15U10 city15U9 city15U8 city15U7
             city15U6 city15U5 city15U4 city15U3 city15U2 city15U1
             city14U11 city14U10 city14U9 city14U8 city14U7 city14U6
             city14U5 city14U4 city14U3 city14U2 city14U1 city13U11
             city13U10 city13U9 city13U8 city13U7 city13U6 city13U5 city13U4
             city13U3 city13U2 city13U1 city12U11 city12U10 city12U9
             city12U8 city12U7 city12U6 city12U5 city12U4 city12U3 city12U2
             city12U1 city11U11 city11U10 city11U9 city11U8 city11U7
             city11U6 city11U5 city11U4 city11U3 city11U2 city11U1
             city10U11 city10U10 city10U9 city10U8 city10U7 city10U6
             city10U5 city10U4 city10U3 city10U2 city10U1 city9U11 city9U10
             city9U9 city9U8 city9U7 city9U6 city9U5 city9U4 city9U3
             city9U2 city9U1 city8U11 city8U10 city8U9 city8U8 city8U7
             city8U6 city8U5 city8U4 city8U3 city8U2 city8U1 city7U11
             city7U10 city7U9 city7U8 city7U7 city7U6 city7U5 city7U4
             city7U3 city7U2 city7U1 city6U11 city6U10 city6U9 city6U8
             city6U7 city6U6 city6U5 city6U4 city6U3 city6U2 city6U1
             city5U11 city5U10 city5U9 city5U8 city5U7 city5U6 city5U5
             city5U4 city5U3 city5U2 city5U1 city4U11 city4U10 city4U9
             city4U8 city4U7 city4U6 city4U5 city4U4 city4U3 city4U2
             city4U1 city3U11 city3U10 city3U9 city3U8 city3U7 city3U6
             city3U5 city3U4 city3U3 city3U2 city3U1 city2U11 city2U10
             city2U9 city2U8 city2U7 city2U6 city2U5 city2U4 city2U3
             city2U2 city2U1 city1U11 city1U10 city1U9 city1U8 city1U7
             city1U6 city1U5 city1U4 city1U3 city1U2 city1U1 - location
             city22U12 city21U12 city20U12 city19U12 city18U12 city17U12
             city16U12 city15U12 city14U12 city13U12 city12U12 city11U12
             city10U12 city9U12 city8U12 city7U12 city6U12 city5U12 city4U12
             city3U12 city2U12 city1U12 - airport)
   (:init (inUcity city22U12 city22)
          (inUcity city22U11 city22)
          (inUcity city22U10 city22)
          (inUcity city22U9 city22)
          (inUcity city22U8 city22)
          (inUcity city22U7 city22)
          (inUcity city22U6 city22)
          (inUcity city22U5 city22)
          (inUcity city22U4 city22)
          (inUcity city22U3 city22)
          (inUcity city22U2 city22)
          (inUcity city22U1 city22)
          (inUcity city21U12 city21)
          (inUcity city21U11 city21)
          (inUcity city21U10 city21)
          (inUcity city21U9 city21)
          (inUcity city21U8 city21)
          (inUcity city21U7 city21)
          (inUcity city21U6 city21)
          (inUcity city21U5 city21)
          (inUcity city21U4 city21)
          (inUcity city21U3 city21)
          (inUcity city21U2 city21)
          (inUcity city21U1 city21)
          (inUcity city20U12 city20)
          (inUcity city20U11 city20)
          (inUcity city20U10 city20)
          (inUcity city20U9 city20)
          (inUcity city20U8 city20)
          (inUcity city20U7 city20)
          (inUcity city20U6 city20)
          (inUcity city20U5 city20)
          (inUcity city20U4 city20)
          (inUcity city20U3 city20)
          (inUcity city20U2 city20)
          (inUcity city20U1 city20)
          (inUcity city19U12 city19)
          (inUcity city19U11 city19)
          (inUcity city19U10 city19)
          (inUcity city19U9 city19)
          (inUcity city19U8 city19)
          (inUcity city19U7 city19)
          (inUcity city19U6 city19)
          (inUcity city19U5 city19)
          (inUcity city19U4 city19)
          (inUcity city19U3 city19)
          (inUcity city19U2 city19)
          (inUcity city19U1 city19)
          (inUcity city18U12 city18)
          (inUcity city18U11 city18)
          (inUcity city18U10 city18)
          (inUcity city18U9 city18)
          (inUcity city18U8 city18)
          (inUcity city18U7 city18)
          (inUcity city18U6 city18)
          (inUcity city18U5 city18)
          (inUcity city18U4 city18)
          (inUcity city18U3 city18)
          (inUcity city18U2 city18)
          (inUcity city18U1 city18)
          (inUcity city17U12 city17)
          (inUcity city17U11 city17)
          (inUcity city17U10 city17)
          (inUcity city17U9 city17)
          (inUcity city17U8 city17)
          (inUcity city17U7 city17)
          (inUcity city17U6 city17)
          (inUcity city17U5 city17)
          (inUcity city17U4 city17)
          (inUcity city17U3 city17)
          (inUcity city17U2 city17)
          (inUcity city17U1 city17)
          (inUcity city16U12 city16)
          (inUcity city16U11 city16)
          (inUcity city16U10 city16)
          (inUcity city16U9 city16)
          (inUcity city16U8 city16)
          (inUcity city16U7 city16)
          (inUcity city16U6 city16)
          (inUcity city16U5 city16)
          (inUcity city16U4 city16)
          (inUcity city16U3 city16)
          (inUcity city16U2 city16)
          (inUcity city16U1 city16)
          (inUcity city15U12 city15)
          (inUcity city15U11 city15)
          (inUcity city15U10 city15)
          (inUcity city15U9 city15)
          (inUcity city15U8 city15)
          (inUcity city15U7 city15)
          (inUcity city15U6 city15)
          (inUcity city15U5 city15)
          (inUcity city15U4 city15)
          (inUcity city15U3 city15)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U12 city14)
          (inUcity city14U11 city14)
          (inUcity city14U10 city14)
          (inUcity city14U9 city14)
          (inUcity city14U8 city14)
          (inUcity city14U7 city14)
          (inUcity city14U6 city14)
          (inUcity city14U5 city14)
          (inUcity city14U4 city14)
          (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U12 city13)
          (inUcity city13U11 city13)
          (inUcity city13U10 city13)
          (inUcity city13U9 city13)
          (inUcity city13U8 city13)
          (inUcity city13U7 city13)
          (inUcity city13U6 city13)
          (inUcity city13U5 city13)
          (inUcity city13U4 city13)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U12 city12)
          (inUcity city12U11 city12)
          (inUcity city12U10 city12)
          (inUcity city12U9 city12)
          (inUcity city12U8 city12)
          (inUcity city12U7 city12)
          (inUcity city12U6 city12)
          (inUcity city12U5 city12)
          (inUcity city12U4 city12)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U12 city11)
          (inUcity city11U11 city11)
          (inUcity city11U10 city11)
          (inUcity city11U9 city11)
          (inUcity city11U8 city11)
          (inUcity city11U7 city11)
          (inUcity city11U6 city11)
          (inUcity city11U5 city11)
          (inUcity city11U4 city11)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U12 city10)
          (inUcity city10U11 city10)
          (inUcity city10U10 city10)
          (inUcity city10U9 city10)
          (inUcity city10U8 city10)
          (inUcity city10U7 city10)
          (inUcity city10U6 city10)
          (inUcity city10U5 city10)
          (inUcity city10U4 city10)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U12 city9)
          (inUcity city9U11 city9)
          (inUcity city9U10 city9)
          (inUcity city9U9 city9)
          (inUcity city9U8 city9)
          (inUcity city9U7 city9)
          (inUcity city9U6 city9)
          (inUcity city9U5 city9)
          (inUcity city9U4 city9)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U12 city8)
          (inUcity city8U11 city8)
          (inUcity city8U10 city8)
          (inUcity city8U9 city8)
          (inUcity city8U8 city8)
          (inUcity city8U7 city8)
          (inUcity city8U6 city8)
          (inUcity city8U5 city8)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U12 city7)
          (inUcity city7U11 city7)
          (inUcity city7U10 city7)
          (inUcity city7U9 city7)
          (inUcity city7U8 city7)
          (inUcity city7U7 city7)
          (inUcity city7U6 city7)
          (inUcity city7U5 city7)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U12 city6)
          (inUcity city6U11 city6)
          (inUcity city6U10 city6)
          (inUcity city6U9 city6)
          (inUcity city6U8 city6)
          (inUcity city6U7 city6)
          (inUcity city6U6 city6)
          (inUcity city6U5 city6)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U12 city5)
          (inUcity city5U11 city5)
          (inUcity city5U10 city5)
          (inUcity city5U9 city5)
          (inUcity city5U8 city5)
          (inUcity city5U7 city5)
          (inUcity city5U6 city5)
          (inUcity city5U5 city5)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U12 city4)
          (inUcity city4U11 city4)
          (inUcity city4U10 city4)
          (inUcity city4U9 city4)
          (inUcity city4U8 city4)
          (inUcity city4U7 city4)
          (inUcity city4U6 city4)
          (inUcity city4U5 city4)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U12 city3)
          (inUcity city3U11 city3)
          (inUcity city3U10 city3)
          (inUcity city3U9 city3)
          (inUcity city3U8 city3)
          (inUcity city3U7 city3)
          (inUcity city3U6 city3)
          (inUcity city3U5 city3)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U12 city2)
          (inUcity city2U11 city2)
          (inUcity city2U10 city2)
          (inUcity city2U9 city2)
          (inUcity city2U8 city2)
          (inUcity city2U7 city2)
          (inUcity city2U6 city2)
          (inUcity city2U5 city2)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U12 city1)
          (inUcity city1U11 city1)
          (inUcity city1U10 city1)
          (inUcity city1U9 city1)
          (inUcity city1U8 city1)
          (inUcity city1U7 city1)
          (inUcity city1U6 city1)
          (inUcity city1U5 city1)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane3 city20U12)
          (at plane2 city8U12)
          (at plane1 city14U12)
          (at truck80 city22U1)
          (at truck79 city21U7)
          (at truck78 city20U4)
          (at truck77 city19U7)
          (at truck76 city18U4)
          (at truck75 city17U5)
          (at truck74 city16U2)
          (at truck73 city15U9)
          (at truck72 city14U4)
          (at truck71 city13U9)
          (at truck70 city12U5)
          (at truck69 city11U1)
          (at truck68 city10U9)
          (at truck67 city9U8)
          (at truck66 city8U8)
          (at truck65 city7U1)
          (at truck64 city6U2)
          (at truck63 city5U4)
          (at truck62 city4U1)
          (at truck61 city3U7)
          (at truck60 city2U7)
          (at truck59 city1U10)
          (at truck58 city1U5)
          (at truck57 city20U9)
          (at truck56 city5U10)
          (at truck55 city19U5)
          (at truck54 city5U2)
          (at truck53 city11U8)
          (at truck52 city21U9)
          (at truck51 city3U4)
          (at truck50 city11U1)
          (at truck49 city9U6)
          (at truck48 city17U11)
          (at truck47 city6U6)
          (at truck46 city3U7)
          (at truck45 city14U6)
          (at truck44 city8U3)
          (at truck43 city5U2)
          (at truck42 city2U8)
          (at truck41 city15U11)
          (at truck40 city14U5)
          (at truck39 city7U2)
          (at truck38 city10U8)
          (at truck37 city21U6)
          (at truck36 city11U2)
          (at truck35 city21U6)
          (at truck34 city15U12)
          (at truck33 city7U12)
          (at truck32 city8U3)
          (at truck31 city22U9)
          (at truck30 city16U7)
          (at truck29 city8U6)
          (at truck28 city15U7)
          (at truck27 city12U12)
          (at truck26 city14U10)
          (at truck25 city8U7)
          (at truck24 city10U7)
          (at truck23 city10U10)
          (at truck22 city11U3)
          (at truck21 city9U5)
          (at truck20 city6U3)
          (at truck19 city4U4)
          (at truck18 city5U6)
          (at truck17 city5U10)
          (at truck16 city7U3)
          (at truck15 city21U7)
          (at truck14 city16U9)
          (at truck13 city1U10)
          (at truck12 city2U10)
          (at truck11 city4U9)
          (at truck10 city7U11)
          (at truck9 city8U9)
          (at truck8 city12U7)
          (at truck7 city19U5)
          (at truck6 city3U12)
          (at truck5 city13U2)
          (at truck4 city6U12)
          (at truck3 city2U6)
          (at truck2 city11U3)
          (at truck1 city14U1)
          (at package15 city5U7)
          (at package14 city15U7)
          (at package13 city11U12)
          (at package12 city8U3)
          (at package11 city10U7)
          (at package10 city14U11)
          (at package9 city16U1)
          (at package8 city21U12)
          (at package7 city13U4)
          (at package6 city2U3)
          (at package5 city6U10)
          (at package4 city11U2)
          (at package3 city7U7)
          (at package2 city8U6)
          (at package1 city6U12))
   (:goal (and (at package15 city14U12)
               (at package14 city20U9)
               (at package13 city5U8)
               (at package12 city20U4)
               (at package11 city1U4)
               (at package10 city20U7)
               (at package9 city2U5)
               (at package8 city11U10)
               (at package7 city4U12)
               (at package6 city3U11)
               (at package5 city9U3)
               (at package4 city9U6)
               (at package3 city5U12)
               (at package2 city11U8)
               (at package1 city5U5))))

(define (problem stripsUlogUxU1)
   (:domain logisticsUstrips)
   (:objects package6 package5 package4 package3 package2 package1
             city6 city5 city4 city3 city2 city1 truck6 truck5 truck4
             truck3 truck2 truck1 plane2 plane1 city6U1 city5U1 city4U1
             city3U1 city2U1 city1U1 city6U2 city5U2 city4U2 city3U2
             city2U2 city1U2)
   (:init (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane2)
          (airplane plane1)
          (location city6U1)
          (location city5U1)
          (location city4U1)
          (location city3U1)
          (location city2U1)
          (location city1U1)
          (airport city6U2)
          (location city6U2)
          (airport city5U2)
          (location city5U2)
          (airport city4U2)
          (location city4U2)
          (airport city3U2)
          (location city3U2)
          (airport city2U2)
          (location city2U2)
          (airport city1U2)
          (location city1U2)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane2 city4U2)
          (at plane1 city4U2)
          (at truck6 city6U1)
          (at truck5 city5U1)
          (at truck4 city4U1)
          (at truck3 city3U1)
          (at truck2 city2U1)
          (at truck1 city1U1)
          (at package6 city3U1)
          (at package5 city4U2)
          (at package4 city1U1)
          (at package3 city1U1)
          (at package2 city1U2)
          (at package1 city2U1))
   (:goal (and (at package6 city1U2)
               (at package5 city6U2)
               (at package4 city3U2)
               (at package3 city6U1)
               (at package2 city6U2)
               (at package1 city2U1))))

(define (problem stripsUlogUxU2)
   (:domain logisticsUstrips)
   (:objects package5 package4 package3 package2 package1 city10
             city9 city8 city7 city6 city5 city4 city3 city2 city1 truck10
             truck9 truck8 truck7 truck6 truck5 truck4 truck3 truck2 truck1
             plane4 plane3 plane2 plane1 city10U1 city9U1 city8U1 city7U1
             city6U1 city5U1 city4U1 city3U1 city2U1 city1U1 city10U2
             city9U2 city8U2 city7U2 city6U2 city5U2 city4U2 city3U2
             city2U2 city1U2)
   (:init (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city10U1)
          (location city9U1)
          (location city8U1)
          (location city7U1)
          (location city6U1)
          (location city5U1)
          (location city4U1)
          (location city3U1)
          (location city2U1)
          (location city1U1)
          (airport city10U2)
          (location city10U2)
          (airport city9U2)
          (location city9U2)
          (airport city8U2)
          (location city8U2)
          (airport city7U2)
          (location city7U2)
          (airport city6U2)
          (location city6U2)
          (airport city5U2)
          (location city5U2)
          (airport city4U2)
          (location city4U2)
          (airport city3U2)
          (location city3U2)
          (airport city2U2)
          (location city2U2)
          (airport city1U2)
          (location city1U2)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane4 city3U2)
          (at plane3 city7U2)
          (at plane2 city3U2)
          (at plane1 city6U2)
          (at truck10 city10U1)
          (at truck9 city9U1)
          (at truck8 city8U1)
          (at truck7 city7U1)
          (at truck6 city6U1)
          (at truck5 city5U1)
          (at truck4 city4U1)
          (at truck3 city3U1)
          (at truck2 city2U1)
          (at truck1 city1U1)
          (at package5 city1U2)
          (at package4 city7U2)
          (at package3 city3U2)
          (at package2 city10U1)
          (at package1 city2U2))
   (:goal (and (at package5 city4U2)
               (at package4 city6U1)
               (at package3 city1U1)
               (at package2 city9U2)
               (at package1 city3U1))))

(define (problem stripsUlogUxU3)
   (:domain logisticsUstrips)
   (:objects package9 package8 package7 package6 package5 package4
             package3 package2 package1 city14 city13 city12 city11 city10
             city9 city8 city7 city6 city5 city4 city3 city2 city1 truck14
             truck13 truck12 truck11 truck10 truck9 truck8 truck7 truck6
             truck5 truck4 truck3 truck2 truck1 plane4 plane3 plane2 plane1
             city14U2 city14U1 city13U2 city13U1 city12U2 city12U1 city11U2
             city11U1 city10U2 city10U1 city9U2 city9U1 city8U2 city8U1
             city7U2 city7U1 city6U2 city6U1 city5U2 city5U1 city4U2
             city4U1 city3U2 city3U1 city2U2 city2U1 city1U2 city1U1
             city14U3 city13U3 city12U3 city11U3 city10U3 city9U3 city8U3
             city7U3 city6U3 city5U3 city4U3 city3U3 city2U3 city1U3)
   (:init (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city14U2)
          (location city14U1)
          (location city13U2)
          (location city13U1)
          (location city12U2)
          (location city12U1)
          (location city11U2)
          (location city11U1)
          (location city10U2)
          (location city10U1)
          (location city9U2)
          (location city9U1)
          (location city8U2)
          (location city8U1)
          (location city7U2)
          (location city7U1)
          (location city6U2)
          (location city6U1)
          (location city5U2)
          (location city5U1)
          (location city4U2)
          (location city4U1)
          (location city3U2)
          (location city3U1)
          (location city2U2)
          (location city2U1)
          (location city1U2)
          (location city1U1)
          (airport city14U3)
          (location city14U3)
          (airport city13U3)
          (location city13U3)
          (airport city12U3)
          (location city12U3)
          (airport city11U3)
          (location city11U3)
          (airport city10U3)
          (location city10U3)
          (airport city9U3)
          (location city9U3)
          (airport city8U3)
          (location city8U3)
          (airport city7U3)
          (location city7U3)
          (airport city6U3)
          (location city6U3)
          (airport city5U3)
          (location city5U3)
          (airport city4U3)
          (location city4U3)
          (airport city3U3)
          (location city3U3)
          (airport city2U3)
          (location city2U3)
          (airport city1U3)
          (location city1U3)
          (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane4 city10U3)
          (at plane3 city1U3)
          (at plane2 city11U3)
          (at plane1 city11U3)
          (at truck14 city14U1)
          (at truck13 city13U1)
          (at truck12 city12U1)
          (at truck11 city11U1)
          (at truck10 city10U1)
          (at truck9 city9U2)
          (at truck8 city8U2)
          (at truck7 city7U1)
          (at truck6 city6U2)
          (at truck5 city5U1)
          (at truck4 city4U2)
          (at truck3 city3U2)
          (at truck2 city2U1)
          (at truck1 city1U1)
          (at package9 city4U2)
          (at package8 city9U1)
          (at package7 city1U2)
          (at package6 city9U1)
          (at package5 city12U2)
          (at package4 city8U1)
          (at package3 city12U3)
          (at package2 city12U2)
          (at package1 city8U3))
   (:goal (and (at package9 city11U2)
               (at package8 city5U3)
               (at package7 city10U3)
               (at package6 city9U3)
               (at package5 city10U1)
               (at package4 city13U1)
               (at package3 city1U3))))

(define (problem stripsUlogUxU4)
   (:domain logisticsUstrips)
   (:objects package7 package6 package5 package4 package3 package2
             package1 city13 city12 city11 city10 city9 city8 city7 city6
             city5 city4 city3 city2 city1 truck23 truck22 truck21 truck20
             truck19 truck18 truck17 truck16 truck15 truck14 truck13
             truck12 truck11 truck10 truck9 truck8 truck7 truck6 truck5
             truck4 truck3 truck2 truck1 plane5 plane4 plane3 plane2 plane1
             city13U3 city13U2 city13U1 city12U3 city12U2 city12U1 city11U3
             city11U2 city11U1 city10U3 city10U2 city10U1 city9U3 city9U2
             city9U1 city8U3 city8U2 city8U1 city7U3 city7U2 city7U1
             city6U3 city6U2 city6U1 city5U3 city5U2 city5U1 city4U3
             city4U2 city4U1 city3U3 city3U2 city3U1 city2U3 city2U2
             city2U1 city1U3 city1U2 city1U1 city13U4 city12U4 city11U4
             city10U4 city9U4 city8U4 city7U4 city6U4 city5U4 city4U4
             city3U4 city2U4 city1U4)
   (:init (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city13U3)
          (location city13U2)
          (location city13U1)
          (location city12U3)
          (location city12U2)
          (location city12U1)
          (location city11U3)
          (location city11U2)
          (location city11U1)
          (location city10U3)
          (location city10U2)
          (location city10U1)
          (location city9U3)
          (location city9U2)
          (location city9U1)
          (location city8U3)
          (location city8U2)
          (location city8U1)
          (location city7U3)
          (location city7U2)
          (location city7U1)
          (location city6U3)
          (location city6U2)
          (location city6U1)
          (location city5U3)
          (location city5U2)
          (location city5U1)
          (location city4U3)
          (location city4U2)
          (location city4U1)
          (location city3U3)
          (location city3U2)
          (location city3U1)
          (location city2U3)
          (location city2U2)
          (location city2U1)
          (location city1U3)
          (location city1U2)
          (location city1U1)
          (airport city13U4)
          (location city13U4)
          (airport city12U4)
          (location city12U4)
          (airport city11U4)
          (location city11U4)
          (airport city10U4)
          (location city10U4)
          (airport city9U4)
          (location city9U4)
          (airport city8U4)
          (location city8U4)
          (airport city7U4)
          (location city7U4)
          (airport city6U4)
          (location city6U4)
          (airport city5U4)
          (location city5U4)
          (airport city4U4)
          (location city4U4)
          (airport city3U4)
          (location city3U4)
          (airport city2U4)
          (location city2U4)
          (airport city1U4)
          (location city1U4)
          (inUcity city13U4 city13)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U4 city12)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U4 city11)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U4 city10)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U4 city9)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane5 city12U4)
          (at plane4 city8U4)
          (at plane3 city6U4)
          (at plane2 city13U4)
          (at plane1 city2U4)
          (at truck23 city13U2)
          (at truck22 city12U3)
          (at truck21 city11U3)
          (at truck20 city10U1)
          (at truck19 city9U1)
          (at truck18 city8U2)
          (at truck17 city7U3)
          (at truck16 city6U3)
          (at truck15 city5U2)
          (at truck14 city4U1)
          (at truck13 city3U3)
          (at truck12 city2U1)
          (at truck11 city1U1)
          (at truck10 city10U3)
          (at truck9 city8U1)
          (at truck8 city2U2)
          (at truck7 city9U4)
          (at truck6 city9U2)
          (at truck5 city8U2)
          (at truck4 city7U3)
          (at truck3 city7U1)
          (at truck2 city8U1)
          (at truck1 city5U4)
          (at package7 city1U4)
          (at package6 city2U3)
          (at package5 city10U1)
          (at package4 city5U4)
          (at package3 city11U1)
          (at package2 city11U3)
          (at package1 city4U2))
   (:goal (and (at package7 city12U3)
               (at package6 city9U3)
               (at package5 city12U3)
               (at package4 city8U4)
               (at package3 city13U4)
               (at package2 city7U1)
               (at package1 city13U1))))

(define (problem stripsUlogUxU5)
   (:domain logisticsUstrips)
   (:objects package4 package3 package2 package1 city9 city8 city7
             city6 city5 city4 city3 city2 city1 truck11 truck10 truck9
             truck8 truck7 truck6 truck5 truck4 truck3 truck2 truck1 plane1
             city9U1 city8U1 city7U1 city6U1 city5U1 city4U1 city3U1
             city2U1 city1U1 city9U2 city8U2 city7U2 city6U2 city5U2
             city4U2 city3U2 city2U2 city1U2)
   (:init (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane1)
          (location city9U1)
          (location city8U1)
          (location city7U1)
          (location city6U1)
          (location city5U1)
          (location city4U1)
          (location city3U1)
          (location city2U1)
          (location city1U1)
          (airport city9U2)
          (location city9U2)
          (airport city8U2)
          (location city8U2)
          (airport city7U2)
          (location city7U2)
          (airport city6U2)
          (location city6U2)
          (airport city5U2)
          (location city5U2)
          (airport city4U2)
          (location city4U2)
          (airport city3U2)
          (location city3U2)
          (airport city2U2)
          (location city2U2)
          (airport city1U2)
          (location city1U2)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane1 city8U2)
          (at truck11 city9U1)
          (at truck10 city8U1)
          (at truck9 city7U1)
          (at truck8 city6U1)
          (at truck7 city5U1)
          (at truck6 city4U1)
          (at truck5 city3U1)
          (at truck4 city2U1)
          (at truck3 city1U1)
          (at truck2 city8U1)
          (at truck1 city3U2)
          (at package4 city8U1)
          (at package3 city9U1)
          (at package2 city8U2)
          (at package1 city6U2))
   (:goal (and (at package4 city2U2)
               (at package3 city7U2)
               (at package2 city3U1)
               (at package1 city9U2))))

(define (problem stripsUlogUxU6)
   (:domain logisticsUstrips)
   (:objects package16 package15 package14 package13 package12
             package11 package10 package9 package8 package7 package6
             package5 package4 package3 package2 package1 city18 city17
             city16 city15 city14 city13 city12 city11 city10 city9 city8
             city7 city6 city5 city4 city3 city2 city1 truck26 truck25
             truck24 truck23 truck22 truck21 truck20 truck19 truck18
             truck17 truck16 truck15 truck14 truck13 truck12 truck11
             truck10 truck9 truck8 truck7 truck6 truck5 truck4 truck3 truck2
             truck1 plane2 plane1 city18U3 city18U2 city18U1 city17U3
             city17U2 city17U1 city16U3 city16U2 city16U1 city15U3 city15U2
             city15U1 city14U3 city14U2 city14U1 city13U3 city13U2 city13U1
             city12U3 city12U2 city12U1 city11U3 city11U2 city11U1 city10U3
             city10U2 city10U1 city9U3 city9U2 city9U1 city8U3 city8U2
             city8U1 city7U3 city7U2 city7U1 city6U3 city6U2 city6U1
             city5U3 city5U2 city5U1 city4U3 city4U2 city4U1 city3U3
             city3U2 city3U1 city2U3 city2U2 city2U1 city1U3 city1U2
             city1U1 city18U4 city17U4 city16U4 city15U4 city14U4 city13U4
             city12U4 city11U4 city10U4 city9U4 city8U4 city7U4 city6U4
             city5U4 city4U4 city3U4 city2U4 city1U4)
   (:init (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city18)
          (city city17)
          (city city16)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane2)
          (airplane plane1)
          (location city18U3)
          (location city18U2)
          (location city18U1)
          (location city17U3)
          (location city17U2)
          (location city17U1)
          (location city16U3)
          (location city16U2)
          (location city16U1)
          (location city15U3)
          (location city15U2)
          (location city15U1)
          (location city14U3)
          (location city14U2)
          (location city14U1)
          (location city13U3)
          (location city13U2)
          (location city13U1)
          (location city12U3)
          (location city12U2)
          (location city12U1)
          (location city11U3)
          (location city11U2)
          (location city11U1)
          (location city10U3)
          (location city10U2)
          (location city10U1)
          (location city9U3)
          (location city9U2)
          (location city9U1)
          (location city8U3)
          (location city8U2)
          (location city8U1)
          (location city7U3)
          (location city7U2)
          (location city7U1)
          (location city6U3)
          (location city6U2)
          (location city6U1)
          (location city5U3)
          (location city5U2)
          (location city5U1)
          (location city4U3)
          (location city4U2)
          (location city4U1)
          (location city3U3)
          (location city3U2)
          (location city3U1)
          (location city2U3)
          (location city2U2)
          (location city2U1)
          (location city1U3)
          (location city1U2)
          (location city1U1)
          (airport city18U4)
          (location city18U4)
          (airport city17U4)
          (location city17U4)
          (airport city16U4)
          (location city16U4)
          (airport city15U4)
          (location city15U4)
          (airport city14U4)
          (location city14U4)
          (airport city13U4)
          (location city13U4)
          (airport city12U4)
          (location city12U4)
          (airport city11U4)
          (location city11U4)
          (airport city10U4)
          (location city10U4)
          (airport city9U4)
          (location city9U4)
          (airport city8U4)
          (location city8U4)
          (airport city7U4)
          (location city7U4)
          (airport city6U4)
          (location city6U4)
          (airport city5U4)
          (location city5U4)
          (airport city4U4)
          (location city4U4)
          (airport city3U4)
          (location city3U4)
          (airport city2U4)
          (location city2U4)
          (airport city1U4)
          (location city1U4)
          (inUcity city18U4 city18)
          (inUcity city18U3 city18)
          (inUcity city18U2 city18)
          (inUcity city18U1 city18)
          (inUcity city17U4 city17)
          (inUcity city17U3 city17)
          (inUcity city17U2 city17)
          (inUcity city17U1 city17)
          (inUcity city16U4 city16)
          (inUcity city16U3 city16)
          (inUcity city16U2 city16)
          (inUcity city16U1 city16)
          (inUcity city15U4 city15)
          (inUcity city15U3 city15)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U4 city14)
          (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U4 city13)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U4 city12)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U4 city11)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U4 city10)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U4 city9)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane2 city10U4)
          (at plane1 city18U4)
          (at truck26 city18U2)
          (at truck25 city17U1)
          (at truck24 city16U1)
          (at truck23 city15U2)
          (at truck22 city14U2)
          (at truck21 city13U1)
          (at truck20 city12U3)
          (at truck19 city11U1)
          (at truck18 city10U1)
          (at truck17 city9U1)
          (at truck16 city8U2)
          (at truck15 city7U1)
          (at truck14 city6U1)
          (at truck13 city5U1)
          (at truck12 city4U2)
          (at truck11 city3U2)
          (at truck10 city2U2)
          (at truck9 city1U2)
          (at truck8 city14U1)
          (at truck7 city3U4)
          (at truck6 city1U1)
          (at truck5 city14U1)
          (at truck4 city8U1)
          (at truck3 city10U3)
          (at truck2 city4U3)
          (at truck1 city14U3)
          (at package16 city16U2)
          (at package15 city14U3)
          (at package14 city14U1)
          (at package13 city14U4)
          (at package12 city6U1)
          (at package11 city3U1)
          (at package10 city9U4)
          (at package9 city17U3)
          (at package8 city15U2)
          (at package7 city8U4)
          (at package6 city6U1)
          (at package5 city10U3)
          (at package4 city15U2)
          (at package3 city16U3)
          (at package2 city11U2)
          (at package1 city7U3))
   (:goal (and (at package16 city14U3)
               (at package15 city14U2)
               (at package14 city8U4)
               (at package13 city4U3)
               (at package12 city13U4)
               (at package11 city12U2)
               (at package10 city16U2)
               (at package9 city17U4)
               (at package8 city8U1)
               (at package7 city8U2))))

(define (problem stripsUlogUxU7)
   (:domain logisticsUstrips)
   (:objects package10 package9 package8 package7 package6
             package5 package4 package3 package2 package1 city11 city10
             city9 city8 city7 city6 city5 city4 city3 city2 city1 truck11
             truck10 truck9 truck8 truck7 truck6 truck5 truck4 truck3 truck2
             truck1 plane6 plane5 plane4 plane3 plane2 plane1 city11U1
             city10U1 city9U1 city8U1 city7U1 city6U1 city5U1 city4U1
             city3U1 city2U1 city1U1 city11U2 city10U2 city9U2 city8U2
             city7U2 city6U2 city5U2 city4U2 city3U2 city2U2 city1U2)
   (:init (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city11U1)
          (location city10U1)
          (location city9U1)
          (location city8U1)
          (location city7U1)
          (location city6U1)
          (location city5U1)
          (location city4U1)
          (location city3U1)
          (location city2U1)
          (location city1U1)
          (airport city11U2)
          (location city11U2)
          (airport city10U2)
          (location city10U2)
          (airport city9U2)
          (location city9U2)
          (airport city8U2)
          (location city8U2)
          (airport city7U2)
          (location city7U2)
          (airport city6U2)
          (location city6U2)
          (airport city5U2)
          (location city5U2)
          (airport city4U2)
          (location city4U2)
          (airport city3U2)
          (location city3U2)
          (airport city2U2)
          (location city2U2)
          (airport city1U2)
          (location city1U2)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane6 city2U2)
          (at plane5 city5U2)
          (at plane4 city6U2)
          (at plane3 city9U2)
          (at plane2 city8U2)
          (at plane1 city1U2)
          (at truck11 city11U1)
          (at truck10 city10U1)
          (at truck9 city9U1)
          (at truck8 city8U1)
          (at truck7 city7U1)
          (at truck6 city6U1)
          (at truck5 city5U1)
          (at truck4 city4U1)
          (at truck3 city3U1)
          (at truck2 city2U1)
          (at truck1 city1U1)
          (at package10 city6U2)
          (at package9 city5U2)
          (at package8 city10U2)
          (at package7 city6U2)
          (at package6 city1U2)
          (at package5 city4U1)
          (at package4 city4U2)
          (at package3 city1U2)
          (at package2 city10U2)
          (at package1 city8U1))
   (:goal (and (at package10 city9U1)
               (at package9 city9U2)
               (at package8 city1U2)
               (at package7 city5U1)
               (at package6 city10U2)
               (at package5 city7U1))))

(define (problem stripsUlogUxU8)
   (:domain logisticsUstrips)
   (:objects package24 package23 package22 package21 package20
             package19 package18 package17 package16 package15 package14
             package13 package12 package11 package10 package9 package8
             package7 package6 package5 package4 package3 package2 package1
             city20 city19 city18 city17 city16 city15 city14 city13 city12
             city11 city10 city9 city8 city7 city6 city5 city4 city3 city2
             city1 truck33 truck32 truck31 truck30 truck29 truck28
             truck27 truck26 truck25 truck24 truck23 truck22 truck21
             truck20 truck19 truck18 truck17 truck16 truck15 truck14
             truck13 truck12 truck11 truck10 truck9 truck8 truck7 truck6
             truck5 truck4 truck3 truck2 truck1 plane4 plane3 plane2 plane1
             city20U2 city20U1 city19U2 city19U1 city18U2 city18U1 city17U2
             city17U1 city16U2 city16U1 city15U2 city15U1 city14U2 city14U1
             city13U2 city13U1 city12U2 city12U1 city11U2 city11U1 city10U2
             city10U1 city9U2 city9U1 city8U2 city8U1 city7U2 city7U1
             city6U2 city6U1 city5U2 city5U1 city4U2 city4U1 city3U2
             city3U1 city2U2 city2U1 city1U2 city1U1 city20U3 city19U3
             city18U3 city17U3 city16U3 city15U3 city14U3 city13U3 city12U3
             city11U3 city10U3 city9U3 city8U3 city7U3 city6U3 city5U3
             city4U3 city3U3 city2U3 city1U3)
   (:init (obj package24)
          (obj package23)
          (obj package22)
          (obj package21)
          (obj package20)
          (obj package19)
          (obj package18)
          (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city20)
          (city city19)
          (city city18)
          (city city17)
          (city city16)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck33)
          (truck truck32)
          (truck truck31)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city20U2)
          (location city20U1)
          (location city19U2)
          (location city19U1)
          (location city18U2)
          (location city18U1)
          (location city17U2)
          (location city17U1)
          (location city16U2)
          (location city16U1)
          (location city15U2)
          (location city15U1)
          (location city14U2)
          (location city14U1)
          (location city13U2)
          (location city13U1)
          (location city12U2)
          (location city12U1)
          (location city11U2)
          (location city11U1)
          (location city10U2)
          (location city10U1)
          (location city9U2)
          (location city9U1)
          (location city8U2)
          (location city8U1)
          (location city7U2)
          (location city7U1)
          (location city6U2)
          (location city6U1)
          (location city5U2)
          (location city5U1)
          (location city4U2)
          (location city4U1)
          (location city3U2)
          (location city3U1)
          (location city2U2)
          (location city2U1)
          (location city1U2)
          (location city1U1)
          (airport city20U3)
          (location city20U3)
          (airport city19U3)
          (location city19U3)
          (airport city18U3)
          (location city18U3)
          (airport city17U3)
          (location city17U3)
          (airport city16U3)
          (location city16U3)
          (airport city15U3)
          (location city15U3)
          (airport city14U3)
          (location city14U3)
          (airport city13U3)
          (location city13U3)
          (airport city12U3)
          (location city12U3)
          (airport city11U3)
          (location city11U3)
          (airport city10U3)
          (location city10U3)
          (airport city9U3)
          (location city9U3)
          (airport city8U3)
          (location city8U3)
          (airport city7U3)
          (location city7U3)
          (airport city6U3)
          (location city6U3)
          (airport city5U3)
          (location city5U3)
          (airport city4U3)
          (location city4U3)
          (airport city3U3)
          (location city3U3)
          (airport city2U3)
          (location city2U3)
          (airport city1U3)
          (location city1U3)
          (inUcity city20U3 city20)
          (inUcity city20U2 city20)
          (inUcity city20U1 city20)
          (inUcity city19U3 city19)
          (inUcity city19U2 city19)
          (inUcity city19U1 city19)
          (inUcity city18U3 city18)
          (inUcity city18U2 city18)
          (inUcity city18U1 city18)
          (inUcity city17U3 city17)
          (inUcity city17U2 city17)
          (inUcity city17U1 city17)
          (inUcity city16U3 city16)
          (inUcity city16U2 city16)
          (inUcity city16U1 city16)
          (inUcity city15U3 city15)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane4 city7U3)
          (at plane3 city2U3)
          (at plane2 city16U3)
          (at plane1 city5U3)
          (at truck33 city20U1)
          (at truck32 city19U1)
          (at truck31 city18U2)
          (at truck30 city17U2)
          (at truck29 city16U2)
          (at truck28 city15U2)
          (at truck27 city14U1)
          (at truck26 city13U1)
          (at truck25 city12U2)
          (at truck24 city11U2)
          (at truck23 city10U2)
          (at truck22 city9U1)
          (at truck21 city8U1)
          (at truck20 city7U2)
          (at truck19 city6U2)
          (at truck18 city5U1)
          (at truck17 city4U1)
          (at truck16 city3U2)
          (at truck15 city2U2)
          (at truck14 city1U1)
          (at truck13 city1U3)
          (at truck12 city12U1)
          (at truck11 city5U3)
          (at truck10 city20U3)
          (at truck9 city4U1)
          (at truck8 city10U3)
          (at truck7 city4U2)
          (at truck6 city1U1)
          (at truck5 city5U3)
          (at truck4 city17U2)
          (at truck3 city8U2)
          (at truck2 city2U1)
          (at truck1 city17U2)
          (at package24 city13U1)
          (at package23 city13U3)
          (at package22 city15U3)
          (at package21 city20U3)
          (at package20 city20U2)
          (at package19 city3U3)
          (at package18 city16U1)
          (at package17 city5U2)
          (at package16 city13U1)
          (at package15 city18U2)
          (at package14 city13U1)
          (at package13 city14U1)
          (at package12 city7U2)
          (at package11 city18U3)
          (at package10 city7U1)
          (at package9 city11U3)
          (at package8 city11U3)
          (at package7 city3U3)
          (at package6 city4U2)
          (at package5 city7U3)
          (at package4 city5U2)
          (at package3 city1U1)
          (at package2 city20U3)
          (at package1 city13U1))
   (:goal (and (at package24 city7U1)
               (at package23 city2U1)
               (at package22 city1U3)
               (at package21 city6U3)
               (at package20 city7U1)
               (at package19 city1U2))))

(define (problem stripsUlogUxU9)
   (:domain logisticsUstrips)
   (:objects package12 package11 package10 package9 package8
             package7 package6 package5 package4 package3 package2 package1
             city11 city10 city9 city8 city7 city6 city5 city4 city3 city2
             city1 truck28 truck27 truck26 truck25 truck24 truck23
             truck22 truck21 truck20 truck19 truck18 truck17 truck16
             truck15 truck14 truck13 truck12 truck11 truck10 truck9 truck8
             truck7 truck6 truck5 truck4 truck3 truck2 truck1 plane4 plane3
             plane2 plane1 city11U5 city11U4 city11U3 city11U2 city11U1
             city10U5 city10U4 city10U3 city10U2 city10U1 city9U5 city9U4
             city9U3 city9U2 city9U1 city8U5 city8U4 city8U3 city8U2
             city8U1 city7U5 city7U4 city7U3 city7U2 city7U1 city6U5
             city6U4 city6U3 city6U2 city6U1 city5U5 city5U4 city5U3
             city5U2 city5U1 city4U5 city4U4 city4U3 city4U2 city4U1
             city3U5 city3U4 city3U3 city3U2 city3U1 city2U5 city2U4
             city2U3 city2U2 city2U1 city1U5 city1U4 city1U3 city1U2
             city1U1 city11U6 city10U6 city9U6 city8U6 city7U6 city6U6
             city5U6 city4U6 city3U6 city2U6 city1U6)
   (:init (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city11U5)
          (location city11U4)
          (location city11U3)
          (location city11U2)
          (location city11U1)
          (location city10U5)
          (location city10U4)
          (location city10U3)
          (location city10U2)
          (location city10U1)
          (location city9U5)
          (location city9U4)
          (location city9U3)
          (location city9U2)
          (location city9U1)
          (location city8U5)
          (location city8U4)
          (location city8U3)
          (location city8U2)
          (location city8U1)
          (location city7U5)
          (location city7U4)
          (location city7U3)
          (location city7U2)
          (location city7U1)
          (location city6U5)
          (location city6U4)
          (location city6U3)
          (location city6U2)
          (location city6U1)
          (location city5U5)
          (location city5U4)
          (location city5U3)
          (location city5U2)
          (location city5U1)
          (location city4U5)
          (location city4U4)
          (location city4U3)
          (location city4U2)
          (location city4U1)
          (location city3U5)
          (location city3U4)
          (location city3U3)
          (location city3U2)
          (location city3U1)
          (location city2U5)
          (location city2U4)
          (location city2U3)
          (location city2U2)
          (location city2U1)
          (location city1U5)
          (location city1U4)
          (location city1U3)
          (location city1U2)
          (location city1U1)
          (airport city11U6)
          (location city11U6)
          (airport city10U6)
          (location city10U6)
          (airport city9U6)
          (location city9U6)
          (airport city8U6)
          (location city8U6)
          (airport city7U6)
          (location city7U6)
          (airport city6U6)
          (location city6U6)
          (airport city5U6)
          (location city5U6)
          (airport city4U6)
          (location city4U6)
          (airport city3U6)
          (location city3U6)
          (airport city2U6)
          (location city2U6)
          (airport city1U6)
          (location city1U6)
          (inUcity city11U6 city11)
          (inUcity city11U5 city11)
          (inUcity city11U4 city11)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U6 city10)
          (inUcity city10U5 city10)
          (inUcity city10U4 city10)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U6 city9)
          (inUcity city9U5 city9)
          (inUcity city9U4 city9)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U6 city8)
          (inUcity city8U5 city8)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U6 city7)
          (inUcity city7U5 city7)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U6 city6)
          (inUcity city6U5 city6)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U6 city5)
          (inUcity city5U5 city5)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U6 city4)
          (inUcity city4U5 city4)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U6 city3)
          (inUcity city3U5 city3)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U6 city2)
          (inUcity city2U5 city2)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U6 city1)
          (inUcity city1U5 city1)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane4 city5U6)
          (at plane3 city6U6)
          (at plane2 city7U6)
          (at plane1 city10U6)
          (at truck28 city11U2)
          (at truck27 city10U2)
          (at truck26 city9U1)
          (at truck25 city8U2)
          (at truck24 city7U5)
          (at truck23 city6U1)
          (at truck22 city5U2)
          (at truck21 city4U2)
          (at truck20 city3U3)
          (at truck19 city2U1)
          (at truck18 city1U1)
          (at truck17 city7U3)
          (at truck16 city6U3)
          (at truck15 city8U5)
          (at truck14 city11U6)
          (at truck13 city9U6)
          (at truck12 city7U1)
          (at truck11 city8U6)
          (at truck10 city1U1)
          (at truck9 city4U1)
          (at truck8 city2U5)
          (at truck7 city9U1)
          (at truck6 city2U6)
          (at truck5 city8U6)
          (at truck4 city4U1)
          (at truck3 city4U1)
          (at truck2 city8U2)
          (at truck1 city1U5)
          (at package12 city1U2)
          (at package11 city9U1)
          (at package10 city4U6)
          (at package9 city8U4)
          (at package8 city11U5)
          (at package7 city2U4)
          (at package6 city4U1)
          (at package5 city2U6)
          (at package4 city4U4)
          (at package3 city4U5)
          (at package2 city2U6)
          (at package1 city6U6))
   (:goal (and (at package12 city5U4)
               (at package11 city4U1)
               (at package10 city6U2)
               (at package9 city8U4)
               (at package8 city2U3)
               (at package7 city9U6)
               (at package6 city2U4)
               (at package5 city10U3)
               (at package4 city4U4)
               (at package3 city8U1)
               (at package2 city9U2)
               (at package1 city5U1))))

(define (problem stripsUlogUxU10)
   (:domain logisticsUstrips)
   (:objects package17 package16 package15 package14 package13
             package12 package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 city23
             city22 city21 city20 city19 city18 city17 city16 city15 city14
             city13 city12 city11 city10 city9 city8 city7 city6 city5 city4
             city3 city2 city1 truck23 truck22 truck21 truck20 truck19
             truck18 truck17 truck16 truck15 truck14 truck13 truck12
             truck11 truck10 truck9 truck8 truck7 truck6 truck5 truck4
             truck3 truck2 truck1 plane4 plane3 plane2 plane1 city23U1
             city22U1 city21U1 city20U1 city19U1 city18U1 city17U1 city16U1
             city15U1 city14U1 city13U1 city12U1 city11U1 city10U1 city9U1
             city8U1 city7U1 city6U1 city5U1 city4U1 city3U1 city2U1
             city1U1 city23U2 city22U2 city21U2 city20U2 city19U2 city18U2
             city17U2 city16U2 city15U2 city14U2 city13U2 city12U2 city11U2
             city10U2 city9U2 city8U2 city7U2 city6U2 city5U2 city4U2
             city3U2 city2U2 city1U2)
   (:init (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city23)
          (city city22)
          (city city21)
          (city city20)
          (city city19)
          (city city18)
          (city city17)
          (city city16)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city23U1)
          (location city22U1)
          (location city21U1)
          (location city20U1)
          (location city19U1)
          (location city18U1)
          (location city17U1)
          (location city16U1)
          (location city15U1)
          (location city14U1)
          (location city13U1)
          (location city12U1)
          (location city11U1)
          (location city10U1)
          (location city9U1)
          (location city8U1)
          (location city7U1)
          (location city6U1)
          (location city5U1)
          (location city4U1)
          (location city3U1)
          (location city2U1)
          (location city1U1)
          (airport city23U2)
          (location city23U2)
          (airport city22U2)
          (location city22U2)
          (airport city21U2)
          (location city21U2)
          (airport city20U2)
          (location city20U2)
          (airport city19U2)
          (location city19U2)
          (airport city18U2)
          (location city18U2)
          (airport city17U2)
          (location city17U2)
          (airport city16U2)
          (location city16U2)
          (airport city15U2)
          (location city15U2)
          (airport city14U2)
          (location city14U2)
          (airport city13U2)
          (location city13U2)
          (airport city12U2)
          (location city12U2)
          (airport city11U2)
          (location city11U2)
          (airport city10U2)
          (location city10U2)
          (airport city9U2)
          (location city9U2)
          (airport city8U2)
          (location city8U2)
          (airport city7U2)
          (location city7U2)
          (airport city6U2)
          (location city6U2)
          (airport city5U2)
          (location city5U2)
          (airport city4U2)
          (location city4U2)
          (airport city3U2)
          (location city3U2)
          (airport city2U2)
          (location city2U2)
          (airport city1U2)
          (location city1U2)
          (inUcity city23U2 city23)
          (inUcity city23U1 city23)
          (inUcity city22U2 city22)
          (inUcity city22U1 city22)
          (inUcity city21U2 city21)
          (inUcity city21U1 city21)
          (inUcity city20U2 city20)
          (inUcity city20U1 city20)
          (inUcity city19U2 city19)
          (inUcity city19U1 city19)
          (inUcity city18U2 city18)
          (inUcity city18U1 city18)
          (inUcity city17U2 city17)
          (inUcity city17U1 city17)
          (inUcity city16U2 city16)
          (inUcity city16U1 city16)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane4 city11U2)
          (at plane3 city13U2)
          (at plane2 city18U2)
          (at plane1 city16U2)
          (at truck23 city23U1)
          (at truck22 city22U1)
          (at truck21 city21U1)
          (at truck20 city20U1)
          (at truck19 city19U1)
          (at truck18 city18U1)
          (at truck17 city17U1)
          (at truck16 city16U1)
          (at truck15 city15U1)
          (at truck14 city14U1)
          (at truck13 city13U1)
          (at truck12 city12U1)
          (at truck11 city11U1)
          (at truck10 city10U1)
          (at truck9 city9U1)
          (at truck8 city8U1)
          (at truck7 city7U1)
          (at truck6 city6U1)
          (at truck5 city5U1)
          (at truck4 city4U1)
          (at truck3 city3U1)
          (at truck2 city2U1)
          (at truck1 city1U1)
          (at package17 city8U2)
          (at package16 city13U2)
          (at package15 city15U2)
          (at package14 city3U2)
          (at package13 city14U2)
          (at package12 city5U1)
          (at package11 city16U1)
          (at package10 city3U2)
          (at package9 city21U1)
          (at package8 city8U1)
          (at package7 city11U1)
          (at package6 city15U2)
          (at package5 city6U1)
          (at package4 city7U1)
          (at package3 city19U1)
          (at package2 city22U1)
          (at package1 city13U1))
   (:goal (and (at package17 city3U1)
               (at package16 city4U2)
               (at package15 city19U1)
               (at package14 city9U1)
               (at package13 city3U2)
               (at package12 city21U1)
               (at package11 city21U2)
               (at package10 city9U2)
               (at package9 city20U2)
               (at package8 city13U2)
               (at package7 city3U1)
               (at package6 city15U2)
               (at package5 city8U1)
               (at package4 city1U1)
               (at package3 city9U2)
               (at package2 city2U1)
               (at package1 city13U1))))

(define (problem stripsUlogUxU11)
   (:domain logisticsUstrips)
   (:objects package8 package7 package6 package5 package4 package3
             package2 package1 city3 city2 city1 truck22 truck21 truck20
             truck19 truck18 truck17 truck16 truck15 truck14 truck13
             truck12 truck11 truck10 truck9 truck8 truck7 truck6 truck5
             truck4 truck3 truck2 truck1 plane6 plane5 plane4 plane3 plane2
             plane1 city3U2 city3U1 city2U2 city2U1 city1U2 city1U1
             city3U3 city2U3 city1U3)
   (:init (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city3)
          (city city2)
          (city city1)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city3U2)
          (location city3U1)
          (location city2U2)
          (location city2U1)
          (location city1U2)
          (location city1U1)
          (airport city3U3)
          (location city3U3)
          (airport city2U3)
          (location city2U3)
          (airport city1U3)
          (location city1U3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane6 city2U3)
          (at plane5 city1U3)
          (at plane4 city3U3)
          (at plane3 city2U3)
          (at plane2 city2U3)
          (at plane1 city1U3)
          (at truck22 city3U2)
          (at truck21 city2U1)
          (at truck20 city1U2)
          (at truck19 city2U3)
          (at truck18 city1U2)
          (at truck17 city2U2)
          (at truck16 city2U1)
          (at truck15 city2U3)
          (at truck14 city2U2)
          (at truck13 city1U2)
          (at truck12 city2U2)
          (at truck11 city3U3)
          (at truck10 city3U1)
          (at truck9 city2U3)
          (at truck8 city3U3)
          (at truck7 city2U3)
          (at truck6 city2U3)
          (at truck5 city2U3)
          (at truck4 city3U2)
          (at truck3 city2U2)
          (at truck2 city1U1)
          (at truck1 city2U3)
          (at package8 city1U2)
          (at package7 city2U1)
          (at package6 city3U2)
          (at package5 city1U3)
          (at package4 city3U3)
          (at package3 city2U2)
          (at package2 city3U2)
          (at package1 city1U3))
   (:goal (and (at package8 city3U3)
               (at package7 city3U3)
               (at package6 city3U2)
               (at package5 city1U3)
               (at package4 city3U3)
               (at package3 city1U2)
               (at package2 city2U3)
               (at package1 city1U1))))

(define (problem stripsUlogUxU12)
   (:domain logisticsUstrips)
   (:objects package5 package4 package3 package2 package1 city27
             city26 city25 city24 city23 city22 city21 city20 city19 city18
             city17 city16 city15 city14 city13 city12 city11 city10 city9
             city8 city7 city6 city5 city4 city3 city2 city1 truck55
             truck54 truck53 truck52 truck51 truck50 truck49 truck48
             truck47 truck46 truck45 truck44 truck43 truck42 truck41
             truck40 truck39 truck38 truck37 truck36 truck35 truck34
             truck33 truck32 truck31 truck30 truck29 truck28 truck27
             truck26 truck25 truck24 truck23 truck22 truck21 truck20
             truck19 truck18 truck17 truck16 truck15 truck14 truck13
             truck12 truck11 truck10 truck9 truck8 truck7 truck6 truck5
             truck4 truck3 truck2 truck1 plane9 plane8 plane7 plane6 plane5
             plane4 plane3 plane2 plane1 city27U3 city27U2 city27U1
             city26U3 city26U2 city26U1 city25U3 city25U2 city25U1 city24U3
             city24U2 city24U1 city23U3 city23U2 city23U1 city22U3 city22U2
             city22U1 city21U3 city21U2 city21U1 city20U3 city20U2 city20U1
             city19U3 city19U2 city19U1 city18U3 city18U2 city18U1 city17U3
             city17U2 city17U1 city16U3 city16U2 city16U1 city15U3 city15U2
             city15U1 city14U3 city14U2 city14U1 city13U3 city13U2 city13U1
             city12U3 city12U2 city12U1 city11U3 city11U2 city11U1 city10U3
             city10U2 city10U1 city9U3 city9U2 city9U1 city8U3 city8U2
             city8U1 city7U3 city7U2 city7U1 city6U3 city6U2 city6U1
             city5U3 city5U2 city5U1 city4U3 city4U2 city4U1 city3U3
             city3U2 city3U1 city2U3 city2U2 city2U1 city1U3 city1U2
             city1U1 city27U4 city26U4 city25U4 city24U4 city23U4 city22U4
             city21U4 city20U4 city19U4 city18U4 city17U4 city16U4 city15U4
             city14U4 city13U4 city12U4 city11U4 city10U4 city9U4 city8U4
             city7U4 city6U4 city5U4 city4U4 city3U4 city2U4 city1U4)
   (:init (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city27)
          (city city26)
          (city city25)
          (city city24)
          (city city23)
          (city city22)
          (city city21)
          (city city20)
          (city city19)
          (city city18)
          (city city17)
          (city city16)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck55)
          (truck truck54)
          (truck truck53)
          (truck truck52)
          (truck truck51)
          (truck truck50)
          (truck truck49)
          (truck truck48)
          (truck truck47)
          (truck truck46)
          (truck truck45)
          (truck truck44)
          (truck truck43)
          (truck truck42)
          (truck truck41)
          (truck truck40)
          (truck truck39)
          (truck truck38)
          (truck truck37)
          (truck truck36)
          (truck truck35)
          (truck truck34)
          (truck truck33)
          (truck truck32)
          (truck truck31)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane9)
          (airplane plane8)
          (airplane plane7)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city27U3)
          (location city27U2)
          (location city27U1)
          (location city26U3)
          (location city26U2)
          (location city26U1)
          (location city25U3)
          (location city25U2)
          (location city25U1)
          (location city24U3)
          (location city24U2)
          (location city24U1)
          (location city23U3)
          (location city23U2)
          (location city23U1)
          (location city22U3)
          (location city22U2)
          (location city22U1)
          (location city21U3)
          (location city21U2)
          (location city21U1)
          (location city20U3)
          (location city20U2)
          (location city20U1)
          (location city19U3)
          (location city19U2)
          (location city19U1)
          (location city18U3)
          (location city18U2)
          (location city18U1)
          (location city17U3)
          (location city17U2)
          (location city17U1)
          (location city16U3)
          (location city16U2)
          (location city16U1)
          (location city15U3)
          (location city15U2)
          (location city15U1)
          (location city14U3)
          (location city14U2)
          (location city14U1)
          (location city13U3)
          (location city13U2)
          (location city13U1)
          (location city12U3)
          (location city12U2)
          (location city12U1)
          (location city11U3)
          (location city11U2)
          (location city11U1)
          (location city10U3)
          (location city10U2)
          (location city10U1)
          (location city9U3)
          (location city9U2)
          (location city9U1)
          (location city8U3)
          (location city8U2)
          (location city8U1)
          (location city7U3)
          (location city7U2)
          (location city7U1)
          (location city6U3)
          (location city6U2)
          (location city6U1)
          (location city5U3)
          (location city5U2)
          (location city5U1)
          (location city4U3)
          (location city4U2)
          (location city4U1)
          (location city3U3)
          (location city3U2)
          (location city3U1)
          (location city2U3)
          (location city2U2)
          (location city2U1)
          (location city1U3)
          (location city1U2)
          (location city1U1)
          (airport city27U4)
          (location city27U4)
          (airport city26U4)
          (location city26U4)
          (airport city25U4)
          (location city25U4)
          (airport city24U4)
          (location city24U4)
          (airport city23U4)
          (location city23U4)
          (airport city22U4)
          (location city22U4)
          (airport city21U4)
          (location city21U4)
          (airport city20U4)
          (location city20U4)
          (airport city19U4)
          (location city19U4)
          (airport city18U4)
          (location city18U4)
          (airport city17U4)
          (location city17U4)
          (airport city16U4)
          (location city16U4)
          (airport city15U4)
          (location city15U4)
          (airport city14U4)
          (location city14U4)
          (airport city13U4)
          (location city13U4)
          (airport city12U4)
          (location city12U4)
          (airport city11U4)
          (location city11U4)
          (airport city10U4)
          (location city10U4)
          (airport city9U4)
          (location city9U4)
          (airport city8U4)
          (location city8U4)
          (airport city7U4)
          (location city7U4)
          (airport city6U4)
          (location city6U4)
          (airport city5U4)
          (location city5U4)
          (airport city4U4)
          (location city4U4)
          (airport city3U4)
          (location city3U4)
          (airport city2U4)
          (location city2U4)
          (airport city1U4)
          (location city1U4)
          (inUcity city27U4 city27)
          (inUcity city27U3 city27)
          (inUcity city27U2 city27)
          (inUcity city27U1 city27)
          (inUcity city26U4 city26)
          (inUcity city26U3 city26)
          (inUcity city26U2 city26)
          (inUcity city26U1 city26)
          (inUcity city25U4 city25)
          (inUcity city25U3 city25)
          (inUcity city25U2 city25)
          (inUcity city25U1 city25)
          (inUcity city24U4 city24)
          (inUcity city24U3 city24)
          (inUcity city24U2 city24)
          (inUcity city24U1 city24)
          (inUcity city23U4 city23)
          (inUcity city23U3 city23)
          (inUcity city23U2 city23)
          (inUcity city23U1 city23)
          (inUcity city22U4 city22)
          (inUcity city22U3 city22)
          (inUcity city22U2 city22)
          (inUcity city22U1 city22)
          (inUcity city21U4 city21)
          (inUcity city21U3 city21)
          (inUcity city21U2 city21)
          (inUcity city21U1 city21)
          (inUcity city20U4 city20)
          (inUcity city20U3 city20)
          (inUcity city20U2 city20)
          (inUcity city20U1 city20)
          (inUcity city19U4 city19)
          (inUcity city19U3 city19)
          (inUcity city19U2 city19)
          (inUcity city19U1 city19)
          (inUcity city18U4 city18)
          (inUcity city18U3 city18)
          (inUcity city18U2 city18)
          (inUcity city18U1 city18)
          (inUcity city17U4 city17)
          (inUcity city17U3 city17)
          (inUcity city17U2 city17)
          (inUcity city17U1 city17)
          (inUcity city16U4 city16)
          (inUcity city16U3 city16)
          (inUcity city16U2 city16)
          (inUcity city16U1 city16)
          (inUcity city15U4 city15)
          (inUcity city15U3 city15)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U4 city14)
          (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U4 city13)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U4 city12)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U4 city11)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U4 city10)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U4 city9)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane9 city7U4)
          (at plane8 city2U4)
          (at plane7 city14U4)
          (at plane6 city25U4)
          (at plane5 city23U4)
          (at plane4 city2U4)
          (at plane3 city13U4)
          (at plane2 city1U4)
          (at plane1 city23U4)
          (at truck55 city27U2)
          (at truck54 city26U3)
          (at truck53 city25U2)
          (at truck52 city24U3)
          (at truck51 city23U1)
          (at truck50 city22U2)
          (at truck49 city21U1)
          (at truck48 city20U2)
          (at truck47 city19U1)
          (at truck46 city18U3)
          (at truck45 city17U1)
          (at truck44 city16U3)
          (at truck43 city15U1)
          (at truck42 city14U3)
          (at truck41 city13U1)
          (at truck40 city12U3)
          (at truck39 city11U2)
          (at truck38 city10U1)
          (at truck37 city9U2)
          (at truck36 city8U1)
          (at truck35 city7U2)
          (at truck34 city6U1)
          (at truck33 city5U1)
          (at truck32 city4U1)
          (at truck31 city3U3)
          (at truck30 city2U2)
          (at truck29 city1U2)
          (at truck28 city10U4)
          (at truck27 city7U3)
          (at truck26 city12U4)
          (at truck25 city7U1)
          (at truck24 city11U3)
          (at truck23 city15U3)
          (at truck22 city8U4)
          (at truck21 city8U3)
          (at truck20 city10U1)
          (at truck19 city22U4)
          (at truck18 city25U2)
          (at truck17 city14U2)
          (at truck16 city15U3)
          (at truck15 city25U3)
          (at truck14 city2U3)
          (at truck13 city12U3)
          (at truck12 city19U4)
          (at truck11 city14U2)
          (at truck10 city11U3)
          (at truck9 city24U2)
          (at truck8 city3U3)
          (at truck7 city22U2)
          (at truck6 city25U2)
          (at truck5 city23U3)
          (at truck4 city8U4)
          (at truck3 city3U4)
          (at truck2 city3U3)
          (at truck1 city15U4)
          (at package5 city12U1)
          (at package4 city7U2)
          (at package3 city8U1)
          (at package2 city23U3)
          (at package1 city1U4))
   (:goal (and (at package5 city18U4)
               (at package4 city10U3)
               (at package3 city1U4)
               (at package2 city14U3)
               (at package1 city9U2))))

(define (problem stripsUlogUxU13)
   (:domain logisticsUstrips)
   (:objects package23 package22 package21 package20 package19
             package18 package17 package16 package15 package14 package13
             package12 package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 city29
             city28 city27 city26 city25 city24 city23 city22 city21 city20
             city19 city18 city17 city16 city15 city14 city13 city12 city11
             city10 city9 city8 city7 city6 city5 city4 city3 city2 city1
             truck29 truck28 truck27 truck26 truck25 truck24 truck23
             truck22 truck21 truck20 truck19 truck18 truck17 truck16
             truck15 truck14 truck13 truck12 truck11 truck10 truck9 truck8
             truck7 truck6 truck5 truck4 truck3 truck2 truck1 plane9 plane8
             plane7 plane6 plane5 plane4 plane3 plane2 plane1 city29U3
             city29U2 city29U1 city28U3 city28U2 city28U1 city27U3 city27U2
             city27U1 city26U3 city26U2 city26U1 city25U3 city25U2 city25U1
             city24U3 city24U2 city24U1 city23U3 city23U2 city23U1 city22U3
             city22U2 city22U1 city21U3 city21U2 city21U1 city20U3 city20U2
             city20U1 city19U3 city19U2 city19U1 city18U3 city18U2 city18U1
             city17U3 city17U2 city17U1 city16U3 city16U2 city16U1 city15U3
             city15U2 city15U1 city14U3 city14U2 city14U1 city13U3 city13U2
             city13U1 city12U3 city12U2 city12U1 city11U3 city11U2 city11U1
             city10U3 city10U2 city10U1 city9U3 city9U2 city9U1 city8U3
             city8U2 city8U1 city7U3 city7U2 city7U1 city6U3 city6U2
             city6U1 city5U3 city5U2 city5U1 city4U3 city4U2 city4U1
             city3U3 city3U2 city3U1 city2U3 city2U2 city2U1 city1U3
             city1U2 city1U1 city29U4 city28U4 city27U4 city26U4 city25U4
             city24U4 city23U4 city22U4 city21U4 city20U4 city19U4 city18U4
             city17U4 city16U4 city15U4 city14U4 city13U4 city12U4 city11U4
             city10U4 city9U4 city8U4 city7U4 city6U4 city5U4 city4U4
             city3U4 city2U4 city1U4)
   (:init (obj package23)
          (obj package22)
          (obj package21)
          (obj package20)
          (obj package19)
          (obj package18)
          (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city29)
          (city city28)
          (city city27)
          (city city26)
          (city city25)
          (city city24)
          (city city23)
          (city city22)
          (city city21)
          (city city20)
          (city city19)
          (city city18)
          (city city17)
          (city city16)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane9)
          (airplane plane8)
          (airplane plane7)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city29U3)
          (location city29U2)
          (location city29U1)
          (location city28U3)
          (location city28U2)
          (location city28U1)
          (location city27U3)
          (location city27U2)
          (location city27U1)
          (location city26U3)
          (location city26U2)
          (location city26U1)
          (location city25U3)
          (location city25U2)
          (location city25U1)
          (location city24U3)
          (location city24U2)
          (location city24U1)
          (location city23U3)
          (location city23U2)
          (location city23U1)
          (location city22U3)
          (location city22U2)
          (location city22U1)
          (location city21U3)
          (location city21U2)
          (location city21U1)
          (location city20U3)
          (location city20U2)
          (location city20U1)
          (location city19U3)
          (location city19U2)
          (location city19U1)
          (location city18U3)
          (location city18U2)
          (location city18U1)
          (location city17U3)
          (location city17U2)
          (location city17U1)
          (location city16U3)
          (location city16U2)
          (location city16U1)
          (location city15U3)
          (location city15U2)
          (location city15U1)
          (location city14U3)
          (location city14U2)
          (location city14U1)
          (location city13U3)
          (location city13U2)
          (location city13U1)
          (location city12U3)
          (location city12U2)
          (location city12U1)
          (location city11U3)
          (location city11U2)
          (location city11U1)
          (location city10U3)
          (location city10U2)
          (location city10U1)
          (location city9U3)
          (location city9U2)
          (location city9U1)
          (location city8U3)
          (location city8U2)
          (location city8U1)
          (location city7U3)
          (location city7U2)
          (location city7U1)
          (location city6U3)
          (location city6U2)
          (location city6U1)
          (location city5U3)
          (location city5U2)
          (location city5U1)
          (location city4U3)
          (location city4U2)
          (location city4U1)
          (location city3U3)
          (location city3U2)
          (location city3U1)
          (location city2U3)
          (location city2U2)
          (location city2U1)
          (location city1U3)
          (location city1U2)
          (location city1U1)
          (airport city29U4)
          (location city29U4)
          (airport city28U4)
          (location city28U4)
          (airport city27U4)
          (location city27U4)
          (airport city26U4)
          (location city26U4)
          (airport city25U4)
          (location city25U4)
          (airport city24U4)
          (location city24U4)
          (airport city23U4)
          (location city23U4)
          (airport city22U4)
          (location city22U4)
          (airport city21U4)
          (location city21U4)
          (airport city20U4)
          (location city20U4)
          (airport city19U4)
          (location city19U4)
          (airport city18U4)
          (location city18U4)
          (airport city17U4)
          (location city17U4)
          (airport city16U4)
          (location city16U4)
          (airport city15U4)
          (location city15U4)
          (airport city14U4)
          (location city14U4)
          (airport city13U4)
          (location city13U4)
          (airport city12U4)
          (location city12U4)
          (airport city11U4)
          (location city11U4)
          (airport city10U4)
          (location city10U4)
          (airport city9U4)
          (location city9U4)
          (airport city8U4)
          (location city8U4)
          (airport city7U4)
          (location city7U4)
          (airport city6U4)
          (location city6U4)
          (airport city5U4)
          (location city5U4)
          (airport city4U4)
          (location city4U4)
          (airport city3U4)
          (location city3U4)
          (airport city2U4)
          (location city2U4)
          (airport city1U4)
          (location city1U4)
          (inUcity city29U4 city29)
          (inUcity city29U3 city29)
          (inUcity city29U2 city29)
          (inUcity city29U1 city29)
          (inUcity city28U4 city28)
          (inUcity city28U3 city28)
          (inUcity city28U2 city28)
          (inUcity city28U1 city28)
          (inUcity city27U4 city27)
          (inUcity city27U3 city27)
          (inUcity city27U2 city27)
          (inUcity city27U1 city27)
          (inUcity city26U4 city26)
          (inUcity city26U3 city26)
          (inUcity city26U2 city26)
          (inUcity city26U1 city26)
          (inUcity city25U4 city25)
          (inUcity city25U3 city25)
          (inUcity city25U2 city25)
          (inUcity city25U1 city25)
          (inUcity city24U4 city24)
          (inUcity city24U3 city24)
          (inUcity city24U2 city24)
          (inUcity city24U1 city24)
          (inUcity city23U4 city23)
          (inUcity city23U3 city23)
          (inUcity city23U2 city23)
          (inUcity city23U1 city23)
          (inUcity city22U4 city22)
          (inUcity city22U3 city22)
          (inUcity city22U2 city22)
          (inUcity city22U1 city22)
          (inUcity city21U4 city21)
          (inUcity city21U3 city21)
          (inUcity city21U2 city21)
          (inUcity city21U1 city21)
          (inUcity city20U4 city20)
          (inUcity city20U3 city20)
          (inUcity city20U2 city20)
          (inUcity city20U1 city20)
          (inUcity city19U4 city19)
          (inUcity city19U3 city19)
          (inUcity city19U2 city19)
          (inUcity city19U1 city19)
          (inUcity city18U4 city18)
          (inUcity city18U3 city18)
          (inUcity city18U2 city18)
          (inUcity city18U1 city18)
          (inUcity city17U4 city17)
          (inUcity city17U3 city17)
          (inUcity city17U2 city17)
          (inUcity city17U1 city17)
          (inUcity city16U4 city16)
          (inUcity city16U3 city16)
          (inUcity city16U2 city16)
          (inUcity city16U1 city16)
          (inUcity city15U4 city15)
          (inUcity city15U3 city15)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U4 city14)
          (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U4 city13)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U4 city12)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U4 city11)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U4 city10)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U4 city9)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane9 city28U4)
          (at plane8 city23U4)
          (at plane7 city27U4)
          (at plane6 city29U4)
          (at plane5 city13U4)
          (at plane4 city4U4)
          (at plane3 city14U4)
          (at plane2 city14U4)
          (at plane1 city13U4)
          (at truck29 city29U1)
          (at truck28 city28U2)
          (at truck27 city27U3)
          (at truck26 city26U1)
          (at truck25 city25U2)
          (at truck24 city24U3)
          (at truck23 city23U3)
          (at truck22 city22U3)
          (at truck21 city21U1)
          (at truck20 city20U1)
          (at truck19 city19U3)
          (at truck18 city18U2)
          (at truck17 city17U3)
          (at truck16 city16U2)
          (at truck15 city15U3)
          (at truck14 city14U3)
          (at truck13 city13U2)
          (at truck12 city12U3)
          (at truck11 city11U1)
          (at truck10 city10U2)
          (at truck9 city9U3)
          (at truck8 city8U2)
          (at truck7 city7U3)
          (at truck6 city6U3)
          (at truck5 city5U3)
          (at truck4 city4U2)
          (at truck3 city3U2)
          (at truck2 city2U3)
          (at truck1 city1U1)
          (at package23 city26U2)
          (at package22 city1U1)
          (at package21 city3U1)
          (at package20 city18U2)
          (at package19 city17U2)
          (at package18 city21U1)
          (at package17 city1U4)
          (at package16 city29U4)
          (at package15 city1U2)
          (at package14 city4U4)
          (at package13 city10U1)
          (at package12 city13U1)
          (at package11 city24U3)
          (at package10 city5U4)
          (at package9 city9U4)
          (at package8 city3U4)
          (at package7 city13U1)
          (at package6 city7U3)
          (at package5 city16U1)
          (at package4 city3U2)
          (at package3 city17U1)
          (at package2 city11U1)
          (at package1 city21U4))
   (:goal (and (at package23 city7U4)
               (at package22 city11U3)
               (at package21 city16U4)
               (at package20 city4U4)
               (at package19 city21U2)
               (at package18 city22U1)
               (at package17 city18U3)
               (at package16 city14U3))))

(define (problem stripsUlogUxU14)
   (:domain logisticsUstrips)
   (:objects package29 package28 package27 package26 package25
             package24 package23 package22 package21 package20 package19
             package18 package17 package16 package15 package14 package13
             package12 package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 city11
             city10 city9 city8 city7 city6 city5 city4 city3 city2 city1
             truck47 truck46 truck45 truck44 truck43 truck42 truck41
             truck40 truck39 truck38 truck37 truck36 truck35 truck34
             truck33 truck32 truck31 truck30 truck29 truck28 truck27
             truck26 truck25 truck24 truck23 truck22 truck21 truck20
             truck19 truck18 truck17 truck16 truck15 truck14 truck13
             truck12 truck11 truck10 truck9 truck8 truck7 truck6 truck5
             truck4 truck3 truck2 truck1 plane8 plane7 plane6 plane5 plane4
             plane3 plane2 plane1 city11U1 city10U1 city9U1 city8U1
             city7U1 city6U1 city5U1 city4U1 city3U1 city2U1 city1U1
             city11U2 city10U2 city9U2 city8U2 city7U2 city6U2 city5U2
             city4U2 city3U2 city2U2 city1U2)
   (:init (obj package29)
          (obj package28)
          (obj package27)
          (obj package26)
          (obj package25)
          (obj package24)
          (obj package23)
          (obj package22)
          (obj package21)
          (obj package20)
          (obj package19)
          (obj package18)
          (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck47)
          (truck truck46)
          (truck truck45)
          (truck truck44)
          (truck truck43)
          (truck truck42)
          (truck truck41)
          (truck truck40)
          (truck truck39)
          (truck truck38)
          (truck truck37)
          (truck truck36)
          (truck truck35)
          (truck truck34)
          (truck truck33)
          (truck truck32)
          (truck truck31)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane8)
          (airplane plane7)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city11U1)
          (location city10U1)
          (location city9U1)
          (location city8U1)
          (location city7U1)
          (location city6U1)
          (location city5U1)
          (location city4U1)
          (location city3U1)
          (location city2U1)
          (location city1U1)
          (airport city11U2)
          (location city11U2)
          (airport city10U2)
          (location city10U2)
          (airport city9U2)
          (location city9U2)
          (airport city8U2)
          (location city8U2)
          (airport city7U2)
          (location city7U2)
          (airport city6U2)
          (location city6U2)
          (airport city5U2)
          (location city5U2)
          (airport city4U2)
          (location city4U2)
          (airport city3U2)
          (location city3U2)
          (airport city2U2)
          (location city2U2)
          (airport city1U2)
          (location city1U2)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane8 city9U2)
          (at plane7 city4U2)
          (at plane6 city1U2)
          (at plane5 city2U2)
          (at plane4 city4U2)
          (at plane3 city11U2)
          (at plane2 city2U2)
          (at plane1 city6U2)
          (at truck47 city11U1)
          (at truck46 city10U1)
          (at truck45 city9U1)
          (at truck44 city8U1)
          (at truck43 city7U1)
          (at truck42 city6U1)
          (at truck41 city5U1)
          (at truck40 city4U1)
          (at truck39 city3U1)
          (at truck38 city2U1)
          (at truck37 city1U1)
          (at truck36 city1U1)
          (at truck35 city4U1)
          (at truck34 city7U1)
          (at truck33 city7U1)
          (at truck32 city10U2)
          (at truck31 city3U2)
          (at truck30 city6U2)
          (at truck29 city6U2)
          (at truck28 city10U1)
          (at truck27 city10U1)
          (at truck26 city8U1)
          (at truck25 city10U1)
          (at truck24 city6U1)
          (at truck23 city5U2)
          (at truck22 city9U2)
          (at truck21 city4U2)
          (at truck20 city2U2)
          (at truck19 city8U1)
          (at truck18 city4U2)
          (at truck17 city3U1)
          (at truck16 city2U1)
          (at truck15 city2U2)
          (at truck14 city6U2)
          (at truck13 city10U2)
          (at truck12 city10U2)
          (at truck11 city7U2)
          (at truck10 city2U1)
          (at truck9 city3U2)
          (at truck8 city1U2)
          (at truck7 city3U1)
          (at truck6 city8U2)
          (at truck5 city7U1)
          (at truck4 city8U2)
          (at truck3 city1U2)
          (at truck2 city1U1)
          (at truck1 city2U1)
          (at package29 city10U1)
          (at package28 city4U2)
          (at package27 city10U2)
          (at package26 city6U1)
          (at package25 city6U2)
          (at package24 city8U2)
          (at package23 city1U1)
          (at package22 city9U1)
          (at package21 city9U2)
          (at package20 city6U2)
          (at package19 city9U1)
          (at package18 city2U2)
          (at package17 city4U2)
          (at package16 city2U2)
          (at package15 city1U2)
          (at package14 city9U1)
          (at package13 city7U1)
          (at package12 city9U2)
          (at package11 city6U2)
          (at package10 city8U2)
          (at package9 city1U2)
          (at package8 city8U1)
          (at package7 city8U2)
          (at package6 city1U2)
          (at package5 city2U2)
          (at package4 city10U2)
          (at package3 city11U1)
          (at package2 city11U1)
          (at package1 city11U2))
   (:goal (and (at package29 city5U2)
               (at package28 city11U2)
               (at package27 city10U1)
               (at package26 city9U1)
               (at package25 city4U1)
               (at package24 city8U2)
               (at package23 city10U2)
               (at package22 city1U2)
               (at package21 city1U1)
               (at package20 city4U1)
               (at package19 city6U1)
               (at package18 city9U1)
               (at package17 city4U1)
               (at package16 city11U1)
               (at package15 city2U2)
               (at package14 city8U2)
               (at package13 city10U2)
               (at package12 city11U2)
               (at package11 city2U2))))

(define (problem stripsUlogUxU15)
   (:domain logisticsUstrips)
   (:objects package23 package22 package21 package20 package19
             package18 package17 package16 package15 package14 package13
             package12 package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 city3
             city2 city1 truck5 truck4 truck3 truck2 truck1 plane7 plane6
             plane5 plane4 plane3 plane2 plane1 city3U5 city3U4 city3U3
             city3U2 city3U1 city2U5 city2U4 city2U3 city2U2 city2U1
             city1U5 city1U4 city1U3 city1U2 city1U1 city3U6 city2U6
             city1U6)
   (:init (obj package23)
          (obj package22)
          (obj package21)
          (obj package20)
          (obj package19)
          (obj package18)
          (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city3)
          (city city2)
          (city city1)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane7)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city3U5)
          (location city3U4)
          (location city3U3)
          (location city3U2)
          (location city3U1)
          (location city2U5)
          (location city2U4)
          (location city2U3)
          (location city2U2)
          (location city2U1)
          (location city1U5)
          (location city1U4)
          (location city1U3)
          (location city1U2)
          (location city1U1)
          (airport city3U6)
          (location city3U6)
          (airport city2U6)
          (location city2U6)
          (airport city1U6)
          (location city1U6)
          (inUcity city3U6 city3)
          (inUcity city3U5 city3)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U6 city2)
          (inUcity city2U5 city2)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U6 city1)
          (inUcity city1U5 city1)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane7 city1U6)
          (at plane6 city2U6)
          (at plane5 city1U6)
          (at plane4 city1U6)
          (at plane3 city3U6)
          (at plane2 city1U6)
          (at plane1 city2U6)
          (at truck5 city3U4)
          (at truck4 city2U3)
          (at truck3 city1U5)
          (at truck2 city1U3)
          (at truck1 city1U6)
          (at package23 city1U5)
          (at package22 city1U5)
          (at package21 city2U4)
          (at package20 city2U3)
          (at package19 city1U2)
          (at package18 city3U3)
          (at package17 city2U3)
          (at package16 city3U5)
          (at package15 city2U2)
          (at package14 city2U1)
          (at package13 city3U4)
          (at package12 city1U6)
          (at package11 city1U4)
          (at package10 city3U3)
          (at package9 city3U3)
          (at package8 city1U2)
          (at package7 city1U4)
          (at package6 city1U4)
          (at package5 city3U1)
          (at package4 city2U1)
          (at package3 city1U5)
          (at package2 city3U3)
          (at package1 city1U2))
   (:goal (and (at package23 city2U3)
               (at package22 city1U5)
               (at package21 city1U6)
               (at package20 city1U1)
               (at package19 city1U3)
               (at package18 city1U3)
               (at package17 city1U5)
               (at package16 city1U1)
               (at package15 city3U3)
               (at package14 city1U5)
               (at package13 city2U5)
               (at package12 city3U2)
               (at package11 city2U6)
               (at package10 city1U6))))

(define (problem stripsUlogUxU16)
   (:domain logisticsUstrips)
   (:objects package7 package6 package5 package4 package3 package2
             package1 city11 city10 city9 city8 city7 city6 city5 city4 city3
             city2 city1 truck52 truck51 truck50 truck49 truck48 truck47
             truck46 truck45 truck44 truck43 truck42 truck41 truck40
             truck39 truck38 truck37 truck36 truck35 truck34 truck33
             truck32 truck31 truck30 truck29 truck28 truck27 truck26
             truck25 truck24 truck23 truck22 truck21 truck20 truck19
             truck18 truck17 truck16 truck15 truck14 truck13 truck12
             truck11 truck10 truck9 truck8 truck7 truck6 truck5 truck4
             truck3 truck2 truck1 plane13 plane12 plane11 plane10 plane9
             plane8 plane7 plane6 plane5 plane4 plane3 plane2 plane1
             city11U2 city11U1 city10U2 city10U1 city9U2 city9U1 city8U2
             city8U1 city7U2 city7U1 city6U2 city6U1 city5U2 city5U1
             city4U2 city4U1 city3U2 city3U1 city2U2 city2U1 city1U2
             city1U1 city11U3 city10U3 city9U3 city8U3 city7U3 city6U3
             city5U3 city4U3 city3U3 city2U3 city1U3)
   (:init (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck52)
          (truck truck51)
          (truck truck50)
          (truck truck49)
          (truck truck48)
          (truck truck47)
          (truck truck46)
          (truck truck45)
          (truck truck44)
          (truck truck43)
          (truck truck42)
          (truck truck41)
          (truck truck40)
          (truck truck39)
          (truck truck38)
          (truck truck37)
          (truck truck36)
          (truck truck35)
          (truck truck34)
          (truck truck33)
          (truck truck32)
          (truck truck31)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane13)
          (airplane plane12)
          (airplane plane11)
          (airplane plane10)
          (airplane plane9)
          (airplane plane8)
          (airplane plane7)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city11U2)
          (location city11U1)
          (location city10U2)
          (location city10U1)
          (location city9U2)
          (location city9U1)
          (location city8U2)
          (location city8U1)
          (location city7U2)
          (location city7U1)
          (location city6U2)
          (location city6U1)
          (location city5U2)
          (location city5U1)
          (location city4U2)
          (location city4U1)
          (location city3U2)
          (location city3U1)
          (location city2U2)
          (location city2U1)
          (location city1U2)
          (location city1U1)
          (airport city11U3)
          (location city11U3)
          (airport city10U3)
          (location city10U3)
          (airport city9U3)
          (location city9U3)
          (airport city8U3)
          (location city8U3)
          (airport city7U3)
          (location city7U3)
          (airport city6U3)
          (location city6U3)
          (airport city5U3)
          (location city5U3)
          (airport city4U3)
          (location city4U3)
          (airport city3U3)
          (location city3U3)
          (airport city2U3)
          (location city2U3)
          (airport city1U3)
          (location city1U3)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane13 city10U3)
          (at plane12 city5U3)
          (at plane11 city11U3)
          (at plane10 city1U3)
          (at plane9 city9U3)
          (at plane8 city7U3)
          (at plane7 city1U3)
          (at plane6 city8U3)
          (at plane5 city7U3)
          (at plane4 city9U3)
          (at plane3 city1U3)
          (at plane2 city11U3)
          (at plane1 city6U3)
          (at truck52 city11U2)
          (at truck51 city10U1)
          (at truck50 city9U2)
          (at truck49 city8U1)
          (at truck48 city7U1)
          (at truck47 city6U1)
          (at truck46 city5U2)
          (at truck45 city4U1)
          (at truck44 city3U2)
          (at truck43 city2U2)
          (at truck42 city1U2)
          (at truck41 city7U2)
          (at truck40 city6U1)
          (at truck39 city2U3)
          (at truck38 city3U1)
          (at truck37 city2U3)
          (at truck36 city7U1)
          (at truck35 city8U2)
          (at truck34 city8U2)
          (at truck33 city7U2)
          (at truck32 city6U3)
          (at truck31 city2U2)
          (at truck30 city11U3)
          (at truck29 city1U2)
          (at truck28 city3U1)
          (at truck27 city9U2)
          (at truck26 city7U2)
          (at truck25 city1U3)
          (at truck24 city4U1)
          (at truck23 city9U2)
          (at truck22 city3U1)
          (at truck21 city1U1)
          (at truck20 city7U3)
          (at truck19 city4U3)
          (at truck18 city1U1)
          (at truck17 city4U3)
          (at truck16 city11U3)
          (at truck15 city6U2)
          (at truck14 city5U3)
          (at truck13 city5U1)
          (at truck12 city8U1)
          (at truck11 city8U1)
          (at truck10 city5U2)
          (at truck9 city8U3)
          (at truck8 city1U1)
          (at truck7 city8U2)
          (at truck6 city9U3)
          (at truck5 city10U2)
          (at truck4 city6U3)
          (at truck3 city11U1)
          (at truck2 city5U3)
          (at truck1 city5U2)
          (at package7 city4U2)
          (at package6 city4U1)
          (at package5 city11U2)
          (at package4 city2U2)
          (at package3 city7U2)
          (at package2 city7U2)
          (at package1 city7U2))
   (:goal (and (at package7 city5U1)
               (at package6 city5U2)
               (at package5 city2U1)
               (at package4 city5U3)
               (at package3 city5U1)
               (at package2 city5U2)
               (at package1 city4U1))))

(define (problem stripsUlogUxU17)
   (:domain logisticsUstrips)
   (:objects package15 package14 package13 package12 package11
             package10 package9 package8 package7 package6 package5 package4
             package3 package2 package1 city4 city3 city2 city1 truck45
             truck44 truck43 truck42 truck41 truck40 truck39 truck38
             truck37 truck36 truck35 truck34 truck33 truck32 truck31
             truck30 truck29 truck28 truck27 truck26 truck25 truck24
             truck23 truck22 truck21 truck20 truck19 truck18 truck17
             truck16 truck15 truck14 truck13 truck12 truck11 truck10 truck9
             truck8 truck7 truck6 truck5 truck4 truck3 truck2 truck1 plane5
             plane4 plane3 plane2 plane1 city4U2 city4U1 city3U2 city3U1
             city2U2 city2U1 city1U2 city1U1 city4U3 city3U3 city2U3
             city1U3)
   (:init (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck45)
          (truck truck44)
          (truck truck43)
          (truck truck42)
          (truck truck41)
          (truck truck40)
          (truck truck39)
          (truck truck38)
          (truck truck37)
          (truck truck36)
          (truck truck35)
          (truck truck34)
          (truck truck33)
          (truck truck32)
          (truck truck31)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city4U2)
          (location city4U1)
          (location city3U2)
          (location city3U1)
          (location city2U2)
          (location city2U1)
          (location city1U2)
          (location city1U1)
          (airport city4U3)
          (location city4U3)
          (airport city3U3)
          (location city3U3)
          (airport city2U3)
          (location city2U3)
          (airport city1U3)
          (location city1U3)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane5 city1U3)
          (at plane4 city4U3)
          (at plane3 city4U3)
          (at plane2 city3U3)
          (at plane1 city4U3)
          (at truck45 city4U2)
          (at truck44 city3U2)
          (at truck43 city2U2)
          (at truck42 city1U1)
          (at truck41 city1U3)
          (at truck40 city3U2)
          (at truck39 city2U1)
          (at truck38 city2U3)
          (at truck37 city4U2)
          (at truck36 city3U2)
          (at truck35 city1U1)
          (at truck34 city3U3)
          (at truck33 city3U3)
          (at truck32 city2U1)
          (at truck31 city3U1)
          (at truck30 city3U2)
          (at truck29 city2U2)
          (at truck28 city1U3)
          (at truck27 city4U1)
          (at truck26 city3U2)
          (at truck25 city4U3)
          (at truck24 city2U1)
          (at truck23 city4U1)
          (at truck22 city1U1)
          (at truck21 city3U2)
          (at truck20 city4U3)
          (at truck19 city3U3)
          (at truck18 city1U2)
          (at truck17 city4U2)
          (at truck16 city3U1)
          (at truck15 city3U2)
          (at truck14 city4U3)
          (at truck13 city2U2)
          (at truck12 city2U1)
          (at truck11 city1U1)
          (at truck10 city1U2)
          (at truck9 city1U2)
          (at truck8 city1U1)
          (at truck7 city1U2)
          (at truck6 city2U2)
          (at truck5 city3U1)
          (at truck4 city4U1)
          (at truck3 city1U3)
          (at truck2 city1U3)
          (at truck1 city4U2)
          (at package15 city1U2)
          (at package14 city3U1)
          (at package13 city1U1)
          (at package12 city1U1)
          (at package11 city3U3)
          (at package10 city4U2)
          (at package9 city3U2)
          (at package8 city4U2)
          (at package7 city4U3)
          (at package6 city3U2)
          (at package5 city2U2)
          (at package4 city2U3)
          (at package3 city1U3)
          (at package2 city4U2)
          (at package1 city2U1))
   (:goal (and (at package15 city4U2)
               (at package14 city4U2)
               (at package13 city4U3)
               (at package12 city2U2)
               (at package11 city2U1)
               (at package10 city4U2)
               (at package9 city4U2)
               (at package8 city4U2))))

(define (problem stripsUlogUxU18)
   (:domain logisticsUstrips)
   (:objects package20 package19 package18 package17 package16
             package15 package14 package13 package12 package11 package10
             package9 package8 package7 package6 package5 package4 package3
             package2 package1 city30 city29 city28 city27 city26 city25
             city24 city23 city22 city21 city20 city19 city18 city17 city16
             city15 city14 city13 city12 city11 city10 city9 city8 city7
             city6 city5 city4 city3 city2 city1 truck30 truck29 truck28
             truck27 truck26 truck25 truck24 truck23 truck22 truck21
             truck20 truck19 truck18 truck17 truck16 truck15 truck14
             truck13 truck12 truck11 truck10 truck9 truck8 truck7 truck6
             truck5 truck4 truck3 truck2 truck1 plane10 plane9 plane8
             plane7 plane6 plane5 plane4 plane3 plane2 plane1 city30U2
             city30U1 city29U2 city29U1 city28U2 city28U1 city27U2 city27U1
             city26U2 city26U1 city25U2 city25U1 city24U2 city24U1 city23U2
             city23U1 city22U2 city22U1 city21U2 city21U1 city20U2 city20U1
             city19U2 city19U1 city18U2 city18U1 city17U2 city17U1 city16U2
             city16U1 city15U2 city15U1 city14U2 city14U1 city13U2 city13U1
             city12U2 city12U1 city11U2 city11U1 city10U2 city10U1 city9U2
             city9U1 city8U2 city8U1 city7U2 city7U1 city6U2 city6U1
             city5U2 city5U1 city4U2 city4U1 city3U2 city3U1 city2U2
             city2U1 city1U2 city1U1 city30U3 city29U3 city28U3 city27U3
             city26U3 city25U3 city24U3 city23U3 city22U3 city21U3 city20U3
             city19U3 city18U3 city17U3 city16U3 city15U3 city14U3 city13U3
             city12U3 city11U3 city10U3 city9U3 city8U3 city7U3 city6U3
             city5U3 city4U3 city3U3 city2U3 city1U3)
   (:init (obj package20)
          (obj package19)
          (obj package18)
          (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city30)
          (city city29)
          (city city28)
          (city city27)
          (city city26)
          (city city25)
          (city city24)
          (city city23)
          (city city22)
          (city city21)
          (city city20)
          (city city19)
          (city city18)
          (city city17)
          (city city16)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane10)
          (airplane plane9)
          (airplane plane8)
          (airplane plane7)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city30U2)
          (location city30U1)
          (location city29U2)
          (location city29U1)
          (location city28U2)
          (location city28U1)
          (location city27U2)
          (location city27U1)
          (location city26U2)
          (location city26U1)
          (location city25U2)
          (location city25U1)
          (location city24U2)
          (location city24U1)
          (location city23U2)
          (location city23U1)
          (location city22U2)
          (location city22U1)
          (location city21U2)
          (location city21U1)
          (location city20U2)
          (location city20U1)
          (location city19U2)
          (location city19U1)
          (location city18U2)
          (location city18U1)
          (location city17U2)
          (location city17U1)
          (location city16U2)
          (location city16U1)
          (location city15U2)
          (location city15U1)
          (location city14U2)
          (location city14U1)
          (location city13U2)
          (location city13U1)
          (location city12U2)
          (location city12U1)
          (location city11U2)
          (location city11U1)
          (location city10U2)
          (location city10U1)
          (location city9U2)
          (location city9U1)
          (location city8U2)
          (location city8U1)
          (location city7U2)
          (location city7U1)
          (location city6U2)
          (location city6U1)
          (location city5U2)
          (location city5U1)
          (location city4U2)
          (location city4U1)
          (location city3U2)
          (location city3U1)
          (location city2U2)
          (location city2U1)
          (location city1U2)
          (location city1U1)
          (airport city30U3)
          (location city30U3)
          (airport city29U3)
          (location city29U3)
          (airport city28U3)
          (location city28U3)
          (airport city27U3)
          (location city27U3)
          (airport city26U3)
          (location city26U3)
          (airport city25U3)
          (location city25U3)
          (airport city24U3)
          (location city24U3)
          (airport city23U3)
          (location city23U3)
          (airport city22U3)
          (location city22U3)
          (airport city21U3)
          (location city21U3)
          (airport city20U3)
          (location city20U3)
          (airport city19U3)
          (location city19U3)
          (airport city18U3)
          (location city18U3)
          (airport city17U3)
          (location city17U3)
          (airport city16U3)
          (location city16U3)
          (airport city15U3)
          (location city15U3)
          (airport city14U3)
          (location city14U3)
          (airport city13U3)
          (location city13U3)
          (airport city12U3)
          (location city12U3)
          (airport city11U3)
          (location city11U3)
          (airport city10U3)
          (location city10U3)
          (airport city9U3)
          (location city9U3)
          (airport city8U3)
          (location city8U3)
          (airport city7U3)
          (location city7U3)
          (airport city6U3)
          (location city6U3)
          (airport city5U3)
          (location city5U3)
          (airport city4U3)
          (location city4U3)
          (airport city3U3)
          (location city3U3)
          (airport city2U3)
          (location city2U3)
          (airport city1U3)
          (location city1U3)
          (inUcity city30U3 city30)
          (inUcity city30U2 city30)
          (inUcity city30U1 city30)
          (inUcity city29U3 city29)
          (inUcity city29U2 city29)
          (inUcity city29U1 city29)
          (inUcity city28U3 city28)
          (inUcity city28U2 city28)
          (inUcity city28U1 city28)
          (inUcity city27U3 city27)
          (inUcity city27U2 city27)
          (inUcity city27U1 city27)
          (inUcity city26U3 city26)
          (inUcity city26U2 city26)
          (inUcity city26U1 city26)
          (inUcity city25U3 city25)
          (inUcity city25U2 city25)
          (inUcity city25U1 city25)
          (inUcity city24U3 city24)
          (inUcity city24U2 city24)
          (inUcity city24U1 city24)
          (inUcity city23U3 city23)
          (inUcity city23U2 city23)
          (inUcity city23U1 city23)
          (inUcity city22U3 city22)
          (inUcity city22U2 city22)
          (inUcity city22U1 city22)
          (inUcity city21U3 city21)
          (inUcity city21U2 city21)
          (inUcity city21U1 city21)
          (inUcity city20U3 city20)
          (inUcity city20U2 city20)
          (inUcity city20U1 city20)
          (inUcity city19U3 city19)
          (inUcity city19U2 city19)
          (inUcity city19U1 city19)
          (inUcity city18U3 city18)
          (inUcity city18U2 city18)
          (inUcity city18U1 city18)
          (inUcity city17U3 city17)
          (inUcity city17U2 city17)
          (inUcity city17U1 city17)
          (inUcity city16U3 city16)
          (inUcity city16U2 city16)
          (inUcity city16U1 city16)
          (inUcity city15U3 city15)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane10 city6U3)
          (at plane9 city10U3)
          (at plane8 city9U3)
          (at plane7 city23U3)
          (at plane6 city15U3)
          (at plane5 city6U3)
          (at plane4 city8U3)
          (at plane3 city28U3)
          (at plane2 city12U3)
          (at plane1 city19U3)
          (at truck30 city30U1)
          (at truck29 city29U2)
          (at truck28 city28U2)
          (at truck27 city27U2)
          (at truck26 city26U2)
          (at truck25 city25U1)
          (at truck24 city24U2)
          (at truck23 city23U2)
          (at truck22 city22U2)
          (at truck21 city21U1)
          (at truck20 city20U1)
          (at truck19 city19U2)
          (at truck18 city18U1)
          (at truck17 city17U1)
          (at truck16 city16U1)
          (at truck15 city15U2)
          (at truck14 city14U1)
          (at truck13 city13U2)
          (at truck12 city12U2)
          (at truck11 city11U1)
          (at truck10 city10U1)
          (at truck9 city9U2)
          (at truck8 city8U2)
          (at truck7 city7U1)
          (at truck6 city6U1)
          (at truck5 city5U2)
          (at truck4 city4U2)
          (at truck3 city3U2)
          (at truck2 city2U1)
          (at truck1 city1U1)
          (at package20 city28U1)
          (at package19 city19U2)
          (at package18 city10U2)
          (at package17 city20U1)
          (at package16 city20U1)
          (at package15 city13U1)
          (at package14 city8U1)
          (at package13 city17U1)
          (at package12 city9U1)
          (at package11 city7U3)
          (at package10 city4U2)
          (at package9 city7U1)
          (at package8 city15U1)
          (at package7 city23U1)
          (at package6 city22U1)
          (at package5 city12U2)
          (at package4 city28U3)
          (at package3 city6U3)
          (at package2 city28U3)
          (at package1 city16U1))
   (:goal (and (at package20 city6U2)
               (at package19 city12U2)
               (at package18 city2U1)
               (at package17 city25U1)
               (at package16 city22U2)
               (at package15 city4U1)
               (at package14 city6U3)
               (at package13 city1U3)
               (at package12 city29U1)
               (at package11 city6U1)
               (at package10 city30U3)
               (at package9 city17U3)
               (at package8 city10U1)
               (at package7 city14U1)
               (at package6 city28U1)
               (at package5 city25U2)
               (at package4 city10U1)
               (at package3 city10U3)
               (at package2 city9U2)
               (at package1 city29U3))))

(define (problem stripsUlogUxU19)
   (:domain logisticsUstrips)
   (:objects package19 package18 package17 package16 package15
             package14 package13 package12 package11 package10 package9
             package8 package7 package6 package5 package4 package3 package2
             package1 city8 city7 city6 city5 city4 city3 city2 city1 truck30
             truck29 truck28 truck27 truck26 truck25 truck24 truck23
             truck22 truck21 truck20 truck19 truck18 truck17 truck16
             truck15 truck14 truck13 truck12 truck11 truck10 truck9 truck8
             truck7 truck6 truck5 truck4 truck3 truck2 truck1 plane11
             plane10 plane9 plane8 plane7 plane6 plane5 plane4 plane3 plane2
             plane1 city8U7 city8U6 city8U5 city8U4 city8U3 city8U2
             city8U1 city7U7 city7U6 city7U5 city7U4 city7U3 city7U2
             city7U1 city6U7 city6U6 city6U5 city6U4 city6U3 city6U2
             city6U1 city5U7 city5U6 city5U5 city5U4 city5U3 city5U2
             city5U1 city4U7 city4U6 city4U5 city4U4 city4U3 city4U2
             city4U1 city3U7 city3U6 city3U5 city3U4 city3U3 city3U2
             city3U1 city2U7 city2U6 city2U5 city2U4 city2U3 city2U2
             city2U1 city1U7 city1U6 city1U5 city1U4 city1U3 city1U2
             city1U1 city8U8 city7U8 city6U8 city5U8 city4U8 city3U8
             city2U8 city1U8)
   (:init (obj package19)
          (obj package18)
          (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane11)
          (airplane plane10)
          (airplane plane9)
          (airplane plane8)
          (airplane plane7)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city8U7)
          (location city8U6)
          (location city8U5)
          (location city8U4)
          (location city8U3)
          (location city8U2)
          (location city8U1)
          (location city7U7)
          (location city7U6)
          (location city7U5)
          (location city7U4)
          (location city7U3)
          (location city7U2)
          (location city7U1)
          (location city6U7)
          (location city6U6)
          (location city6U5)
          (location city6U4)
          (location city6U3)
          (location city6U2)
          (location city6U1)
          (location city5U7)
          (location city5U6)
          (location city5U5)
          (location city5U4)
          (location city5U3)
          (location city5U2)
          (location city5U1)
          (location city4U7)
          (location city4U6)
          (location city4U5)
          (location city4U4)
          (location city4U3)
          (location city4U2)
          (location city4U1)
          (location city3U7)
          (location city3U6)
          (location city3U5)
          (location city3U4)
          (location city3U3)
          (location city3U2)
          (location city3U1)
          (location city2U7)
          (location city2U6)
          (location city2U5)
          (location city2U4)
          (location city2U3)
          (location city2U2)
          (location city2U1)
          (location city1U7)
          (location city1U6)
          (location city1U5)
          (location city1U4)
          (location city1U3)
          (location city1U2)
          (location city1U1)
          (airport city8U8)
          (location city8U8)
          (airport city7U8)
          (location city7U8)
          (airport city6U8)
          (location city6U8)
          (airport city5U8)
          (location city5U8)
          (airport city4U8)
          (location city4U8)
          (airport city3U8)
          (location city3U8)
          (airport city2U8)
          (location city2U8)
          (airport city1U8)
          (location city1U8)
          (inUcity city8U8 city8)
          (inUcity city8U7 city8)
          (inUcity city8U6 city8)
          (inUcity city8U5 city8)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U8 city7)
          (inUcity city7U7 city7)
          (inUcity city7U6 city7)
          (inUcity city7U5 city7)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U8 city6)
          (inUcity city6U7 city6)
          (inUcity city6U6 city6)
          (inUcity city6U5 city6)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U8 city5)
          (inUcity city5U7 city5)
          (inUcity city5U6 city5)
          (inUcity city5U5 city5)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U8 city4)
          (inUcity city4U7 city4)
          (inUcity city4U6 city4)
          (inUcity city4U5 city4)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U8 city3)
          (inUcity city3U7 city3)
          (inUcity city3U6 city3)
          (inUcity city3U5 city3)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U8 city2)
          (inUcity city2U7 city2)
          (inUcity city2U6 city2)
          (inUcity city2U5 city2)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U8 city1)
          (inUcity city1U7 city1)
          (inUcity city1U6 city1)
          (inUcity city1U5 city1)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane11 city3U8)
          (at plane10 city7U8)
          (at plane9 city3U8)
          (at plane8 city4U8)
          (at plane7 city2U8)
          (at plane6 city1U8)
          (at plane5 city1U8)
          (at plane4 city2U8)
          (at plane3 city3U8)
          (at plane2 city2U8)
          (at plane1 city7U8)
          (at truck30 city8U5)
          (at truck29 city7U3)
          (at truck28 city6U2)
          (at truck27 city5U6)
          (at truck26 city4U3)
          (at truck25 city3U5)
          (at truck24 city2U1)
          (at truck23 city1U7)
          (at truck22 city2U4)
          (at truck21 city3U8)
          (at truck20 city4U7)
          (at truck19 city6U7)
          (at truck18 city7U6)
          (at truck17 city6U6)
          (at truck16 city7U3)
          (at truck15 city1U8)
          (at truck14 city8U8)
          (at truck13 city1U8)
          (at truck12 city5U7)
          (at truck11 city2U6)
          (at truck10 city1U5)
          (at truck9 city2U7)
          (at truck8 city8U5)
          (at truck7 city4U1)
          (at truck6 city3U5)
          (at truck5 city3U8)
          (at truck4 city2U1)
          (at truck3 city3U1)
          (at truck2 city1U8)
          (at truck1 city5U6)
          (at package19 city7U7)
          (at package18 city4U5)
          (at package17 city3U6)
          (at package16 city1U5)
          (at package15 city8U2)
          (at package14 city8U3)
          (at package13 city6U8)
          (at package12 city8U1)
          (at package11 city2U6)
          (at package10 city6U5)
          (at package9 city7U2)
          (at package8 city6U1)
          (at package7 city4U8)
          (at package6 city6U3)
          (at package5 city4U3)
          (at package4 city1U5)
          (at package3 city2U2)
          (at package2 city4U5)
          (at package1 city7U3))
   (:goal (and (at package19 city6U1)
               (at package18 city2U2)
               (at package17 city1U8)
               (at package16 city2U5)
               (at package15 city3U6)
               (at package14 city7U6)
               (at package13 city8U2)
               (at package12 city7U4)
               (at package11 city8U5)
               (at package10 city1U7)
               (at package9 city1U7)
               (at package8 city6U4)
               (at package7 city4U5)
               (at package6 city2U7)
               (at package5 city3U8)
               (at package4 city7U5)
               (at package3 city2U1)
               (at package2 city7U4)
               (at package1 city5U2))))

(define (problem stripsUlogUxU20)
   (:domain logisticsUstrips)
   (:objects package16 package15 package14 package13 package12
             package11 package10 package9 package8 package7 package6
             package5 package4 package3 package2 package1 city15 city14
             city13 city12 city11 city10 city9 city8 city7 city6 city5 city4
             city3 city2 city1 truck19 truck18 truck17 truck16 truck15
             truck14 truck13 truck12 truck11 truck10 truck9 truck8 truck7
             truck6 truck5 truck4 truck3 truck2 truck1 plane15 plane14
             plane13 plane12 plane11 plane10 plane9 plane8 plane7 plane6
             plane5 plane4 plane3 plane2 plane1 city15U11 city15U10
             city15U9 city15U8 city15U7 city15U6 city15U5 city15U4 city15U3
             city15U2 city15U1 city14U11 city14U10 city14U9 city14U8
             city14U7 city14U6 city14U5 city14U4 city14U3 city14U2 city14U1
             city13U11 city13U10 city13U9 city13U8 city13U7 city13U6
             city13U5 city13U4 city13U3 city13U2 city13U1 city12U11
             city12U10 city12U9 city12U8 city12U7 city12U6 city12U5 city12U4
             city12U3 city12U2 city12U1 city11U11 city11U10 city11U9
             city11U8 city11U7 city11U6 city11U5 city11U4 city11U3 city11U2
             city11U1 city10U11 city10U10 city10U9 city10U8 city10U7
             city10U6 city10U5 city10U4 city10U3 city10U2 city10U1 city9U11
             city9U10 city9U9 city9U8 city9U7 city9U6 city9U5 city9U4
             city9U3 city9U2 city9U1 city8U11 city8U10 city8U9 city8U8
             city8U7 city8U6 city8U5 city8U4 city8U3 city8U2 city8U1
             city7U11 city7U10 city7U9 city7U8 city7U7 city7U6 city7U5
             city7U4 city7U3 city7U2 city7U1 city6U11 city6U10 city6U9
             city6U8 city6U7 city6U6 city6U5 city6U4 city6U3 city6U2
             city6U1 city5U11 city5U10 city5U9 city5U8 city5U7 city5U6
             city5U5 city5U4 city5U3 city5U2 city5U1 city4U11 city4U10
             city4U9 city4U8 city4U7 city4U6 city4U5 city4U4 city4U3
             city4U2 city4U1 city3U11 city3U10 city3U9 city3U8 city3U7
             city3U6 city3U5 city3U4 city3U3 city3U2 city3U1 city2U11
             city2U10 city2U9 city2U8 city2U7 city2U6 city2U5 city2U4
             city2U3 city2U2 city2U1 city1U11 city1U10 city1U9 city1U8
             city1U7 city1U6 city1U5 city1U4 city1U3 city1U2 city1U1
             city15U12 city14U12 city13U12 city12U12 city11U12 city10U12
             city9U12 city8U12 city7U12 city6U12 city5U12 city4U12 city3U12
             city2U12 city1U12)
   (:init (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane15)
          (airplane plane14)
          (airplane plane13)
          (airplane plane12)
          (airplane plane11)
          (airplane plane10)
          (airplane plane9)
          (airplane plane8)
          (airplane plane7)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city15U11)
          (location city15U10)
          (location city15U9)
          (location city15U8)
          (location city15U7)
          (location city15U6)
          (location city15U5)
          (location city15U4)
          (location city15U3)
          (location city15U2)
          (location city15U1)
          (location city14U11)
          (location city14U10)
          (location city14U9)
          (location city14U8)
          (location city14U7)
          (location city14U6)
          (location city14U5)
          (location city14U4)
          (location city14U3)
          (location city14U2)
          (location city14U1)
          (location city13U11)
          (location city13U10)
          (location city13U9)
          (location city13U8)
          (location city13U7)
          (location city13U6)
          (location city13U5)
          (location city13U4)
          (location city13U3)
          (location city13U2)
          (location city13U1)
          (location city12U11)
          (location city12U10)
          (location city12U9)
          (location city12U8)
          (location city12U7)
          (location city12U6)
          (location city12U5)
          (location city12U4)
          (location city12U3)
          (location city12U2)
          (location city12U1)
          (location city11U11)
          (location city11U10)
          (location city11U9)
          (location city11U8)
          (location city11U7)
          (location city11U6)
          (location city11U5)
          (location city11U4)
          (location city11U3)
          (location city11U2)
          (location city11U1)
          (location city10U11)
          (location city10U10)
          (location city10U9)
          (location city10U8)
          (location city10U7)
          (location city10U6)
          (location city10U5)
          (location city10U4)
          (location city10U3)
          (location city10U2)
          (location city10U1)
          (location city9U11)
          (location city9U10)
          (location city9U9)
          (location city9U8)
          (location city9U7)
          (location city9U6)
          (location city9U5)
          (location city9U4)
          (location city9U3)
          (location city9U2)
          (location city9U1)
          (location city8U11)
          (location city8U10)
          (location city8U9)
          (location city8U8)
          (location city8U7)
          (location city8U6)
          (location city8U5)
          (location city8U4)
          (location city8U3)
          (location city8U2)
          (location city8U1)
          (location city7U11)
          (location city7U10)
          (location city7U9)
          (location city7U8)
          (location city7U7)
          (location city7U6)
          (location city7U5)
          (location city7U4)
          (location city7U3)
          (location city7U2)
          (location city7U1)
          (location city6U11)
          (location city6U10)
          (location city6U9)
          (location city6U8)
          (location city6U7)
          (location city6U6)
          (location city6U5)
          (location city6U4)
          (location city6U3)
          (location city6U2)
          (location city6U1)
          (location city5U11)
          (location city5U10)
          (location city5U9)
          (location city5U8)
          (location city5U7)
          (location city5U6)
          (location city5U5)
          (location city5U4)
          (location city5U3)
          (location city5U2)
          (location city5U1)
          (location city4U11)
          (location city4U10)
          (location city4U9)
          (location city4U8)
          (location city4U7)
          (location city4U6)
          (location city4U5)
          (location city4U4)
          (location city4U3)
          (location city4U2)
          (location city4U1)
          (location city3U11)
          (location city3U10)
          (location city3U9)
          (location city3U8)
          (location city3U7)
          (location city3U6)
          (location city3U5)
          (location city3U4)
          (location city3U3)
          (location city3U2)
          (location city3U1)
          (location city2U11)
          (location city2U10)
          (location city2U9)
          (location city2U8)
          (location city2U7)
          (location city2U6)
          (location city2U5)
          (location city2U4)
          (location city2U3)
          (location city2U2)
          (location city2U1)
          (location city1U11)
          (location city1U10)
          (location city1U9)
          (location city1U8)
          (location city1U7)
          (location city1U6)
          (location city1U5)
          (location city1U4)
          (location city1U3)
          (location city1U2)
          (location city1U1)
          (airport city15U12)
          (location city15U12)
          (airport city14U12)
          (location city14U12)
          (airport city13U12)
          (location city13U12)
          (airport city12U12)
          (location city12U12)
          (airport city11U12)
          (location city11U12)
          (airport city10U12)
          (location city10U12)
          (airport city9U12)
          (location city9U12)
          (airport city8U12)
          (location city8U12)
          (airport city7U12)
          (location city7U12)
          (airport city6U12)
          (location city6U12)
          (airport city5U12)
          (location city5U12)
          (airport city4U12)
          (location city4U12)
          (airport city3U12)
          (location city3U12)
          (airport city2U12)
          (location city2U12)
          (airport city1U12)
          (location city1U12)
          (inUcity city15U12 city15)
          (inUcity city15U11 city15)
          (inUcity city15U10 city15)
          (inUcity city15U9 city15)
          (inUcity city15U8 city15)
          (inUcity city15U7 city15)
          (inUcity city15U6 city15)
          (inUcity city15U5 city15)
          (inUcity city15U4 city15)
          (inUcity city15U3 city15)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U12 city14)
          (inUcity city14U11 city14)
          (inUcity city14U10 city14)
          (inUcity city14U9 city14)
          (inUcity city14U8 city14)
          (inUcity city14U7 city14)
          (inUcity city14U6 city14)
          (inUcity city14U5 city14)
          (inUcity city14U4 city14)
          (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U12 city13)
          (inUcity city13U11 city13)
          (inUcity city13U10 city13)
          (inUcity city13U9 city13)
          (inUcity city13U8 city13)
          (inUcity city13U7 city13)
          (inUcity city13U6 city13)
          (inUcity city13U5 city13)
          (inUcity city13U4 city13)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U12 city12)
          (inUcity city12U11 city12)
          (inUcity city12U10 city12)
          (inUcity city12U9 city12)
          (inUcity city12U8 city12)
          (inUcity city12U7 city12)
          (inUcity city12U6 city12)
          (inUcity city12U5 city12)
          (inUcity city12U4 city12)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U12 city11)
          (inUcity city11U11 city11)
          (inUcity city11U10 city11)
          (inUcity city11U9 city11)
          (inUcity city11U8 city11)
          (inUcity city11U7 city11)
          (inUcity city11U6 city11)
          (inUcity city11U5 city11)
          (inUcity city11U4 city11)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U12 city10)
          (inUcity city10U11 city10)
          (inUcity city10U10 city10)
          (inUcity city10U9 city10)
          (inUcity city10U8 city10)
          (inUcity city10U7 city10)
          (inUcity city10U6 city10)
          (inUcity city10U5 city10)
          (inUcity city10U4 city10)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U12 city9)
          (inUcity city9U11 city9)
          (inUcity city9U10 city9)
          (inUcity city9U9 city9)
          (inUcity city9U8 city9)
          (inUcity city9U7 city9)
          (inUcity city9U6 city9)
          (inUcity city9U5 city9)
          (inUcity city9U4 city9)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U12 city8)
          (inUcity city8U11 city8)
          (inUcity city8U10 city8)
          (inUcity city8U9 city8)
          (inUcity city8U8 city8)
          (inUcity city8U7 city8)
          (inUcity city8U6 city8)
          (inUcity city8U5 city8)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U12 city7)
          (inUcity city7U11 city7)
          (inUcity city7U10 city7)
          (inUcity city7U9 city7)
          (inUcity city7U8 city7)
          (inUcity city7U7 city7)
          (inUcity city7U6 city7)
          (inUcity city7U5 city7)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U12 city6)
          (inUcity city6U11 city6)
          (inUcity city6U10 city6)
          (inUcity city6U9 city6)
          (inUcity city6U8 city6)
          (inUcity city6U7 city6)
          (inUcity city6U6 city6)
          (inUcity city6U5 city6)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U12 city5)
          (inUcity city5U11 city5)
          (inUcity city5U10 city5)
          (inUcity city5U9 city5)
          (inUcity city5U8 city5)
          (inUcity city5U7 city5)
          (inUcity city5U6 city5)
          (inUcity city5U5 city5)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U12 city4)
          (inUcity city4U11 city4)
          (inUcity city4U10 city4)
          (inUcity city4U9 city4)
          (inUcity city4U8 city4)
          (inUcity city4U7 city4)
          (inUcity city4U6 city4)
          (inUcity city4U5 city4)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U12 city3)
          (inUcity city3U11 city3)
          (inUcity city3U10 city3)
          (inUcity city3U9 city3)
          (inUcity city3U8 city3)
          (inUcity city3U7 city3)
          (inUcity city3U6 city3)
          (inUcity city3U5 city3)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U12 city2)
          (inUcity city2U11 city2)
          (inUcity city2U10 city2)
          (inUcity city2U9 city2)
          (inUcity city2U8 city2)
          (inUcity city2U7 city2)
          (inUcity city2U6 city2)
          (inUcity city2U5 city2)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U12 city1)
          (inUcity city1U11 city1)
          (inUcity city1U10 city1)
          (inUcity city1U9 city1)
          (inUcity city1U8 city1)
          (inUcity city1U7 city1)
          (inUcity city1U6 city1)
          (inUcity city1U5 city1)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane15 city5U12)
          (at plane14 city6U12)
          (at plane13 city4U12)
          (at plane12 city7U12)
          (at plane11 city10U12)
          (at plane10 city3U12)
          (at plane9 city9U12)
          (at plane8 city9U12)
          (at plane7 city14U12)
          (at plane6 city8U12)
          (at plane5 city7U12)
          (at plane4 city11U12)
          (at plane3 city11U12)
          (at plane2 city14U12)
          (at plane1 city13U12)
          (at truck19 city15U6)
          (at truck18 city14U5)
          (at truck17 city13U6)
          (at truck16 city12U10)
          (at truck15 city11U5)
          (at truck14 city10U11)
          (at truck13 city9U3)
          (at truck12 city8U7)
          (at truck11 city7U4)
          (at truck10 city6U9)
          (at truck9 city5U11)
          (at truck8 city4U9)
          (at truck7 city3U8)
          (at truck6 city2U11)
          (at truck5 city1U11)
          (at truck4 city4U9)
          (at truck3 city2U9)
          (at truck2 city10U5)
          (at truck1 city6U6)
          (at package16 city1U12)
          (at package15 city3U10)
          (at package14 city9U8)
          (at package13 city5U2)
          (at package12 city15U5)
          (at package11 city13U3)
          (at package10 city2U3)
          (at package9 city10U1)
          (at package8 city4U9)
          (at package7 city3U4)
          (at package6 city9U2)
          (at package5 city8U1)
          (at package4 city7U5)
          (at package3 city12U5)
          (at package2 city9U7)
          (at package1 city12U11))
   (:goal (and (at package16 city9U10)
               (at package15 city5U12)
               (at package14 city10U4)
               (at package13 city3U4)
               (at package12 city10U10)
               (at package11 city7U4)
               (at package10 city8U5)
               (at package9 city4U2)
               (at package8 city15U6)
               (at package7 city4U9)
               (at package6 city5U10)
               (at package5 city8U10)
               (at package4 city3U11)
               (at package3 city3U7)
               (at package2 city9U12)
               (at package1 city10U10))))

(define (problem stripsUlogUxU21)
   (:domain logisticsUstrips)
   (:objects package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 city14
             city13 city12 city11 city10 city9 city8 city7 city6 city5 city4
             city3 city2 city1 truck40 truck39 truck38 truck37 truck36
             truck35 truck34 truck33 truck32 truck31 truck30 truck29
             truck28 truck27 truck26 truck25 truck24 truck23 truck22
             truck21 truck20 truck19 truck18 truck17 truck16 truck15
             truck14 truck13 truck12 truck11 truck10 truck9 truck8 truck7
             truck6 truck5 truck4 truck3 truck2 truck1 plane13 plane12
             plane11 plane10 plane9 plane8 plane7 plane6 plane5 plane4
             plane3 plane2 plane1 city14U8 city14U7 city14U6 city14U5
             city14U4 city14U3 city14U2 city14U1 city13U8 city13U7 city13U6
             city13U5 city13U4 city13U3 city13U2 city13U1 city12U8 city12U7
             city12U6 city12U5 city12U4 city12U3 city12U2 city12U1 city11U8
             city11U7 city11U6 city11U5 city11U4 city11U3 city11U2 city11U1
             city10U8 city10U7 city10U6 city10U5 city10U4 city10U3 city10U2
             city10U1 city9U8 city9U7 city9U6 city9U5 city9U4 city9U3
             city9U2 city9U1 city8U8 city8U7 city8U6 city8U5 city8U4
             city8U3 city8U2 city8U1 city7U8 city7U7 city7U6 city7U5
             city7U4 city7U3 city7U2 city7U1 city6U8 city6U7 city6U6
             city6U5 city6U4 city6U3 city6U2 city6U1 city5U8 city5U7
             city5U6 city5U5 city5U4 city5U3 city5U2 city5U1 city4U8
             city4U7 city4U6 city4U5 city4U4 city4U3 city4U2 city4U1
             city3U8 city3U7 city3U6 city3U5 city3U4 city3U3 city3U2
             city3U1 city2U8 city2U7 city2U6 city2U5 city2U4 city2U3
             city2U2 city2U1 city1U8 city1U7 city1U6 city1U5 city1U4
             city1U3 city1U2 city1U1 city14U9 city13U9 city12U9 city11U9
             city10U9 city9U9 city8U9 city7U9 city6U9 city5U9 city4U9
             city3U9 city2U9 city1U9)
   (:init (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck40)
          (truck truck39)
          (truck truck38)
          (truck truck37)
          (truck truck36)
          (truck truck35)
          (truck truck34)
          (truck truck33)
          (truck truck32)
          (truck truck31)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane13)
          (airplane plane12)
          (airplane plane11)
          (airplane plane10)
          (airplane plane9)
          (airplane plane8)
          (airplane plane7)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city14U8)
          (location city14U7)
          (location city14U6)
          (location city14U5)
          (location city14U4)
          (location city14U3)
          (location city14U2)
          (location city14U1)
          (location city13U8)
          (location city13U7)
          (location city13U6)
          (location city13U5)
          (location city13U4)
          (location city13U3)
          (location city13U2)
          (location city13U1)
          (location city12U8)
          (location city12U7)
          (location city12U6)
          (location city12U5)
          (location city12U4)
          (location city12U3)
          (location city12U2)
          (location city12U1)
          (location city11U8)
          (location city11U7)
          (location city11U6)
          (location city11U5)
          (location city11U4)
          (location city11U3)
          (location city11U2)
          (location city11U1)
          (location city10U8)
          (location city10U7)
          (location city10U6)
          (location city10U5)
          (location city10U4)
          (location city10U3)
          (location city10U2)
          (location city10U1)
          (location city9U8)
          (location city9U7)
          (location city9U6)
          (location city9U5)
          (location city9U4)
          (location city9U3)
          (location city9U2)
          (location city9U1)
          (location city8U8)
          (location city8U7)
          (location city8U6)
          (location city8U5)
          (location city8U4)
          (location city8U3)
          (location city8U2)
          (location city8U1)
          (location city7U8)
          (location city7U7)
          (location city7U6)
          (location city7U5)
          (location city7U4)
          (location city7U3)
          (location city7U2)
          (location city7U1)
          (location city6U8)
          (location city6U7)
          (location city6U6)
          (location city6U5)
          (location city6U4)
          (location city6U3)
          (location city6U2)
          (location city6U1)
          (location city5U8)
          (location city5U7)
          (location city5U6)
          (location city5U5)
          (location city5U4)
          (location city5U3)
          (location city5U2)
          (location city5U1)
          (location city4U8)
          (location city4U7)
          (location city4U6)
          (location city4U5)
          (location city4U4)
          (location city4U3)
          (location city4U2)
          (location city4U1)
          (location city3U8)
          (location city3U7)
          (location city3U6)
          (location city3U5)
          (location city3U4)
          (location city3U3)
          (location city3U2)
          (location city3U1)
          (location city2U8)
          (location city2U7)
          (location city2U6)
          (location city2U5)
          (location city2U4)
          (location city2U3)
          (location city2U2)
          (location city2U1)
          (location city1U8)
          (location city1U7)
          (location city1U6)
          (location city1U5)
          (location city1U4)
          (location city1U3)
          (location city1U2)
          (location city1U1)
          (airport city14U9)
          (location city14U9)
          (airport city13U9)
          (location city13U9)
          (airport city12U9)
          (location city12U9)
          (airport city11U9)
          (location city11U9)
          (airport city10U9)
          (location city10U9)
          (airport city9U9)
          (location city9U9)
          (airport city8U9)
          (location city8U9)
          (airport city7U9)
          (location city7U9)
          (airport city6U9)
          (location city6U9)
          (airport city5U9)
          (location city5U9)
          (airport city4U9)
          (location city4U9)
          (airport city3U9)
          (location city3U9)
          (airport city2U9)
          (location city2U9)
          (airport city1U9)
          (location city1U9)
          (inUcity city14U9 city14)
          (inUcity city14U8 city14)
          (inUcity city14U7 city14)
          (inUcity city14U6 city14)
          (inUcity city14U5 city14)
          (inUcity city14U4 city14)
          (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U9 city13)
          (inUcity city13U8 city13)
          (inUcity city13U7 city13)
          (inUcity city13U6 city13)
          (inUcity city13U5 city13)
          (inUcity city13U4 city13)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U9 city12)
          (inUcity city12U8 city12)
          (inUcity city12U7 city12)
          (inUcity city12U6 city12)
          (inUcity city12U5 city12)
          (inUcity city12U4 city12)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U9 city11)
          (inUcity city11U8 city11)
          (inUcity city11U7 city11)
          (inUcity city11U6 city11)
          (inUcity city11U5 city11)
          (inUcity city11U4 city11)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U9 city10)
          (inUcity city10U8 city10)
          (inUcity city10U7 city10)
          (inUcity city10U6 city10)
          (inUcity city10U5 city10)
          (inUcity city10U4 city10)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U9 city9)
          (inUcity city9U8 city9)
          (inUcity city9U7 city9)
          (inUcity city9U6 city9)
          (inUcity city9U5 city9)
          (inUcity city9U4 city9)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U9 city8)
          (inUcity city8U8 city8)
          (inUcity city8U7 city8)
          (inUcity city8U6 city8)
          (inUcity city8U5 city8)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U9 city7)
          (inUcity city7U8 city7)
          (inUcity city7U7 city7)
          (inUcity city7U6 city7)
          (inUcity city7U5 city7)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U9 city6)
          (inUcity city6U8 city6)
          (inUcity city6U7 city6)
          (inUcity city6U6 city6)
          (inUcity city6U5 city6)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U9 city5)
          (inUcity city5U8 city5)
          (inUcity city5U7 city5)
          (inUcity city5U6 city5)
          (inUcity city5U5 city5)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U9 city4)
          (inUcity city4U8 city4)
          (inUcity city4U7 city4)
          (inUcity city4U6 city4)
          (inUcity city4U5 city4)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U9 city3)
          (inUcity city3U8 city3)
          (inUcity city3U7 city3)
          (inUcity city3U6 city3)
          (inUcity city3U5 city3)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U9 city2)
          (inUcity city2U8 city2)
          (inUcity city2U7 city2)
          (inUcity city2U6 city2)
          (inUcity city2U5 city2)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U9 city1)
          (inUcity city1U8 city1)
          (inUcity city1U7 city1)
          (inUcity city1U6 city1)
          (inUcity city1U5 city1)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane13 city8U9)
          (at plane12 city4U9)
          (at plane11 city2U9)
          (at plane10 city5U9)
          (at plane9 city2U9)
          (at plane8 city7U9)
          (at plane7 city5U9)
          (at plane6 city3U9)
          (at plane5 city11U9)
          (at plane4 city7U9)
          (at plane3 city6U9)
          (at plane2 city11U9)
          (at plane1 city2U9)
          (at truck40 city14U3)
          (at truck39 city13U7)
          (at truck38 city12U7)
          (at truck37 city11U5)
          (at truck36 city10U1)
          (at truck35 city9U3)
          (at truck34 city8U8)
          (at truck33 city7U1)
          (at truck32 city6U3)
          (at truck31 city5U7)
          (at truck30 city4U4)
          (at truck29 city3U1)
          (at truck28 city2U7)
          (at truck27 city1U5)
          (at truck26 city4U6)
          (at truck25 city9U1)
          (at truck24 city9U7)
          (at truck23 city4U4)
          (at truck22 city3U3)
          (at truck21 city7U8)
          (at truck20 city2U6)
          (at truck19 city13U3)
          (at truck18 city5U5)
          (at truck17 city4U5)
          (at truck16 city7U1)
          (at truck15 city7U8)
          (at truck14 city4U9)
          (at truck13 city2U1)
          (at truck12 city2U8)
          (at truck11 city6U2)
          (at truck10 city8U3)
          (at truck9 city3U1)
          (at truck8 city11U7)
          (at truck7 city8U5)
          (at truck6 city4U7)
          (at truck5 city1U3)
          (at truck4 city1U3)
          (at truck3 city2U6)
          (at truck2 city2U9)
          (at truck1 city12U9)
          (at package11 city3U8)
          (at package10 city3U1)
          (at package9 city2U5)
          (at package8 city6U6)
          (at package7 city9U8)
          (at package6 city1U6)
          (at package5 city1U1)
          (at package4 city8U8)
          (at package3 city5U8)
          (at package2 city10U1)
          (at package1 city12U1))
   (:goal (and (at package11 city9U8)
               (at package10 city12U9)
               (at package9 city2U3)
               (at package8 city10U7)
               (at package7 city2U2)
               (at package6 city12U6)
               (at package5 city14U8)
               (at package4 city13U2)
               (at package3 city2U8)
               (at package2 city6U2)
               (at package1 city11U6))))

(define (problem stripsUlogUxU22)
   (:domain logisticsUstrips)
   (:objects package44 package43 package42 package41 package40
             package39 package38 package37 package36 package35 package34
             package33 package32 package31 package30 package29 package28
             package27 package26 package25 package24 package23 package22
             package21 package20 package19 package18 package17 package16
             package15 package14 package13 package12 package11 package10
             package9 package8 package7 package6 package5 package4 package3
             package2 package1 city30 city29 city28 city27 city26 city25
             city24 city23 city22 city21 city20 city19 city18 city17 city16
             city15 city14 city13 city12 city11 city10 city9 city8 city7
             city6 city5 city4 city3 city2 city1 truck74 truck73 truck72
             truck71 truck70 truck69 truck68 truck67 truck66 truck65
             truck64 truck63 truck62 truck61 truck60 truck59 truck58
             truck57 truck56 truck55 truck54 truck53 truck52 truck51
             truck50 truck49 truck48 truck47 truck46 truck45 truck44
             truck43 truck42 truck41 truck40 truck39 truck38 truck37
             truck36 truck35 truck34 truck33 truck32 truck31 truck30
             truck29 truck28 truck27 truck26 truck25 truck24 truck23
             truck22 truck21 truck20 truck19 truck18 truck17 truck16
             truck15 truck14 truck13 truck12 truck11 truck10 truck9 truck8
             truck7 truck6 truck5 truck4 truck3 truck2 truck1 plane6 plane5
             plane4 plane3 plane2 plane1 city30U3 city30U2 city30U1
             city29U3 city29U2 city29U1 city28U3 city28U2 city28U1 city27U3
             city27U2 city27U1 city26U3 city26U2 city26U1 city25U3 city25U2
             city25U1 city24U3 city24U2 city24U1 city23U3 city23U2 city23U1
             city22U3 city22U2 city22U1 city21U3 city21U2 city21U1 city20U3
             city20U2 city20U1 city19U3 city19U2 city19U1 city18U3 city18U2
             city18U1 city17U3 city17U2 city17U1 city16U3 city16U2 city16U1
             city15U3 city15U2 city15U1 city14U3 city14U2 city14U1 city13U3
             city13U2 city13U1 city12U3 city12U2 city12U1 city11U3 city11U2
             city11U1 city10U3 city10U2 city10U1 city9U3 city9U2 city9U1
             city8U3 city8U2 city8U1 city7U3 city7U2 city7U1 city6U3
             city6U2 city6U1 city5U3 city5U2 city5U1 city4U3 city4U2
             city4U1 city3U3 city3U2 city3U1 city2U3 city2U2 city2U1
             city1U3 city1U2 city1U1 city30U4 city29U4 city28U4 city27U4
             city26U4 city25U4 city24U4 city23U4 city22U4 city21U4 city20U4
             city19U4 city18U4 city17U4 city16U4 city15U4 city14U4 city13U4
             city12U4 city11U4 city10U4 city9U4 city8U4 city7U4 city6U4
             city5U4 city4U4 city3U4 city2U4 city1U4)
   (:init (obj package44)
          (obj package43)
          (obj package42)
          (obj package41)
          (obj package40)
          (obj package39)
          (obj package38)
          (obj package37)
          (obj package36)
          (obj package35)
          (obj package34)
          (obj package33)
          (obj package32)
          (obj package31)
          (obj package30)
          (obj package29)
          (obj package28)
          (obj package27)
          (obj package26)
          (obj package25)
          (obj package24)
          (obj package23)
          (obj package22)
          (obj package21)
          (obj package20)
          (obj package19)
          (obj package18)
          (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city30)
          (city city29)
          (city city28)
          (city city27)
          (city city26)
          (city city25)
          (city city24)
          (city city23)
          (city city22)
          (city city21)
          (city city20)
          (city city19)
          (city city18)
          (city city17)
          (city city16)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck74)
          (truck truck73)
          (truck truck72)
          (truck truck71)
          (truck truck70)
          (truck truck69)
          (truck truck68)
          (truck truck67)
          (truck truck66)
          (truck truck65)
          (truck truck64)
          (truck truck63)
          (truck truck62)
          (truck truck61)
          (truck truck60)
          (truck truck59)
          (truck truck58)
          (truck truck57)
          (truck truck56)
          (truck truck55)
          (truck truck54)
          (truck truck53)
          (truck truck52)
          (truck truck51)
          (truck truck50)
          (truck truck49)
          (truck truck48)
          (truck truck47)
          (truck truck46)
          (truck truck45)
          (truck truck44)
          (truck truck43)
          (truck truck42)
          (truck truck41)
          (truck truck40)
          (truck truck39)
          (truck truck38)
          (truck truck37)
          (truck truck36)
          (truck truck35)
          (truck truck34)
          (truck truck33)
          (truck truck32)
          (truck truck31)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city30U3)
          (location city30U2)
          (location city30U1)
          (location city29U3)
          (location city29U2)
          (location city29U1)
          (location city28U3)
          (location city28U2)
          (location city28U1)
          (location city27U3)
          (location city27U2)
          (location city27U1)
          (location city26U3)
          (location city26U2)
          (location city26U1)
          (location city25U3)
          (location city25U2)
          (location city25U1)
          (location city24U3)
          (location city24U2)
          (location city24U1)
          (location city23U3)
          (location city23U2)
          (location city23U1)
          (location city22U3)
          (location city22U2)
          (location city22U1)
          (location city21U3)
          (location city21U2)
          (location city21U1)
          (location city20U3)
          (location city20U2)
          (location city20U1)
          (location city19U3)
          (location city19U2)
          (location city19U1)
          (location city18U3)
          (location city18U2)
          (location city18U1)
          (location city17U3)
          (location city17U2)
          (location city17U1)
          (location city16U3)
          (location city16U2)
          (location city16U1)
          (location city15U3)
          (location city15U2)
          (location city15U1)
          (location city14U3)
          (location city14U2)
          (location city14U1)
          (location city13U3)
          (location city13U2)
          (location city13U1)
          (location city12U3)
          (location city12U2)
          (location city12U1)
          (location city11U3)
          (location city11U2)
          (location city11U1)
          (location city10U3)
          (location city10U2)
          (location city10U1)
          (location city9U3)
          (location city9U2)
          (location city9U1)
          (location city8U3)
          (location city8U2)
          (location city8U1)
          (location city7U3)
          (location city7U2)
          (location city7U1)
          (location city6U3)
          (location city6U2)
          (location city6U1)
          (location city5U3)
          (location city5U2)
          (location city5U1)
          (location city4U3)
          (location city4U2)
          (location city4U1)
          (location city3U3)
          (location city3U2)
          (location city3U1)
          (location city2U3)
          (location city2U2)
          (location city2U1)
          (location city1U3)
          (location city1U2)
          (location city1U1)
          (airport city30U4)
          (location city30U4)
          (airport city29U4)
          (location city29U4)
          (airport city28U4)
          (location city28U4)
          (airport city27U4)
          (location city27U4)
          (airport city26U4)
          (location city26U4)
          (airport city25U4)
          (location city25U4)
          (airport city24U4)
          (location city24U4)
          (airport city23U4)
          (location city23U4)
          (airport city22U4)
          (location city22U4)
          (airport city21U4)
          (location city21U4)
          (airport city20U4)
          (location city20U4)
          (airport city19U4)
          (location city19U4)
          (airport city18U4)
          (location city18U4)
          (airport city17U4)
          (location city17U4)
          (airport city16U4)
          (location city16U4)
          (airport city15U4)
          (location city15U4)
          (airport city14U4)
          (location city14U4)
          (airport city13U4)
          (location city13U4)
          (airport city12U4)
          (location city12U4)
          (airport city11U4)
          (location city11U4)
          (airport city10U4)
          (location city10U4)
          (airport city9U4)
          (location city9U4)
          (airport city8U4)
          (location city8U4)
          (airport city7U4)
          (location city7U4)
          (airport city6U4)
          (location city6U4)
          (airport city5U4)
          (location city5U4)
          (airport city4U4)
          (location city4U4)
          (airport city3U4)
          (location city3U4)
          (airport city2U4)
          (location city2U4)
          (airport city1U4)
          (location city1U4)
          (inUcity city30U4 city30)
          (inUcity city30U3 city30)
          (inUcity city30U2 city30)
          (inUcity city30U1 city30)
          (inUcity city29U4 city29)
          (inUcity city29U3 city29)
          (inUcity city29U2 city29)
          (inUcity city29U1 city29)
          (inUcity city28U4 city28)
          (inUcity city28U3 city28)
          (inUcity city28U2 city28)
          (inUcity city28U1 city28)
          (inUcity city27U4 city27)
          (inUcity city27U3 city27)
          (inUcity city27U2 city27)
          (inUcity city27U1 city27)
          (inUcity city26U4 city26)
          (inUcity city26U3 city26)
          (inUcity city26U2 city26)
          (inUcity city26U1 city26)
          (inUcity city25U4 city25)
          (inUcity city25U3 city25)
          (inUcity city25U2 city25)
          (inUcity city25U1 city25)
          (inUcity city24U4 city24)
          (inUcity city24U3 city24)
          (inUcity city24U2 city24)
          (inUcity city24U1 city24)
          (inUcity city23U4 city23)
          (inUcity city23U3 city23)
          (inUcity city23U2 city23)
          (inUcity city23U1 city23)
          (inUcity city22U4 city22)
          (inUcity city22U3 city22)
          (inUcity city22U2 city22)
          (inUcity city22U1 city22)
          (inUcity city21U4 city21)
          (inUcity city21U3 city21)
          (inUcity city21U2 city21)
          (inUcity city21U1 city21)
          (inUcity city20U4 city20)
          (inUcity city20U3 city20)
          (inUcity city20U2 city20)
          (inUcity city20U1 city20)
          (inUcity city19U4 city19)
          (inUcity city19U3 city19)
          (inUcity city19U2 city19)
          (inUcity city19U1 city19)
          (inUcity city18U4 city18)
          (inUcity city18U3 city18)
          (inUcity city18U2 city18)
          (inUcity city18U1 city18)
          (inUcity city17U4 city17)
          (inUcity city17U3 city17)
          (inUcity city17U2 city17)
          (inUcity city17U1 city17)
          (inUcity city16U4 city16)
          (inUcity city16U3 city16)
          (inUcity city16U2 city16)
          (inUcity city16U1 city16)
          (inUcity city15U4 city15)
          (inUcity city15U3 city15)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U4 city14)
          (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U4 city13)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U4 city12)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U4 city11)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U4 city10)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U4 city9)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane6 city11U4)
          (at plane5 city24U4)
          (at plane4 city30U4)
          (at plane3 city9U4)
          (at plane2 city20U4)
          (at plane1 city2U4)
          (at truck74 city30U2)
          (at truck73 city29U2)
          (at truck72 city28U2)
          (at truck71 city27U3)
          (at truck70 city26U1)
          (at truck69 city25U2)
          (at truck68 city24U1)
          (at truck67 city23U3)
          (at truck66 city22U2)
          (at truck65 city21U3)
          (at truck64 city20U1)
          (at truck63 city19U2)
          (at truck62 city18U3)
          (at truck61 city17U1)
          (at truck60 city16U1)
          (at truck59 city15U1)
          (at truck58 city14U2)
          (at truck57 city13U3)
          (at truck56 city12U3)
          (at truck55 city11U2)
          (at truck54 city10U3)
          (at truck53 city9U2)
          (at truck52 city8U3)
          (at truck51 city7U2)
          (at truck50 city6U1)
          (at truck49 city5U1)
          (at truck48 city4U3)
          (at truck47 city3U3)
          (at truck46 city2U3)
          (at truck45 city1U2)
          (at truck44 city7U3)
          (at truck43 city1U4)
          (at truck42 city29U3)
          (at truck41 city9U2)
          (at truck40 city26U2)
          (at truck39 city12U1)
          (at truck38 city28U3)
          (at truck37 city6U4)
          (at truck36 city8U3)
          (at truck35 city14U4)
          (at truck34 city29U4)
          (at truck33 city4U4)
          (at truck32 city17U1)
          (at truck31 city29U1)
          (at truck30 city14U2)
          (at truck29 city9U2)
          (at truck28 city28U1)
          (at truck27 city18U2)
          (at truck26 city17U2)
          (at truck25 city15U4)
          (at truck24 city28U2)
          (at truck23 city7U3)
          (at truck22 city6U2)
          (at truck21 city29U3)
          (at truck20 city18U2)
          (at truck19 city28U3)
          (at truck18 city26U2)
          (at truck17 city1U4)
          (at truck16 city5U1)
          (at truck15 city18U1)
          (at truck14 city29U1)
          (at truck13 city12U4)
          (at truck12 city30U3)
          (at truck11 city7U3)
          (at truck10 city29U1)
          (at truck9 city26U4)
          (at truck8 city2U4)
          (at truck7 city13U1)
          (at truck6 city3U4)
          (at truck5 city8U4)
          (at truck4 city20U4)
          (at truck3 city10U1)
          (at truck2 city10U1)
          (at truck1 city21U2)
          (at package44 city13U1)
          (at package43 city20U2)
          (at package42 city30U4)
          (at package41 city14U4)
          (at package40 city10U3)
          (at package39 city3U3)
          (at package38 city27U3)
          (at package37 city30U3)
          (at package36 city22U1)
          (at package35 city10U3)
          (at package34 city2U4)
          (at package33 city22U2)
          (at package32 city1U4)
          (at package31 city6U3)
          (at package30 city7U3)
          (at package29 city5U3)
          (at package28 city23U2)
          (at package27 city21U3)
          (at package26 city9U4)
          (at package25 city11U2)
          (at package24 city12U3)
          (at package23 city30U2)
          (at package22 city22U1)
          (at package21 city18U2)
          (at package20 city22U1)
          (at package19 city4U1)
          (at package18 city19U2)
          (at package17 city6U4)
          (at package16 city9U1)
          (at package15 city1U1)
          (at package14 city3U2)
          (at package13 city28U2)
          (at package12 city9U3)
          (at package11 city26U2)
          (at package10 city30U2)
          (at package9 city20U3)
          (at package8 city27U4)
          (at package7 city2U2)
          (at package6 city18U3)
          (at package5 city20U1)
          (at package4 city10U3)
          (at package3 city20U1)
          (at package2 city8U2)
          (at package1 city22U1))
   (:goal (and (at package44 city29U3)
               (at package43 city28U3)
               (at package42 city30U3)
               (at package41 city29U3)
               (at package40 city4U2)
               (at package39 city15U3)
               (at package38 city6U4)
               (at package37 city10U1)
               (at package36 city28U2)
               (at package35 city20U2)
               (at package34 city10U4)
               (at package33 city21U2)
               (at package32 city26U4)
               (at package31 city17U4)
               (at package30 city13U4)
               (at package29 city30U4)
               (at package28 city12U3)
               (at package27 city10U1)
               (at package26 city29U2)
               (at package25 city22U1)
               (at package24 city30U3)
               (at package23 city20U3)
               (at package22 city28U4)
               (at package21 city22U2)
               (at package20 city16U2)
               (at package19 city5U3)
               (at package18 city16U2)
               (at package17 city22U2)
               (at package16 city14U4)
               (at package15 city18U3)
               (at package14 city13U2)
               (at package13 city2U3)
               (at package12 city28U1)
               (at package11 city22U2)
               (at package10 city5U4)
               (at package9 city12U3))))

(define (problem stripsUlogUxU23)
   (:domain logisticsUstrips)
   (:objects package21 package20 package19 package18 package17
             package16 package15 package14 package13 package12 package11
             package10 package9 package8 package7 package6 package5 package4
             package3 package2 package1 city8 city7 city6 city5 city4 city3
             city2 city1 truck28 truck27 truck26 truck25 truck24 truck23
             truck22 truck21 truck20 truck19 truck18 truck17 truck16
             truck15 truck14 truck13 truck12 truck11 truck10 truck9 truck8
             truck7 truck6 truck5 truck4 truck3 truck2 truck1 plane4 plane3
             plane2 plane1 city8U1 city7U1 city6U1 city5U1 city4U1 city3U1
             city2U1 city1U1 city8U2 city7U2 city6U2 city5U2 city4U2
             city3U2 city2U2 city1U2)
   (:init (obj package21)
          (obj package20)
          (obj package19)
          (obj package18)
          (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city8U1)
          (location city7U1)
          (location city6U1)
          (location city5U1)
          (location city4U1)
          (location city3U1)
          (location city2U1)
          (location city1U1)
          (airport city8U2)
          (location city8U2)
          (airport city7U2)
          (location city7U2)
          (airport city6U2)
          (location city6U2)
          (airport city5U2)
          (location city5U2)
          (airport city4U2)
          (location city4U2)
          (airport city3U2)
          (location city3U2)
          (airport city2U2)
          (location city2U2)
          (airport city1U2)
          (location city1U2)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane4 city5U2)
          (at plane3 city7U2)
          (at plane2 city3U2)
          (at plane1 city1U2)
          (at truck28 city8U1)
          (at truck27 city7U1)
          (at truck26 city6U1)
          (at truck25 city5U1)
          (at truck24 city4U1)
          (at truck23 city3U1)
          (at truck22 city2U1)
          (at truck21 city1U1)
          (at truck20 city2U2)
          (at truck19 city1U1)
          (at truck18 city2U1)
          (at truck17 city7U1)
          (at truck16 city2U2)
          (at truck15 city3U1)
          (at truck14 city5U2)
          (at truck13 city5U1)
          (at truck12 city5U2)
          (at truck11 city6U2)
          (at truck10 city2U2)
          (at truck9 city2U2)
          (at truck8 city1U1)
          (at truck7 city1U1)
          (at truck6 city4U1)
          (at truck5 city6U2)
          (at truck4 city4U1)
          (at truck3 city4U1)
          (at truck2 city2U1)
          (at truck1 city5U2)
          (at package21 city3U1)
          (at package20 city3U1)
          (at package19 city8U1)
          (at package18 city5U1)
          (at package17 city1U2)
          (at package16 city6U1)
          (at package15 city7U2)
          (at package14 city4U2)
          (at package13 city1U1)
          (at package12 city1U2)
          (at package11 city1U2)
          (at package10 city1U2)
          (at package9 city1U1)
          (at package8 city6U1)
          (at package7 city1U1)
          (at package6 city7U1)
          (at package5 city3U1)
          (at package4 city3U2)
          (at package3 city3U1)
          (at package2 city1U2)
          (at package1 city1U1))
   (:goal (and (at package21 city5U2)
               (at package20 city2U2)
               (at package19 city2U1)
               (at package18 city2U2)
               (at package17 city6U1)
               (at package16 city1U1)
               (at package15 city3U2)
               (at package14 city3U1)
               (at package13 city6U1)
               (at package12 city8U1)
               (at package11 city1U2)
               (at package10 city4U1)
               (at package9 city7U1)
               (at package8 city2U1)
               (at package7 city3U2)
               (at package6 city2U2)
               (at package5 city8U2)
               (at package4 city8U2)
               (at package3 city1U2)
               (at package2 city6U2)
               (at package1 city8U2))))

(define (problem stripsUlogUxU24)
   (:domain logisticsUstrips)
   (:objects package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 city9
             city8 city7 city6 city5 city4 city3 city2 city1 truck54
             truck53 truck52 truck51 truck50 truck49 truck48 truck47
             truck46 truck45 truck44 truck43 truck42 truck41 truck40
             truck39 truck38 truck37 truck36 truck35 truck34 truck33
             truck32 truck31 truck30 truck29 truck28 truck27 truck26
             truck25 truck24 truck23 truck22 truck21 truck20 truck19
             truck18 truck17 truck16 truck15 truck14 truck13 truck12
             truck11 truck10 truck9 truck8 truck7 truck6 truck5 truck4
             truck3 truck2 truck1 plane8 plane7 plane6 plane5 plane4 plane3
             plane2 plane1 city9U11 city9U10 city9U9 city9U8 city9U7
             city9U6 city9U5 city9U4 city9U3 city9U2 city9U1 city8U11
             city8U10 city8U9 city8U8 city8U7 city8U6 city8U5 city8U4
             city8U3 city8U2 city8U1 city7U11 city7U10 city7U9 city7U8
             city7U7 city7U6 city7U5 city7U4 city7U3 city7U2 city7U1
             city6U11 city6U10 city6U9 city6U8 city6U7 city6U6 city6U5
             city6U4 city6U3 city6U2 city6U1 city5U11 city5U10 city5U9
             city5U8 city5U7 city5U6 city5U5 city5U4 city5U3 city5U2
             city5U1 city4U11 city4U10 city4U9 city4U8 city4U7 city4U6
             city4U5 city4U4 city4U3 city4U2 city4U1 city3U11 city3U10
             city3U9 city3U8 city3U7 city3U6 city3U5 city3U4 city3U3
             city3U2 city3U1 city2U11 city2U10 city2U9 city2U8 city2U7
             city2U6 city2U5 city2U4 city2U3 city2U2 city2U1 city1U11
             city1U10 city1U9 city1U8 city1U7 city1U6 city1U5 city1U4
             city1U3 city1U2 city1U1 city9U12 city8U12 city7U12 city6U12
             city5U12 city4U12 city3U12 city2U12 city1U12)
   (:init (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck54)
          (truck truck53)
          (truck truck52)
          (truck truck51)
          (truck truck50)
          (truck truck49)
          (truck truck48)
          (truck truck47)
          (truck truck46)
          (truck truck45)
          (truck truck44)
          (truck truck43)
          (truck truck42)
          (truck truck41)
          (truck truck40)
          (truck truck39)
          (truck truck38)
          (truck truck37)
          (truck truck36)
          (truck truck35)
          (truck truck34)
          (truck truck33)
          (truck truck32)
          (truck truck31)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane8)
          (airplane plane7)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city9U11)
          (location city9U10)
          (location city9U9)
          (location city9U8)
          (location city9U7)
          (location city9U6)
          (location city9U5)
          (location city9U4)
          (location city9U3)
          (location city9U2)
          (location city9U1)
          (location city8U11)
          (location city8U10)
          (location city8U9)
          (location city8U8)
          (location city8U7)
          (location city8U6)
          (location city8U5)
          (location city8U4)
          (location city8U3)
          (location city8U2)
          (location city8U1)
          (location city7U11)
          (location city7U10)
          (location city7U9)
          (location city7U8)
          (location city7U7)
          (location city7U6)
          (location city7U5)
          (location city7U4)
          (location city7U3)
          (location city7U2)
          (location city7U1)
          (location city6U11)
          (location city6U10)
          (location city6U9)
          (location city6U8)
          (location city6U7)
          (location city6U6)
          (location city6U5)
          (location city6U4)
          (location city6U3)
          (location city6U2)
          (location city6U1)
          (location city5U11)
          (location city5U10)
          (location city5U9)
          (location city5U8)
          (location city5U7)
          (location city5U6)
          (location city5U5)
          (location city5U4)
          (location city5U3)
          (location city5U2)
          (location city5U1)
          (location city4U11)
          (location city4U10)
          (location city4U9)
          (location city4U8)
          (location city4U7)
          (location city4U6)
          (location city4U5)
          (location city4U4)
          (location city4U3)
          (location city4U2)
          (location city4U1)
          (location city3U11)
          (location city3U10)
          (location city3U9)
          (location city3U8)
          (location city3U7)
          (location city3U6)
          (location city3U5)
          (location city3U4)
          (location city3U3)
          (location city3U2)
          (location city3U1)
          (location city2U11)
          (location city2U10)
          (location city2U9)
          (location city2U8)
          (location city2U7)
          (location city2U6)
          (location city2U5)
          (location city2U4)
          (location city2U3)
          (location city2U2)
          (location city2U1)
          (location city1U11)
          (location city1U10)
          (location city1U9)
          (location city1U8)
          (location city1U7)
          (location city1U6)
          (location city1U5)
          (location city1U4)
          (location city1U3)
          (location city1U2)
          (location city1U1)
          (airport city9U12)
          (location city9U12)
          (airport city8U12)
          (location city8U12)
          (airport city7U12)
          (location city7U12)
          (airport city6U12)
          (location city6U12)
          (airport city5U12)
          (location city5U12)
          (airport city4U12)
          (location city4U12)
          (airport city3U12)
          (location city3U12)
          (airport city2U12)
          (location city2U12)
          (airport city1U12)
          (location city1U12)
          (inUcity city9U12 city9)
          (inUcity city9U11 city9)
          (inUcity city9U10 city9)
          (inUcity city9U9 city9)
          (inUcity city9U8 city9)
          (inUcity city9U7 city9)
          (inUcity city9U6 city9)
          (inUcity city9U5 city9)
          (inUcity city9U4 city9)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U12 city8)
          (inUcity city8U11 city8)
          (inUcity city8U10 city8)
          (inUcity city8U9 city8)
          (inUcity city8U8 city8)
          (inUcity city8U7 city8)
          (inUcity city8U6 city8)
          (inUcity city8U5 city8)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U12 city7)
          (inUcity city7U11 city7)
          (inUcity city7U10 city7)
          (inUcity city7U9 city7)
          (inUcity city7U8 city7)
          (inUcity city7U7 city7)
          (inUcity city7U6 city7)
          (inUcity city7U5 city7)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U12 city6)
          (inUcity city6U11 city6)
          (inUcity city6U10 city6)
          (inUcity city6U9 city6)
          (inUcity city6U8 city6)
          (inUcity city6U7 city6)
          (inUcity city6U6 city6)
          (inUcity city6U5 city6)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U12 city5)
          (inUcity city5U11 city5)
          (inUcity city5U10 city5)
          (inUcity city5U9 city5)
          (inUcity city5U8 city5)
          (inUcity city5U7 city5)
          (inUcity city5U6 city5)
          (inUcity city5U5 city5)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U12 city4)
          (inUcity city4U11 city4)
          (inUcity city4U10 city4)
          (inUcity city4U9 city4)
          (inUcity city4U8 city4)
          (inUcity city4U7 city4)
          (inUcity city4U6 city4)
          (inUcity city4U5 city4)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U12 city3)
          (inUcity city3U11 city3)
          (inUcity city3U10 city3)
          (inUcity city3U9 city3)
          (inUcity city3U8 city3)
          (inUcity city3U7 city3)
          (inUcity city3U6 city3)
          (inUcity city3U5 city3)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U12 city2)
          (inUcity city2U11 city2)
          (inUcity city2U10 city2)
          (inUcity city2U9 city2)
          (inUcity city2U8 city2)
          (inUcity city2U7 city2)
          (inUcity city2U6 city2)
          (inUcity city2U5 city2)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U12 city1)
          (inUcity city1U11 city1)
          (inUcity city1U10 city1)
          (inUcity city1U9 city1)
          (inUcity city1U8 city1)
          (inUcity city1U7 city1)
          (inUcity city1U6 city1)
          (inUcity city1U5 city1)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane8 city6U12)
          (at plane7 city6U12)
          (at plane6 city9U12)
          (at plane5 city3U12)
          (at plane4 city9U12)
          (at plane3 city2U12)
          (at plane2 city7U12)
          (at plane1 city6U12)
          (at truck54 city9U4)
          (at truck53 city8U5)
          (at truck52 city7U11)
          (at truck51 city6U1)
          (at truck50 city5U4)
          (at truck49 city4U5)
          (at truck48 city3U2)
          (at truck47 city2U8)
          (at truck46 city1U9)
          (at truck45 city5U4)
          (at truck44 city7U6)
          (at truck43 city8U5)
          (at truck42 city3U2)
          (at truck41 city6U8)
          (at truck40 city2U3)
          (at truck39 city2U10)
          (at truck38 city2U12)
          (at truck37 city2U5)
          (at truck36 city5U7)
          (at truck35 city1U3)
          (at truck34 city1U11)
          (at truck33 city6U10)
          (at truck32 city1U2)
          (at truck31 city3U3)
          (at truck30 city5U12)
          (at truck29 city2U4)
          (at truck28 city3U3)
          (at truck27 city2U3)
          (at truck26 city3U3)
          (at truck25 city4U1)
          (at truck24 city1U12)
          (at truck23 city1U1)
          (at truck22 city7U11)
          (at truck21 city4U5)
          (at truck20 city8U6)
          (at truck19 city1U4)
          (at truck18 city4U7)
          (at truck17 city4U10)
          (at truck16 city1U11)
          (at truck15 city9U7)
          (at truck14 city3U3)
          (at truck13 city1U4)
          (at truck12 city4U8)
          (at truck11 city8U9)
          (at truck10 city6U7)
          (at truck9 city6U10)
          (at truck8 city1U1)
          (at truck7 city4U3)
          (at truck6 city4U5)
          (at truck5 city4U5)
          (at truck4 city9U8)
          (at truck3 city4U8)
          (at truck2 city1U5)
          (at truck1 city9U7)
          (at package11 city5U4)
          (at package10 city2U5)
          (at package9 city6U5)
          (at package8 city1U5)
          (at package7 city3U9)
          (at package6 city6U9)
          (at package5 city4U12)
          (at package4 city7U1)
          (at package3 city6U6)
          (at package2 city2U7)
          (at package1 city8U1))
   (:goal (and (at package11 city8U8)
               (at package10 city3U2)
               (at package9 city1U11)
               (at package8 city3U4))))

(define (problem stripsUlogUxU25)
   (:domain logisticsUstrips)
   (:objects package18 package17 package16 package15 package14
             package13 package12 package11 package10 package9 package8
             package7 package6 package5 package4 package3 package2 package1
             city27 city26 city25 city24 city23 city22 city21 city20 city19
             city18 city17 city16 city15 city14 city13 city12 city11 city10
             city9 city8 city7 city6 city5 city4 city3 city2 city1 truck29
             truck28 truck27 truck26 truck25 truck24 truck23 truck22
             truck21 truck20 truck19 truck18 truck17 truck16 truck15
             truck14 truck13 truck12 truck11 truck10 truck9 truck8 truck7
             truck6 truck5 truck4 truck3 truck2 truck1 plane13 plane12
             plane11 plane10 plane9 plane8 plane7 plane6 plane5 plane4
             plane3 plane2 plane1 city27U12 city27U11 city27U10 city27U9
             city27U8 city27U7 city27U6 city27U5 city27U4 city27U3 city27U2
             city27U1 city26U12 city26U11 city26U10 city26U9 city26U8
             city26U7 city26U6 city26U5 city26U4 city26U3 city26U2 city26U1
             city25U12 city25U11 city25U10 city25U9 city25U8 city25U7
             city25U6 city25U5 city25U4 city25U3 city25U2 city25U1
             city24U12 city24U11 city24U10 city24U9 city24U8 city24U7
             city24U6 city24U5 city24U4 city24U3 city24U2 city24U1
             city23U12 city23U11 city23U10 city23U9 city23U8 city23U7
             city23U6 city23U5 city23U4 city23U3 city23U2 city23U1
             city22U12 city22U11 city22U10 city22U9 city22U8 city22U7
             city22U6 city22U5 city22U4 city22U3 city22U2 city22U1
             city21U12 city21U11 city21U10 city21U9 city21U8 city21U7
             city21U6 city21U5 city21U4 city21U3 city21U2 city21U1
             city20U12 city20U11 city20U10 city20U9 city20U8 city20U7
             city20U6 city20U5 city20U4 city20U3 city20U2 city20U1
             city19U12 city19U11 city19U10 city19U9 city19U8 city19U7
             city19U6 city19U5 city19U4 city19U3 city19U2 city19U1
             city18U12 city18U11 city18U10 city18U9 city18U8 city18U7
             city18U6 city18U5 city18U4 city18U3 city18U2 city18U1
             city17U12 city17U11 city17U10 city17U9 city17U8 city17U7
             city17U6 city17U5 city17U4 city17U3 city17U2 city17U1
             city16U12 city16U11 city16U10 city16U9 city16U8 city16U7
             city16U6 city16U5 city16U4 city16U3 city16U2 city16U1
             city15U12 city15U11 city15U10 city15U9 city15U8 city15U7
             city15U6 city15U5 city15U4 city15U3 city15U2 city15U1
             city14U12 city14U11 city14U10 city14U9 city14U8 city14U7
             city14U6 city14U5 city14U4 city14U3 city14U2 city14U1
             city13U12 city13U11 city13U10 city13U9 city13U8 city13U7
             city13U6 city13U5 city13U4 city13U3 city13U2 city13U1
             city12U12 city12U11 city12U10 city12U9 city12U8 city12U7
             city12U6 city12U5 city12U4 city12U3 city12U2 city12U1
             city11U12 city11U11 city11U10 city11U9 city11U8 city11U7
             city11U6 city11U5 city11U4 city11U3 city11U2 city11U1
             city10U12 city10U11 city10U10 city10U9 city10U8 city10U7
             city10U6 city10U5 city10U4 city10U3 city10U2 city10U1 city9U12
             city9U11 city9U10 city9U9 city9U8 city9U7 city9U6 city9U5
             city9U4 city9U3 city9U2 city9U1 city8U12 city8U11 city8U10
             city8U9 city8U8 city8U7 city8U6 city8U5 city8U4 city8U3
             city8U2 city8U1 city7U12 city7U11 city7U10 city7U9 city7U8
             city7U7 city7U6 city7U5 city7U4 city7U3 city7U2 city7U1
             city6U12 city6U11 city6U10 city6U9 city6U8 city6U7 city6U6
             city6U5 city6U4 city6U3 city6U2 city6U1 city5U12 city5U11
             city5U10 city5U9 city5U8 city5U7 city5U6 city5U5 city5U4
             city5U3 city5U2 city5U1 city4U12 city4U11 city4U10 city4U9
             city4U8 city4U7 city4U6 city4U5 city4U4 city4U3 city4U2
             city4U1 city3U12 city3U11 city3U10 city3U9 city3U8 city3U7
             city3U6 city3U5 city3U4 city3U3 city3U2 city3U1 city2U12
             city2U11 city2U10 city2U9 city2U8 city2U7 city2U6 city2U5
             city2U4 city2U3 city2U2 city2U1 city1U12 city1U11 city1U10
             city1U9 city1U8 city1U7 city1U6 city1U5 city1U4 city1U3
             city1U2 city1U1 city27U13 city26U13 city25U13 city24U13
             city23U13 city22U13 city21U13 city20U13 city19U13 city18U13
             city17U13 city16U13 city15U13 city14U13 city13U13 city12U13
             city11U13 city10U13 city9U13 city8U13 city7U13 city6U13
             city5U13 city4U13 city3U13 city2U13 city1U13)
   (:init (obj package18)
          (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city27)
          (city city26)
          (city city25)
          (city city24)
          (city city23)
          (city city22)
          (city city21)
          (city city20)
          (city city19)
          (city city18)
          (city city17)
          (city city16)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane13)
          (airplane plane12)
          (airplane plane11)
          (airplane plane10)
          (airplane plane9)
          (airplane plane8)
          (airplane plane7)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city27U12)
          (location city27U11)
          (location city27U10)
          (location city27U9)
          (location city27U8)
          (location city27U7)
          (location city27U6)
          (location city27U5)
          (location city27U4)
          (location city27U3)
          (location city27U2)
          (location city27U1)
          (location city26U12)
          (location city26U11)
          (location city26U10)
          (location city26U9)
          (location city26U8)
          (location city26U7)
          (location city26U6)
          (location city26U5)
          (location city26U4)
          (location city26U3)
          (location city26U2)
          (location city26U1)
          (location city25U12)
          (location city25U11)
          (location city25U10)
          (location city25U9)
          (location city25U8)
          (location city25U7)
          (location city25U6)
          (location city25U5)
          (location city25U4)
          (location city25U3)
          (location city25U2)
          (location city25U1)
          (location city24U12)
          (location city24U11)
          (location city24U10)
          (location city24U9)
          (location city24U8)
          (location city24U7)
          (location city24U6)
          (location city24U5)
          (location city24U4)
          (location city24U3)
          (location city24U2)
          (location city24U1)
          (location city23U12)
          (location city23U11)
          (location city23U10)
          (location city23U9)
          (location city23U8)
          (location city23U7)
          (location city23U6)
          (location city23U5)
          (location city23U4)
          (location city23U3)
          (location city23U2)
          (location city23U1)
          (location city22U12)
          (location city22U11)
          (location city22U10)
          (location city22U9)
          (location city22U8)
          (location city22U7)
          (location city22U6)
          (location city22U5)
          (location city22U4)
          (location city22U3)
          (location city22U2)
          (location city22U1)
          (location city21U12)
          (location city21U11)
          (location city21U10)
          (location city21U9)
          (location city21U8)
          (location city21U7)
          (location city21U6)
          (location city21U5)
          (location city21U4)
          (location city21U3)
          (location city21U2)
          (location city21U1)
          (location city20U12)
          (location city20U11)
          (location city20U10)
          (location city20U9)
          (location city20U8)
          (location city20U7)
          (location city20U6)
          (location city20U5)
          (location city20U4)
          (location city20U3)
          (location city20U2)
          (location city20U1)
          (location city19U12)
          (location city19U11)
          (location city19U10)
          (location city19U9)
          (location city19U8)
          (location city19U7)
          (location city19U6)
          (location city19U5)
          (location city19U4)
          (location city19U3)
          (location city19U2)
          (location city19U1)
          (location city18U12)
          (location city18U11)
          (location city18U10)
          (location city18U9)
          (location city18U8)
          (location city18U7)
          (location city18U6)
          (location city18U5)
          (location city18U4)
          (location city18U3)
          (location city18U2)
          (location city18U1)
          (location city17U12)
          (location city17U11)
          (location city17U10)
          (location city17U9)
          (location city17U8)
          (location city17U7)
          (location city17U6)
          (location city17U5)
          (location city17U4)
          (location city17U3)
          (location city17U2)
          (location city17U1)
          (location city16U12)
          (location city16U11)
          (location city16U10)
          (location city16U9)
          (location city16U8)
          (location city16U7)
          (location city16U6)
          (location city16U5)
          (location city16U4)
          (location city16U3)
          (location city16U2)
          (location city16U1)
          (location city15U12)
          (location city15U11)
          (location city15U10)
          (location city15U9)
          (location city15U8)
          (location city15U7)
          (location city15U6)
          (location city15U5)
          (location city15U4)
          (location city15U3)
          (location city15U2)
          (location city15U1)
          (location city14U12)
          (location city14U11)
          (location city14U10)
          (location city14U9)
          (location city14U8)
          (location city14U7)
          (location city14U6)
          (location city14U5)
          (location city14U4)
          (location city14U3)
          (location city14U2)
          (location city14U1)
          (location city13U12)
          (location city13U11)
          (location city13U10)
          (location city13U9)
          (location city13U8)
          (location city13U7)
          (location city13U6)
          (location city13U5)
          (location city13U4)
          (location city13U3)
          (location city13U2)
          (location city13U1)
          (location city12U12)
          (location city12U11)
          (location city12U10)
          (location city12U9)
          (location city12U8)
          (location city12U7)
          (location city12U6)
          (location city12U5)
          (location city12U4)
          (location city12U3)
          (location city12U2)
          (location city12U1)
          (location city11U12)
          (location city11U11)
          (location city11U10)
          (location city11U9)
          (location city11U8)
          (location city11U7)
          (location city11U6)
          (location city11U5)
          (location city11U4)
          (location city11U3)
          (location city11U2)
          (location city11U1)
          (location city10U12)
          (location city10U11)
          (location city10U10)
          (location city10U9)
          (location city10U8)
          (location city10U7)
          (location city10U6)
          (location city10U5)
          (location city10U4)
          (location city10U3)
          (location city10U2)
          (location city10U1)
          (location city9U12)
          (location city9U11)
          (location city9U10)
          (location city9U9)
          (location city9U8)
          (location city9U7)
          (location city9U6)
          (location city9U5)
          (location city9U4)
          (location city9U3)
          (location city9U2)
          (location city9U1)
          (location city8U12)
          (location city8U11)
          (location city8U10)
          (location city8U9)
          (location city8U8)
          (location city8U7)
          (location city8U6)
          (location city8U5)
          (location city8U4)
          (location city8U3)
          (location city8U2)
          (location city8U1)
          (location city7U12)
          (location city7U11)
          (location city7U10)
          (location city7U9)
          (location city7U8)
          (location city7U7)
          (location city7U6)
          (location city7U5)
          (location city7U4)
          (location city7U3)
          (location city7U2)
          (location city7U1)
          (location city6U12)
          (location city6U11)
          (location city6U10)
          (location city6U9)
          (location city6U8)
          (location city6U7)
          (location city6U6)
          (location city6U5)
          (location city6U4)
          (location city6U3)
          (location city6U2)
          (location city6U1)
          (location city5U12)
          (location city5U11)
          (location city5U10)
          (location city5U9)
          (location city5U8)
          (location city5U7)
          (location city5U6)
          (location city5U5)
          (location city5U4)
          (location city5U3)
          (location city5U2)
          (location city5U1)
          (location city4U12)
          (location city4U11)
          (location city4U10)
          (location city4U9)
          (location city4U8)
          (location city4U7)
          (location city4U6)
          (location city4U5)
          (location city4U4)
          (location city4U3)
          (location city4U2)
          (location city4U1)
          (location city3U12)
          (location city3U11)
          (location city3U10)
          (location city3U9)
          (location city3U8)
          (location city3U7)
          (location city3U6)
          (location city3U5)
          (location city3U4)
          (location city3U3)
          (location city3U2)
          (location city3U1)
          (location city2U12)
          (location city2U11)
          (location city2U10)
          (location city2U9)
          (location city2U8)
          (location city2U7)
          (location city2U6)
          (location city2U5)
          (location city2U4)
          (location city2U3)
          (location city2U2)
          (location city2U1)
          (location city1U12)
          (location city1U11)
          (location city1U10)
          (location city1U9)
          (location city1U8)
          (location city1U7)
          (location city1U6)
          (location city1U5)
          (location city1U4)
          (location city1U3)
          (location city1U2)
          (location city1U1)
          (airport city27U13)
          (location city27U13)
          (airport city26U13)
          (location city26U13)
          (airport city25U13)
          (location city25U13)
          (airport city24U13)
          (location city24U13)
          (airport city23U13)
          (location city23U13)
          (airport city22U13)
          (location city22U13)
          (airport city21U13)
          (location city21U13)
          (airport city20U13)
          (location city20U13)
          (airport city19U13)
          (location city19U13)
          (airport city18U13)
          (location city18U13)
          (airport city17U13)
          (location city17U13)
          (airport city16U13)
          (location city16U13)
          (airport city15U13)
          (location city15U13)
          (airport city14U13)
          (location city14U13)
          (airport city13U13)
          (location city13U13)
          (airport city12U13)
          (location city12U13)
          (airport city11U13)
          (location city11U13)
          (airport city10U13)
          (location city10U13)
          (airport city9U13)
          (location city9U13)
          (airport city8U13)
          (location city8U13)
          (airport city7U13)
          (location city7U13)
          (airport city6U13)
          (location city6U13)
          (airport city5U13)
          (location city5U13)
          (airport city4U13)
          (location city4U13)
          (airport city3U13)
          (location city3U13)
          (airport city2U13)
          (location city2U13)
          (airport city1U13)
          (location city1U13)
          (inUcity city27U13 city27)
          (inUcity city27U12 city27)
          (inUcity city27U11 city27)
          (inUcity city27U10 city27)
          (inUcity city27U9 city27)
          (inUcity city27U8 city27)
          (inUcity city27U7 city27)
          (inUcity city27U6 city27)
          (inUcity city27U5 city27)
          (inUcity city27U4 city27)
          (inUcity city27U3 city27)
          (inUcity city27U2 city27)
          (inUcity city27U1 city27)
          (inUcity city26U13 city26)
          (inUcity city26U12 city26)
          (inUcity city26U11 city26)
          (inUcity city26U10 city26)
          (inUcity city26U9 city26)
          (inUcity city26U8 city26)
          (inUcity city26U7 city26)
          (inUcity city26U6 city26)
          (inUcity city26U5 city26)
          (inUcity city26U4 city26)
          (inUcity city26U3 city26)
          (inUcity city26U2 city26)
          (inUcity city26U1 city26)
          (inUcity city25U13 city25)
          (inUcity city25U12 city25)
          (inUcity city25U11 city25)
          (inUcity city25U10 city25)
          (inUcity city25U9 city25)
          (inUcity city25U8 city25)
          (inUcity city25U7 city25)
          (inUcity city25U6 city25)
          (inUcity city25U5 city25)
          (inUcity city25U4 city25)
          (inUcity city25U3 city25)
          (inUcity city25U2 city25)
          (inUcity city25U1 city25)
          (inUcity city24U13 city24)
          (inUcity city24U12 city24)
          (inUcity city24U11 city24)
          (inUcity city24U10 city24)
          (inUcity city24U9 city24)
          (inUcity city24U8 city24)
          (inUcity city24U7 city24)
          (inUcity city24U6 city24)
          (inUcity city24U5 city24)
          (inUcity city24U4 city24)
          (inUcity city24U3 city24)
          (inUcity city24U2 city24)
          (inUcity city24U1 city24)
          (inUcity city23U13 city23)
          (inUcity city23U12 city23)
          (inUcity city23U11 city23)
          (inUcity city23U10 city23)
          (inUcity city23U9 city23)
          (inUcity city23U8 city23)
          (inUcity city23U7 city23)
          (inUcity city23U6 city23)
          (inUcity city23U5 city23)
          (inUcity city23U4 city23)
          (inUcity city23U3 city23)
          (inUcity city23U2 city23)
          (inUcity city23U1 city23)
          (inUcity city22U13 city22)
          (inUcity city22U12 city22)
          (inUcity city22U11 city22)
          (inUcity city22U10 city22)
          (inUcity city22U9 city22)
          (inUcity city22U8 city22)
          (inUcity city22U7 city22)
          (inUcity city22U6 city22)
          (inUcity city22U5 city22)
          (inUcity city22U4 city22)
          (inUcity city22U3 city22)
          (inUcity city22U2 city22)
          (inUcity city22U1 city22)
          (inUcity city21U13 city21)
          (inUcity city21U12 city21)
          (inUcity city21U11 city21)
          (inUcity city21U10 city21)
          (inUcity city21U9 city21)
          (inUcity city21U8 city21)
          (inUcity city21U7 city21)
          (inUcity city21U6 city21)
          (inUcity city21U5 city21)
          (inUcity city21U4 city21)
          (inUcity city21U3 city21)
          (inUcity city21U2 city21)
          (inUcity city21U1 city21)
          (inUcity city20U13 city20)
          (inUcity city20U12 city20)
          (inUcity city20U11 city20)
          (inUcity city20U10 city20)
          (inUcity city20U9 city20)
          (inUcity city20U8 city20)
          (inUcity city20U7 city20)
          (inUcity city20U6 city20)
          (inUcity city20U5 city20)
          (inUcity city20U4 city20)
          (inUcity city20U3 city20)
          (inUcity city20U2 city20)
          (inUcity city20U1 city20)
          (inUcity city19U13 city19)
          (inUcity city19U12 city19)
          (inUcity city19U11 city19)
          (inUcity city19U10 city19)
          (inUcity city19U9 city19)
          (inUcity city19U8 city19)
          (inUcity city19U7 city19)
          (inUcity city19U6 city19)
          (inUcity city19U5 city19)
          (inUcity city19U4 city19)
          (inUcity city19U3 city19)
          (inUcity city19U2 city19)
          (inUcity city19U1 city19)
          (inUcity city18U13 city18)
          (inUcity city18U12 city18)
          (inUcity city18U11 city18)
          (inUcity city18U10 city18)
          (inUcity city18U9 city18)
          (inUcity city18U8 city18)
          (inUcity city18U7 city18)
          (inUcity city18U6 city18)
          (inUcity city18U5 city18)
          (inUcity city18U4 city18)
          (inUcity city18U3 city18)
          (inUcity city18U2 city18)
          (inUcity city18U1 city18)
          (inUcity city17U13 city17)
          (inUcity city17U12 city17)
          (inUcity city17U11 city17)
          (inUcity city17U10 city17)
          (inUcity city17U9 city17)
          (inUcity city17U8 city17)
          (inUcity city17U7 city17)
          (inUcity city17U6 city17)
          (inUcity city17U5 city17)
          (inUcity city17U4 city17)
          (inUcity city17U3 city17)
          (inUcity city17U2 city17)
          (inUcity city17U1 city17)
          (inUcity city16U13 city16)
          (inUcity city16U12 city16)
          (inUcity city16U11 city16)
          (inUcity city16U10 city16)
          (inUcity city16U9 city16)
          (inUcity city16U8 city16)
          (inUcity city16U7 city16)
          (inUcity city16U6 city16)
          (inUcity city16U5 city16)
          (inUcity city16U4 city16)
          (inUcity city16U3 city16)
          (inUcity city16U2 city16)
          (inUcity city16U1 city16)
          (inUcity city15U13 city15)
          (inUcity city15U12 city15)
          (inUcity city15U11 city15)
          (inUcity city15U10 city15)
          (inUcity city15U9 city15)
          (inUcity city15U8 city15)
          (inUcity city15U7 city15)
          (inUcity city15U6 city15)
          (inUcity city15U5 city15)
          (inUcity city15U4 city15)
          (inUcity city15U3 city15)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U13 city14)
          (inUcity city14U12 city14)
          (inUcity city14U11 city14)
          (inUcity city14U10 city14)
          (inUcity city14U9 city14)
          (inUcity city14U8 city14)
          (inUcity city14U7 city14)
          (inUcity city14U6 city14)
          (inUcity city14U5 city14)
          (inUcity city14U4 city14)
          (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U13 city13)
          (inUcity city13U12 city13)
          (inUcity city13U11 city13)
          (inUcity city13U10 city13)
          (inUcity city13U9 city13)
          (inUcity city13U8 city13)
          (inUcity city13U7 city13)
          (inUcity city13U6 city13)
          (inUcity city13U5 city13)
          (inUcity city13U4 city13)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U13 city12)
          (inUcity city12U12 city12)
          (inUcity city12U11 city12)
          (inUcity city12U10 city12)
          (inUcity city12U9 city12)
          (inUcity city12U8 city12)
          (inUcity city12U7 city12)
          (inUcity city12U6 city12)
          (inUcity city12U5 city12)
          (inUcity city12U4 city12)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U13 city11)
          (inUcity city11U12 city11)
          (inUcity city11U11 city11)
          (inUcity city11U10 city11)
          (inUcity city11U9 city11)
          (inUcity city11U8 city11)
          (inUcity city11U7 city11)
          (inUcity city11U6 city11)
          (inUcity city11U5 city11)
          (inUcity city11U4 city11)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U13 city10)
          (inUcity city10U12 city10)
          (inUcity city10U11 city10)
          (inUcity city10U10 city10)
          (inUcity city10U9 city10)
          (inUcity city10U8 city10)
          (inUcity city10U7 city10)
          (inUcity city10U6 city10)
          (inUcity city10U5 city10)
          (inUcity city10U4 city10)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U13 city9)
          (inUcity city9U12 city9)
          (inUcity city9U11 city9)
          (inUcity city9U10 city9)
          (inUcity city9U9 city9)
          (inUcity city9U8 city9)
          (inUcity city9U7 city9)
          (inUcity city9U6 city9)
          (inUcity city9U5 city9)
          (inUcity city9U4 city9)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U13 city8)
          (inUcity city8U12 city8)
          (inUcity city8U11 city8)
          (inUcity city8U10 city8)
          (inUcity city8U9 city8)
          (inUcity city8U8 city8)
          (inUcity city8U7 city8)
          (inUcity city8U6 city8)
          (inUcity city8U5 city8)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U13 city7)
          (inUcity city7U12 city7)
          (inUcity city7U11 city7)
          (inUcity city7U10 city7)
          (inUcity city7U9 city7)
          (inUcity city7U8 city7)
          (inUcity city7U7 city7)
          (inUcity city7U6 city7)
          (inUcity city7U5 city7)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U13 city6)
          (inUcity city6U12 city6)
          (inUcity city6U11 city6)
          (inUcity city6U10 city6)
          (inUcity city6U9 city6)
          (inUcity city6U8 city6)
          (inUcity city6U7 city6)
          (inUcity city6U6 city6)
          (inUcity city6U5 city6)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U13 city5)
          (inUcity city5U12 city5)
          (inUcity city5U11 city5)
          (inUcity city5U10 city5)
          (inUcity city5U9 city5)
          (inUcity city5U8 city5)
          (inUcity city5U7 city5)
          (inUcity city5U6 city5)
          (inUcity city5U5 city5)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U13 city4)
          (inUcity city4U12 city4)
          (inUcity city4U11 city4)
          (inUcity city4U10 city4)
          (inUcity city4U9 city4)
          (inUcity city4U8 city4)
          (inUcity city4U7 city4)
          (inUcity city4U6 city4)
          (inUcity city4U5 city4)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U13 city3)
          (inUcity city3U12 city3)
          (inUcity city3U11 city3)
          (inUcity city3U10 city3)
          (inUcity city3U9 city3)
          (inUcity city3U8 city3)
          (inUcity city3U7 city3)
          (inUcity city3U6 city3)
          (inUcity city3U5 city3)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U13 city2)
          (inUcity city2U12 city2)
          (inUcity city2U11 city2)
          (inUcity city2U10 city2)
          (inUcity city2U9 city2)
          (inUcity city2U8 city2)
          (inUcity city2U7 city2)
          (inUcity city2U6 city2)
          (inUcity city2U5 city2)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U13 city1)
          (inUcity city1U12 city1)
          (inUcity city1U11 city1)
          (inUcity city1U10 city1)
          (inUcity city1U9 city1)
          (inUcity city1U8 city1)
          (inUcity city1U7 city1)
          (inUcity city1U6 city1)
          (inUcity city1U5 city1)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane13 city16U13)
          (at plane12 city7U13)
          (at plane11 city3U13)
          (at plane10 city6U13)
          (at plane9 city3U13)
          (at plane8 city8U13)
          (at plane7 city21U13)
          (at plane6 city9U13)
          (at plane5 city26U13)
          (at plane4 city20U13)
          (at plane3 city23U13)
          (at plane2 city22U13)
          (at plane1 city1U13)
          (at truck29 city27U2)
          (at truck28 city26U6)
          (at truck27 city25U6)
          (at truck26 city24U9)
          (at truck25 city23U3)
          (at truck24 city22U5)
          (at truck23 city21U8)
          (at truck22 city20U5)
          (at truck21 city19U9)
          (at truck20 city18U9)
          (at truck19 city17U8)
          (at truck18 city16U9)
          (at truck17 city15U2)
          (at truck16 city14U9)
          (at truck15 city13U8)
          (at truck14 city12U1)
          (at truck13 city11U4)
          (at truck12 city10U5)
          (at truck11 city9U1)
          (at truck10 city8U9)
          (at truck9 city7U3)
          (at truck8 city6U10)
          (at truck7 city5U5)
          (at truck6 city4U10)
          (at truck5 city3U4)
          (at truck4 city2U10)
          (at truck3 city1U7)
          (at truck2 city11U7)
          (at truck1 city14U7)
          (at package18 city27U2)
          (at package17 city5U11)
          (at package16 city7U11)
          (at package15 city6U7)
          (at package14 city9U5)
          (at package13 city1U12)
          (at package12 city8U7)
          (at package11 city21U11)
          (at package10 city24U12)
          (at package9 city2U1)
          (at package8 city6U13)
          (at package7 city20U7)
          (at package6 city5U2)
          (at package5 city13U4)
          (at package4 city15U10)
          (at package3 city15U5)
          (at package2 city5U7)
          (at package1 city20U7))
   (:goal (and (at package18 city11U8)
               (at package17 city21U6)
               (at package16 city26U12)
               (at package15 city16U11)
               (at package14 city10U8)
               (at package13 city7U2)
               (at package12 city24U6)
               (at package11 city23U12)
               (at package10 city14U3)
               (at package9 city22U1)
               (at package8 city3U11)
               (at package7 city11U11)
               (at package6 city9U1)
               (at package5 city6U3)
               (at package4 city9U4)
               (at package3 city19U5)
               (at package2 city16U11)
               (at package1 city26U3))))

(define (problem stripsUlogUxU26)
   (:domain logisticsUstrips)
   (:objects package33 package32 package31 package30 package29
             package28 package27 package26 package25 package24 package23
             package22 package21 package20 package19 package18 package17
             package16 package15 package14 package13 package12 package11
             package10 package9 package8 package7 package6 package5 package4
             package3 package2 package1 city47 city46 city45 city44 city43
             city42 city41 city40 city39 city38 city37 city36 city35 city34
             city33 city32 city31 city30 city29 city28 city27 city26 city25
             city24 city23 city22 city21 city20 city19 city18 city17 city16
             city15 city14 city13 city12 city11 city10 city9 city8 city7
             city6 city5 city4 city3 city2 city1 truck106 truck105
             truck104 truck103 truck102 truck101 truck100 truck99 truck98
             truck97 truck96 truck95 truck94 truck93 truck92 truck91
             truck90 truck89 truck88 truck87 truck86 truck85 truck84
             truck83 truck82 truck81 truck80 truck79 truck78 truck77
             truck76 truck75 truck74 truck73 truck72 truck71 truck70
             truck69 truck68 truck67 truck66 truck65 truck64 truck63
             truck62 truck61 truck60 truck59 truck58 truck57 truck56
             truck55 truck54 truck53 truck52 truck51 truck50 truck49
             truck48 truck47 truck46 truck45 truck44 truck43 truck42
             truck41 truck40 truck39 truck38 truck37 truck36 truck35
             truck34 truck33 truck32 truck31 truck30 truck29 truck28
             truck27 truck26 truck25 truck24 truck23 truck22 truck21
             truck20 truck19 truck18 truck17 truck16 truck15 truck14
             truck13 truck12 truck11 truck10 truck9 truck8 truck7 truck6
             truck5 truck4 truck3 truck2 truck1 plane2 plane1 city47U1
             city46U1 city45U1 city44U1 city43U1 city42U1 city41U1 city40U1
             city39U1 city38U1 city37U1 city36U1 city35U1 city34U1 city33U1
             city32U1 city31U1 city30U1 city29U1 city28U1 city27U1 city26U1
             city25U1 city24U1 city23U1 city22U1 city21U1 city20U1 city19U1
             city18U1 city17U1 city16U1 city15U1 city14U1 city13U1 city12U1
             city11U1 city10U1 city9U1 city8U1 city7U1 city6U1 city5U1
             city4U1 city3U1 city2U1 city1U1 city47U2 city46U2 city45U2
             city44U2 city43U2 city42U2 city41U2 city40U2 city39U2 city38U2
             city37U2 city36U2 city35U2 city34U2 city33U2 city32U2 city31U2
             city30U2 city29U2 city28U2 city27U2 city26U2 city25U2 city24U2
             city23U2 city22U2 city21U2 city20U2 city19U2 city18U2 city17U2
             city16U2 city15U2 city14U2 city13U2 city12U2 city11U2 city10U2
             city9U2 city8U2 city7U2 city6U2 city5U2 city4U2 city3U2
             city2U2 city1U2)
   (:init (obj package33)
          (obj package32)
          (obj package31)
          (obj package30)
          (obj package29)
          (obj package28)
          (obj package27)
          (obj package26)
          (obj package25)
          (obj package24)
          (obj package23)
          (obj package22)
          (obj package21)
          (obj package20)
          (obj package19)
          (obj package18)
          (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city47)
          (city city46)
          (city city45)
          (city city44)
          (city city43)
          (city city42)
          (city city41)
          (city city40)
          (city city39)
          (city city38)
          (city city37)
          (city city36)
          (city city35)
          (city city34)
          (city city33)
          (city city32)
          (city city31)
          (city city30)
          (city city29)
          (city city28)
          (city city27)
          (city city26)
          (city city25)
          (city city24)
          (city city23)
          (city city22)
          (city city21)
          (city city20)
          (city city19)
          (city city18)
          (city city17)
          (city city16)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck106)
          (truck truck105)
          (truck truck104)
          (truck truck103)
          (truck truck102)
          (truck truck101)
          (truck truck100)
          (truck truck99)
          (truck truck98)
          (truck truck97)
          (truck truck96)
          (truck truck95)
          (truck truck94)
          (truck truck93)
          (truck truck92)
          (truck truck91)
          (truck truck90)
          (truck truck89)
          (truck truck88)
          (truck truck87)
          (truck truck86)
          (truck truck85)
          (truck truck84)
          (truck truck83)
          (truck truck82)
          (truck truck81)
          (truck truck80)
          (truck truck79)
          (truck truck78)
          (truck truck77)
          (truck truck76)
          (truck truck75)
          (truck truck74)
          (truck truck73)
          (truck truck72)
          (truck truck71)
          (truck truck70)
          (truck truck69)
          (truck truck68)
          (truck truck67)
          (truck truck66)
          (truck truck65)
          (truck truck64)
          (truck truck63)
          (truck truck62)
          (truck truck61)
          (truck truck60)
          (truck truck59)
          (truck truck58)
          (truck truck57)
          (truck truck56)
          (truck truck55)
          (truck truck54)
          (truck truck53)
          (truck truck52)
          (truck truck51)
          (truck truck50)
          (truck truck49)
          (truck truck48)
          (truck truck47)
          (truck truck46)
          (truck truck45)
          (truck truck44)
          (truck truck43)
          (truck truck42)
          (truck truck41)
          (truck truck40)
          (truck truck39)
          (truck truck38)
          (truck truck37)
          (truck truck36)
          (truck truck35)
          (truck truck34)
          (truck truck33)
          (truck truck32)
          (truck truck31)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane2)
          (airplane plane1)
          (location city47U1)
          (location city46U1)
          (location city45U1)
          (location city44U1)
          (location city43U1)
          (location city42U1)
          (location city41U1)
          (location city40U1)
          (location city39U1)
          (location city38U1)
          (location city37U1)
          (location city36U1)
          (location city35U1)
          (location city34U1)
          (location city33U1)
          (location city32U1)
          (location city31U1)
          (location city30U1)
          (location city29U1)
          (location city28U1)
          (location city27U1)
          (location city26U1)
          (location city25U1)
          (location city24U1)
          (location city23U1)
          (location city22U1)
          (location city21U1)
          (location city20U1)
          (location city19U1)
          (location city18U1)
          (location city17U1)
          (location city16U1)
          (location city15U1)
          (location city14U1)
          (location city13U1)
          (location city12U1)
          (location city11U1)
          (location city10U1)
          (location city9U1)
          (location city8U1)
          (location city7U1)
          (location city6U1)
          (location city5U1)
          (location city4U1)
          (location city3U1)
          (location city2U1)
          (location city1U1)
          (airport city47U2)
          (location city47U2)
          (airport city46U2)
          (location city46U2)
          (airport city45U2)
          (location city45U2)
          (airport city44U2)
          (location city44U2)
          (airport city43U2)
          (location city43U2)
          (airport city42U2)
          (location city42U2)
          (airport city41U2)
          (location city41U2)
          (airport city40U2)
          (location city40U2)
          (airport city39U2)
          (location city39U2)
          (airport city38U2)
          (location city38U2)
          (airport city37U2)
          (location city37U2)
          (airport city36U2)
          (location city36U2)
          (airport city35U2)
          (location city35U2)
          (airport city34U2)
          (location city34U2)
          (airport city33U2)
          (location city33U2)
          (airport city32U2)
          (location city32U2)
          (airport city31U2)
          (location city31U2)
          (airport city30U2)
          (location city30U2)
          (airport city29U2)
          (location city29U2)
          (airport city28U2)
          (location city28U2)
          (airport city27U2)
          (location city27U2)
          (airport city26U2)
          (location city26U2)
          (airport city25U2)
          (location city25U2)
          (airport city24U2)
          (location city24U2)
          (airport city23U2)
          (location city23U2)
          (airport city22U2)
          (location city22U2)
          (airport city21U2)
          (location city21U2)
          (airport city20U2)
          (location city20U2)
          (airport city19U2)
          (location city19U2)
          (airport city18U2)
          (location city18U2)
          (airport city17U2)
          (location city17U2)
          (airport city16U2)
          (location city16U2)
          (airport city15U2)
          (location city15U2)
          (airport city14U2)
          (location city14U2)
          (airport city13U2)
          (location city13U2)
          (airport city12U2)
          (location city12U2)
          (airport city11U2)
          (location city11U2)
          (airport city10U2)
          (location city10U2)
          (airport city9U2)
          (location city9U2)
          (airport city8U2)
          (location city8U2)
          (airport city7U2)
          (location city7U2)
          (airport city6U2)
          (location city6U2)
          (airport city5U2)
          (location city5U2)
          (airport city4U2)
          (location city4U2)
          (airport city3U2)
          (location city3U2)
          (airport city2U2)
          (location city2U2)
          (airport city1U2)
          (location city1U2)
          (inUcity city47U2 city47)
          (inUcity city47U1 city47)
          (inUcity city46U2 city46)
          (inUcity city46U1 city46)
          (inUcity city45U2 city45)
          (inUcity city45U1 city45)
          (inUcity city44U2 city44)
          (inUcity city44U1 city44)
          (inUcity city43U2 city43)
          (inUcity city43U1 city43)
          (inUcity city42U2 city42)
          (inUcity city42U1 city42)
          (inUcity city41U2 city41)
          (inUcity city41U1 city41)
          (inUcity city40U2 city40)
          (inUcity city40U1 city40)
          (inUcity city39U2 city39)
          (inUcity city39U1 city39)
          (inUcity city38U2 city38)
          (inUcity city38U1 city38)
          (inUcity city37U2 city37)
          (inUcity city37U1 city37)
          (inUcity city36U2 city36)
          (inUcity city36U1 city36)
          (inUcity city35U2 city35)
          (inUcity city35U1 city35)
          (inUcity city34U2 city34)
          (inUcity city34U1 city34)
          (inUcity city33U2 city33)
          (inUcity city33U1 city33)
          (inUcity city32U2 city32)
          (inUcity city32U1 city32)
          (inUcity city31U2 city31)
          (inUcity city31U1 city31)
          (inUcity city30U2 city30)
          (inUcity city30U1 city30)
          (inUcity city29U2 city29)
          (inUcity city29U1 city29)
          (inUcity city28U2 city28)
          (inUcity city28U1 city28)
          (inUcity city27U2 city27)
          (inUcity city27U1 city27)
          (inUcity city26U2 city26)
          (inUcity city26U1 city26)
          (inUcity city25U2 city25)
          (inUcity city25U1 city25)
          (inUcity city24U2 city24)
          (inUcity city24U1 city24)
          (inUcity city23U2 city23)
          (inUcity city23U1 city23)
          (inUcity city22U2 city22)
          (inUcity city22U1 city22)
          (inUcity city21U2 city21)
          (inUcity city21U1 city21)
          (inUcity city20U2 city20)
          (inUcity city20U1 city20)
          (inUcity city19U2 city19)
          (inUcity city19U1 city19)
          (inUcity city18U2 city18)
          (inUcity city18U1 city18)
          (inUcity city17U2 city17)
          (inUcity city17U1 city17)
          (inUcity city16U2 city16)
          (inUcity city16U1 city16)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane2 city37U2)
          (at plane1 city33U2)
          (at truck106 city47U1)
          (at truck105 city46U1)
          (at truck104 city45U1)
          (at truck103 city44U1)
          (at truck102 city43U1)
          (at truck101 city42U1)
          (at truck100 city41U1)
          (at truck99 city40U1)
          (at truck98 city39U1)
          (at truck97 city38U1)
          (at truck96 city37U1)
          (at truck95 city36U1)
          (at truck94 city35U1)
          (at truck93 city34U1)
          (at truck92 city33U1)
          (at truck91 city32U1)
          (at truck90 city31U1)
          (at truck89 city30U1)
          (at truck88 city29U1)
          (at truck87 city28U1)
          (at truck86 city27U1)
          (at truck85 city26U1)
          (at truck84 city25U1)
          (at truck83 city24U1)
          (at truck82 city23U1)
          (at truck81 city22U1)
          (at truck80 city21U1)
          (at truck79 city20U1)
          (at truck78 city19U1)
          (at truck77 city18U1)
          (at truck76 city17U1)
          (at truck75 city16U1)
          (at truck74 city15U1)
          (at truck73 city14U1)
          (at truck72 city13U1)
          (at truck71 city12U1)
          (at truck70 city11U1)
          (at truck69 city10U1)
          (at truck68 city9U1)
          (at truck67 city8U1)
          (at truck66 city7U1)
          (at truck65 city6U1)
          (at truck64 city5U1)
          (at truck63 city4U1)
          (at truck62 city3U1)
          (at truck61 city2U1)
          (at truck60 city1U1)
          (at truck59 city1U2)
          (at truck58 city12U1)
          (at truck57 city15U2)
          (at truck56 city28U2)
          (at truck55 city7U1)
          (at truck54 city36U1)
          (at truck53 city15U1)
          (at truck52 city45U2)
          (at truck51 city3U1)
          (at truck50 city44U2)
          (at truck49 city42U1)
          (at truck48 city42U2)
          (at truck47 city23U1)
          (at truck46 city5U1)
          (at truck45 city11U1)
          (at truck44 city23U2)
          (at truck43 city19U2)
          (at truck42 city17U2)
          (at truck41 city42U1)
          (at truck40 city25U2)
          (at truck39 city14U1)
          (at truck38 city9U1)
          (at truck37 city32U2)
          (at truck36 city3U1)
          (at truck35 city13U2)
          (at truck34 city47U2)
          (at truck33 city1U2)
          (at truck32 city10U2)
          (at truck31 city35U1)
          (at truck30 city44U2)
          (at truck29 city14U2)
          (at truck28 city23U1)
          (at truck27 city24U1)
          (at truck26 city24U2)
          (at truck25 city23U1)
          (at truck24 city5U2)
          (at truck23 city4U1)
          (at truck22 city30U1)
          (at truck21 city6U2)
          (at truck20 city31U2)
          (at truck19 city7U1)
          (at truck18 city35U2)
          (at truck17 city40U1)
          (at truck16 city45U2)
          (at truck15 city35U2)
          (at truck14 city12U2)
          (at truck13 city2U2)
          (at truck12 city29U1)
          (at truck11 city1U1)
          (at truck10 city25U1)
          (at truck9 city1U2)
          (at truck8 city30U1)
          (at truck7 city16U2)
          (at truck6 city25U2)
          (at truck5 city37U1)
          (at truck4 city41U2)
          (at truck3 city36U2)
          (at truck2 city39U2)
          (at truck1 city4U2)
          (at package33 city29U2)
          (at package32 city10U2)
          (at package31 city45U2)
          (at package30 city21U2)
          (at package29 city34U1)
          (at package28 city4U2)
          (at package27 city30U2)
          (at package26 city5U2)
          (at package25 city38U1)
          (at package24 city10U1)
          (at package23 city23U1)
          (at package22 city42U1)
          (at package21 city18U1)
          (at package20 city35U2)
          (at package19 city37U2)
          (at package18 city43U1)
          (at package17 city14U2)
          (at package16 city42U2)
          (at package15 city27U2)
          (at package14 city40U2)
          (at package13 city7U1)
          (at package12 city6U1)
          (at package11 city40U2)
          (at package10 city14U2)
          (at package9 city34U1)
          (at package8 city7U1)
          (at package7 city12U1)
          (at package6 city44U1)
          (at package5 city11U1)
          (at package4 city28U2)
          (at package3 city6U2)
          (at package2 city27U1)
          (at package1 city12U2))
   (:goal (and (at package33 city40U2)
               (at package32 city46U2)
               (at package31 city26U2)
               (at package30 city25U2)
               (at package29 city23U1)
               (at package28 city30U2)
               (at package27 city11U2)
               (at package26 city2U1)
               (at package25 city7U1)
               (at package24 city46U1)
               (at package23 city39U1)
               (at package22 city25U1)
               (at package21 city31U2)
               (at package20 city11U2)
               (at package19 city14U1)
               (at package18 city3U2)
               (at package17 city2U1)
               (at package16 city19U2)
               (at package15 city8U2)
               (at package14 city17U1)
               (at package13 city37U2)
               (at package12 city27U1)
               (at package11 city9U2)
               (at package10 city22U2)
               (at package9 city38U1)
               (at package8 city20U1)
               (at package7 city30U1)
               (at package6 city46U1)
               (at package5 city6U2)
               (at package4 city5U2)
               (at package3 city2U2))))

(define (problem stripsUlogUxU27)
   (:domain logisticsUstrips)
   (:objects package57 package56 package55 package54 package53
             package52 package51 package50 package49 package48 package47
             package46 package45 package44 package43 package42 package41
             package40 package39 package38 package37 package36 package35
             package34 package33 package32 package31 package30 package29
             package28 package27 package26 package25 package24 package23
             package22 package21 package20 package19 package18 package17
             package16 package15 package14 package13 package12 package11
             package10 package9 package8 package7 package6 package5 package4
             package3 package2 package1 city15 city14 city13 city12 city11
             city10 city9 city8 city7 city6 city5 city4 city3 city2 city1
             truck28 truck27 truck26 truck25 truck24 truck23 truck22
             truck21 truck20 truck19 truck18 truck17 truck16 truck15
             truck14 truck13 truck12 truck11 truck10 truck9 truck8 truck7
             truck6 truck5 truck4 truck3 truck2 truck1 plane9 plane8 plane7
             plane6 plane5 plane4 plane3 plane2 plane1 city15U13 city15U12
             city15U11 city15U10 city15U9 city15U8 city15U7 city15U6
             city15U5 city15U4 city15U3 city15U2 city15U1 city14U13
             city14U12 city14U11 city14U10 city14U9 city14U8 city14U7
             city14U6 city14U5 city14U4 city14U3 city14U2 city14U1
             city13U13 city13U12 city13U11 city13U10 city13U9 city13U8
             city13U7 city13U6 city13U5 city13U4 city13U3 city13U2 city13U1
             city12U13 city12U12 city12U11 city12U10 city12U9 city12U8
             city12U7 city12U6 city12U5 city12U4 city12U3 city12U2 city12U1
             city11U13 city11U12 city11U11 city11U10 city11U9 city11U8
             city11U7 city11U6 city11U5 city11U4 city11U3 city11U2 city11U1
             city10U13 city10U12 city10U11 city10U10 city10U9 city10U8
             city10U7 city10U6 city10U5 city10U4 city10U3 city10U2 city10U1
             city9U13 city9U12 city9U11 city9U10 city9U9 city9U8 city9U7
             city9U6 city9U5 city9U4 city9U3 city9U2 city9U1 city8U13
             city8U12 city8U11 city8U10 city8U9 city8U8 city8U7 city8U6
             city8U5 city8U4 city8U3 city8U2 city8U1 city7U13 city7U12
             city7U11 city7U10 city7U9 city7U8 city7U7 city7U6 city7U5
             city7U4 city7U3 city7U2 city7U1 city6U13 city6U12 city6U11
             city6U10 city6U9 city6U8 city6U7 city6U6 city6U5 city6U4
             city6U3 city6U2 city6U1 city5U13 city5U12 city5U11 city5U10
             city5U9 city5U8 city5U7 city5U6 city5U5 city5U4 city5U3
             city5U2 city5U1 city4U13 city4U12 city4U11 city4U10 city4U9
             city4U8 city4U7 city4U6 city4U5 city4U4 city4U3 city4U2
             city4U1 city3U13 city3U12 city3U11 city3U10 city3U9 city3U8
             city3U7 city3U6 city3U5 city3U4 city3U3 city3U2 city3U1
             city2U13 city2U12 city2U11 city2U10 city2U9 city2U8 city2U7
             city2U6 city2U5 city2U4 city2U3 city2U2 city2U1 city1U13
             city1U12 city1U11 city1U10 city1U9 city1U8 city1U7 city1U6
             city1U5 city1U4 city1U3 city1U2 city1U1 city15U14 city14U14
             city13U14 city12U14 city11U14 city10U14 city9U14 city8U14
             city7U14 city6U14 city5U14 city4U14 city3U14 city2U14 city1U14)
   (:init (obj package57)
          (obj package56)
          (obj package55)
          (obj package54)
          (obj package53)
          (obj package52)
          (obj package51)
          (obj package50)
          (obj package49)
          (obj package48)
          (obj package47)
          (obj package46)
          (obj package45)
          (obj package44)
          (obj package43)
          (obj package42)
          (obj package41)
          (obj package40)
          (obj package39)
          (obj package38)
          (obj package37)
          (obj package36)
          (obj package35)
          (obj package34)
          (obj package33)
          (obj package32)
          (obj package31)
          (obj package30)
          (obj package29)
          (obj package28)
          (obj package27)
          (obj package26)
          (obj package25)
          (obj package24)
          (obj package23)
          (obj package22)
          (obj package21)
          (obj package20)
          (obj package19)
          (obj package18)
          (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane9)
          (airplane plane8)
          (airplane plane7)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city15U13)
          (location city15U12)
          (location city15U11)
          (location city15U10)
          (location city15U9)
          (location city15U8)
          (location city15U7)
          (location city15U6)
          (location city15U5)
          (location city15U4)
          (location city15U3)
          (location city15U2)
          (location city15U1)
          (location city14U13)
          (location city14U12)
          (location city14U11)
          (location city14U10)
          (location city14U9)
          (location city14U8)
          (location city14U7)
          (location city14U6)
          (location city14U5)
          (location city14U4)
          (location city14U3)
          (location city14U2)
          (location city14U1)
          (location city13U13)
          (location city13U12)
          (location city13U11)
          (location city13U10)
          (location city13U9)
          (location city13U8)
          (location city13U7)
          (location city13U6)
          (location city13U5)
          (location city13U4)
          (location city13U3)
          (location city13U2)
          (location city13U1)
          (location city12U13)
          (location city12U12)
          (location city12U11)
          (location city12U10)
          (location city12U9)
          (location city12U8)
          (location city12U7)
          (location city12U6)
          (location city12U5)
          (location city12U4)
          (location city12U3)
          (location city12U2)
          (location city12U1)
          (location city11U13)
          (location city11U12)
          (location city11U11)
          (location city11U10)
          (location city11U9)
          (location city11U8)
          (location city11U7)
          (location city11U6)
          (location city11U5)
          (location city11U4)
          (location city11U3)
          (location city11U2)
          (location city11U1)
          (location city10U13)
          (location city10U12)
          (location city10U11)
          (location city10U10)
          (location city10U9)
          (location city10U8)
          (location city10U7)
          (location city10U6)
          (location city10U5)
          (location city10U4)
          (location city10U3)
          (location city10U2)
          (location city10U1)
          (location city9U13)
          (location city9U12)
          (location city9U11)
          (location city9U10)
          (location city9U9)
          (location city9U8)
          (location city9U7)
          (location city9U6)
          (location city9U5)
          (location city9U4)
          (location city9U3)
          (location city9U2)
          (location city9U1)
          (location city8U13)
          (location city8U12)
          (location city8U11)
          (location city8U10)
          (location city8U9)
          (location city8U8)
          (location city8U7)
          (location city8U6)
          (location city8U5)
          (location city8U4)
          (location city8U3)
          (location city8U2)
          (location city8U1)
          (location city7U13)
          (location city7U12)
          (location city7U11)
          (location city7U10)
          (location city7U9)
          (location city7U8)
          (location city7U7)
          (location city7U6)
          (location city7U5)
          (location city7U4)
          (location city7U3)
          (location city7U2)
          (location city7U1)
          (location city6U13)
          (location city6U12)
          (location city6U11)
          (location city6U10)
          (location city6U9)
          (location city6U8)
          (location city6U7)
          (location city6U6)
          (location city6U5)
          (location city6U4)
          (location city6U3)
          (location city6U2)
          (location city6U1)
          (location city5U13)
          (location city5U12)
          (location city5U11)
          (location city5U10)
          (location city5U9)
          (location city5U8)
          (location city5U7)
          (location city5U6)
          (location city5U5)
          (location city5U4)
          (location city5U3)
          (location city5U2)
          (location city5U1)
          (location city4U13)
          (location city4U12)
          (location city4U11)
          (location city4U10)
          (location city4U9)
          (location city4U8)
          (location city4U7)
          (location city4U6)
          (location city4U5)
          (location city4U4)
          (location city4U3)
          (location city4U2)
          (location city4U1)
          (location city3U13)
          (location city3U12)
          (location city3U11)
          (location city3U10)
          (location city3U9)
          (location city3U8)
          (location city3U7)
          (location city3U6)
          (location city3U5)
          (location city3U4)
          (location city3U3)
          (location city3U2)
          (location city3U1)
          (location city2U13)
          (location city2U12)
          (location city2U11)
          (location city2U10)
          (location city2U9)
          (location city2U8)
          (location city2U7)
          (location city2U6)
          (location city2U5)
          (location city2U4)
          (location city2U3)
          (location city2U2)
          (location city2U1)
          (location city1U13)
          (location city1U12)
          (location city1U11)
          (location city1U10)
          (location city1U9)
          (location city1U8)
          (location city1U7)
          (location city1U6)
          (location city1U5)
          (location city1U4)
          (location city1U3)
          (location city1U2)
          (location city1U1)
          (airport city15U14)
          (location city15U14)
          (airport city14U14)
          (location city14U14)
          (airport city13U14)
          (location city13U14)
          (airport city12U14)
          (location city12U14)
          (airport city11U14)
          (location city11U14)
          (airport city10U14)
          (location city10U14)
          (airport city9U14)
          (location city9U14)
          (airport city8U14)
          (location city8U14)
          (airport city7U14)
          (location city7U14)
          (airport city6U14)
          (location city6U14)
          (airport city5U14)
          (location city5U14)
          (airport city4U14)
          (location city4U14)
          (airport city3U14)
          (location city3U14)
          (airport city2U14)
          (location city2U14)
          (airport city1U14)
          (location city1U14)
          (inUcity city15U14 city15)
          (inUcity city15U13 city15)
          (inUcity city15U12 city15)
          (inUcity city15U11 city15)
          (inUcity city15U10 city15)
          (inUcity city15U9 city15)
          (inUcity city15U8 city15)
          (inUcity city15U7 city15)
          (inUcity city15U6 city15)
          (inUcity city15U5 city15)
          (inUcity city15U4 city15)
          (inUcity city15U3 city15)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U14 city14)
          (inUcity city14U13 city14)
          (inUcity city14U12 city14)
          (inUcity city14U11 city14)
          (inUcity city14U10 city14)
          (inUcity city14U9 city14)
          (inUcity city14U8 city14)
          (inUcity city14U7 city14)
          (inUcity city14U6 city14)
          (inUcity city14U5 city14)
          (inUcity city14U4 city14)
          (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U14 city13)
          (inUcity city13U13 city13)
          (inUcity city13U12 city13)
          (inUcity city13U11 city13)
          (inUcity city13U10 city13)
          (inUcity city13U9 city13)
          (inUcity city13U8 city13)
          (inUcity city13U7 city13)
          (inUcity city13U6 city13)
          (inUcity city13U5 city13)
          (inUcity city13U4 city13)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U14 city12)
          (inUcity city12U13 city12)
          (inUcity city12U12 city12)
          (inUcity city12U11 city12)
          (inUcity city12U10 city12)
          (inUcity city12U9 city12)
          (inUcity city12U8 city12)
          (inUcity city12U7 city12)
          (inUcity city12U6 city12)
          (inUcity city12U5 city12)
          (inUcity city12U4 city12)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U14 city11)
          (inUcity city11U13 city11)
          (inUcity city11U12 city11)
          (inUcity city11U11 city11)
          (inUcity city11U10 city11)
          (inUcity city11U9 city11)
          (inUcity city11U8 city11)
          (inUcity city11U7 city11)
          (inUcity city11U6 city11)
          (inUcity city11U5 city11)
          (inUcity city11U4 city11)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U14 city10)
          (inUcity city10U13 city10)
          (inUcity city10U12 city10)
          (inUcity city10U11 city10)
          (inUcity city10U10 city10)
          (inUcity city10U9 city10)
          (inUcity city10U8 city10)
          (inUcity city10U7 city10)
          (inUcity city10U6 city10)
          (inUcity city10U5 city10)
          (inUcity city10U4 city10)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U14 city9)
          (inUcity city9U13 city9)
          (inUcity city9U12 city9)
          (inUcity city9U11 city9)
          (inUcity city9U10 city9)
          (inUcity city9U9 city9)
          (inUcity city9U8 city9)
          (inUcity city9U7 city9)
          (inUcity city9U6 city9)
          (inUcity city9U5 city9)
          (inUcity city9U4 city9)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U14 city8)
          (inUcity city8U13 city8)
          (inUcity city8U12 city8)
          (inUcity city8U11 city8)
          (inUcity city8U10 city8)
          (inUcity city8U9 city8)
          (inUcity city8U8 city8)
          (inUcity city8U7 city8)
          (inUcity city8U6 city8)
          (inUcity city8U5 city8)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U14 city7)
          (inUcity city7U13 city7)
          (inUcity city7U12 city7)
          (inUcity city7U11 city7)
          (inUcity city7U10 city7)
          (inUcity city7U9 city7)
          (inUcity city7U8 city7)
          (inUcity city7U7 city7)
          (inUcity city7U6 city7)
          (inUcity city7U5 city7)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U14 city6)
          (inUcity city6U13 city6)
          (inUcity city6U12 city6)
          (inUcity city6U11 city6)
          (inUcity city6U10 city6)
          (inUcity city6U9 city6)
          (inUcity city6U8 city6)
          (inUcity city6U7 city6)
          (inUcity city6U6 city6)
          (inUcity city6U5 city6)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U14 city5)
          (inUcity city5U13 city5)
          (inUcity city5U12 city5)
          (inUcity city5U11 city5)
          (inUcity city5U10 city5)
          (inUcity city5U9 city5)
          (inUcity city5U8 city5)
          (inUcity city5U7 city5)
          (inUcity city5U6 city5)
          (inUcity city5U5 city5)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U14 city4)
          (inUcity city4U13 city4)
          (inUcity city4U12 city4)
          (inUcity city4U11 city4)
          (inUcity city4U10 city4)
          (inUcity city4U9 city4)
          (inUcity city4U8 city4)
          (inUcity city4U7 city4)
          (inUcity city4U6 city4)
          (inUcity city4U5 city4)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U14 city3)
          (inUcity city3U13 city3)
          (inUcity city3U12 city3)
          (inUcity city3U11 city3)
          (inUcity city3U10 city3)
          (inUcity city3U9 city3)
          (inUcity city3U8 city3)
          (inUcity city3U7 city3)
          (inUcity city3U6 city3)
          (inUcity city3U5 city3)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U14 city2)
          (inUcity city2U13 city2)
          (inUcity city2U12 city2)
          (inUcity city2U11 city2)
          (inUcity city2U10 city2)
          (inUcity city2U9 city2)
          (inUcity city2U8 city2)
          (inUcity city2U7 city2)
          (inUcity city2U6 city2)
          (inUcity city2U5 city2)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U14 city1)
          (inUcity city1U13 city1)
          (inUcity city1U12 city1)
          (inUcity city1U11 city1)
          (inUcity city1U10 city1)
          (inUcity city1U9 city1)
          (inUcity city1U8 city1)
          (inUcity city1U7 city1)
          (inUcity city1U6 city1)
          (inUcity city1U5 city1)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane9 city11U14)
          (at plane8 city2U14)
          (at plane7 city6U14)
          (at plane6 city4U14)
          (at plane5 city6U14)
          (at plane4 city13U14)
          (at plane3 city7U14)
          (at plane2 city8U14)
          (at plane1 city9U14)
          (at truck28 city15U5)
          (at truck27 city14U8)
          (at truck26 city13U2)
          (at truck25 city12U8)
          (at truck24 city11U7)
          (at truck23 city10U10)
          (at truck22 city9U8)
          (at truck21 city8U6)
          (at truck20 city7U1)
          (at truck19 city6U13)
          (at truck18 city5U9)
          (at truck17 city4U8)
          (at truck16 city3U6)
          (at truck15 city2U12)
          (at truck14 city1U11)
          (at truck13 city7U9)
          (at truck12 city2U12)
          (at truck11 city9U12)
          (at truck10 city12U9)
          (at truck9 city14U9)
          (at truck8 city14U4)
          (at truck7 city10U6)
          (at truck6 city14U10)
          (at truck5 city10U11)
          (at truck4 city7U10)
          (at truck3 city5U2)
          (at truck2 city3U2)
          (at truck1 city15U1)
          (at package57 city6U7)
          (at package56 city2U4)
          (at package55 city2U8)
          (at package54 city15U7)
          (at package53 city6U14)
          (at package52 city11U4)
          (at package51 city11U14)
          (at package50 city14U13)
          (at package49 city2U7)
          (at package48 city5U14)
          (at package47 city14U13)
          (at package46 city2U2)
          (at package45 city3U5)
          (at package44 city2U1)
          (at package43 city15U12)
          (at package42 city15U1)
          (at package41 city13U14)
          (at package40 city4U14)
          (at package39 city13U6)
          (at package38 city2U12)
          (at package37 city9U7)
          (at package36 city7U10)
          (at package35 city7U3)
          (at package34 city10U4)
          (at package33 city6U14)
          (at package32 city13U6)
          (at package31 city15U13)
          (at package30 city11U5)
          (at package29 city12U12)
          (at package28 city14U1)
          (at package27 city7U8)
          (at package26 city15U7)
          (at package25 city4U6)
          (at package24 city7U8)
          (at package23 city10U14)
          (at package22 city9U11)
          (at package21 city8U14)
          (at package20 city3U8)
          (at package19 city9U4)
          (at package18 city8U2)
          (at package17 city11U9)
          (at package16 city10U14)
          (at package15 city7U8)
          (at package14 city5U13)
          (at package13 city5U12)
          (at package12 city6U12)
          (at package11 city5U12)
          (at package10 city11U1)
          (at package9 city10U12)
          (at package8 city12U3)
          (at package7 city13U4)
          (at package6 city5U8)
          (at package5 city2U1)
          (at package4 city3U9)
          (at package3 city9U2)
          (at package2 city8U7)
          (at package1 city6U12))
   (:goal (and (at package57 city12U11)
               (at package56 city2U8)
               (at package55 city10U4)
               (at package54 city11U12)
               (at package53 city4U6)
               (at package52 city8U4)
               (at package51 city13U4)
               (at package50 city14U7)
               (at package49 city15U10)
               (at package48 city9U12)
               (at package47 city9U7)
               (at package46 city8U2)
               (at package45 city9U4)
               (at package44 city4U13)
               (at package43 city14U7)
               (at package42 city11U3)
               (at package41 city9U9))))

(define (problem stripsUlogUxU28)
   (:domain logisticsUstrips)
   (:objects package42 package41 package40 package39 package38
             package37 package36 package35 package34 package33 package32
             package31 package30 package29 package28 package27 package26
             package25 package24 package23 package22 package21 package20
             package19 package18 package17 package16 package15 package14
             package13 package12 package11 package10 package9 package8
             package7 package6 package5 package4 package3 package2 package1
             city20 city19 city18 city17 city16 city15 city14 city13 city12
             city11 city10 city9 city8 city7 city6 city5 city4 city3 city2
             city1 truck83 truck82 truck81 truck80 truck79 truck78
             truck77 truck76 truck75 truck74 truck73 truck72 truck71
             truck70 truck69 truck68 truck67 truck66 truck65 truck64
             truck63 truck62 truck61 truck60 truck59 truck58 truck57
             truck56 truck55 truck54 truck53 truck52 truck51 truck50
             truck49 truck48 truck47 truck46 truck45 truck44 truck43
             truck42 truck41 truck40 truck39 truck38 truck37 truck36
             truck35 truck34 truck33 truck32 truck31 truck30 truck29
             truck28 truck27 truck26 truck25 truck24 truck23 truck22
             truck21 truck20 truck19 truck18 truck17 truck16 truck15
             truck14 truck13 truck12 truck11 truck10 truck9 truck8 truck7
             truck6 truck5 truck4 truck3 truck2 truck1 plane5 plane4 plane3
             plane2 plane1 city20U16 city20U15 city20U14 city20U13
             city20U12 city20U11 city20U10 city20U9 city20U8 city20U7
             city20U6 city20U5 city20U4 city20U3 city20U2 city20U1
             city19U16 city19U15 city19U14 city19U13 city19U12 city19U11
             city19U10 city19U9 city19U8 city19U7 city19U6 city19U5 city19U4
             city19U3 city19U2 city19U1 city18U16 city18U15 city18U14
             city18U13 city18U12 city18U11 city18U10 city18U9 city18U8
             city18U7 city18U6 city18U5 city18U4 city18U3 city18U2 city18U1
             city17U16 city17U15 city17U14 city17U13 city17U12 city17U11
             city17U10 city17U9 city17U8 city17U7 city17U6 city17U5 city17U4
             city17U3 city17U2 city17U1 city16U16 city16U15 city16U14
             city16U13 city16U12 city16U11 city16U10 city16U9 city16U8
             city16U7 city16U6 city16U5 city16U4 city16U3 city16U2 city16U1
             city15U16 city15U15 city15U14 city15U13 city15U12 city15U11
             city15U10 city15U9 city15U8 city15U7 city15U6 city15U5 city15U4
             city15U3 city15U2 city15U1 city14U16 city14U15 city14U14
             city14U13 city14U12 city14U11 city14U10 city14U9 city14U8
             city14U7 city14U6 city14U5 city14U4 city14U3 city14U2 city14U1
             city13U16 city13U15 city13U14 city13U13 city13U12 city13U11
             city13U10 city13U9 city13U8 city13U7 city13U6 city13U5 city13U4
             city13U3 city13U2 city13U1 city12U16 city12U15 city12U14
             city12U13 city12U12 city12U11 city12U10 city12U9 city12U8
             city12U7 city12U6 city12U5 city12U4 city12U3 city12U2 city12U1
             city11U16 city11U15 city11U14 city11U13 city11U12 city11U11
             city11U10 city11U9 city11U8 city11U7 city11U6 city11U5 city11U4
             city11U3 city11U2 city11U1 city10U16 city10U15 city10U14
             city10U13 city10U12 city10U11 city10U10 city10U9 city10U8
             city10U7 city10U6 city10U5 city10U4 city10U3 city10U2 city10U1
             city9U16 city9U15 city9U14 city9U13 city9U12 city9U11 city9U10
             city9U9 city9U8 city9U7 city9U6 city9U5 city9U4 city9U3
             city9U2 city9U1 city8U16 city8U15 city8U14 city8U13 city8U12
             city8U11 city8U10 city8U9 city8U8 city8U7 city8U6 city8U5
             city8U4 city8U3 city8U2 city8U1 city7U16 city7U15 city7U14
             city7U13 city7U12 city7U11 city7U10 city7U9 city7U8 city7U7
             city7U6 city7U5 city7U4 city7U3 city7U2 city7U1 city6U16
             city6U15 city6U14 city6U13 city6U12 city6U11 city6U10 city6U9
             city6U8 city6U7 city6U6 city6U5 city6U4 city6U3 city6U2
             city6U1 city5U16 city5U15 city5U14 city5U13 city5U12 city5U11
             city5U10 city5U9 city5U8 city5U7 city5U6 city5U5 city5U4
             city5U3 city5U2 city5U1 city4U16 city4U15 city4U14 city4U13
             city4U12 city4U11 city4U10 city4U9 city4U8 city4U7 city4U6
             city4U5 city4U4 city4U3 city4U2 city4U1 city3U16 city3U15
             city3U14 city3U13 city3U12 city3U11 city3U10 city3U9 city3U8
             city3U7 city3U6 city3U5 city3U4 city3U3 city3U2 city3U1
             city2U16 city2U15 city2U14 city2U13 city2U12 city2U11 city2U10
             city2U9 city2U8 city2U7 city2U6 city2U5 city2U4 city2U3
             city2U2 city2U1 city1U16 city1U15 city1U14 city1U13 city1U12
             city1U11 city1U10 city1U9 city1U8 city1U7 city1U6 city1U5
             city1U4 city1U3 city1U2 city1U1 city20U17 city19U17 city18U17
             city17U17 city16U17 city15U17 city14U17 city13U17 city12U17
             city11U17 city10U17 city9U17 city8U17 city7U17 city6U17
             city5U17 city4U17 city3U17 city2U17 city1U17)
   (:init (obj package42)
          (obj package41)
          (obj package40)
          (obj package39)
          (obj package38)
          (obj package37)
          (obj package36)
          (obj package35)
          (obj package34)
          (obj package33)
          (obj package32)
          (obj package31)
          (obj package30)
          (obj package29)
          (obj package28)
          (obj package27)
          (obj package26)
          (obj package25)
          (obj package24)
          (obj package23)
          (obj package22)
          (obj package21)
          (obj package20)
          (obj package19)
          (obj package18)
          (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city20)
          (city city19)
          (city city18)
          (city city17)
          (city city16)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck83)
          (truck truck82)
          (truck truck81)
          (truck truck80)
          (truck truck79)
          (truck truck78)
          (truck truck77)
          (truck truck76)
          (truck truck75)
          (truck truck74)
          (truck truck73)
          (truck truck72)
          (truck truck71)
          (truck truck70)
          (truck truck69)
          (truck truck68)
          (truck truck67)
          (truck truck66)
          (truck truck65)
          (truck truck64)
          (truck truck63)
          (truck truck62)
          (truck truck61)
          (truck truck60)
          (truck truck59)
          (truck truck58)
          (truck truck57)
          (truck truck56)
          (truck truck55)
          (truck truck54)
          (truck truck53)
          (truck truck52)
          (truck truck51)
          (truck truck50)
          (truck truck49)
          (truck truck48)
          (truck truck47)
          (truck truck46)
          (truck truck45)
          (truck truck44)
          (truck truck43)
          (truck truck42)
          (truck truck41)
          (truck truck40)
          (truck truck39)
          (truck truck38)
          (truck truck37)
          (truck truck36)
          (truck truck35)
          (truck truck34)
          (truck truck33)
          (truck truck32)
          (truck truck31)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city20U16)
          (location city20U15)
          (location city20U14)
          (location city20U13)
          (location city20U12)
          (location city20U11)
          (location city20U10)
          (location city20U9)
          (location city20U8)
          (location city20U7)
          (location city20U6)
          (location city20U5)
          (location city20U4)
          (location city20U3)
          (location city20U2)
          (location city20U1)
          (location city19U16)
          (location city19U15)
          (location city19U14)
          (location city19U13)
          (location city19U12)
          (location city19U11)
          (location city19U10)
          (location city19U9)
          (location city19U8)
          (location city19U7)
          (location city19U6)
          (location city19U5)
          (location city19U4)
          (location city19U3)
          (location city19U2)
          (location city19U1)
          (location city18U16)
          (location city18U15)
          (location city18U14)
          (location city18U13)
          (location city18U12)
          (location city18U11)
          (location city18U10)
          (location city18U9)
          (location city18U8)
          (location city18U7)
          (location city18U6)
          (location city18U5)
          (location city18U4)
          (location city18U3)
          (location city18U2)
          (location city18U1)
          (location city17U16)
          (location city17U15)
          (location city17U14)
          (location city17U13)
          (location city17U12)
          (location city17U11)
          (location city17U10)
          (location city17U9)
          (location city17U8)
          (location city17U7)
          (location city17U6)
          (location city17U5)
          (location city17U4)
          (location city17U3)
          (location city17U2)
          (location city17U1)
          (location city16U16)
          (location city16U15)
          (location city16U14)
          (location city16U13)
          (location city16U12)
          (location city16U11)
          (location city16U10)
          (location city16U9)
          (location city16U8)
          (location city16U7)
          (location city16U6)
          (location city16U5)
          (location city16U4)
          (location city16U3)
          (location city16U2)
          (location city16U1)
          (location city15U16)
          (location city15U15)
          (location city15U14)
          (location city15U13)
          (location city15U12)
          (location city15U11)
          (location city15U10)
          (location city15U9)
          (location city15U8)
          (location city15U7)
          (location city15U6)
          (location city15U5)
          (location city15U4)
          (location city15U3)
          (location city15U2)
          (location city15U1)
          (location city14U16)
          (location city14U15)
          (location city14U14)
          (location city14U13)
          (location city14U12)
          (location city14U11)
          (location city14U10)
          (location city14U9)
          (location city14U8)
          (location city14U7)
          (location city14U6)
          (location city14U5)
          (location city14U4)
          (location city14U3)
          (location city14U2)
          (location city14U1)
          (location city13U16)
          (location city13U15)
          (location city13U14)
          (location city13U13)
          (location city13U12)
          (location city13U11)
          (location city13U10)
          (location city13U9)
          (location city13U8)
          (location city13U7)
          (location city13U6)
          (location city13U5)
          (location city13U4)
          (location city13U3)
          (location city13U2)
          (location city13U1)
          (location city12U16)
          (location city12U15)
          (location city12U14)
          (location city12U13)
          (location city12U12)
          (location city12U11)
          (location city12U10)
          (location city12U9)
          (location city12U8)
          (location city12U7)
          (location city12U6)
          (location city12U5)
          (location city12U4)
          (location city12U3)
          (location city12U2)
          (location city12U1)
          (location city11U16)
          (location city11U15)
          (location city11U14)
          (location city11U13)
          (location city11U12)
          (location city11U11)
          (location city11U10)
          (location city11U9)
          (location city11U8)
          (location city11U7)
          (location city11U6)
          (location city11U5)
          (location city11U4)
          (location city11U3)
          (location city11U2)
          (location city11U1)
          (location city10U16)
          (location city10U15)
          (location city10U14)
          (location city10U13)
          (location city10U12)
          (location city10U11)
          (location city10U10)
          (location city10U9)
          (location city10U8)
          (location city10U7)
          (location city10U6)
          (location city10U5)
          (location city10U4)
          (location city10U3)
          (location city10U2)
          (location city10U1)
          (location city9U16)
          (location city9U15)
          (location city9U14)
          (location city9U13)
          (location city9U12)
          (location city9U11)
          (location city9U10)
          (location city9U9)
          (location city9U8)
          (location city9U7)
          (location city9U6)
          (location city9U5)
          (location city9U4)
          (location city9U3)
          (location city9U2)
          (location city9U1)
          (location city8U16)
          (location city8U15)
          (location city8U14)
          (location city8U13)
          (location city8U12)
          (location city8U11)
          (location city8U10)
          (location city8U9)
          (location city8U8)
          (location city8U7)
          (location city8U6)
          (location city8U5)
          (location city8U4)
          (location city8U3)
          (location city8U2)
          (location city8U1)
          (location city7U16)
          (location city7U15)
          (location city7U14)
          (location city7U13)
          (location city7U12)
          (location city7U11)
          (location city7U10)
          (location city7U9)
          (location city7U8)
          (location city7U7)
          (location city7U6)
          (location city7U5)
          (location city7U4)
          (location city7U3)
          (location city7U2)
          (location city7U1)
          (location city6U16)
          (location city6U15)
          (location city6U14)
          (location city6U13)
          (location city6U12)
          (location city6U11)
          (location city6U10)
          (location city6U9)
          (location city6U8)
          (location city6U7)
          (location city6U6)
          (location city6U5)
          (location city6U4)
          (location city6U3)
          (location city6U2)
          (location city6U1)
          (location city5U16)
          (location city5U15)
          (location city5U14)
          (location city5U13)
          (location city5U12)
          (location city5U11)
          (location city5U10)
          (location city5U9)
          (location city5U8)
          (location city5U7)
          (location city5U6)
          (location city5U5)
          (location city5U4)
          (location city5U3)
          (location city5U2)
          (location city5U1)
          (location city4U16)
          (location city4U15)
          (location city4U14)
          (location city4U13)
          (location city4U12)
          (location city4U11)
          (location city4U10)
          (location city4U9)
          (location city4U8)
          (location city4U7)
          (location city4U6)
          (location city4U5)
          (location city4U4)
          (location city4U3)
          (location city4U2)
          (location city4U1)
          (location city3U16)
          (location city3U15)
          (location city3U14)
          (location city3U13)
          (location city3U12)
          (location city3U11)
          (location city3U10)
          (location city3U9)
          (location city3U8)
          (location city3U7)
          (location city3U6)
          (location city3U5)
          (location city3U4)
          (location city3U3)
          (location city3U2)
          (location city3U1)
          (location city2U16)
          (location city2U15)
          (location city2U14)
          (location city2U13)
          (location city2U12)
          (location city2U11)
          (location city2U10)
          (location city2U9)
          (location city2U8)
          (location city2U7)
          (location city2U6)
          (location city2U5)
          (location city2U4)
          (location city2U3)
          (location city2U2)
          (location city2U1)
          (location city1U16)
          (location city1U15)
          (location city1U14)
          (location city1U13)
          (location city1U12)
          (location city1U11)
          (location city1U10)
          (location city1U9)
          (location city1U8)
          (location city1U7)
          (location city1U6)
          (location city1U5)
          (location city1U4)
          (location city1U3)
          (location city1U2)
          (location city1U1)
          (airport city20U17)
          (location city20U17)
          (airport city19U17)
          (location city19U17)
          (airport city18U17)
          (location city18U17)
          (airport city17U17)
          (location city17U17)
          (airport city16U17)
          (location city16U17)
          (airport city15U17)
          (location city15U17)
          (airport city14U17)
          (location city14U17)
          (airport city13U17)
          (location city13U17)
          (airport city12U17)
          (location city12U17)
          (airport city11U17)
          (location city11U17)
          (airport city10U17)
          (location city10U17)
          (airport city9U17)
          (location city9U17)
          (airport city8U17)
          (location city8U17)
          (airport city7U17)
          (location city7U17)
          (airport city6U17)
          (location city6U17)
          (airport city5U17)
          (location city5U17)
          (airport city4U17)
          (location city4U17)
          (airport city3U17)
          (location city3U17)
          (airport city2U17)
          (location city2U17)
          (airport city1U17)
          (location city1U17)
          (inUcity city20U17 city20)
          (inUcity city20U16 city20)
          (inUcity city20U15 city20)
          (inUcity city20U14 city20)
          (inUcity city20U13 city20)
          (inUcity city20U12 city20)
          (inUcity city20U11 city20)
          (inUcity city20U10 city20)
          (inUcity city20U9 city20)
          (inUcity city20U8 city20)
          (inUcity city20U7 city20)
          (inUcity city20U6 city20)
          (inUcity city20U5 city20)
          (inUcity city20U4 city20)
          (inUcity city20U3 city20)
          (inUcity city20U2 city20)
          (inUcity city20U1 city20)
          (inUcity city19U17 city19)
          (inUcity city19U16 city19)
          (inUcity city19U15 city19)
          (inUcity city19U14 city19)
          (inUcity city19U13 city19)
          (inUcity city19U12 city19)
          (inUcity city19U11 city19)
          (inUcity city19U10 city19)
          (inUcity city19U9 city19)
          (inUcity city19U8 city19)
          (inUcity city19U7 city19)
          (inUcity city19U6 city19)
          (inUcity city19U5 city19)
          (inUcity city19U4 city19)
          (inUcity city19U3 city19)
          (inUcity city19U2 city19)
          (inUcity city19U1 city19)
          (inUcity city18U17 city18)
          (inUcity city18U16 city18)
          (inUcity city18U15 city18)
          (inUcity city18U14 city18)
          (inUcity city18U13 city18)
          (inUcity city18U12 city18)
          (inUcity city18U11 city18)
          (inUcity city18U10 city18)
          (inUcity city18U9 city18)
          (inUcity city18U8 city18)
          (inUcity city18U7 city18)
          (inUcity city18U6 city18)
          (inUcity city18U5 city18)
          (inUcity city18U4 city18)
          (inUcity city18U3 city18)
          (inUcity city18U2 city18)
          (inUcity city18U1 city18)
          (inUcity city17U17 city17)
          (inUcity city17U16 city17)
          (inUcity city17U15 city17)
          (inUcity city17U14 city17)
          (inUcity city17U13 city17)
          (inUcity city17U12 city17)
          (inUcity city17U11 city17)
          (inUcity city17U10 city17)
          (inUcity city17U9 city17)
          (inUcity city17U8 city17)
          (inUcity city17U7 city17)
          (inUcity city17U6 city17)
          (inUcity city17U5 city17)
          (inUcity city17U4 city17)
          (inUcity city17U3 city17)
          (inUcity city17U2 city17)
          (inUcity city17U1 city17)
          (inUcity city16U17 city16)
          (inUcity city16U16 city16)
          (inUcity city16U15 city16)
          (inUcity city16U14 city16)
          (inUcity city16U13 city16)
          (inUcity city16U12 city16)
          (inUcity city16U11 city16)
          (inUcity city16U10 city16)
          (inUcity city16U9 city16)
          (inUcity city16U8 city16)
          (inUcity city16U7 city16)
          (inUcity city16U6 city16)
          (inUcity city16U5 city16)
          (inUcity city16U4 city16)
          (inUcity city16U3 city16)
          (inUcity city16U2 city16)
          (inUcity city16U1 city16)
          (inUcity city15U17 city15)
          (inUcity city15U16 city15)
          (inUcity city15U15 city15)
          (inUcity city15U14 city15)
          (inUcity city15U13 city15)
          (inUcity city15U12 city15)
          (inUcity city15U11 city15)
          (inUcity city15U10 city15)
          (inUcity city15U9 city15)
          (inUcity city15U8 city15)
          (inUcity city15U7 city15)
          (inUcity city15U6 city15)
          (inUcity city15U5 city15)
          (inUcity city15U4 city15)
          (inUcity city15U3 city15)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U17 city14)
          (inUcity city14U16 city14)
          (inUcity city14U15 city14)
          (inUcity city14U14 city14)
          (inUcity city14U13 city14)
          (inUcity city14U12 city14)
          (inUcity city14U11 city14)
          (inUcity city14U10 city14)
          (inUcity city14U9 city14)
          (inUcity city14U8 city14)
          (inUcity city14U7 city14)
          (inUcity city14U6 city14)
          (inUcity city14U5 city14)
          (inUcity city14U4 city14)
          (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U17 city13)
          (inUcity city13U16 city13)
          (inUcity city13U15 city13)
          (inUcity city13U14 city13)
          (inUcity city13U13 city13)
          (inUcity city13U12 city13)
          (inUcity city13U11 city13)
          (inUcity city13U10 city13)
          (inUcity city13U9 city13)
          (inUcity city13U8 city13)
          (inUcity city13U7 city13)
          (inUcity city13U6 city13)
          (inUcity city13U5 city13)
          (inUcity city13U4 city13)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U17 city12)
          (inUcity city12U16 city12)
          (inUcity city12U15 city12)
          (inUcity city12U14 city12)
          (inUcity city12U13 city12)
          (inUcity city12U12 city12)
          (inUcity city12U11 city12)
          (inUcity city12U10 city12)
          (inUcity city12U9 city12)
          (inUcity city12U8 city12)
          (inUcity city12U7 city12)
          (inUcity city12U6 city12)
          (inUcity city12U5 city12)
          (inUcity city12U4 city12)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U17 city11)
          (inUcity city11U16 city11)
          (inUcity city11U15 city11)
          (inUcity city11U14 city11)
          (inUcity city11U13 city11)
          (inUcity city11U12 city11)
          (inUcity city11U11 city11)
          (inUcity city11U10 city11)
          (inUcity city11U9 city11)
          (inUcity city11U8 city11)
          (inUcity city11U7 city11)
          (inUcity city11U6 city11)
          (inUcity city11U5 city11)
          (inUcity city11U4 city11)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U17 city10)
          (inUcity city10U16 city10)
          (inUcity city10U15 city10)
          (inUcity city10U14 city10)
          (inUcity city10U13 city10)
          (inUcity city10U12 city10)
          (inUcity city10U11 city10)
          (inUcity city10U10 city10)
          (inUcity city10U9 city10)
          (inUcity city10U8 city10)
          (inUcity city10U7 city10)
          (inUcity city10U6 city10)
          (inUcity city10U5 city10)
          (inUcity city10U4 city10)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U17 city9)
          (inUcity city9U16 city9)
          (inUcity city9U15 city9)
          (inUcity city9U14 city9)
          (inUcity city9U13 city9)
          (inUcity city9U12 city9)
          (inUcity city9U11 city9)
          (inUcity city9U10 city9)
          (inUcity city9U9 city9)
          (inUcity city9U8 city9)
          (inUcity city9U7 city9)
          (inUcity city9U6 city9)
          (inUcity city9U5 city9)
          (inUcity city9U4 city9)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U17 city8)
          (inUcity city8U16 city8)
          (inUcity city8U15 city8)
          (inUcity city8U14 city8)
          (inUcity city8U13 city8)
          (inUcity city8U12 city8)
          (inUcity city8U11 city8)
          (inUcity city8U10 city8)
          (inUcity city8U9 city8)
          (inUcity city8U8 city8)
          (inUcity city8U7 city8)
          (inUcity city8U6 city8)
          (inUcity city8U5 city8)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U17 city7)
          (inUcity city7U16 city7)
          (inUcity city7U15 city7)
          (inUcity city7U14 city7)
          (inUcity city7U13 city7)
          (inUcity city7U12 city7)
          (inUcity city7U11 city7)
          (inUcity city7U10 city7)
          (inUcity city7U9 city7)
          (inUcity city7U8 city7)
          (inUcity city7U7 city7)
          (inUcity city7U6 city7)
          (inUcity city7U5 city7)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U17 city6)
          (inUcity city6U16 city6)
          (inUcity city6U15 city6)
          (inUcity city6U14 city6)
          (inUcity city6U13 city6)
          (inUcity city6U12 city6)
          (inUcity city6U11 city6)
          (inUcity city6U10 city6)
          (inUcity city6U9 city6)
          (inUcity city6U8 city6)
          (inUcity city6U7 city6)
          (inUcity city6U6 city6)
          (inUcity city6U5 city6)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U17 city5)
          (inUcity city5U16 city5)
          (inUcity city5U15 city5)
          (inUcity city5U14 city5)
          (inUcity city5U13 city5)
          (inUcity city5U12 city5)
          (inUcity city5U11 city5)
          (inUcity city5U10 city5)
          (inUcity city5U9 city5)
          (inUcity city5U8 city5)
          (inUcity city5U7 city5)
          (inUcity city5U6 city5)
          (inUcity city5U5 city5)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U17 city4)
          (inUcity city4U16 city4)
          (inUcity city4U15 city4)
          (inUcity city4U14 city4)
          (inUcity city4U13 city4)
          (inUcity city4U12 city4)
          (inUcity city4U11 city4)
          (inUcity city4U10 city4)
          (inUcity city4U9 city4)
          (inUcity city4U8 city4)
          (inUcity city4U7 city4)
          (inUcity city4U6 city4)
          (inUcity city4U5 city4)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U17 city3)
          (inUcity city3U16 city3)
          (inUcity city3U15 city3)
          (inUcity city3U14 city3)
          (inUcity city3U13 city3)
          (inUcity city3U12 city3)
          (inUcity city3U11 city3)
          (inUcity city3U10 city3)
          (inUcity city3U9 city3)
          (inUcity city3U8 city3)
          (inUcity city3U7 city3)
          (inUcity city3U6 city3)
          (inUcity city3U5 city3)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U17 city2)
          (inUcity city2U16 city2)
          (inUcity city2U15 city2)
          (inUcity city2U14 city2)
          (inUcity city2U13 city2)
          (inUcity city2U12 city2)
          (inUcity city2U11 city2)
          (inUcity city2U10 city2)
          (inUcity city2U9 city2)
          (inUcity city2U8 city2)
          (inUcity city2U7 city2)
          (inUcity city2U6 city2)
          (inUcity city2U5 city2)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U17 city1)
          (inUcity city1U16 city1)
          (inUcity city1U15 city1)
          (inUcity city1U14 city1)
          (inUcity city1U13 city1)
          (inUcity city1U12 city1)
          (inUcity city1U11 city1)
          (inUcity city1U10 city1)
          (inUcity city1U9 city1)
          (inUcity city1U8 city1)
          (inUcity city1U7 city1)
          (inUcity city1U6 city1)
          (inUcity city1U5 city1)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane5 city19U17)
          (at plane4 city9U17)
          (at plane3 city18U17)
          (at plane2 city18U17)
          (at plane1 city14U17)
          (at truck83 city20U7)
          (at truck82 city19U2)
          (at truck81 city18U5)
          (at truck80 city17U14)
          (at truck79 city16U15)
          (at truck78 city15U7)
          (at truck77 city14U14)
          (at truck76 city13U9)
          (at truck75 city12U8)
          (at truck74 city11U1)
          (at truck73 city10U13)
          (at truck72 city9U4)
          (at truck71 city8U3)
          (at truck70 city7U15)
          (at truck69 city6U2)
          (at truck68 city5U8)
          (at truck67 city4U5)
          (at truck66 city3U15)
          (at truck65 city2U7)
          (at truck64 city1U2)
          (at truck63 city1U16)
          (at truck62 city9U15)
          (at truck61 city19U9)
          (at truck60 city12U8)
          (at truck59 city7U10)
          (at truck58 city15U5)
          (at truck57 city7U13)
          (at truck56 city11U1)
          (at truck55 city2U11)
          (at truck54 city13U7)
          (at truck53 city18U13)
          (at truck52 city16U11)
          (at truck51 city19U10)
          (at truck50 city2U8)
          (at truck49 city19U8)
          (at truck48 city19U9)
          (at truck47 city11U2)
          (at truck46 city14U7)
          (at truck45 city2U17)
          (at truck44 city9U17)
          (at truck43 city2U8)
          (at truck42 city19U12)
          (at truck41 city7U15)
          (at truck40 city2U4)
          (at truck39 city18U1)
          (at truck38 city16U6)
          (at truck37 city7U7)
          (at truck36 city12U6)
          (at truck35 city15U17)
          (at truck34 city2U2)
          (at truck33 city13U16)
          (at truck32 city11U2)
          (at truck31 city3U13)
          (at truck30 city8U5)
          (at truck29 city5U7)
          (at truck28 city5U10)
          (at truck27 city4U8)
          (at truck26 city2U5)
          (at truck25 city10U17)
          (at truck24 city13U16)
          (at truck23 city3U13)
          (at truck22 city5U9)
          (at truck21 city11U11)
          (at truck20 city15U13)
          (at truck19 city8U1)
          (at truck18 city5U17)
          (at truck17 city17U15)
          (at truck16 city3U11)
          (at truck15 city10U16)
          (at truck14 city12U4)
          (at truck13 city15U15)
          (at truck12 city13U7)
          (at truck11 city13U2)
          (at truck10 city19U5)
          (at truck9 city6U10)
          (at truck8 city13U6)
          (at truck7 city15U16)
          (at truck6 city8U14)
          (at truck5 city18U3)
          (at truck4 city13U8)
          (at truck3 city17U17)
          (at truck2 city10U6)
          (at truck1 city13U11)
          (at package42 city16U15)
          (at package41 city19U8)
          (at package40 city3U6)
          (at package39 city7U6)
          (at package38 city16U7)
          (at package37 city10U13)
          (at package36 city13U17)
          (at package35 city18U8)
          (at package34 city15U1)
          (at package33 city6U7)
          (at package32 city12U6)
          (at package31 city16U8)
          (at package30 city16U3)
          (at package29 city11U14)
          (at package28 city8U4)
          (at package27 city11U2)
          (at package26 city12U7)
          (at package25 city13U6)
          (at package24 city16U9)
          (at package23 city11U9)
          (at package22 city16U7)
          (at package21 city5U3)
          (at package20 city3U6)
          (at package19 city3U13)
          (at package18 city1U12)
          (at package17 city8U13)
          (at package16 city9U1)
          (at package15 city15U4)
          (at package14 city3U17)
          (at package13 city15U6)
          (at package12 city3U3)
          (at package11 city13U8)
          (at package10 city2U17)
          (at package9 city12U4)
          (at package8 city3U1)
          (at package7 city13U5)
          (at package6 city5U4)
          (at package5 city14U3)
          (at package4 city5U3)
          (at package3 city15U1)
          (at package2 city2U7)
          (at package1 city4U10))
   (:goal (and (at package42 city13U8)
               (at package41 city3U16)
               (at package40 city8U9)
               (at package39 city3U8)
               (at package38 city12U4)
               (at package37 city19U7)
               (at package36 city19U16)
               (at package35 city17U15)
               (at package34 city8U4)
               (at package33 city9U12)
               (at package32 city2U16)
               (at package31 city4U12)
               (at package30 city17U2)
               (at package29 city11U7)
               (at package28 city10U17)
               (at package27 city15U14)
               (at package26 city12U11)
               (at package25 city8U12)
               (at package24 city18U5)
               (at package23 city16U16)
               (at package22 city4U11)
               (at package21 city11U2)
               (at package20 city9U2)
               (at package19 city17U4)
               (at package18 city10U16)
               (at package17 city1U3)
               (at package16 city20U11)
               (at package15 city11U16)
               (at package14 city2U6)
               (at package13 city10U14))))

(define (problem stripsUlogUxU29)
   (:domain logisticsUstrips)
   (:objects package53 package52 package51 package50 package49
             package48 package47 package46 package45 package44 package43
             package42 package41 package40 package39 package38 package37
             package36 package35 package34 package33 package32 package31
             package30 package29 package28 package27 package26 package25
             package24 package23 package22 package21 package20 package19
             package18 package17 package16 package15 package14 package13
             package12 package11 package10 package9 package8 package7
             package6 package5 package4 package3 package2 package1 city27
             city26 city25 city24 city23 city22 city21 city20 city19 city18
             city17 city16 city15 city14 city13 city12 city11 city10 city9
             city8 city7 city6 city5 city4 city3 city2 city1 truck46
             truck45 truck44 truck43 truck42 truck41 truck40 truck39
             truck38 truck37 truck36 truck35 truck34 truck33 truck32
             truck31 truck30 truck29 truck28 truck27 truck26 truck25
             truck24 truck23 truck22 truck21 truck20 truck19 truck18
             truck17 truck16 truck15 truck14 truck13 truck12 truck11
             truck10 truck9 truck8 truck7 truck6 truck5 truck4 truck3 truck2
             truck1 plane10 plane9 plane8 plane7 plane6 plane5 plane4
             plane3 plane2 plane1 city27U2 city27U1 city26U2 city26U1
             city25U2 city25U1 city24U2 city24U1 city23U2 city23U1 city22U2
             city22U1 city21U2 city21U1 city20U2 city20U1 city19U2 city19U1
             city18U2 city18U1 city17U2 city17U1 city16U2 city16U1 city15U2
             city15U1 city14U2 city14U1 city13U2 city13U1 city12U2 city12U1
             city11U2 city11U1 city10U2 city10U1 city9U2 city9U1 city8U2
             city8U1 city7U2 city7U1 city6U2 city6U1 city5U2 city5U1
             city4U2 city4U1 city3U2 city3U1 city2U2 city2U1 city1U2
             city1U1 city27U3 city26U3 city25U3 city24U3 city23U3 city22U3
             city21U3 city20U3 city19U3 city18U3 city17U3 city16U3 city15U3
             city14U3 city13U3 city12U3 city11U3 city10U3 city9U3 city8U3
             city7U3 city6U3 city5U3 city4U3 city3U3 city2U3 city1U3)
   (:init (obj package53)
          (obj package52)
          (obj package51)
          (obj package50)
          (obj package49)
          (obj package48)
          (obj package47)
          (obj package46)
          (obj package45)
          (obj package44)
          (obj package43)
          (obj package42)
          (obj package41)
          (obj package40)
          (obj package39)
          (obj package38)
          (obj package37)
          (obj package36)
          (obj package35)
          (obj package34)
          (obj package33)
          (obj package32)
          (obj package31)
          (obj package30)
          (obj package29)
          (obj package28)
          (obj package27)
          (obj package26)
          (obj package25)
          (obj package24)
          (obj package23)
          (obj package22)
          (obj package21)
          (obj package20)
          (obj package19)
          (obj package18)
          (obj package17)
          (obj package16)
          (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city27)
          (city city26)
          (city city25)
          (city city24)
          (city city23)
          (city city22)
          (city city21)
          (city city20)
          (city city19)
          (city city18)
          (city city17)
          (city city16)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck46)
          (truck truck45)
          (truck truck44)
          (truck truck43)
          (truck truck42)
          (truck truck41)
          (truck truck40)
          (truck truck39)
          (truck truck38)
          (truck truck37)
          (truck truck36)
          (truck truck35)
          (truck truck34)
          (truck truck33)
          (truck truck32)
          (truck truck31)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane10)
          (airplane plane9)
          (airplane plane8)
          (airplane plane7)
          (airplane plane6)
          (airplane plane5)
          (airplane plane4)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city27U2)
          (location city27U1)
          (location city26U2)
          (location city26U1)
          (location city25U2)
          (location city25U1)
          (location city24U2)
          (location city24U1)
          (location city23U2)
          (location city23U1)
          (location city22U2)
          (location city22U1)
          (location city21U2)
          (location city21U1)
          (location city20U2)
          (location city20U1)
          (location city19U2)
          (location city19U1)
          (location city18U2)
          (location city18U1)
          (location city17U2)
          (location city17U1)
          (location city16U2)
          (location city16U1)
          (location city15U2)
          (location city15U1)
          (location city14U2)
          (location city14U1)
          (location city13U2)
          (location city13U1)
          (location city12U2)
          (location city12U1)
          (location city11U2)
          (location city11U1)
          (location city10U2)
          (location city10U1)
          (location city9U2)
          (location city9U1)
          (location city8U2)
          (location city8U1)
          (location city7U2)
          (location city7U1)
          (location city6U2)
          (location city6U1)
          (location city5U2)
          (location city5U1)
          (location city4U2)
          (location city4U1)
          (location city3U2)
          (location city3U1)
          (location city2U2)
          (location city2U1)
          (location city1U2)
          (location city1U1)
          (airport city27U3)
          (location city27U3)
          (airport city26U3)
          (location city26U3)
          (airport city25U3)
          (location city25U3)
          (airport city24U3)
          (location city24U3)
          (airport city23U3)
          (location city23U3)
          (airport city22U3)
          (location city22U3)
          (airport city21U3)
          (location city21U3)
          (airport city20U3)
          (location city20U3)
          (airport city19U3)
          (location city19U3)
          (airport city18U3)
          (location city18U3)
          (airport city17U3)
          (location city17U3)
          (airport city16U3)
          (location city16U3)
          (airport city15U3)
          (location city15U3)
          (airport city14U3)
          (location city14U3)
          (airport city13U3)
          (location city13U3)
          (airport city12U3)
          (location city12U3)
          (airport city11U3)
          (location city11U3)
          (airport city10U3)
          (location city10U3)
          (airport city9U3)
          (location city9U3)
          (airport city8U3)
          (location city8U3)
          (airport city7U3)
          (location city7U3)
          (airport city6U3)
          (location city6U3)
          (airport city5U3)
          (location city5U3)
          (airport city4U3)
          (location city4U3)
          (airport city3U3)
          (location city3U3)
          (airport city2U3)
          (location city2U3)
          (airport city1U3)
          (location city1U3)
          (inUcity city27U3 city27)
          (inUcity city27U2 city27)
          (inUcity city27U1 city27)
          (inUcity city26U3 city26)
          (inUcity city26U2 city26)
          (inUcity city26U1 city26)
          (inUcity city25U3 city25)
          (inUcity city25U2 city25)
          (inUcity city25U1 city25)
          (inUcity city24U3 city24)
          (inUcity city24U2 city24)
          (inUcity city24U1 city24)
          (inUcity city23U3 city23)
          (inUcity city23U2 city23)
          (inUcity city23U1 city23)
          (inUcity city22U3 city22)
          (inUcity city22U2 city22)
          (inUcity city22U1 city22)
          (inUcity city21U3 city21)
          (inUcity city21U2 city21)
          (inUcity city21U1 city21)
          (inUcity city20U3 city20)
          (inUcity city20U2 city20)
          (inUcity city20U1 city20)
          (inUcity city19U3 city19)
          (inUcity city19U2 city19)
          (inUcity city19U1 city19)
          (inUcity city18U3 city18)
          (inUcity city18U2 city18)
          (inUcity city18U1 city18)
          (inUcity city17U3 city17)
          (inUcity city17U2 city17)
          (inUcity city17U1 city17)
          (inUcity city16U3 city16)
          (inUcity city16U2 city16)
          (inUcity city16U1 city16)
          (inUcity city15U3 city15)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane10 city9U3)
          (at plane9 city18U3)
          (at plane8 city15U3)
          (at plane7 city6U3)
          (at plane6 city7U3)
          (at plane5 city15U3)
          (at plane4 city13U3)
          (at plane3 city25U3)
          (at plane2 city6U3)
          (at plane1 city4U3)
          (at truck46 city27U2)
          (at truck45 city26U1)
          (at truck44 city25U1)
          (at truck43 city24U1)
          (at truck42 city23U2)
          (at truck41 city22U1)
          (at truck40 city21U1)
          (at truck39 city20U1)
          (at truck38 city19U2)
          (at truck37 city18U2)
          (at truck36 city17U1)
          (at truck35 city16U2)
          (at truck34 city15U1)
          (at truck33 city14U2)
          (at truck32 city13U2)
          (at truck31 city12U1)
          (at truck30 city11U2)
          (at truck29 city10U1)
          (at truck28 city9U1)
          (at truck27 city8U1)
          (at truck26 city7U1)
          (at truck25 city6U1)
          (at truck24 city5U2)
          (at truck23 city4U2)
          (at truck22 city3U2)
          (at truck21 city2U2)
          (at truck20 city1U1)
          (at truck19 city16U3)
          (at truck18 city21U1)
          (at truck17 city1U3)
          (at truck16 city25U3)
          (at truck15 city15U3)
          (at truck14 city25U1)
          (at truck13 city16U2)
          (at truck12 city24U1)
          (at truck11 city7U1)
          (at truck10 city10U3)
          (at truck9 city4U3)
          (at truck8 city25U1)
          (at truck7 city19U3)
          (at truck6 city25U2)
          (at truck5 city4U2)
          (at truck4 city19U2)
          (at truck3 city3U2)
          (at truck2 city27U3)
          (at truck1 city9U1)
          (at package53 city6U3)
          (at package52 city6U3)
          (at package51 city16U2)
          (at package50 city25U1)
          (at package49 city24U1)
          (at package48 city1U2)
          (at package47 city6U2)
          (at package46 city7U3)
          (at package45 city15U1)
          (at package44 city20U2)
          (at package43 city25U3)
          (at package42 city20U2)
          (at package41 city18U1)
          (at package40 city20U2)
          (at package39 city6U1)
          (at package38 city27U3)
          (at package37 city8U2)
          (at package36 city14U3)
          (at package35 city20U2)
          (at package34 city25U1)
          (at package33 city23U3)
          (at package32 city4U1)
          (at package31 city27U1)
          (at package30 city17U3)
          (at package29 city13U2)
          (at package28 city25U3)
          (at package27 city19U1)
          (at package26 city26U3)
          (at package25 city8U2)
          (at package24 city3U1)
          (at package23 city10U2)
          (at package22 city11U2)
          (at package21 city8U2)
          (at package20 city4U2)
          (at package19 city22U2)
          (at package18 city23U1)
          (at package17 city24U1)
          (at package16 city14U1)
          (at package15 city6U2)
          (at package14 city11U1)
          (at package13 city16U1)
          (at package12 city5U3)
          (at package11 city9U2)
          (at package10 city21U2)
          (at package9 city18U2)
          (at package8 city9U1)
          (at package7 city27U1)
          (at package6 city12U3)
          (at package5 city23U1)
          (at package4 city21U3)
          (at package3 city18U3)
          (at package2 city6U3)
          (at package1 city25U1))
   (:goal (and (at package53 city16U2)
               (at package52 city6U3)
               (at package51 city12U2)
               (at package50 city9U2)
               (at package49 city9U3)
               (at package48 city20U1)
               (at package47 city17U2)
               (at package46 city22U3)
               (at package45 city8U3)
               (at package44 city8U1)
               (at package43 city19U3)
               (at package42 city7U1)
               (at package41 city26U3)
               (at package40 city2U2)
               (at package39 city12U1)
               (at package38 city11U2)
               (at package37 city1U3)
               (at package36 city22U3)
               (at package35 city14U2)
               (at package34 city1U3)
               (at package33 city3U3)
               (at package32 city9U3)
               (at package31 city1U2)
               (at package30 city1U2)
               (at package29 city14U1)
               (at package28 city23U3)
               (at package27 city23U3)
               (at package26 city22U1)
               (at package25 city23U2)
               (at package24 city7U3)
               (at package23 city23U3)
               (at package22 city12U1)
               (at package21 city12U2)
               (at package20 city10U3)
               (at package19 city18U1)
               (at package18 city24U2)
               (at package17 city16U3)
               (at package16 city18U3)
               (at package15 city8U2)
               (at package14 city18U3)
               (at package13 city7U1)
               (at package12 city22U1)
               (at package11 city1U1)
               (at package10 city6U3)
               (at package9 city9U1))))

(define (problem stripsUlogUxU30)
   (:domain logisticsUstrips)
   (:objects package15 package14 package13 package12 package11
             package10 package9 package8 package7 package6 package5 package4
             package3 package2 package1 city22 city21 city20 city19 city18
             city17 city16 city15 city14 city13 city12 city11 city10 city9
             city8 city7 city6 city5 city4 city3 city2 city1 truck80
             truck79 truck78 truck77 truck76 truck75 truck74 truck73
             truck72 truck71 truck70 truck69 truck68 truck67 truck66
             truck65 truck64 truck63 truck62 truck61 truck60 truck59
             truck58 truck57 truck56 truck55 truck54 truck53 truck52
             truck51 truck50 truck49 truck48 truck47 truck46 truck45
             truck44 truck43 truck42 truck41 truck40 truck39 truck38
             truck37 truck36 truck35 truck34 truck33 truck32 truck31
             truck30 truck29 truck28 truck27 truck26 truck25 truck24
             truck23 truck22 truck21 truck20 truck19 truck18 truck17
             truck16 truck15 truck14 truck13 truck12 truck11 truck10 truck9
             truck8 truck7 truck6 truck5 truck4 truck3 truck2 truck1 plane3
             plane2 plane1 city22U11 city22U10 city22U9 city22U8 city22U7
             city22U6 city22U5 city22U4 city22U3 city22U2 city22U1
             city21U11 city21U10 city21U9 city21U8 city21U7 city21U6
             city21U5 city21U4 city21U3 city21U2 city21U1 city20U11
             city20U10 city20U9 city20U8 city20U7 city20U6 city20U5 city20U4
             city20U3 city20U2 city20U1 city19U11 city19U10 city19U9
             city19U8 city19U7 city19U6 city19U5 city19U4 city19U3 city19U2
             city19U1 city18U11 city18U10 city18U9 city18U8 city18U7
             city18U6 city18U5 city18U4 city18U3 city18U2 city18U1
             city17U11 city17U10 city17U9 city17U8 city17U7 city17U6
             city17U5 city17U4 city17U3 city17U2 city17U1 city16U11
             city16U10 city16U9 city16U8 city16U7 city16U6 city16U5 city16U4
             city16U3 city16U2 city16U1 city15U11 city15U10 city15U9
             city15U8 city15U7 city15U6 city15U5 city15U4 city15U3 city15U2
             city15U1 city14U11 city14U10 city14U9 city14U8 city14U7
             city14U6 city14U5 city14U4 city14U3 city14U2 city14U1
             city13U11 city13U10 city13U9 city13U8 city13U7 city13U6
             city13U5 city13U4 city13U3 city13U2 city13U1 city12U11
             city12U10 city12U9 city12U8 city12U7 city12U6 city12U5 city12U4
             city12U3 city12U2 city12U1 city11U11 city11U10 city11U9
             city11U8 city11U7 city11U6 city11U5 city11U4 city11U3 city11U2
             city11U1 city10U11 city10U10 city10U9 city10U8 city10U7
             city10U6 city10U5 city10U4 city10U3 city10U2 city10U1 city9U11
             city9U10 city9U9 city9U8 city9U7 city9U6 city9U5 city9U4
             city9U3 city9U2 city9U1 city8U11 city8U10 city8U9 city8U8
             city8U7 city8U6 city8U5 city8U4 city8U3 city8U2 city8U1
             city7U11 city7U10 city7U9 city7U8 city7U7 city7U6 city7U5
             city7U4 city7U3 city7U2 city7U1 city6U11 city6U10 city6U9
             city6U8 city6U7 city6U6 city6U5 city6U4 city6U3 city6U2
             city6U1 city5U11 city5U10 city5U9 city5U8 city5U7 city5U6
             city5U5 city5U4 city5U3 city5U2 city5U1 city4U11 city4U10
             city4U9 city4U8 city4U7 city4U6 city4U5 city4U4 city4U3
             city4U2 city4U1 city3U11 city3U10 city3U9 city3U8 city3U7
             city3U6 city3U5 city3U4 city3U3 city3U2 city3U1 city2U11
             city2U10 city2U9 city2U8 city2U7 city2U6 city2U5 city2U4
             city2U3 city2U2 city2U1 city1U11 city1U10 city1U9 city1U8
             city1U7 city1U6 city1U5 city1U4 city1U3 city1U2 city1U1
             city22U12 city21U12 city20U12 city19U12 city18U12 city17U12
             city16U12 city15U12 city14U12 city13U12 city12U12 city11U12
             city10U12 city9U12 city8U12 city7U12 city6U12 city5U12 city4U12
             city3U12 city2U12 city1U12)
   (:init (obj package15)
          (obj package14)
          (obj package13)
          (obj package12)
          (obj package11)
          (obj package10)
          (obj package9)
          (obj package8)
          (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city22)
          (city city21)
          (city city20)
          (city city19)
          (city city18)
          (city city17)
          (city city16)
          (city city15)
          (city city14)
          (city city13)
          (city city12)
          (city city11)
          (city city10)
          (city city9)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck80)
          (truck truck79)
          (truck truck78)
          (truck truck77)
          (truck truck76)
          (truck truck75)
          (truck truck74)
          (truck truck73)
          (truck truck72)
          (truck truck71)
          (truck truck70)
          (truck truck69)
          (truck truck68)
          (truck truck67)
          (truck truck66)
          (truck truck65)
          (truck truck64)
          (truck truck63)
          (truck truck62)
          (truck truck61)
          (truck truck60)
          (truck truck59)
          (truck truck58)
          (truck truck57)
          (truck truck56)
          (truck truck55)
          (truck truck54)
          (truck truck53)
          (truck truck52)
          (truck truck51)
          (truck truck50)
          (truck truck49)
          (truck truck48)
          (truck truck47)
          (truck truck46)
          (truck truck45)
          (truck truck44)
          (truck truck43)
          (truck truck42)
          (truck truck41)
          (truck truck40)
          (truck truck39)
          (truck truck38)
          (truck truck37)
          (truck truck36)
          (truck truck35)
          (truck truck34)
          (truck truck33)
          (truck truck32)
          (truck truck31)
          (truck truck30)
          (truck truck29)
          (truck truck28)
          (truck truck27)
          (truck truck26)
          (truck truck25)
          (truck truck24)
          (truck truck23)
          (truck truck22)
          (truck truck21)
          (truck truck20)
          (truck truck19)
          (truck truck18)
          (truck truck17)
          (truck truck16)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane3)
          (airplane plane2)
          (airplane plane1)
          (location city22U11)
          (location city22U10)
          (location city22U9)
          (location city22U8)
          (location city22U7)
          (location city22U6)
          (location city22U5)
          (location city22U4)
          (location city22U3)
          (location city22U2)
          (location city22U1)
          (location city21U11)
          (location city21U10)
          (location city21U9)
          (location city21U8)
          (location city21U7)
          (location city21U6)
          (location city21U5)
          (location city21U4)
          (location city21U3)
          (location city21U2)
          (location city21U1)
          (location city20U11)
          (location city20U10)
          (location city20U9)
          (location city20U8)
          (location city20U7)
          (location city20U6)
          (location city20U5)
          (location city20U4)
          (location city20U3)
          (location city20U2)
          (location city20U1)
          (location city19U11)
          (location city19U10)
          (location city19U9)
          (location city19U8)
          (location city19U7)
          (location city19U6)
          (location city19U5)
          (location city19U4)
          (location city19U3)
          (location city19U2)
          (location city19U1)
          (location city18U11)
          (location city18U10)
          (location city18U9)
          (location city18U8)
          (location city18U7)
          (location city18U6)
          (location city18U5)
          (location city18U4)
          (location city18U3)
          (location city18U2)
          (location city18U1)
          (location city17U11)
          (location city17U10)
          (location city17U9)
          (location city17U8)
          (location city17U7)
          (location city17U6)
          (location city17U5)
          (location city17U4)
          (location city17U3)
          (location city17U2)
          (location city17U1)
          (location city16U11)
          (location city16U10)
          (location city16U9)
          (location city16U8)
          (location city16U7)
          (location city16U6)
          (location city16U5)
          (location city16U4)
          (location city16U3)
          (location city16U2)
          (location city16U1)
          (location city15U11)
          (location city15U10)
          (location city15U9)
          (location city15U8)
          (location city15U7)
          (location city15U6)
          (location city15U5)
          (location city15U4)
          (location city15U3)
          (location city15U2)
          (location city15U1)
          (location city14U11)
          (location city14U10)
          (location city14U9)
          (location city14U8)
          (location city14U7)
          (location city14U6)
          (location city14U5)
          (location city14U4)
          (location city14U3)
          (location city14U2)
          (location city14U1)
          (location city13U11)
          (location city13U10)
          (location city13U9)
          (location city13U8)
          (location city13U7)
          (location city13U6)
          (location city13U5)
          (location city13U4)
          (location city13U3)
          (location city13U2)
          (location city13U1)
          (location city12U11)
          (location city12U10)
          (location city12U9)
          (location city12U8)
          (location city12U7)
          (location city12U6)
          (location city12U5)
          (location city12U4)
          (location city12U3)
          (location city12U2)
          (location city12U1)
          (location city11U11)
          (location city11U10)
          (location city11U9)
          (location city11U8)
          (location city11U7)
          (location city11U6)
          (location city11U5)
          (location city11U4)
          (location city11U3)
          (location city11U2)
          (location city11U1)
          (location city10U11)
          (location city10U10)
          (location city10U9)
          (location city10U8)
          (location city10U7)
          (location city10U6)
          (location city10U5)
          (location city10U4)
          (location city10U3)
          (location city10U2)
          (location city10U1)
          (location city9U11)
          (location city9U10)
          (location city9U9)
          (location city9U8)
          (location city9U7)
          (location city9U6)
          (location city9U5)
          (location city9U4)
          (location city9U3)
          (location city9U2)
          (location city9U1)
          (location city8U11)
          (location city8U10)
          (location city8U9)
          (location city8U8)
          (location city8U7)
          (location city8U6)
          (location city8U5)
          (location city8U4)
          (location city8U3)
          (location city8U2)
          (location city8U1)
          (location city7U11)
          (location city7U10)
          (location city7U9)
          (location city7U8)
          (location city7U7)
          (location city7U6)
          (location city7U5)
          (location city7U4)
          (location city7U3)
          (location city7U2)
          (location city7U1)
          (location city6U11)
          (location city6U10)
          (location city6U9)
          (location city6U8)
          (location city6U7)
          (location city6U6)
          (location city6U5)
          (location city6U4)
          (location city6U3)
          (location city6U2)
          (location city6U1)
          (location city5U11)
          (location city5U10)
          (location city5U9)
          (location city5U8)
          (location city5U7)
          (location city5U6)
          (location city5U5)
          (location city5U4)
          (location city5U3)
          (location city5U2)
          (location city5U1)
          (location city4U11)
          (location city4U10)
          (location city4U9)
          (location city4U8)
          (location city4U7)
          (location city4U6)
          (location city4U5)
          (location city4U4)
          (location city4U3)
          (location city4U2)
          (location city4U1)
          (location city3U11)
          (location city3U10)
          (location city3U9)
          (location city3U8)
          (location city3U7)
          (location city3U6)
          (location city3U5)
          (location city3U4)
          (location city3U3)
          (location city3U2)
          (location city3U1)
          (location city2U11)
          (location city2U10)
          (location city2U9)
          (location city2U8)
          (location city2U7)
          (location city2U6)
          (location city2U5)
          (location city2U4)
          (location city2U3)
          (location city2U2)
          (location city2U1)
          (location city1U11)
          (location city1U10)
          (location city1U9)
          (location city1U8)
          (location city1U7)
          (location city1U6)
          (location city1U5)
          (location city1U4)
          (location city1U3)
          (location city1U2)
          (location city1U1)
          (airport city22U12)
          (location city22U12)
          (airport city21U12)
          (location city21U12)
          (airport city20U12)
          (location city20U12)
          (airport city19U12)
          (location city19U12)
          (airport city18U12)
          (location city18U12)
          (airport city17U12)
          (location city17U12)
          (airport city16U12)
          (location city16U12)
          (airport city15U12)
          (location city15U12)
          (airport city14U12)
          (location city14U12)
          (airport city13U12)
          (location city13U12)
          (airport city12U12)
          (location city12U12)
          (airport city11U12)
          (location city11U12)
          (airport city10U12)
          (location city10U12)
          (airport city9U12)
          (location city9U12)
          (airport city8U12)
          (location city8U12)
          (airport city7U12)
          (location city7U12)
          (airport city6U12)
          (location city6U12)
          (airport city5U12)
          (location city5U12)
          (airport city4U12)
          (location city4U12)
          (airport city3U12)
          (location city3U12)
          (airport city2U12)
          (location city2U12)
          (airport city1U12)
          (location city1U12)
          (inUcity city22U12 city22)
          (inUcity city22U11 city22)
          (inUcity city22U10 city22)
          (inUcity city22U9 city22)
          (inUcity city22U8 city22)
          (inUcity city22U7 city22)
          (inUcity city22U6 city22)
          (inUcity city22U5 city22)
          (inUcity city22U4 city22)
          (inUcity city22U3 city22)
          (inUcity city22U2 city22)
          (inUcity city22U1 city22)
          (inUcity city21U12 city21)
          (inUcity city21U11 city21)
          (inUcity city21U10 city21)
          (inUcity city21U9 city21)
          (inUcity city21U8 city21)
          (inUcity city21U7 city21)
          (inUcity city21U6 city21)
          (inUcity city21U5 city21)
          (inUcity city21U4 city21)
          (inUcity city21U3 city21)
          (inUcity city21U2 city21)
          (inUcity city21U1 city21)
          (inUcity city20U12 city20)
          (inUcity city20U11 city20)
          (inUcity city20U10 city20)
          (inUcity city20U9 city20)
          (inUcity city20U8 city20)
          (inUcity city20U7 city20)
          (inUcity city20U6 city20)
          (inUcity city20U5 city20)
          (inUcity city20U4 city20)
          (inUcity city20U3 city20)
          (inUcity city20U2 city20)
          (inUcity city20U1 city20)
          (inUcity city19U12 city19)
          (inUcity city19U11 city19)
          (inUcity city19U10 city19)
          (inUcity city19U9 city19)
          (inUcity city19U8 city19)
          (inUcity city19U7 city19)
          (inUcity city19U6 city19)
          (inUcity city19U5 city19)
          (inUcity city19U4 city19)
          (inUcity city19U3 city19)
          (inUcity city19U2 city19)
          (inUcity city19U1 city19)
          (inUcity city18U12 city18)
          (inUcity city18U11 city18)
          (inUcity city18U10 city18)
          (inUcity city18U9 city18)
          (inUcity city18U8 city18)
          (inUcity city18U7 city18)
          (inUcity city18U6 city18)
          (inUcity city18U5 city18)
          (inUcity city18U4 city18)
          (inUcity city18U3 city18)
          (inUcity city18U2 city18)
          (inUcity city18U1 city18)
          (inUcity city17U12 city17)
          (inUcity city17U11 city17)
          (inUcity city17U10 city17)
          (inUcity city17U9 city17)
          (inUcity city17U8 city17)
          (inUcity city17U7 city17)
          (inUcity city17U6 city17)
          (inUcity city17U5 city17)
          (inUcity city17U4 city17)
          (inUcity city17U3 city17)
          (inUcity city17U2 city17)
          (inUcity city17U1 city17)
          (inUcity city16U12 city16)
          (inUcity city16U11 city16)
          (inUcity city16U10 city16)
          (inUcity city16U9 city16)
          (inUcity city16U8 city16)
          (inUcity city16U7 city16)
          (inUcity city16U6 city16)
          (inUcity city16U5 city16)
          (inUcity city16U4 city16)
          (inUcity city16U3 city16)
          (inUcity city16U2 city16)
          (inUcity city16U1 city16)
          (inUcity city15U12 city15)
          (inUcity city15U11 city15)
          (inUcity city15U10 city15)
          (inUcity city15U9 city15)
          (inUcity city15U8 city15)
          (inUcity city15U7 city15)
          (inUcity city15U6 city15)
          (inUcity city15U5 city15)
          (inUcity city15U4 city15)
          (inUcity city15U3 city15)
          (inUcity city15U2 city15)
          (inUcity city15U1 city15)
          (inUcity city14U12 city14)
          (inUcity city14U11 city14)
          (inUcity city14U10 city14)
          (inUcity city14U9 city14)
          (inUcity city14U8 city14)
          (inUcity city14U7 city14)
          (inUcity city14U6 city14)
          (inUcity city14U5 city14)
          (inUcity city14U4 city14)
          (inUcity city14U3 city14)
          (inUcity city14U2 city14)
          (inUcity city14U1 city14)
          (inUcity city13U12 city13)
          (inUcity city13U11 city13)
          (inUcity city13U10 city13)
          (inUcity city13U9 city13)
          (inUcity city13U8 city13)
          (inUcity city13U7 city13)
          (inUcity city13U6 city13)
          (inUcity city13U5 city13)
          (inUcity city13U4 city13)
          (inUcity city13U3 city13)
          (inUcity city13U2 city13)
          (inUcity city13U1 city13)
          (inUcity city12U12 city12)
          (inUcity city12U11 city12)
          (inUcity city12U10 city12)
          (inUcity city12U9 city12)
          (inUcity city12U8 city12)
          (inUcity city12U7 city12)
          (inUcity city12U6 city12)
          (inUcity city12U5 city12)
          (inUcity city12U4 city12)
          (inUcity city12U3 city12)
          (inUcity city12U2 city12)
          (inUcity city12U1 city12)
          (inUcity city11U12 city11)
          (inUcity city11U11 city11)
          (inUcity city11U10 city11)
          (inUcity city11U9 city11)
          (inUcity city11U8 city11)
          (inUcity city11U7 city11)
          (inUcity city11U6 city11)
          (inUcity city11U5 city11)
          (inUcity city11U4 city11)
          (inUcity city11U3 city11)
          (inUcity city11U2 city11)
          (inUcity city11U1 city11)
          (inUcity city10U12 city10)
          (inUcity city10U11 city10)
          (inUcity city10U10 city10)
          (inUcity city10U9 city10)
          (inUcity city10U8 city10)
          (inUcity city10U7 city10)
          (inUcity city10U6 city10)
          (inUcity city10U5 city10)
          (inUcity city10U4 city10)
          (inUcity city10U3 city10)
          (inUcity city10U2 city10)
          (inUcity city10U1 city10)
          (inUcity city9U12 city9)
          (inUcity city9U11 city9)
          (inUcity city9U10 city9)
          (inUcity city9U9 city9)
          (inUcity city9U8 city9)
          (inUcity city9U7 city9)
          (inUcity city9U6 city9)
          (inUcity city9U5 city9)
          (inUcity city9U4 city9)
          (inUcity city9U3 city9)
          (inUcity city9U2 city9)
          (inUcity city9U1 city9)
          (inUcity city8U12 city8)
          (inUcity city8U11 city8)
          (inUcity city8U10 city8)
          (inUcity city8U9 city8)
          (inUcity city8U8 city8)
          (inUcity city8U7 city8)
          (inUcity city8U6 city8)
          (inUcity city8U5 city8)
          (inUcity city8U4 city8)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U12 city7)
          (inUcity city7U11 city7)
          (inUcity city7U10 city7)
          (inUcity city7U9 city7)
          (inUcity city7U8 city7)
          (inUcity city7U7 city7)
          (inUcity city7U6 city7)
          (inUcity city7U5 city7)
          (inUcity city7U4 city7)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U12 city6)
          (inUcity city6U11 city6)
          (inUcity city6U10 city6)
          (inUcity city6U9 city6)
          (inUcity city6U8 city6)
          (inUcity city6U7 city6)
          (inUcity city6U6 city6)
          (inUcity city6U5 city6)
          (inUcity city6U4 city6)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U12 city5)
          (inUcity city5U11 city5)
          (inUcity city5U10 city5)
          (inUcity city5U9 city5)
          (inUcity city5U8 city5)
          (inUcity city5U7 city5)
          (inUcity city5U6 city5)
          (inUcity city5U5 city5)
          (inUcity city5U4 city5)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U12 city4)
          (inUcity city4U11 city4)
          (inUcity city4U10 city4)
          (inUcity city4U9 city4)
          (inUcity city4U8 city4)
          (inUcity city4U7 city4)
          (inUcity city4U6 city4)
          (inUcity city4U5 city4)
          (inUcity city4U4 city4)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U12 city3)
          (inUcity city3U11 city3)
          (inUcity city3U10 city3)
          (inUcity city3U9 city3)
          (inUcity city3U8 city3)
          (inUcity city3U7 city3)
          (inUcity city3U6 city3)
          (inUcity city3U5 city3)
          (inUcity city3U4 city3)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U12 city2)
          (inUcity city2U11 city2)
          (inUcity city2U10 city2)
          (inUcity city2U9 city2)
          (inUcity city2U8 city2)
          (inUcity city2U7 city2)
          (inUcity city2U6 city2)
          (inUcity city2U5 city2)
          (inUcity city2U4 city2)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U12 city1)
          (inUcity city1U11 city1)
          (inUcity city1U10 city1)
          (inUcity city1U9 city1)
          (inUcity city1U8 city1)
          (inUcity city1U7 city1)
          (inUcity city1U6 city1)
          (inUcity city1U5 city1)
          (inUcity city1U4 city1)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane3 city20U12)
          (at plane2 city8U12)
          (at plane1 city14U12)
          (at truck80 city22U1)
          (at truck79 city21U7)
          (at truck78 city20U4)
          (at truck77 city19U7)
          (at truck76 city18U4)
          (at truck75 city17U5)
          (at truck74 city16U2)
          (at truck73 city15U9)
          (at truck72 city14U4)
          (at truck71 city13U9)
          (at truck70 city12U5)
          (at truck69 city11U1)
          (at truck68 city10U9)
          (at truck67 city9U8)
          (at truck66 city8U8)
          (at truck65 city7U1)
          (at truck64 city6U2)
          (at truck63 city5U4)
          (at truck62 city4U1)
          (at truck61 city3U7)
          (at truck60 city2U7)
          (at truck59 city1U10)
          (at truck58 city1U5)
          (at truck57 city20U9)
          (at truck56 city5U10)
          (at truck55 city19U5)
          (at truck54 city5U2)
          (at truck53 city11U8)
          (at truck52 city21U9)
          (at truck51 city3U4)
          (at truck50 city11U1)
          (at truck49 city9U6)
          (at truck48 city17U11)
          (at truck47 city6U6)
          (at truck46 city3U7)
          (at truck45 city14U6)
          (at truck44 city8U3)
          (at truck43 city5U2)
          (at truck42 city2U8)
          (at truck41 city15U11)
          (at truck40 city14U5)
          (at truck39 city7U2)
          (at truck38 city10U8)
          (at truck37 city21U6)
          (at truck36 city11U2)
          (at truck35 city21U6)
          (at truck34 city15U12)
          (at truck33 city7U12)
          (at truck32 city8U3)
          (at truck31 city22U9)
          (at truck30 city16U7)
          (at truck29 city8U6)
          (at truck28 city15U7)
          (at truck27 city12U12)
          (at truck26 city14U10)
          (at truck25 city8U7)
          (at truck24 city10U7)
          (at truck23 city10U10)
          (at truck22 city11U3)
          (at truck21 city9U5)
          (at truck20 city6U3)
          (at truck19 city4U4)
          (at truck18 city5U6)
          (at truck17 city5U10)
          (at truck16 city7U3)
          (at truck15 city21U7)
          (at truck14 city16U9)
          (at truck13 city1U10)
          (at truck12 city2U10)
          (at truck11 city4U9)
          (at truck10 city7U11)
          (at truck9 city8U9)
          (at truck8 city12U7)
          (at truck7 city19U5)
          (at truck6 city3U12)
          (at truck5 city13U2)
          (at truck4 city6U12)
          (at truck3 city2U6)
          (at truck2 city11U3)
          (at truck1 city14U1)
          (at package15 city5U7)
          (at package14 city15U7)
          (at package13 city11U12)
          (at package12 city8U3)
          (at package11 city10U7)
          (at package10 city14U11)
          (at package9 city16U1)
          (at package8 city21U12)
          (at package7 city13U4)
          (at package6 city2U3)
          (at package5 city6U10)
          (at package4 city11U2)
          (at package3 city7U7)
          (at package2 city8U6)
          (at package1 city6U12))
   (:goal (and (at package15 city14U12)
               (at package14 city20U9)
               (at package13 city5U8)
               (at package12 city20U4)
               (at package11 city1U4)
               (at package10 city20U7)
               (at package9 city2U5)
               (at package8 city11U10)
               (at package7 city4U12)
               (at package6 city3U11)
               (at package5 city9U3)
               (at package4 city9U6)
               (at package3 city5U12)
               (at package2 city11U8)
               (at package1 city5U5))))

(define (problem stripsUlogUyU1)
   (:domain logisticsUstrips)
   (:objects package3 package2 package1 city5 city4 city3 city2
             city1 truck5 truck4 truck3 truck2 truck1 plane2 plane1
             city5U1 city4U1 city3U1 city2U1 city1U1 city5U2 city4U2
             city3U2 city2U2 city1U2)
   (:init (obj package3)
          (obj package2)
          (obj package1)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane2)
          (airplane plane1)
          (location city5U1)
          (location city4U1)
          (location city3U1)
          (location city2U1)
          (location city1U1)
          (airport city5U2)
          (location city5U2)
          (airport city4U2)
          (location city4U2)
          (airport city3U2)
          (location city3U2)
          (airport city2U2)
          (location city2U2)
          (airport city1U2)
          (location city1U2)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane2 city1U2)
          (at plane1 city2U2)
          (at truck5 city5U1)
          (at truck4 city4U1)
          (at truck3 city3U1)
          (at truck2 city2U1)
          (at truck1 city1U1)
          (at package3 city1U1)
          (at package2 city1U2)
          (at package1 city4U1))
   (:goal (and (at package3 city1U2)
               (at package2 city1U1)
               (at package1 city3U2))))

(define (problem stripsUlogUyU2)
   (:domain logisticsUstrips)
   (:objects package5 package4 package3 package2 package1 city3
             city2 city1 truck6 truck5 truck4 truck3 truck2 truck1 plane1
             city3U1 city2U1 city1U1 city3U2 city2U2 city1U2)
   (:init (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city3)
          (city city2)
          (city city1)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane1)
          (location city3U1)
          (location city2U1)
          (location city1U1)
          (airport city3U2)
          (location city3U2)
          (airport city2U2)
          (location city2U2)
          (airport city1U2)
          (location city1U2)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane1 city3U2)
          (at truck6 city3U1)
          (at truck5 city2U1)
          (at truck4 city1U1)
          (at truck3 city3U2)
          (at truck2 city1U2)
          (at truck1 city2U2)
          (at package5 city2U1)
          (at package4 city1U2)
          (at package3 city1U1)
          (at package2 city2U2)
          (at package1 city2U1))
   (:goal (and (at package5 city3U2)
               (at package4 city2U1)
               (at package3 city2U1))))

(define (problem stripsUlogUyU3)
   (:domain logisticsUstrips)
   (:objects package7 package6 package5 package4 package3 package2
             package1 city3 city2 city1 truck9 truck8 truck7 truck6 truck5
             truck4 truck3 truck2 truck1 plane1 city3U1 city2U1 city1U1
             city3U2 city2U2 city1U2)
   (:init (obj package7)
          (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city3)
          (city city2)
          (city city1)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane1)
          (location city3U1)
          (location city2U1)
          (location city1U1)
          (airport city3U2)
          (location city3U2)
          (airport city2U2)
          (location city2U2)
          (airport city1U2)
          (location city1U2)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane1 city1U2)
          (at truck9 city3U1)
          (at truck8 city2U1)
          (at truck7 city1U1)
          (at truck6 city1U2)
          (at truck5 city3U1)
          (at truck4 city3U1)
          (at truck3 city1U2)
          (at truck2 city1U2)
          (at truck1 city2U2)
          (at package7 city2U1)
          (at package6 city2U2)
          (at package5 city2U2)
          (at package4 city3U1)
          (at package3 city2U1)
          (at package2 city1U2)
          (at package1 city1U2))
   (:goal (and (at package7 city2U2)
               (at package6 city3U2)
               (at package5 city3U2)
               (at package4 city2U2)
               (at package3 city3U2)
               (at package2 city1U1)
               (at package1 city2U1))))

(define (problem stripsUlogUyU4)
   (:domain logisticsUstrips)
   (:objects package6 package5 package4 package3 package2 package1
             city5 city4 city3 city2 city1 truck14 truck13 truck12 truck11
             truck10 truck9 truck8 truck7 truck6 truck5 truck4 truck3 truck2
             truck1 plane2 plane1 city5U2 city5U1 city4U2 city4U1 city3U2
             city3U1 city2U2 city2U1 city1U2 city1U1 city5U3 city4U3
             city3U3 city2U3 city1U3)
   (:init (obj package6)
          (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane2)
          (airplane plane1)
          (location city5U2)
          (location city5U1)
          (location city4U2)
          (location city4U1)
          (location city3U2)
          (location city3U1)
          (location city2U2)
          (location city2U1)
          (location city1U2)
          (location city1U1)
          (airport city5U3)
          (location city5U3)
          (airport city4U3)
          (location city4U3)
          (airport city3U3)
          (location city3U3)
          (airport city2U3)
          (location city2U3)
          (airport city1U3)
          (location city1U3)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane2 city3U3)
          (at plane1 city5U3)
          (at truck14 city5U1)
          (at truck13 city4U1)
          (at truck12 city3U2)
          (at truck11 city2U2)
          (at truck10 city1U2)
          (at truck9 city3U1)
          (at truck8 city3U1)
          (at truck7 city1U3)
          (at truck6 city5U1)
          (at truck5 city4U1)
          (at truck4 city1U1)
          (at truck3 city1U2)
          (at truck2 city3U1)
          (at truck1 city2U1)
          (at package6 city4U2)
          (at package5 city4U3)
          (at package4 city1U1)
          (at package3 city3U2)
          (at package2 city5U1)
          (at package1 city4U1))
   (:goal (and (at package6 city1U3)
               (at package5 city5U2)
               (at package4 city3U1)
               (at package3 city4U2)
               (at package2 city2U3)
               (at package1 city2U2))))

(define (problem stripsUlogUyU5)
   (:domain logisticsUstrips)
   (:objects package5 package4 package3 package2 package1 city8
             city7 city6 city5 city4 city3 city2 city1 truck15 truck14
             truck13 truck12 truck11 truck10 truck9 truck8 truck7 truck6
             truck5 truck4 truck3 truck2 truck1 plane1 city8U2 city8U1
             city7U2 city7U1 city6U2 city6U1 city5U2 city5U1 city4U2
             city4U1 city3U2 city3U1 city2U2 city2U1 city1U2 city1U1
             city8U3 city7U3 city6U3 city5U3 city4U3 city3U3 city2U3
             city1U3)
   (:init (obj package5)
          (obj package4)
          (obj package3)
          (obj package2)
          (obj package1)
          (city city8)
          (city city7)
          (city city6)
          (city city5)
          (city city4)
          (city city3)
          (city city2)
          (city city1)
          (truck truck15)
          (truck truck14)
          (truck truck13)
          (truck truck12)
          (truck truck11)
          (truck truck10)
          (truck truck9)
          (truck truck8)
          (truck truck7)
          (truck truck6)
          (truck truck5)
          (truck truck4)
          (truck truck3)
          (truck truck2)
          (truck truck1)
          (airplane plane1)
          (location city8U2)
          (location city8U1)
          (location city7U2)
          (location city7U1)
          (location city6U2)
          (location city6U1)
          (location city5U2)
          (location city5U1)
          (location city4U2)
          (location city4U1)
          (location city3U2)
          (location city3U1)
          (location city2U2)
          (location city2U1)
          (location city1U2)
          (location city1U1)
          (airport city8U3)
          (location city8U3)
          (airport city7U3)
          (location city7U3)
          (airport city6U3)
          (location city6U3)
          (airport city5U3)
          (location city5U3)
          (airport city4U3)
          (location city4U3)
          (airport city3U3)
          (location city3U3)
          (airport city2U3)
          (location city2U3)
          (airport city1U3)
          (location city1U3)
          (inUcity city8U3 city8)
          (inUcity city8U2 city8)
          (inUcity city8U1 city8)
          (inUcity city7U3 city7)
          (inUcity city7U2 city7)
          (inUcity city7U1 city7)
          (inUcity city6U3 city6)
          (inUcity city6U2 city6)
          (inUcity city6U1 city6)
          (inUcity city5U3 city5)
          (inUcity city5U2 city5)
          (inUcity city5U1 city5)
          (inUcity city4U3 city4)
          (inUcity city4U2 city4)
          (inUcity city4U1 city4)
          (inUcity city3U3 city3)
          (inUcity city3U2 city3)
          (inUcity city3U1 city3)
          (inUcity city2U3 city2)
          (inUcity city2U2 city2)
          (inUcity city2U1 city2)
          (inUcity city1U3 city1)
          (inUcity city1U2 city1)
          (inUcity city1U1 city1)
          (at plane1 city3U3)
          (at truck15 city8U2)
          (at truck14 city7U2)
          (at truck13 city6U1)
          (at truck12 city5U2)
          (at truck11 city4U1)
          (at truck10 city3U2)
          (at truck9 city2U1)
          (at truck8 city1U2)
          (at truck7 city6U1)
          (at truck6 city3U2)
          (at truck5 city1U3)
          (at truck4 city4U3)
          (at truck3 city1U3)
          (at truck2 city7U1)
          (at truck1 city8U1)
          (at package5 city3U2)
          (at package4 city5U1)
          (at package3 city1U1)
          (at package2 city5U2)
          (at package1 city2U1))
   (:goal (and (at package5 city6U3)
               (at package4 city5U3)
               (at package3 city8U3)
               (at package2 city4U3)
               (at package1 city6U3))))

(define (problem stripsUlogUyU1)
        (:domain logisticsUadl)
        (:objects city1U2 city2U2 city3U2 city4U2 city5U2 - airport city1U2
                  city2U2 city3U2 city4U2 city5U2 city1U1 city2U1 city3U1
                  city4U1 city5U1 - location plane1 plane2 - airplane truck1
                  truck2 truck3 truck4 truck5 - truck city1 city2 city3 city4
                  city5 - city package1 package2 package3 - obj)
        (:init (inUcity city5U2 city5)
               (inUcity city5U1 city5)
               (inUcity city4U2 city4)
               (inUcity city4U1 city4)
               (inUcity city3U2 city3)
               (inUcity city3U1 city3)
               (inUcity city2U2 city2)
               (inUcity city2U1 city2)
               (inUcity city1U2 city1)
               (inUcity city1U1 city1)
               (at plane2 city1U2)
               (at plane1 city2U2)
               (at truck5 city5U1)
               (at truck4 city4U1)
               (at truck3 city3U1)
               (at truck2 city2U1)
               (at truck1 city1U1)
               (at package3 city1U1)
               (at package2 city1U2)
               (at package1 city4U1))
        (:goal (and (at package3 city1U2)
                    (at package2 city1U1)
                    (at package1 city3U2))))

(define (problem stripsUlogUyU2)
        (:domain logisticsUadl)
        (:objects city1U2 city2U2 city3U2 - airport city1U2 city2U2 city3U2
                  city1U1 city2U1 city3U1 - location plane1 - airplane truck1
                  truck2 truck3 truck4 truck5 truck6 - truck city1 city2 city3 -
                  city package1 package2 package3 package4 package5 - obj)
        (:init (inUcity city3U2 city3)
               (inUcity city3U1 city3)
               (inUcity city2U2 city2)
               (inUcity city2U1 city2)
               (inUcity city1U2 city1)
               (inUcity city1U1 city1)
               (at plane1 city3U2)
               (at truck6 city3U1)
               (at truck5 city2U1)
               (at truck4 city1U1)
               (at truck3 city3U2)
               (at truck2 city1U2)
               (at truck1 city2U2)
               (at package5 city2U1)
               (at package4 city1U2)
               (at package3 city1U1)
               (at package2 city2U2)
               (at package1 city2U1))
        (:goal (and (at package5 city3U2)
                    (at package4 city2U1)
                    (at package3 city2U1))))

(define (problem stripsUlogUyU3)
        (:domain logisticsUadl)
        (:objects city1U2 city2U2 city3U2 - airport city1U2 city2U2 city3U2
                  city1U1 city2U1 city3U1 - location plane1 - airplane truck1
                  truck2 truck3 truck4 truck5 truck6 truck7 truck8 truck9 -
                  truck city1 city2 city3 - city package1 package2 package3
                  package4 package5 package6 package7 - obj)
        (:init (inUcity city3U2 city3)
               (inUcity city3U1 city3)
               (inUcity city2U2 city2)
               (inUcity city2U1 city2)
               (inUcity city1U2 city1)
               (inUcity city1U1 city1)
               (at plane1 city1U2)
               (at truck9 city3U1)
               (at truck8 city2U1)
               (at truck7 city1U1)
               (at truck6 city1U2)
               (at truck5 city3U1)
               (at truck4 city3U1)
               (at truck3 city1U2)
               (at truck2 city1U2)
               (at truck1 city2U2)
               (at package7 city2U1)
               (at package6 city2U2)
               (at package5 city2U2)
               (at package4 city3U1)
               (at package3 city2U1)
               (at package2 city1U2)
               (at package1 city1U2))
        (:goal
         (and (at package7 city2U2)
              (at package6 city3U2)
              (at package5 city3U2)
              (at package4 city2U2)
              (at package3 city3U2)
              (at package2 city1U1)
              (at package1 city2U1))))

(define (problem stripsUlogUyU4)
        (:domain logisticsUadl)
        (:objects city1U3 city2U3 city3U3 city4U3 city5U3 - airport city1U3
                  city2U3 city3U3 city4U3 city5U3 city1U1 city1U2 city2U1
                  city2U2 city3U1 city3U2 city4U1 city4U2 city5U1 city5U2 -
                  location plane1 plane2 - airplane truck1 truck2 truck3 truck4
                  truck5 truck6 truck7 truck8 truck9 truck10 truck11 truck12
                  truck13 truck14 - truck city1 city2 city3 city4 city5 - city
                  package1 package2 package3 package4 package5 package6 - obj)
        (:init (inUcity city5U3 city5)
               (inUcity city5U2 city5)
               (inUcity city5U1 city5)
               (inUcity city4U3 city4)
               (inUcity city4U2 city4)
               (inUcity city4U1 city4)
               (inUcity city3U3 city3)
               (inUcity city3U2 city3)
               (inUcity city3U1 city3)
               (inUcity city2U3 city2)
               (inUcity city2U2 city2)
               (inUcity city2U1 city2)
               (inUcity city1U3 city1)
               (inUcity city1U2 city1)
               (inUcity city1U1 city1)
               (at plane2 city3U3)
               (at plane1 city5U3)
               (at truck14 city5U1)
               (at truck13 city4U1)
               (at truck12 city3U2)
               (at truck11 city2U2)
               (at truck10 city1U2)
               (at truck9 city3U1)
               (at truck8 city3U1)
               (at truck7 city1U3)
               (at truck6 city5U1)
               (at truck5 city4U1)
               (at truck4 city1U1)
               (at truck3 city1U2)
               (at truck2 city3U1)
               (at truck1 city2U1)
               (at package6 city4U2)
               (at package5 city4U3)
               (at package4 city1U1)
               (at package3 city3U2)
               (at package2 city5U1)
               (at package1 city4U1))
        (:goal
         (and (at package6 city1U3)
              (at package5 city5U2)
              (at package4 city3U1)
              (at package3 city4U2)
              (at package2 city2U3)
              (at package1 city2U2))))

(define (problem stripsUlogUyU5)
        (:domain logisticsUadl)
        (:objects city1U3 city2U3 city3U3 city4U3 city5U3 city6U3 city7U3
                  city8U3 - airport city1U3 city2U3 city3U3 city4U3 city5U3
                  city6U3 city7U3 city8U3 city1U1 city1U2 city2U1 city2U2
                  city3U1 city3U2 city4U1 city4U2 city5U1 city5U2 city6U1
                  city6U2 city7U1 city7U2 city8U1 city8U2 - location plane1 -
                  airplane truck1 truck2 truck3 truck4 truck5 truck6 truck7
                  truck8 truck9 truck10 truck11 truck12 truck13 truck14 truck15
                  - truck city1 city2 city3 city4 city5 city6 city7 city8 - city
                  package1 package2 package3 package4 package5 - obj)
        (:init (inUcity city8U3 city8)
               (inUcity city8U2 city8)
               (inUcity city8U1 city8)
               (inUcity city7U3 city7)
               (inUcity city7U2 city7)
               (inUcity city7U1 city7)
               (inUcity city6U3 city6)
               (inUcity city6U2 city6)
               (inUcity city6U1 city6)
               (inUcity city5U3 city5)
               (inUcity city5U2 city5)
               (inUcity city5U1 city5)
               (inUcity city4U3 city4)
               (inUcity city4U2 city4)
               (inUcity city4U1 city4)
               (inUcity city3U3 city3)
               (inUcity city3U2 city3)
               (inUcity city3U1 city3)
               (inUcity city2U3 city2)
               (inUcity city2U2 city2)
               (inUcity city2U1 city2)
               (inUcity city1U3 city1)
               (inUcity city1U2 city1)
               (inUcity city1U1 city1)
               (at plane1 city3U3)
               (at truck15 city8U2)
               (at truck14 city7U2)
               (at truck13 city6U1)
               (at truck12 city5U2)
               (at truck11 city4U1)
               (at truck10 city3U2)
               (at truck9 city2U1)
               (at truck8 city1U2)
               (at truck7 city6U1)
               (at truck6 city3U2)
               (at truck5 city1U3)
               (at truck4 city4U3)
               (at truck3 city1U3)
               (at truck2 city7U1)
               (at truck1 city8U1)
               (at package5 city3U2)
               (at package4 city5U1)
               (at package3 city1U1)
               (at package2 city5U2)
               (at package1 city2U1))
        (:goal (and (at package5 city6U3)
                    (at package4 city5U3)
                    (at package3 city8U3)
                    (at package2 city4U3)
                    (at package1 city6U3))))

